#ifndef __VMLINUX_H__
#define __VMLINUX_H__

#ifndef BPF_NO_PRESERVE_ACCESS_INDEX
#pragma clang attribute push (__attribute__((preserve_access_index)), apply_to = record)
#endif

typedef unsigned char __u8;

typedef short int __s16;

typedef short unsigned int __u16;

typedef int __s32;

typedef unsigned int __u32;

typedef long long int __s64;

typedef long long unsigned int __u64;

typedef __u8 u8;

typedef __s16 s16;

typedef __u16 u16;

typedef __s32 s32;

typedef __u32 u32;

typedef __s64 s64;

typedef __u64 u64;

enum {
	false = 0,
	true = 1,
};

typedef long int __kernel_long_t;

typedef long unsigned int __kernel_ulong_t;

typedef int __kernel_pid_t;

typedef unsigned int __kernel_uid32_t;

typedef unsigned int __kernel_gid32_t;

typedef __kernel_ulong_t __kernel_size_t;

typedef __kernel_long_t __kernel_ssize_t;

typedef long long int __kernel_loff_t;

typedef long long int __kernel_time64_t;

typedef __kernel_long_t __kernel_clock_t;

typedef int __kernel_timer_t;

typedef int __kernel_clockid_t;

typedef unsigned int __poll_t;

typedef u32 __kernel_dev_t;

typedef __kernel_dev_t dev_t;

typedef short unsigned int umode_t;

typedef __kernel_pid_t pid_t;

typedef __kernel_clockid_t clockid_t;

typedef _Bool bool;

typedef __kernel_uid32_t uid_t;

typedef __kernel_gid32_t gid_t;

typedef __kernel_loff_t loff_t;

typedef __kernel_size_t size_t;

typedef __kernel_ssize_t ssize_t;

typedef s32 int32_t;

typedef u32 uint32_t;

typedef u64 sector_t;

typedef u64 blkcnt_t;

typedef unsigned int gfp_t;

typedef unsigned int fmode_t;

typedef u64 phys_addr_t;

typedef struct {
	int counter;
} atomic_t;

typedef struct {
	s64 counter;
} atomic64_t;

struct list_head {
	struct list_head *next;
	struct list_head *prev;
};

struct hlist_node;

struct hlist_head {
	struct hlist_node *first;
};

struct hlist_node {
	struct hlist_node *next;
	struct hlist_node **pprev;
};

struct callback_head {
	struct callback_head *next;
	void (*func)(struct callback_head *);
};

struct lock_class_key {};

struct fs_context;

struct fs_parameter_spec;

struct dentry;

struct super_block;

struct module;

struct file_system_type {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry * (*mount)(struct file_system_type *, int, const char *, void *);
	void (*kill_sb)(struct super_block *);
	struct module *owner;
	struct file_system_type *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct qspinlock {
	union {
		atomic_t val;
		struct {
			u8 locked;
			u8 pending;
		};
		struct {
			u16 locked_pending;
			u16 tail;
		};
	};
};

typedef struct qspinlock arch_spinlock_t;

struct qrwlock {
	union {
		atomic_t cnts;
		struct {
			u8 wlocked;
			u8 __lstate[3];
		};
	};
	arch_spinlock_t wait_lock;
};

typedef struct qrwlock arch_rwlock_t;

struct raw_spinlock {
	arch_spinlock_t raw_lock;
};

typedef struct raw_spinlock raw_spinlock_t;

struct spinlock {
	union {
		struct raw_spinlock rlock;
	};
};

typedef struct spinlock spinlock_t;

typedef struct {
	arch_rwlock_t raw_lock;
} rwlock_t;

struct ratelimit_state {
	raw_spinlock_t lock;
	int interval;
	int burst;
	int printed;
	int missed;
	long unsigned int begin;
	long unsigned int flags;
};

typedef void *fl_owner_t;

struct file;

struct kiocb;

struct iov_iter;

struct dir_context;

struct poll_table_struct;

struct vm_area_struct;

struct inode;

struct file_lock;

struct page;

struct pipe_inode_info;

struct seq_file;

struct file_operations {
	struct module *owner;
	loff_t (*llseek)(struct file *, loff_t, int);
	ssize_t (*read)(struct file *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb *, struct iov_iter *);
	ssize_t (*write_iter)(struct kiocb *, struct iov_iter *);
	int (*iopoll)(struct kiocb *, bool);
	int (*iterate)(struct file *, struct dir_context *);
	int (*iterate_shared)(struct file *, struct dir_context *);
	__poll_t (*poll)(struct file *, struct poll_table_struct *);
	long int (*unlocked_ioctl)(struct file *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file *, unsigned int, long unsigned int);
	int (*mmap)(struct file *, struct vm_area_struct *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode *, struct file *);
	int (*flush)(struct file *, fl_owner_t);
	int (*release)(struct inode *, struct file *);
	int (*fsync)(struct file *, loff_t, loff_t, int);
	int (*fasync)(int, struct file *, int);
	int (*lock)(struct file *, int, struct file_lock *);
	ssize_t (*sendpage)(struct file *, struct page *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file *, long unsigned int);
	int (*flock)(struct file *, int, struct file_lock *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file *, long int, struct file_lock **, void **);
	long int (*fallocate)(struct file *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file *, struct file *);
	ssize_t (*copy_file_range)(struct file *, loff_t, struct file *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file *, loff_t, struct file *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file *, loff_t, loff_t, int);
};

typedef __s64 time64_t;

struct __kernel_timespec {
	__kernel_time64_t tv_sec;
	long long int tv_nsec;
};

struct timespec64 {
	time64_t tv_sec;
	long int tv_nsec;
};

enum timespec_type {
	TT_NONE = 0,
	TT_NATIVE = 1,
	TT_COMPAT = 2,
};

typedef s32 old_time32_t;

struct old_timespec32 {
	old_time32_t tv_sec;
	s32 tv_nsec;
};

struct pollfd;

struct restart_block {
	long unsigned int arch_data;
	long int (*fn)(struct restart_block *);
	union {
		struct {
			u32 *uaddr;
			u32 val;
			u32 flags;
			u32 bitset;
			u64 time;
			u32 *uaddr2;
		} futex;
		struct {
			clockid_t clockid;
			enum timespec_type type;
			union {
				struct __kernel_timespec *rmtp;
				struct old_timespec32 *compat_rmtp;
			};
			u64 expires;
		} nanosleep;
		struct {
			struct pollfd *ufds;
			int nfds;
			int has_timeout;
			long unsigned int tv_sec;
			long unsigned int tv_nsec;
		} poll;
	};
};

struct thread_info {
	long unsigned int flags;
	long unsigned int syscall_work;
	u32 status;
};

struct refcount_struct {
	atomic_t refs;
};

typedef struct refcount_struct refcount_t;

struct llist_node {
	struct llist_node *next;
};

struct __call_single_node {
	struct llist_node llist;
	union {
		unsigned int u_flags;
		atomic_t a_flags;
	};
	u16 src;
	u16 dst;
};

struct load_weight {
	long unsigned int weight;
	u32 inv_weight;
};

struct rb_node {
	long unsigned int __rb_parent_color;
	struct rb_node *rb_right;
	struct rb_node *rb_left;
};

struct sched_statistics {
	u64 wait_start;
	u64 wait_max;
	u64 wait_count;
	u64 wait_sum;
	u64 iowait_count;
	u64 iowait_sum;
	u64 sleep_start;
	u64 sleep_max;
	s64 sum_sleep_runtime;
	u64 block_start;
	u64 block_max;
	u64 exec_max;
	u64 slice_max;
	u64 nr_migrations_cold;
	u64 nr_failed_migrations_affine;
	u64 nr_failed_migrations_running;
	u64 nr_failed_migrations_hot;
	u64 nr_forced_migrations;
	u64 nr_wakeups;
	u64 nr_wakeups_sync;
	u64 nr_wakeups_migrate;
	u64 nr_wakeups_local;
	u64 nr_wakeups_remote;
	u64 nr_wakeups_affine;
	u64 nr_wakeups_affine_attempts;
	u64 nr_wakeups_passive;
	u64 nr_wakeups_idle;
};

struct util_est {
	unsigned int enqueued;
	unsigned int ewma;
};

struct sched_avg {
	u64 last_update_time;
	u64 load_sum;
	u64 runnable_sum;
	u32 util_sum;
	u32 period_contrib;
	long unsigned int load_avg;
	long unsigned int runnable_avg;
	long unsigned int util_avg;
	struct util_est util_est;
};

struct cfs_rq;

struct sched_entity {
	struct load_weight load;
	struct rb_node run_node;
	struct list_head group_node;
	unsigned int on_rq;
	u64 exec_start;
	u64 sum_exec_runtime;
	u64 vruntime;
	u64 prev_sum_exec_runtime;
	u64 nr_migrations;
	struct sched_statistics statistics;
	int depth;
	struct sched_entity *parent;
	struct cfs_rq *cfs_rq;
	struct cfs_rq *my_q;
	long unsigned int runnable_weight;
	long: 64;
	long: 64;
	long: 64;
	struct sched_avg avg;
};

struct sched_rt_entity {
	struct list_head run_list;
	long unsigned int timeout;
	long unsigned int watchdog_stamp;
	unsigned int time_slice;
	short unsigned int on_rq;
	short unsigned int on_list;
	struct sched_rt_entity *back;
};

typedef s64 ktime_t;

struct timerqueue_node {
	struct rb_node node;
	ktime_t expires;
};

enum hrtimer_restart {
	HRTIMER_NORESTART = 0,
	HRTIMER_RESTART = 1,
};

struct hrtimer_clock_base;

struct hrtimer {
	struct timerqueue_node node;
	ktime_t _softexpires;
	enum hrtimer_restart (*function)(struct hrtimer *);
	struct hrtimer_clock_base *base;
	u8 state;
	u8 is_rel;
	u8 is_soft;
	u8 is_hard;
};

struct sched_dl_entity {
	struct rb_node rb_node;
	u64 dl_runtime;
	u64 dl_deadline;
	u64 dl_period;
	u64 dl_bw;
	u64 dl_density;
	s64 runtime;
	u64 deadline;
	unsigned int flags;
	unsigned int dl_throttled: 1;
	unsigned int dl_yielded: 1;
	unsigned int dl_non_contending: 1;
	unsigned int dl_overrun: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer dl_timer;
	struct hrtimer inactive_timer;
	struct sched_dl_entity *pi_se;
};

struct uclamp_se {
	unsigned int value: 11;
	unsigned int bucket_id: 3;
	unsigned int active: 1;
	unsigned int user_defined: 1;
};

struct cpumask {
	long unsigned int bits[128];
};

typedef struct cpumask cpumask_t;

union rcu_special {
	struct {
		u8 blocked;
		u8 need_qs;
		u8 exp_hint;
		u8 need_mb;
	} b;
	u32 s;
};

struct sched_info {
	long unsigned int pcount;
	long long unsigned int run_delay;
	long long unsigned int last_arrival;
	long long unsigned int last_queued;
};

struct plist_node {
	int prio;
	struct list_head prio_list;
	struct list_head node_list;
};

struct vmacache {
	u64 seqnum;
	struct vm_area_struct *vmas[4];
};

struct task_rss_stat {
	int events;
	int count[4];
};

struct prev_cputime {
	u64 utime;
	u64 stime;
	raw_spinlock_t lock;
};

struct rb_root {
	struct rb_node *rb_node;
};

struct rb_root_cached {
	struct rb_root rb_root;
	struct rb_node *rb_leftmost;
};

struct timerqueue_head {
	struct rb_root_cached rb_root;
};

struct posix_cputimer_base {
	u64 nextevt;
	struct timerqueue_head tqhead;
};

struct posix_cputimers {
	struct posix_cputimer_base bases[3];
	unsigned int timers_active;
	unsigned int expiry_active;
};

struct posix_cputimers_work {
	struct callback_head work;
	unsigned int scheduled;
};

struct nameidata;

struct sem_undo_list;

struct sysv_sem {
	struct sem_undo_list *undo_list;
};

struct sysv_shm {
	struct list_head shm_clist;
};

struct io_uring_task;

typedef struct {
	long unsigned int sig[1];
} sigset_t;

struct sigpending {
	struct list_head list;
	sigset_t signal;
};

struct audit_context;

typedef struct {
	uid_t val;
} kuid_t;

struct seccomp_filter;

struct seccomp {
	int mode;
	atomic_t filter_count;
	struct seccomp_filter *filter;
};

struct syscall_user_dispatch {
	char *selector;
	long unsigned int offset;
	long unsigned int len;
	bool on_dispatch;
};

struct wake_q_node {
	struct wake_q_node *next;
};

struct capture_control;

struct task_io_accounting {
	u64 rchar;
	u64 wchar;
	u64 syscr;
	u64 syscw;
	u64 read_bytes;
	u64 write_bytes;
	u64 cancelled_write_bytes;
};

typedef struct {
	long unsigned int bits[16];
} nodemask_t;

struct seqcount {
	unsigned int sequence;
};

typedef struct seqcount seqcount_t;

struct seqcount_spinlock {
	seqcount_t seqcount;
};

typedef struct seqcount_spinlock seqcount_spinlock_t;

struct robust_list_head;

struct futex_pi_state;

typedef atomic64_t atomic_long_t;

struct optimistic_spin_queue {
	atomic_t tail;
};

struct mutex {
	atomic_long_t owner;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct list_head wait_list;
};

struct arch_tlbflush_unmap_batch {
	struct cpumask cpumask;
};

struct tlbflush_unmap_batch {
	struct arch_tlbflush_unmap_batch arch;
	bool flush_required;
	bool writable;
};

struct page_frag {
	struct page *page;
	__u32 offset;
	__u32 size;
};

struct kmap_ctrl {};

struct bpf_local_storage;

struct llist_head {
	struct llist_node *first;
};

struct desc_struct {
	u16 limit0;
	u16 base0;
	u16 base1: 8;
	u16 type: 4;
	u16 s: 1;
	u16 dpl: 2;
	u16 p: 1;
	u16 limit1: 4;
	u16 avl: 1;
	u16 l: 1;
	u16 d: 1;
	u16 g: 1;
	u16 base2: 8;
	long: 56;
};

struct fpu_state_perm {
	u64 __state_perm;
	unsigned int __state_size;
	unsigned int __user_state_size;
};

struct fregs_state {
	u32 cwd;
	u32 swd;
	u32 twd;
	u32 fip;
	u32 fcs;
	u32 foo;
	u32 fos;
	u32 st_space[20];
	u32 status;
};

struct fxregs_state {
	u16 cwd;
	u16 swd;
	u16 twd;
	u16 fop;
	union {
		struct {
			u64 rip;
			u64 rdp;
		};
		struct {
			u32 fip;
			u32 fcs;
			u32 foo;
			u32 fos;
		};
	};
	u32 mxcsr;
	u32 mxcsr_mask;
	u32 st_space[32];
	u32 xmm_space[64];
	u32 padding[12];
	union {
		u32 padding1[12];
		u32 sw_reserved[12];
	};
};

struct math_emu_info;

struct swregs_state {
	u32 cwd;
	u32 swd;
	u32 twd;
	u32 fip;
	u32 fcs;
	u32 foo;
	u32 fos;
	u32 st_space[20];
	u8 ftop;
	u8 changed;
	u8 lookahead;
	u8 no_update;
	u8 rm;
	u8 alimit;
	struct math_emu_info *info;
	u32 entry_eip;
};

struct xstate_header {
	u64 xfeatures;
	u64 xcomp_bv;
	u64 reserved[6];
};

struct xregs_state {
	struct fxregs_state i387;
	struct xstate_header header;
	u8 extended_state_area[0];
};

union fpregs_state {
	struct fregs_state fsave;
	struct fxregs_state fxsave;
	struct swregs_state soft;
	struct xregs_state xsave;
	u8 __padding[4096];
};

struct fpstate {
	unsigned int size;
	unsigned int user_size;
	u64 xfeatures;
	u64 user_xfeatures;
	u64 xfd;
	unsigned int is_valloc: 1;
	unsigned int is_guest: 1;
	unsigned int is_confidential: 1;
	unsigned int in_use: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	union fpregs_state regs;
};

struct fpu {
	unsigned int last_cpu;
	long unsigned int avx512_timestamp;
	struct fpstate *fpstate;
	struct fpstate *__task_fpstate;
	struct fpu_state_perm perm;
	long: 64;
	long: 64;
	struct fpstate __fpstate;
};

struct perf_event;

struct io_bitmap;

struct thread_struct {
	struct desc_struct tls_array[3];
	long unsigned int sp;
	short unsigned int es;
	short unsigned int ds;
	short unsigned int fsindex;
	short unsigned int gsindex;
	long unsigned int fsbase;
	long unsigned int gsbase;
	struct perf_event *ptrace_bps[4];
	long unsigned int virtual_dr6;
	long unsigned int ptrace_dr7;
	long unsigned int cr2;
	long unsigned int trap_nr;
	long unsigned int error_code;
	struct io_bitmap *io_bitmap;
	long unsigned int iopl_emul;
	unsigned int iopl_warn: 1;
	unsigned int sig_on_uaccess_err: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u32 pkru;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct fpu fpu;
};

struct sched_class;

struct task_group;

struct mm_struct;

struct pid;

struct completion;

struct cred;

struct key;

struct fs_struct;

struct files_struct;

struct nsproxy;

struct signal_struct;

struct sighand_struct;

struct rt_mutex_waiter;

struct bio_list;

struct blk_plug;

struct reclaim_state;

struct backing_dev_info;

struct io_context;

struct kernel_siginfo;

typedef struct kernel_siginfo kernel_siginfo_t;

struct css_set;

struct compat_robust_list_head;

struct perf_event_context;

struct mempolicy;

struct numa_group;

struct rseq;

struct task_delay_info;

struct ftrace_ret_stack;

struct mem_cgroup;

struct request_queue;

struct uprobe_task;

struct vm_struct;

struct bpf_run_ctx;

struct task_struct {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct *mm;
	struct mm_struct *active_mm;
	struct vmacache vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int restore_sigmask: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct *real_parent;
	struct task_struct *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	struct posix_cputimers_work posix_cputimers_work;
	const struct cred *ptracer_cred;
	const struct cred *real_cred;
	const struct cred *cred;
	struct key *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy *nsproxy;
	struct signal_struct *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set *cgroups;
	struct list_head cg_list;
	u32 closid;
	u32 rmid;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	long: 64;
	long: 64;
	struct pipe_inode_info *splice_pipe;
	struct page_frag task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup *active_memcg;
	struct request_queue *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct *oom_reaper_list;
	struct vm_struct *stack_vm_area;
	refcount_t stack_refcount;
	int patch_state;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	void *mce_vaddr;
	__u64 mce_kflags;
	u64 mce_addr;
	__u64 mce_ripv: 1;
	__u64 mce_whole_page: 1;
	__u64 __mce_reserved: 62;
	long: 2;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct callback_head mce_kill_me;
	int mce_count;
	struct llist_head kretprobe_instances;
	struct callback_head l1d_flush_kill;
	long: 64;
	struct thread_struct thread;
};

struct screen_info {
	__u8 orig_x;
	__u8 orig_y;
	__u16 ext_mem_k;
	__u16 orig_video_page;
	__u8 orig_video_mode;
	__u8 orig_video_cols;
	__u8 flags;
	__u8 unused2;
	__u16 orig_video_ega_bx;
	__u16 unused3;
	__u8 orig_video_lines;
	__u8 orig_video_isVGA;
	__u16 orig_video_points;
	__u16 lfb_width;
	__u16 lfb_height;
	__u16 lfb_depth;
	__u32 lfb_base;
	__u32 lfb_size;
	__u16 cl_magic;
	__u16 cl_offset;
	__u16 lfb_linelength;
	__u8 red_size;
	__u8 red_pos;
	__u8 green_size;
	__u8 green_pos;
	__u8 blue_size;
	__u8 blue_pos;
	__u8 rsvd_size;
	__u8 rsvd_pos;
	__u16 vesapm_seg;
	__u16 vesapm_off;
	__u16 pages;
	__u16 vesa_attributes;
	__u32 capabilities;
	__u32 ext_lfb_base;
	__u8 _reserved[2];
} __attribute__((packed));

struct apm_bios_info {
	__u16 version;
	__u16 cseg;
	__u32 offset;
	__u16 cseg_16;
	__u16 dseg;
	__u16 flags;
	__u16 cseg_len;
	__u16 cseg_16_len;
	__u16 dseg_len;
};

struct edd_device_params {
	__u16 length;
	__u16 info_flags;
	__u32 num_default_cylinders;
	__u32 num_default_heads;
	__u32 sectors_per_track;
	__u64 number_of_sectors;
	__u16 bytes_per_sector;
	__u32 dpte_ptr;
	__u16 key;
	__u8 device_path_info_length;
	__u8 reserved2;
	__u16 reserved3;
	__u8 host_bus_type[4];
	__u8 interface_type[8];
	union {
		struct {
			__u16 base_address;
			__u16 reserved1;
			__u32 reserved2;
		} isa;
		struct {
			__u8 bus;
			__u8 slot;
			__u8 function;
			__u8 channel;
			__u32 reserved;
		} pci;
		struct {
			__u64 reserved;
		} ibnd;
		struct {
			__u64 reserved;
		} xprs;
		struct {
			__u64 reserved;
		} htpt;
		struct {
			__u64 reserved;
		} unknown;
	} interface_path;
	union {
		struct {
			__u8 device;
			__u8 reserved1;
			__u16 reserved2;
			__u32 reserved3;
			__u64 reserved4;
		} ata;
		struct {
			__u8 device;
			__u8 lun;
			__u8 reserved1;
			__u8 reserved2;
			__u32 reserved3;
			__u64 reserved4;
		} atapi;
		struct {
			__u16 id;
			__u64 lun;
			__u16 reserved1;
			__u32 reserved2;
		} __attribute__((packed)) scsi;
		struct {
			__u64 serial_number;
			__u64 reserved;
		} usb;
		struct {
			__u64 eui;
			__u64 reserved;
		} i1394;
		struct {
			__u64 wwid;
			__u64 lun;
		} fibre;
		struct {
			__u64 identity_tag;
			__u64 reserved;
		} i2o;
		struct {
			__u32 array_number;
			__u32 reserved1;
			__u64 reserved2;
		} raid;
		struct {
			__u8 device;
			__u8 reserved1;
			__u16 reserved2;
			__u32 reserved3;
			__u64 reserved4;
		} sata;
		struct {
			__u64 reserved1;
			__u64 reserved2;
		} unknown;
	} device_path;
	__u8 reserved4;
	__u8 checksum;
} __attribute__((packed));

struct edd_info {
	__u8 device;
	__u8 version;
	__u16 interface_support;
	__u16 legacy_max_cylinder;
	__u8 legacy_max_head;
	__u8 legacy_sectors_per_track;
	struct edd_device_params params;
} __attribute__((packed));

struct ist_info {
	__u32 signature;
	__u32 command;
	__u32 event;
	__u32 perf_level;
};

struct edid_info {
	unsigned char dummy[128];
};

struct setup_header {
	__u8 setup_sects;
	__u16 root_flags;
	__u32 syssize;
	__u16 ram_size;
	__u16 vid_mode;
	__u16 root_dev;
	__u16 boot_flag;
	__u16 jump;
	__u32 header;
	__u16 version;
	__u32 realmode_swtch;
	__u16 start_sys_seg;
	__u16 kernel_version;
	__u8 type_of_loader;
	__u8 loadflags;
	__u16 setup_move_size;
	__u32 code32_start;
	__u32 ramdisk_image;
	__u32 ramdisk_size;
	__u32 bootsect_kludge;
	__u16 heap_end_ptr;
	__u8 ext_loader_ver;
	__u8 ext_loader_type;
	__u32 cmd_line_ptr;
	__u32 initrd_addr_max;
	__u32 kernel_alignment;
	__u8 relocatable_kernel;
	__u8 min_alignment;
	__u16 xloadflags;
	__u32 cmdline_size;
	__u32 hardware_subarch;
	__u64 hardware_subarch_data;
	__u32 payload_offset;
	__u32 payload_length;
	__u64 setup_data;
	__u64 pref_address;
	__u32 init_size;
	__u32 handover_offset;
	__u32 kernel_info_offset;
} __attribute__((packed));

struct sys_desc_table {
	__u16 length;
	__u8 table[14];
};

struct olpc_ofw_header {
	__u32 ofw_magic;
	__u32 ofw_version;
	__u32 cif_handler;
	__u32 irq_desc_table;
};

struct efi_info {
	__u32 efi_loader_signature;
	__u32 efi_systab;
	__u32 efi_memdesc_size;
	__u32 efi_memdesc_version;
	__u32 efi_memmap;
	__u32 efi_memmap_size;
	__u32 efi_systab_hi;
	__u32 efi_memmap_hi;
};

struct boot_e820_entry {
	__u64 addr;
	__u64 size;
	__u32 type;
} __attribute__((packed));

struct boot_params {
	struct screen_info screen_info;
	struct apm_bios_info apm_bios_info;
	__u8 _pad2[4];
	__u64 tboot_addr;
	struct ist_info ist_info;
	__u64 acpi_rsdp_addr;
	__u8 _pad3[8];
	__u8 hd0_info[16];
	__u8 hd1_info[16];
	struct sys_desc_table sys_desc_table;
	struct olpc_ofw_header olpc_ofw_header;
	__u32 ext_ramdisk_image;
	__u32 ext_ramdisk_size;
	__u32 ext_cmd_line_ptr;
	__u8 _pad4[116];
	struct edid_info edid_info;
	struct efi_info efi_info;
	__u32 alt_mem_k;
	__u32 scratch;
	__u8 e820_entries;
	__u8 eddbuf_entries;
	__u8 edd_mbr_sig_buf_entries;
	__u8 kbd_status;
	__u8 secure_boot;
	__u8 _pad5[2];
	__u8 sentinel;
	__u8 _pad6[1];
	struct setup_header hdr;
	__u8 _pad7[36];
	__u32 edd_mbr_sig_buffer[16];
	struct boot_e820_entry e820_table[128];
	__u8 _pad8[48];
	struct edd_info eddbuf[6];
	__u8 _pad9[276];
} __attribute__((packed));

enum x86_hardware_subarch {
	X86_SUBARCH_PC = 0,
	X86_SUBARCH_LGUEST = 1,
	X86_SUBARCH_XEN = 2,
	X86_SUBARCH_INTEL_MID = 3,
	X86_SUBARCH_CE4100 = 4,
	X86_NR_SUBARCHS = 5,
};

struct range {
	u64 start;
	u64 end;
};

struct pt_regs {
	long unsigned int r15;
	long unsigned int r14;
	long unsigned int r13;
	long unsigned int r12;
	long unsigned int bp;
	long unsigned int bx;
	long unsigned int r11;
	long unsigned int r10;
	long unsigned int r9;
	long unsigned int r8;
	long unsigned int ax;
	long unsigned int cx;
	long unsigned int dx;
	long unsigned int si;
	long unsigned int di;
	long unsigned int orig_ax;
	long unsigned int ip;
	long unsigned int cs;
	long unsigned int flags;
	long unsigned int sp;
	long unsigned int ss;
};

enum {
	GATE_INTERRUPT = 14,
	GATE_TRAP = 15,
	GATE_CALL = 12,
	GATE_TASK = 5,
};

struct idt_bits {
	u16 ist: 3;
	u16 zero: 5;
	u16 type: 5;
	u16 dpl: 2;
	u16 p: 1;
};

struct idt_data {
	unsigned int vector;
	unsigned int segment;
	struct idt_bits bits;
	const void *addr;
};

struct gate_struct {
	u16 offset_low;
	u16 segment;
	struct idt_bits bits;
	u16 offset_middle;
	u32 offset_high;
	u32 reserved;
};

typedef struct gate_struct gate_desc;

struct desc_ptr {
	short unsigned int size;
	long unsigned int address;
} __attribute__((packed));

typedef long unsigned int pteval_t;

typedef long unsigned int pmdval_t;

typedef long unsigned int pudval_t;

typedef long unsigned int p4dval_t;

typedef long unsigned int pgdval_t;

typedef long unsigned int pgprotval_t;

typedef struct {
	pteval_t pte;
} pte_t;

struct pgprot {
	pgprotval_t pgprot;
};

typedef struct pgprot pgprot_t;

typedef struct {
	pgdval_t pgd;
} pgd_t;

typedef struct {
	p4dval_t p4d;
} p4d_t;

typedef struct {
	pudval_t pud;
} pud_t;

typedef struct {
	pmdval_t pmd;
} pmd_t;

typedef struct page *pgtable_t;

struct kmem_cache;

struct address_space;

struct page_pool;

struct dev_pagemap;

struct page {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct paravirt_callee_save {
	void *func;
};

struct pv_lazy_ops {
	void (*enter)();
	void (*leave)();
	void (*flush)();
};

struct pv_cpu_ops {
	void (*io_delay)();
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	void (*write_cr4)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(long unsigned int);
	void (*invalidate_io_bitmap)();
	void (*update_io_bitmap)();
	void (*wbinvd)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int);
	void (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_msr_safe)(unsigned int, int *);
	int (*write_msr_safe)(unsigned int, unsigned int, unsigned int);
	u64 (*read_pmc)(int);
	void (*start_context_switch)(struct task_struct *);
	void (*end_context_switch)(struct task_struct *);
};

struct pv_irq_ops {
	struct paravirt_callee_save save_fl;
	struct paravirt_callee_save irq_disable;
	struct paravirt_callee_save irq_enable;
	void (*safe_halt)();
	void (*halt)();
};

struct flush_tlb_info;

struct mmu_gather;

struct pv_mmu_ops {
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_one_user)(long unsigned int);
	void (*flush_tlb_multi)(const struct cpumask *, const struct flush_tlb_info *);
	void (*tlb_remove_table)(struct mmu_gather *, void *);
	void (*exit_mmap)(struct mm_struct *);
	struct paravirt_callee_save read_cr2;
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct *, struct mm_struct *);
	void (*dup_mmap)(struct mm_struct *, struct mm_struct *);
	int (*pgd_alloc)(struct mm_struct *);
	void (*pgd_free)(struct mm_struct *, pgd_t *);
	void (*alloc_pte)(struct mm_struct *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct *, long unsigned int);
	void (*alloc_pud)(struct mm_struct *, long unsigned int);
	void (*alloc_p4d)(struct mm_struct *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*release_p4d)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	pte_t (*ptep_modify_prot_start)(struct vm_area_struct *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct vm_area_struct *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_p4d)(p4d_t *, p4d_t);
	struct paravirt_callee_save p4d_val;
	struct paravirt_callee_save make_p4d;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

struct flush_tlb_info {
	struct mm_struct *mm;
	long unsigned int start;
	long unsigned int end;
	u64 new_tlb_gen;
	unsigned int initiating_cpu;
	u8 stride_shift;
	u8 freed_tables;
};

struct rw_semaphore {
	atomic_long_t count;
	atomic_long_t owner;
	struct optimistic_spin_queue osq;
	raw_spinlock_t wait_lock;
	struct list_head wait_list;
};

struct mm_rss_stat {
	atomic_long_t count[4];
};

struct ldt_struct;

struct vdso_image;

typedef struct {
	u64 ctx_id;
	atomic64_t tlb_gen;
	struct rw_semaphore ldt_usr_sem;
	struct ldt_struct *ldt;
	short unsigned int flags;
	struct mutex lock;
	void *vdso;
	const struct vdso_image *vdso_image;
	atomic_t perf_rdpmc_allowed;
	u16 pkey_allocation_map;
	s16 execute_only_pkey;
} mm_context_t;

struct kioctx_table;

struct mmu_notifier_subscriptions;

struct xol_area;

struct uprobes_state {
	struct xol_area *xol_area;
};

struct work_struct;

typedef void (*work_func_t)(struct work_struct *);

struct work_struct {
	atomic_long_t data;
	struct list_head entry;
	work_func_t func;
};

struct linux_binfmt;

struct core_state;

struct user_namespace;

struct mm_struct {
	struct {
		struct vm_area_struct *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int mmap_compat_base;
		long unsigned int mmap_compat_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[48];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct *owner;
		struct user_namespace *user_ns;
		struct file *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		bool tlb_flush_batched;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct userfaultfd_ctx;

struct vm_userfaultfd_ctx {
	struct userfaultfd_ctx *ctx;
};

struct anon_vma;

struct vm_operations_struct;

struct vm_area_struct {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct *vm_next;
	struct vm_area_struct *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct *vm_ops;
	long unsigned int vm_pgoff;
	struct file *vm_file;
	struct file *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct pv_lock_ops {
	void (*queued_spin_lock_slowpath)(struct qspinlock *, u32);
	struct paravirt_callee_save queued_spin_unlock;
	void (*wait)(u8 *, u8);
	void (*kick)(int);
	struct paravirt_callee_save vcpu_is_preempted;
};

struct paravirt_patch_template {
	struct pv_cpu_ops cpu;
	struct pv_irq_ops irq;
	struct pv_mmu_ops mmu;
	struct pv_lock_ops lock;
};

struct math_emu_info {
	long int ___orig_eip;
	struct pt_regs *regs;
};

enum {
	UNAME26 = 131072,
	ADDR_NO_RANDOMIZE = 262144,
	FDPIC_FUNCPTRS = 524288,
	MMAP_PAGE_ZERO = 1048576,
	ADDR_COMPAT_LAYOUT = 2097152,
	READ_IMPLIES_EXEC = 4194304,
	ADDR_LIMIT_32BIT = 8388608,
	SHORT_INODE = 16777216,
	WHOLE_SECONDS = 33554432,
	STICKY_TIMEOUTS = 67108864,
	ADDR_LIMIT_3GB = 134217728,
};

enum tlb_infos {
	ENTRIES = 0,
	NR_INFO = 1,
};

enum pcpu_fc {
	PCPU_FC_AUTO = 0,
	PCPU_FC_EMBED = 1,
	PCPU_FC_PAGE = 2,
	PCPU_FC_NR = 3,
};

struct vm_struct {
	struct vm_struct *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct wait_queue_head {
	spinlock_t lock;
	struct list_head head;
};

typedef struct wait_queue_head wait_queue_head_t;

struct seqcount_raw_spinlock {
	seqcount_t seqcount;
};

typedef struct seqcount_raw_spinlock seqcount_raw_spinlock_t;

typedef struct {
	seqcount_spinlock_t seqcount;
	spinlock_t lock;
} seqlock_t;

enum node_states {
	N_POSSIBLE = 0,
	N_ONLINE = 1,
	N_NORMAL_MEMORY = 2,
	N_HIGH_MEMORY = 2,
	N_MEMORY = 3,
	N_CPU = 4,
	N_GENERIC_INITIATOR = 5,
	NR_NODE_STATES = 6,
};

enum {
	MM_FILEPAGES = 0,
	MM_ANONPAGES = 1,
	MM_SWAPENTS = 2,
	MM_SHMEMPAGES = 3,
	NR_MM_COUNTERS = 4,
};

struct swait_queue_head {
	raw_spinlock_t lock;
	struct list_head task_list;
};

struct completion {
	unsigned int done;
	struct swait_queue_head wait;
};

struct arch_uprobe_task {
	long unsigned int saved_scratch_register;
	unsigned int saved_trap_nr;
	unsigned int saved_tf;
};

enum uprobe_task_state {
	UTASK_RUNNING = 0,
	UTASK_SSTEP = 1,
	UTASK_SSTEP_ACK = 2,
	UTASK_SSTEP_TRAPPED = 3,
};

struct uprobe;

struct return_instance;

struct uprobe_task {
	enum uprobe_task_state state;
	union {
		struct {
			struct arch_uprobe_task autask;
			long unsigned int vaddr;
		};
		struct {
			struct callback_head dup_xol_work;
			long unsigned int dup_xol_addr;
		};
	};
	struct uprobe *active_uprobe;
	long unsigned int xol_vaddr;
	struct return_instance *return_instances;
	unsigned int depth;
};

struct return_instance {
	struct uprobe *uprobe;
	long unsigned int func;
	long unsigned int stack;
	long unsigned int orig_ret_vaddr;
	bool chained;
	struct return_instance *next;
};

struct vdso_image {
	void *data;
	long unsigned int size;
	long unsigned int alt;
	long unsigned int alt_len;
	long unsigned int extable_base;
	long unsigned int extable_len;
	const void *extable;
	long int sym_vvar_start;
	long int sym_vvar_page;
	long int sym_pvclock_page;
	long int sym_hvclock_page;
	long int sym_timens_page;
	long int sym_VDSO32_NOTE_MASK;
	long int sym___kernel_sigreturn;
	long int sym___kernel_rt_sigreturn;
	long int sym___kernel_vsyscall;
	long int sym_int80_landing_pad;
	long int sym_vdso32_sigreturn_landing_pad;
	long int sym_vdso32_rt_sigreturn_landing_pad;
};

struct xarray {
	spinlock_t xa_lock;
	gfp_t xa_flags;
	void *xa_head;
};

typedef u32 errseq_t;

struct address_space_operations;

struct address_space {
	struct inode *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct vmem_altmap {
	long unsigned int base_pfn;
	const long unsigned int end_pfn;
	const long unsigned int reserve;
	long unsigned int free;
	long unsigned int align;
	long unsigned int alloc;
};

struct percpu_ref_data;

struct percpu_ref {
	long unsigned int percpu_count_ptr;
	struct percpu_ref_data *data;
};

enum memory_type {
	MEMORY_DEVICE_PRIVATE = 1,
	MEMORY_DEVICE_FS_DAX = 2,
	MEMORY_DEVICE_GENERIC = 3,
	MEMORY_DEVICE_PCI_P2PDMA = 4,
};

struct dev_pagemap_ops;

struct dev_pagemap {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vfsmount;

struct path {
	struct vfsmount *mnt;
	struct dentry *dentry;
};

enum rw_hint {
	WRITE_LIFE_NOT_SET = 0,
	WRITE_LIFE_NONE = 1,
	WRITE_LIFE_SHORT = 2,
	WRITE_LIFE_MEDIUM = 3,
	WRITE_LIFE_LONG = 4,
	WRITE_LIFE_EXTREME = 5,
};

enum pid_type {
	PIDTYPE_PID = 0,
	PIDTYPE_TGID = 1,
	PIDTYPE_PGID = 2,
	PIDTYPE_SID = 3,
	PIDTYPE_MAX = 4,
};

struct fown_struct {
	rwlock_t lock;
	struct pid *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file_ra_state {
	long unsigned int start;
	unsigned int size;
	unsigned int async_size;
	unsigned int ra_pages;
	unsigned int mmap_miss;
	loff_t prev_pos;
};

struct file {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	long: 64;
	long: 64;
	struct path f_path;
	struct inode *f_inode;
	const struct file_operations *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct f_owner;
	const struct cred *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

typedef unsigned int vm_fault_t;

enum page_entry_size {
	PE_SIZE_PTE = 0,
	PE_SIZE_PMD = 1,
	PE_SIZE_PUD = 2,
};

struct vm_fault;

struct vm_operations_struct {
	void (*open)(struct vm_area_struct *);
	void (*close)(struct vm_area_struct *);
	int (*may_split)(struct vm_area_struct *, long unsigned int);
	int (*mremap)(struct vm_area_struct *);
	int (*mprotect)(struct vm_area_struct *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault *);
	vm_fault_t (*huge_fault)(struct vm_fault *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct *);
	vm_fault_t (*page_mkwrite)(struct vm_fault *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault *);
	int (*access)(struct vm_area_struct *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct *);
	int (*set_policy)(struct vm_area_struct *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct *, long unsigned int);
	struct page * (*find_special_page)(struct vm_area_struct *, long unsigned int);
};

struct core_thread {
	struct task_struct *task;
	struct core_thread *next;
};

struct core_state {
	atomic_t nr_threads;
	struct core_thread dumper;
	struct completion startup;
};

enum fault_flag {
	FAULT_FLAG_WRITE = 1,
	FAULT_FLAG_MKWRITE = 2,
	FAULT_FLAG_ALLOW_RETRY = 4,
	FAULT_FLAG_RETRY_NOWAIT = 8,
	FAULT_FLAG_KILLABLE = 16,
	FAULT_FLAG_TRIED = 32,
	FAULT_FLAG_USER = 64,
	FAULT_FLAG_REMOTE = 128,
	FAULT_FLAG_INSTRUCTION = 256,
	FAULT_FLAG_INTERRUPTIBLE = 512,
};

struct vm_fault {
	const struct {
		struct vm_area_struct *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page *cow_page;
	struct page *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t prealloc_pte;
};

enum migratetype {
	MIGRATE_UNMOVABLE = 0,
	MIGRATE_MOVABLE = 1,
	MIGRATE_RECLAIMABLE = 2,
	MIGRATE_PCPTYPES = 3,
	MIGRATE_HIGHATOMIC = 3,
	MIGRATE_ISOLATE = 4,
	MIGRATE_TYPES = 5,
};

enum numa_stat_item {
	NUMA_HIT = 0,
	NUMA_MISS = 1,
	NUMA_FOREIGN = 2,
	NUMA_INTERLEAVE_HIT = 3,
	NUMA_LOCAL = 4,
	NUMA_OTHER = 5,
	NR_VM_NUMA_EVENT_ITEMS = 6,
};

enum zone_stat_item {
	NR_FREE_PAGES = 0,
	NR_ZONE_LRU_BASE = 1,
	NR_ZONE_INACTIVE_ANON = 1,
	NR_ZONE_ACTIVE_ANON = 2,
	NR_ZONE_INACTIVE_FILE = 3,
	NR_ZONE_ACTIVE_FILE = 4,
	NR_ZONE_UNEVICTABLE = 5,
	NR_ZONE_WRITE_PENDING = 6,
	NR_MLOCK = 7,
	NR_BOUNCE = 8,
	NR_ZSPAGES = 9,
	NR_FREE_CMA_PAGES = 10,
	NR_VM_ZONE_STAT_ITEMS = 11,
};

enum node_stat_item {
	NR_LRU_BASE = 0,
	NR_INACTIVE_ANON = 0,
	NR_ACTIVE_ANON = 1,
	NR_INACTIVE_FILE = 2,
	NR_ACTIVE_FILE = 3,
	NR_UNEVICTABLE = 4,
	NR_SLAB_RECLAIMABLE_B = 5,
	NR_SLAB_UNRECLAIMABLE_B = 6,
	NR_ISOLATED_ANON = 7,
	NR_ISOLATED_FILE = 8,
	WORKINGSET_NODES = 9,
	WORKINGSET_REFAULT_BASE = 10,
	WORKINGSET_REFAULT_ANON = 10,
	WORKINGSET_REFAULT_FILE = 11,
	WORKINGSET_ACTIVATE_BASE = 12,
	WORKINGSET_ACTIVATE_ANON = 12,
	WORKINGSET_ACTIVATE_FILE = 13,
	WORKINGSET_RESTORE_BASE = 14,
	WORKINGSET_RESTORE_ANON = 14,
	WORKINGSET_RESTORE_FILE = 15,
	WORKINGSET_NODERECLAIM = 16,
	NR_ANON_MAPPED = 17,
	NR_FILE_MAPPED = 18,
	NR_FILE_PAGES = 19,
	NR_FILE_DIRTY = 20,
	NR_WRITEBACK = 21,
	NR_WRITEBACK_TEMP = 22,
	NR_SHMEM = 23,
	NR_SHMEM_THPS = 24,
	NR_SHMEM_PMDMAPPED = 25,
	NR_FILE_THPS = 26,
	NR_FILE_PMDMAPPED = 27,
	NR_ANON_THPS = 28,
	NR_VMSCAN_WRITE = 29,
	NR_VMSCAN_IMMEDIATE = 30,
	NR_DIRTIED = 31,
	NR_WRITTEN = 32,
	NR_KERNEL_MISC_RECLAIMABLE = 33,
	NR_FOLL_PIN_ACQUIRED = 34,
	NR_FOLL_PIN_RELEASED = 35,
	NR_KERNEL_STACK_KB = 36,
	NR_PAGETABLE = 37,
	NR_SWAPCACHE = 38,
	NR_VM_NODE_STAT_ITEMS = 39,
};

enum lru_list {
	LRU_INACTIVE_ANON = 0,
	LRU_ACTIVE_ANON = 1,
	LRU_INACTIVE_FILE = 2,
	LRU_ACTIVE_FILE = 3,
	LRU_UNEVICTABLE = 4,
	NR_LRU_LISTS = 5,
};

typedef unsigned int isolate_mode_t;

enum zone_watermarks {
	WMARK_MIN = 0,
	WMARK_LOW = 1,
	WMARK_HIGH = 2,
	NR_WMARK = 3,
};

enum {
	ZONELIST_FALLBACK = 0,
	ZONELIST_NOFALLBACK = 1,
	MAX_ZONELISTS = 2,
};

typedef void percpu_ref_func_t(struct percpu_ref *);

struct percpu_ref_data {
	atomic_long_t count;
	percpu_ref_func_t *release;
	percpu_ref_func_t *confirm_switch;
	bool force_atomic: 1;
	bool allow_reinit: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	struct callback_head rcu;
	struct percpu_ref *ref;
};

struct shrink_control {
	gfp_t gfp_mask;
	int nid;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	struct mem_cgroup *memcg;
};

struct shrinker {
	long unsigned int (*count_objects)(struct shrinker *, struct shrink_control *);
	long unsigned int (*scan_objects)(struct shrinker *, struct shrink_control *);
	long int batch;
	int seeks;
	unsigned int flags;
	struct list_head list;
	int id;
	atomic_long_t *nr_deferred;
};

struct rlimit {
	__kernel_ulong_t rlim_cur;
	__kernel_ulong_t rlim_max;
};

struct dev_pagemap_ops {
	void (*page_free)(struct page *);
	void (*kill)(struct dev_pagemap *);
	void (*cleanup)(struct dev_pagemap *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault *);
};

struct pid_namespace;

struct upid {
	int nr;
	struct pid_namespace *ns;
};

struct pid {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid numbers[1];
};

typedef struct {
	gid_t val;
} kgid_t;

struct hrtimer_cpu_base;

struct hrtimer_clock_base {
	struct hrtimer_cpu_base *cpu_base;
	unsigned int index;
	clockid_t clockid;
	seqcount_raw_spinlock_t seq;
	struct hrtimer *running;
	struct timerqueue_head active;
	ktime_t (*get_time)();
	ktime_t offset;
};

struct hrtimer_cpu_base {
	raw_spinlock_t lock;
	unsigned int cpu;
	unsigned int active_bases;
	unsigned int clock_was_set_seq;
	unsigned int hres_active: 1;
	unsigned int in_hrtirq: 1;
	unsigned int hang_detected: 1;
	unsigned int softirq_activated: 1;
	long: 31;
	long: 64;
	long: 64;
	unsigned int nr_events;
	short unsigned int nr_retries;
	short unsigned int nr_hangs;
	unsigned int max_hang_time;
	ktime_t expires_next;
	struct hrtimer *next_timer;
	ktime_t softirq_expires_next;
	struct hrtimer *softirq_next_timer;
	struct hrtimer_clock_base clock_base[8];
};

enum hrtimer_base_type {
	HRTIMER_BASE_MONOTONIC = 0,
	HRTIMER_BASE_REALTIME = 1,
	HRTIMER_BASE_BOOTTIME = 2,
	HRTIMER_BASE_TAI = 3,
	HRTIMER_BASE_MONOTONIC_SOFT = 4,
	HRTIMER_BASE_REALTIME_SOFT = 5,
	HRTIMER_BASE_BOOTTIME_SOFT = 6,
	HRTIMER_BASE_TAI_SOFT = 7,
	HRTIMER_MAX_CLOCK_BASES = 8,
};

typedef void __signalfn_t(int);

typedef __signalfn_t *__sighandler_t;

typedef void __restorefn_t();

typedef __restorefn_t *__sigrestore_t;

union sigval {
	int sival_int;
	void *sival_ptr;
};

typedef union sigval sigval_t;

union __sifields {
	struct {
		__kernel_pid_t _pid;
		__kernel_uid32_t _uid;
	} _kill;
	struct {
		__kernel_timer_t _tid;
		int _overrun;
		sigval_t _sigval;
		int _sys_private;
	} _timer;
	struct {
		__kernel_pid_t _pid;
		__kernel_uid32_t _uid;
		sigval_t _sigval;
	} _rt;
	struct {
		__kernel_pid_t _pid;
		__kernel_uid32_t _uid;
		int _status;
		__kernel_clock_t _utime;
		__kernel_clock_t _stime;
	} _sigchld;
	struct {
		void *_addr;
		union {
			int _trapno;
			short int _addr_lsb;
			struct {
				char _dummy_bnd[8];
				void *_lower;
				void *_upper;
			} _addr_bnd;
			struct {
				char _dummy_pkey[8];
				__u32 _pkey;
			} _addr_pkey;
			struct {
				long unsigned int _data;
				__u32 _type;
			} _perf;
		};
	} _sigfault;
	struct {
		long int _band;
		int _fd;
	} _sigpoll;
	struct {
		void *_call_addr;
		int _syscall;
		unsigned int _arch;
	} _sigsys;
};

struct kernel_siginfo {
	struct {
		int si_signo;
		int si_errno;
		int si_code;
		union __sifields _sifields;
	};
};

struct sigaction {
	__sighandler_t sa_handler;
	long unsigned int sa_flags;
	__sigrestore_t sa_restorer;
	sigset_t sa_mask;
};

struct k_sigaction {
	struct sigaction sa;
};

struct cpu_itimer {
	u64 expires;
	u64 incr;
};

struct task_cputime_atomic {
	atomic64_t utime;
	atomic64_t stime;
	atomic64_t sum_exec_runtime;
};

struct thread_group_cputimer {
	struct task_cputime_atomic cputime_atomic;
};

struct pacct_struct {
	int ac_flag;
	long int ac_exitcode;
	long unsigned int ac_mem;
	u64 ac_utime;
	u64 ac_stime;
	long unsigned int ac_minflt;
	long unsigned int ac_majflt;
};

struct tty_audit_buf;

struct tty_struct;

struct autogroup;

struct taskstats;

struct signal_struct {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper;
	unsigned int has_child_subreaper;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid *pids[4];
	struct pid *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

enum rseq_cs_flags_bit {
	RSEQ_CS_FLAG_NO_RESTART_ON_PREEMPT_BIT = 0,
	RSEQ_CS_FLAG_NO_RESTART_ON_SIGNAL_BIT = 1,
	RSEQ_CS_FLAG_NO_RESTART_ON_MIGRATE_BIT = 2,
};

struct rseq {
	__u32 cpu_id_start;
	__u32 cpu_id;
	union {
		__u64 ptr64;
		__u64 ptr;
	} rseq_cs;
	__u32 flags;
	long: 32;
	long: 64;
};

enum uclamp_id {
	UCLAMP_MIN = 0,
	UCLAMP_MAX = 1,
	UCLAMP_CNT = 2,
};

enum perf_event_task_context {
	perf_invalid_context = 4294967295,
	perf_hw_context = 0,
	perf_sw_context = 1,
	perf_nr_task_contexts = 2,
};

struct rq;

struct task_struct___2;

struct rq_flags;

struct sched_class {
	int uclamp_enabled;
	void (*enqueue_task)(struct rq *, struct task_struct___2 *, int);
	void (*dequeue_task)(struct rq *, struct task_struct___2 *, int);
	void (*yield_task)(struct rq *);
	bool (*yield_to_task)(struct rq *, struct task_struct___2 *);
	void (*check_preempt_curr)(struct rq *, struct task_struct___2 *, int);
	struct task_struct___2 * (*pick_next_task)(struct rq *);
	void (*put_prev_task)(struct rq *, struct task_struct___2 *);
	void (*set_next_task)(struct rq *, struct task_struct___2 *, bool);
	int (*balance)(struct rq *, struct task_struct___2 *, struct rq_flags *);
	int (*select_task_rq)(struct task_struct___2 *, int, int);
	struct task_struct___2 * (*pick_task)(struct rq *);
	void (*migrate_task_rq)(struct task_struct___2 *, int);
	void (*task_woken)(struct rq *, struct task_struct___2 *);
	void (*set_cpus_allowed)(struct task_struct___2 *, const struct cpumask *, u32);
	void (*rq_online)(struct rq *);
	void (*rq_offline)(struct rq *);
	struct rq * (*find_lock_rq)(struct task_struct___2 *, struct rq *);
	void (*task_tick)(struct rq *, struct task_struct___2 *, int);
	void (*task_fork)(struct task_struct___2 *);
	void (*task_dead)(struct task_struct___2 *);
	void (*switched_from)(struct rq *, struct task_struct___2 *);
	void (*switched_to)(struct rq *, struct task_struct___2 *);
	void (*prio_changed)(struct rq *, struct task_struct___2 *, int);
	unsigned int (*get_rr_interval)(struct rq *, struct task_struct___2 *);
	void (*update_curr)(struct rq *);
	void (*task_change_group)(struct task_struct___2 *, int);
};

struct kernel_cap_struct {
	__u32 cap[2];
};

typedef struct kernel_cap_struct kernel_cap_t;

struct user_struct;

struct ucounts;

struct group_info;

struct cred {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key *session_keyring;
	struct key *process_keyring;
	struct key *thread_keyring;
	struct key *request_key_auth;
	void *security;
	struct user_struct *user;
	struct user_namespace *user_ns;
	struct ucounts *ucounts;
	struct group_info *group_info;
	union {
		int non_rcu;
		struct callback_head rcu;
	};
};

typedef int32_t key_serial_t;

struct watch_list;

struct key_user;

typedef uint32_t key_perm_t;

struct key_type;

struct key_tag;

struct keyring_index_key {
	long unsigned int hash;
	union {
		struct {
			u16 desc_len;
			char desc[6];
		};
		long unsigned int x;
	};
	struct key_type *type;
	struct key_tag *domain_tag;
	const char *description;
};

union key_payload {
	void *rcu_data0;
	void *data[4];
};

struct assoc_array_ptr;

struct assoc_array {
	struct assoc_array_ptr *root;
	long unsigned int nr_leaves_on_tree;
};

struct key_restriction;

struct key {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct watch_list *watchers;
	struct rw_semaphore sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			long unsigned int hash;
			long unsigned int len_desc;
			struct key_type *type;
			struct key_tag *domain_tag;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction *restrict_link;
};

struct sighand_struct {
	spinlock_t siglock;
	refcount_t count;
	wait_queue_head_t signalfd_wqh;
	struct k_sigaction action[64];
};

struct io_cq;

struct io_context {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	struct xarray icq_tree;
	struct io_cq *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

enum rseq_event_mask_bits {
	RSEQ_EVENT_PREEMPT_BIT = 0,
	RSEQ_EVENT_SIGNAL_BIT = 1,
	RSEQ_EVENT_MIGRATE_BIT = 2,
};

enum fixed_addresses {
	VSYSCALL_PAGE = 511,
	FIX_DBGP_BASE = 512,
	FIX_EARLYCON_MEM_BASE = 513,
	FIX_APIC_BASE = 514,
	FIX_IO_APIC_BASE_0 = 515,
	FIX_IO_APIC_BASE_END = 642,
	FIX_PARAVIRT_BOOTMAP = 643,
	FIX_APEI_GHES_IRQ = 644,
	FIX_APEI_GHES_NMI = 645,
	__end_of_permanent_fixed_addresses = 646,
	FIX_BTMAP_END = 1024,
	FIX_BTMAP_BEGIN = 1535,
	FIX_TBOOT_BASE = 1536,
	__end_of_fixed_addresses = 1537,
};

struct hlist_bl_node;

struct hlist_bl_head {
	struct hlist_bl_node *first;
};

struct hlist_bl_node {
	struct hlist_bl_node *next;
	struct hlist_bl_node **pprev;
};

struct lockref {
	union {
		__u64 lock_count;
		struct {
			spinlock_t lock;
			int count;
		};
	};
};

struct qstr {
	union {
		struct {
			u32 hash;
			u32 len;
		};
		u64 hash_len;
	};
	const unsigned char *name;
};

struct dentry_operations;

struct dentry {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry *d_parent;
	struct qstr d_name;
	struct inode *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations *d_op;
	struct super_block *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct fsnotify_mark_connector;

struct fscrypt_info;

struct fsverity_info;

struct posix_acl;

struct inode_operations;

struct bdi_writeback;

struct file_lock_context;

struct cdev;

struct inode {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations *i_op;
	struct super_block *i_sb;
	struct address_space *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	long: 64;
	long: 64;
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations *i_fop;
		void (*free_inode)(struct inode *);
	};
	struct file_lock_context *i_flctx;
	struct address_space i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct cdev *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations {
	int (*d_revalidate)(struct dentry *, unsigned int);
	int (*d_weak_revalidate)(struct dentry *, unsigned int);
	int (*d_hash)(const struct dentry *, struct qstr *);
	int (*d_compare)(const struct dentry *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry *);
	int (*d_init)(struct dentry *);
	void (*d_release)(struct dentry *);
	void (*d_prune)(struct dentry *);
	void (*d_iput)(struct dentry *, struct inode *);
	char * (*d_dname)(struct dentry *, char *, int);
	struct vfsmount * (*d_automount)(struct path *);
	int (*d_manage)(const struct path *, bool);
	struct dentry * (*d_real)(struct dentry *, const struct inode *);
	long: 64;
	long: 64;
	long: 64;
};

struct export_operations;

struct fscrypt_operations;

struct fsverity_operations;

struct unicode_map;

struct mtd_info;

typedef long long int qsize_t;

struct quota_format_type;

struct mem_dqinfo {
	struct quota_format_type *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops;

struct quota_info {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode *files[3];
	struct mem_dqinfo info[3];
	const struct quota_format_ops *ops[3];
};

struct rcu_sync {
	int gp_state;
	int gp_count;
	wait_queue_head_t gp_wait;
	struct callback_head cb_head;
};

struct rcuwait {
	struct task_struct *task;
};

struct percpu_rw_semaphore {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore rw_sem[3];
};

typedef struct {
	__u8 b[16];
} uuid_t;

struct list_lru_node;

struct list_lru {
	struct list_lru_node *node;
	struct list_head list;
	int shrinker_id;
	bool memcg_aware;
};

struct super_operations;

struct dquot_operations;

struct quotactl_ops;

struct xattr_handler;

struct block_device;

struct workqueue_struct;

struct super_block {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type *s_type;
	const struct super_operations *s_op;
	const struct dquot_operations *dq_op;
	const struct quotactl_ops *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device *s_bdev;
	struct backing_dev_info *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info s_dquot;
	struct sb_writers s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount {
	struct dentry *mnt_root;
	struct super_block *mnt_sb;
	int mnt_flags;
	struct user_namespace *mnt_userns;
};

struct kstat {
	u32 result_mask;
	umode_t mode;
	unsigned int nlink;
	uint32_t blksize;
	u64 attributes;
	u64 attributes_mask;
	u64 ino;
	dev_t dev;
	dev_t rdev;
	kuid_t uid;
	kgid_t gid;
	loff_t size;
	struct timespec64 atime;
	struct timespec64 mtime;
	struct timespec64 ctime;
	struct timespec64 btime;
	u64 blocks;
	u64 mnt_id;
};

struct list_lru_one {
	struct list_head list;
	long int nr_items;
};

struct list_lru_memcg {
	struct callback_head rcu;
	struct list_lru_one *lru[0];
};

struct list_lru_node {
	spinlock_t lock;
	struct list_lru_one lru;
	struct list_lru_memcg *memcg_lrus;
	long int nr_items;
	long: 64;
	long: 64;
};

enum migrate_mode {
	MIGRATE_ASYNC = 0,
	MIGRATE_SYNC_LIGHT = 1,
	MIGRATE_SYNC = 2,
	MIGRATE_SYNC_NO_COPY = 3,
};

struct key_tag {
	struct callback_head rcu;
	refcount_t usage;
	bool removed;
};

typedef int (*key_restrict_link_func_t)(struct key *, const struct key_type *, const union key_payload *, struct key *);

struct key_restriction {
	key_restrict_link_func_t check;
	struct key *key;
	struct key_type *keytype;
};

struct percpu_counter {
	raw_spinlock_t lock;
	s64 count;
	struct list_head list;
	s32 *counters;
};

struct user_struct {
	refcount_t __count;
	struct percpu_counter epoll_watches;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	atomic_t nr_watches;
	struct ratelimit_state ratelimit;
};

struct group_info {
	atomic_t usage;
	int ngroups;
	kgid_t gid[0];
};

struct delayed_call {
	void (*fn)(void *);
	void *arg;
};

struct io_cq {
	struct request_queue *q;
	struct io_context *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct wait_page_queue;

struct kiocb {
	struct file *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue *ki_waitq;
	};
};

struct iattr {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file *ia_file;
};

typedef __kernel_uid32_t projid_t;

typedef struct {
	projid_t val;
} kprojid_t;

enum quota_type {
	USRQUOTA = 0,
	GRPQUOTA = 1,
	PRJQUOTA = 2,
};

struct kqid {
	union {
		kuid_t uid;
		kgid_t gid;
		kprojid_t projid;
	};
	enum quota_type type;
};

struct mem_dqblk {
	qsize_t dqb_bhardlimit;
	qsize_t dqb_bsoftlimit;
	qsize_t dqb_curspace;
	qsize_t dqb_rsvspace;
	qsize_t dqb_ihardlimit;
	qsize_t dqb_isoftlimit;
	qsize_t dqb_curinodes;
	time64_t dqb_btime;
	time64_t dqb_itime;
};

struct dquot {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

enum {
	DQF_ROOT_SQUASH_B = 0,
	DQF_SYS_FILE_B = 16,
	DQF_PRIVATE = 17,
};

struct quota_format_type {
	int qf_fmt_id;
	const struct quota_format_ops *qf_ops;
	struct module *qf_owner;
	struct quota_format_type *qf_next;
};

enum {
	DQST_LOOKUPS = 0,
	DQST_DROPS = 1,
	DQST_READS = 2,
	DQST_WRITES = 3,
	DQST_CACHE_HITS = 4,
	DQST_ALLOC_DQUOTS = 5,
	DQST_FREE_DQUOTS = 6,
	DQST_SYNCS = 7,
	_DQST_DQSTAT_LAST = 8,
};

struct quota_format_ops {
	int (*check_quota_file)(struct super_block *, int);
	int (*read_file_info)(struct super_block *, int);
	int (*write_file_info)(struct super_block *, int);
	int (*free_file_info)(struct super_block *, int);
	int (*read_dqblk)(struct dquot *);
	int (*commit_dqblk)(struct dquot *);
	int (*release_dqblk)(struct dquot *);
	int (*get_next_id)(struct super_block *, struct kqid *);
};

struct dquot_operations {
	int (*write_dquot)(struct dquot *);
	struct dquot * (*alloc_dquot)(struct super_block *, int);
	void (*destroy_dquot)(struct dquot *);
	int (*acquire_dquot)(struct dquot *);
	int (*release_dquot)(struct dquot *);
	int (*mark_dirty)(struct dquot *);
	int (*write_info)(struct super_block *, int);
	qsize_t * (*get_reserved_space)(struct inode *);
	int (*get_projid)(struct inode *, kprojid_t *);
	int (*get_inode_usage)(struct inode *, qsize_t *);
	int (*get_next_id)(struct super_block *, struct kqid *);
};

struct qc_dqblk {
	int d_fieldmask;
	u64 d_spc_hardlimit;
	u64 d_spc_softlimit;
	u64 d_ino_hardlimit;
	u64 d_ino_softlimit;
	u64 d_space;
	u64 d_ino_count;
	s64 d_ino_timer;
	s64 d_spc_timer;
	int d_ino_warns;
	int d_spc_warns;
	u64 d_rt_spc_hardlimit;
	u64 d_rt_spc_softlimit;
	u64 d_rt_space;
	s64 d_rt_spc_timer;
	int d_rt_spc_warns;
};

struct qc_type_state {
	unsigned int flags;
	unsigned int spc_timelimit;
	unsigned int ino_timelimit;
	unsigned int rt_spc_timelimit;
	unsigned int spc_warnlimit;
	unsigned int ino_warnlimit;
	unsigned int rt_spc_warnlimit;
	long long unsigned int ino;
	blkcnt_t blocks;
	blkcnt_t nextents;
};

struct qc_state {
	unsigned int s_incoredqs;
	struct qc_type_state s_state[3];
};

struct qc_info {
	int i_fieldmask;
	unsigned int i_flags;
	unsigned int i_spc_timelimit;
	unsigned int i_ino_timelimit;
	unsigned int i_rt_spc_timelimit;
	unsigned int i_spc_warnlimit;
	unsigned int i_ino_warnlimit;
	unsigned int i_rt_spc_warnlimit;
};

struct quotactl_ops {
	int (*quota_on)(struct super_block *, int, int, const struct path *);
	int (*quota_off)(struct super_block *, int);
	int (*quota_enable)(struct super_block *, unsigned int);
	int (*quota_disable)(struct super_block *, unsigned int);
	int (*quota_sync)(struct super_block *, int);
	int (*set_info)(struct super_block *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block *, struct qc_state *);
	int (*rm_xquota)(struct super_block *, unsigned int);
};

struct writeback_control;

struct readahead_control;

struct swap_info_struct;

struct address_space_operations {
	int (*writepage)(struct page *, struct writeback_control *);
	int (*readpage)(struct file *, struct page *);
	int (*writepages)(struct address_space *, struct writeback_control *);
	int (*set_page_dirty)(struct page *);
	int (*readpages)(struct file *, struct address_space *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control *);
	int (*write_begin)(struct file *, struct address_space *, loff_t, unsigned int, unsigned int, struct page **, void **);
	int (*write_end)(struct file *, struct address_space *, loff_t, unsigned int, unsigned int, struct page *, void *);
	sector_t (*bmap)(struct address_space *, sector_t);
	void (*invalidatepage)(struct page *, unsigned int, unsigned int);
	int (*releasepage)(struct page *, gfp_t);
	void (*freepage)(struct page *);
	ssize_t (*direct_IO)(struct kiocb *, struct iov_iter *);
	int (*migratepage)(struct address_space *, struct page *, struct page *, enum migrate_mode);
	bool (*isolate_page)(struct page *, isolate_mode_t);
	void (*putback_page)(struct page *);
	int (*launder_page)(struct page *);
	int (*is_partially_uptodate)(struct page *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page *, bool *, bool *);
	int (*error_remove_page)(struct address_space *, struct page *);
	int (*swap_activate)(struct swap_info_struct *, struct file *, sector_t *);
	void (*swap_deactivate)(struct file *);
};

struct fiemap_extent_info;

struct fileattr;

struct inode_operations {
	struct dentry * (*lookup)(struct inode *, struct dentry *, unsigned int);
	const char * (*get_link)(struct dentry *, struct inode *, struct delayed_call *);
	int (*permission)(struct user_namespace *, struct inode *, int);
	struct posix_acl * (*get_acl)(struct inode *, int, bool);
	int (*readlink)(struct dentry *, char *, int);
	int (*create)(struct user_namespace *, struct inode *, struct dentry *, umode_t, bool);
	int (*link)(struct dentry *, struct inode *, struct dentry *);
	int (*unlink)(struct inode *, struct dentry *);
	int (*symlink)(struct user_namespace *, struct inode *, struct dentry *, const char *);
	int (*mkdir)(struct user_namespace *, struct inode *, struct dentry *, umode_t);
	int (*rmdir)(struct inode *, struct dentry *);
	int (*mknod)(struct user_namespace *, struct inode *, struct dentry *, umode_t, dev_t);
	int (*rename)(struct user_namespace *, struct inode *, struct dentry *, struct inode *, struct dentry *, unsigned int);
	int (*setattr)(struct user_namespace *, struct dentry *, struct iattr *);
	int (*getattr)(struct user_namespace *, const struct path *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry *, char *, size_t);
	int (*fiemap)(struct inode *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode *, struct timespec64 *, int);
	int (*atomic_open)(struct inode *, struct dentry *, struct file *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace *, struct inode *, struct dentry *, umode_t);
	int (*set_acl)(struct user_namespace *, struct inode *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace *, struct dentry *, struct fileattr *);
	int (*fileattr_get)(struct dentry *, struct fileattr *);
	long: 64;
};

struct file_lock_context {
	spinlock_t flc_lock;
	struct list_head flc_flock;
	struct list_head flc_posix;
	struct list_head flc_lease;
};

struct file_lock_operations {
	void (*fl_copy_lock)(struct file_lock *, struct file_lock *);
	void (*fl_release_private)(struct file_lock *);
};

struct nlm_lockowner;

struct nfs_lock_info {
	u32 state;
	struct nlm_lockowner *owner;
	struct list_head list;
};

struct nfs4_lock_state;

struct nfs4_lock_info {
	struct nfs4_lock_state *owner;
};

struct fasync_struct;

struct lock_manager_operations;

struct file_lock {
	struct file_lock *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations *fl_ops;
	const struct lock_manager_operations *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock *);
	int (*lm_grant)(struct file_lock *, int);
	bool (*lm_break)(struct file_lock *);
	int (*lm_change)(struct file_lock *, int, struct list_head *);
	void (*lm_setup)(struct file_lock *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock *);
};

struct fasync_struct {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct *fa_next;
	struct file *fa_file;
	struct callback_head fa_rcu;
};

enum {
	SB_UNFROZEN = 0,
	SB_FREEZE_WRITE = 1,
	SB_FREEZE_PAGEFAULT = 2,
	SB_FREEZE_FS = 3,
	SB_FREEZE_COMPLETE = 4,
};

struct kstatfs;

struct super_operations {
	struct inode * (*alloc_inode)(struct super_block *);
	void (*destroy_inode)(struct inode *);
	void (*free_inode)(struct inode *);
	void (*dirty_inode)(struct inode *, int);
	int (*write_inode)(struct inode *, struct writeback_control *);
	int (*drop_inode)(struct inode *);
	void (*evict_inode)(struct inode *);
	void (*put_super)(struct super_block *);
	int (*sync_fs)(struct super_block *, int);
	int (*freeze_super)(struct super_block *);
	int (*freeze_fs)(struct super_block *);
	int (*thaw_super)(struct super_block *);
	int (*unfreeze_fs)(struct super_block *);
	int (*statfs)(struct dentry *, struct kstatfs *);
	int (*remount_fs)(struct super_block *, int *, char *);
	void (*umount_begin)(struct super_block *);
	int (*show_options)(struct seq_file *, struct dentry *);
	int (*show_devname)(struct seq_file *, struct dentry *);
	int (*show_path)(struct seq_file *, struct dentry *);
	int (*show_stats)(struct seq_file *, struct dentry *);
	ssize_t (*quota_read)(struct super_block *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block *, int, const char *, size_t, loff_t);
	struct dquot ** (*get_dquots)(struct inode *);
	long int (*nr_cached_objects)(struct super_block *, struct shrink_control *);
	long int (*free_cached_objects)(struct super_block *, struct shrink_control *);
	struct file * (*real_loop)(struct file *);
};

struct dentry___2;

struct inode___2;

struct xattr_handler {
	const char *name;
	const char *prefix;
	int flags;
	bool (*list)(struct dentry___2 *);
	int (*get)(const struct xattr_handler *, struct dentry___2 *, struct inode___2 *, const char *, void *, size_t);
	int (*set)(const struct xattr_handler *, struct user_namespace *, struct dentry___2 *, struct inode___2 *, const char *, const void *, size_t, int);
};

typedef int (*filldir_t)(struct dir_context *, const char *, int, loff_t, u64, unsigned int);

struct dir_context {
	filldir_t actor;
	loff_t pos;
};

struct p_log;

struct fs_parameter;

struct fs_parse_result;

typedef int fs_param_type(struct p_log *, const struct fs_parameter_spec *, struct fs_parameter *, struct fs_parse_result *);

struct fs_parameter_spec {
	const char *name;
	fs_param_type *type;
	u8 opt;
	short unsigned int flags;
	const void *data;
};

enum compound_dtor_id {
	NULL_COMPOUND_DTOR = 0,
	COMPOUND_PAGE_DTOR = 1,
	HUGETLB_PAGE_DTOR = 2,
	TRANSHUGE_PAGE_DTOR = 3,
	NR_COMPOUND_DTORS = 4,
};

enum vm_event_item {
	PGPGIN = 0,
	PGPGOUT = 1,
	PSWPIN = 2,
	PSWPOUT = 3,
	PGALLOC_DMA = 4,
	PGALLOC_DMA32 = 5,
	PGALLOC_NORMAL = 6,
	PGALLOC_MOVABLE = 7,
	ALLOCSTALL_DMA = 8,
	ALLOCSTALL_DMA32 = 9,
	ALLOCSTALL_NORMAL = 10,
	ALLOCSTALL_MOVABLE = 11,
	PGSCAN_SKIP_DMA = 12,
	PGSCAN_SKIP_DMA32 = 13,
	PGSCAN_SKIP_NORMAL = 14,
	PGSCAN_SKIP_MOVABLE = 15,
	PGFREE = 16,
	PGACTIVATE = 17,
	PGDEACTIVATE = 18,
	PGLAZYFREE = 19,
	PGFAULT = 20,
	PGMAJFAULT = 21,
	PGLAZYFREED = 22,
	PGREFILL = 23,
	PGREUSE = 24,
	PGSTEAL_KSWAPD = 25,
	PGSTEAL_DIRECT = 26,
	PGDEMOTE_KSWAPD = 27,
	PGDEMOTE_DIRECT = 28,
	PGSCAN_KSWAPD = 29,
	PGSCAN_DIRECT = 30,
	PGSCAN_DIRECT_THROTTLE = 31,
	PGSCAN_ANON = 32,
	PGSCAN_FILE = 33,
	PGSTEAL_ANON = 34,
	PGSTEAL_FILE = 35,
	PGSCAN_ZONE_RECLAIM_FAILED = 36,
	PGINODESTEAL = 37,
	SLABS_SCANNED = 38,
	KSWAPD_INODESTEAL = 39,
	KSWAPD_LOW_WMARK_HIT_QUICKLY = 40,
	KSWAPD_HIGH_WMARK_HIT_QUICKLY = 41,
	PAGEOUTRUN = 42,
	PGROTATED = 43,
	DROP_PAGECACHE = 44,
	DROP_SLAB = 45,
	OOM_KILL = 46,
	NUMA_PTE_UPDATES = 47,
	NUMA_HUGE_PTE_UPDATES = 48,
	NUMA_HINT_FAULTS = 49,
	NUMA_HINT_FAULTS_LOCAL = 50,
	NUMA_PAGE_MIGRATE = 51,
	PGMIGRATE_SUCCESS = 52,
	PGMIGRATE_FAIL = 53,
	THP_MIGRATION_SUCCESS = 54,
	THP_MIGRATION_FAIL = 55,
	THP_MIGRATION_SPLIT = 56,
	COMPACTMIGRATE_SCANNED = 57,
	COMPACTFREE_SCANNED = 58,
	COMPACTISOLATED = 59,
	COMPACTSTALL = 60,
	COMPACTFAIL = 61,
	COMPACTSUCCESS = 62,
	KCOMPACTD_WAKE = 63,
	KCOMPACTD_MIGRATE_SCANNED = 64,
	KCOMPACTD_FREE_SCANNED = 65,
	HTLB_BUDDY_PGALLOC = 66,
	HTLB_BUDDY_PGALLOC_FAIL = 67,
	UNEVICTABLE_PGCULLED = 68,
	UNEVICTABLE_PGSCANNED = 69,
	UNEVICTABLE_PGRESCUED = 70,
	UNEVICTABLE_PGMLOCKED = 71,
	UNEVICTABLE_PGMUNLOCKED = 72,
	UNEVICTABLE_PGCLEARED = 73,
	UNEVICTABLE_PGSTRANDED = 74,
	THP_FAULT_ALLOC = 75,
	THP_FAULT_FALLBACK = 76,
	THP_FAULT_FALLBACK_CHARGE = 77,
	THP_COLLAPSE_ALLOC = 78,
	THP_COLLAPSE_ALLOC_FAILED = 79,
	THP_FILE_ALLOC = 80,
	THP_FILE_FALLBACK = 81,
	THP_FILE_FALLBACK_CHARGE = 82,
	THP_FILE_MAPPED = 83,
	THP_SPLIT_PAGE = 84,
	THP_SPLIT_PAGE_FAILED = 85,
	THP_DEFERRED_SPLIT_PAGE = 86,
	THP_SPLIT_PMD = 87,
	THP_SPLIT_PUD = 88,
	THP_ZERO_PAGE_ALLOC = 89,
	THP_ZERO_PAGE_ALLOC_FAILED = 90,
	THP_SWPOUT = 91,
	THP_SWPOUT_FALLBACK = 92,
	BALLOON_INFLATE = 93,
	BALLOON_DEFLATE = 94,
	BALLOON_MIGRATE = 95,
	SWAP_RA = 96,
	SWAP_RA_HIT = 97,
	DIRECT_MAP_LEVEL2_SPLIT = 98,
	DIRECT_MAP_LEVEL3_SPLIT = 99,
	NR_VM_EVENT_ITEMS = 100,
};

struct tlb_context {
	u64 ctx_id;
	u64 tlb_gen;
};

struct tlb_state {
	struct mm_struct *loaded_mm;
	union {
		struct mm_struct *last_user_mm;
		long unsigned int last_user_mm_spec;
	};
	u16 loaded_mm_asid;
	u16 next_asid;
	bool invalidate_other;
	short unsigned int user_pcid_flush_mask;
	long unsigned int cr4;
	struct tlb_context ctxs[6];
};

struct boot_params_to_save {
	unsigned int start;
	unsigned int len;
};

enum cpu_idle_type {
	CPU_IDLE = 0,
	CPU_NOT_IDLE = 1,
	CPU_NEWLY_IDLE = 2,
	CPU_MAX_IDLE_TYPES = 3,
};

enum {
	__SD_BALANCE_NEWIDLE = 0,
	__SD_BALANCE_EXEC = 1,
	__SD_BALANCE_FORK = 2,
	__SD_BALANCE_WAKE = 3,
	__SD_WAKE_AFFINE = 4,
	__SD_ASYM_CPUCAPACITY = 5,
	__SD_ASYM_CPUCAPACITY_FULL = 6,
	__SD_SHARE_CPUCAPACITY = 7,
	__SD_SHARE_PKG_RESOURCES = 8,
	__SD_SERIALIZE = 9,
	__SD_ASYM_PACKING = 10,
	__SD_PREFER_SIBLING = 11,
	__SD_OVERLAP = 12,
	__SD_NUMA = 13,
	__SD_FLAG_CNT = 14,
};

struct x86_legacy_devices {
	int pnpbios;
};

enum x86_legacy_i8042_state {
	X86_LEGACY_I8042_PLATFORM_ABSENT = 0,
	X86_LEGACY_I8042_FIRMWARE_ABSENT = 1,
	X86_LEGACY_I8042_EXPECTED_PRESENT = 2,
};

struct x86_legacy_features {
	enum x86_legacy_i8042_state i8042;
	int rtc;
	int warm_reset;
	int no_vga;
	int reserve_bios_regions;
	struct x86_legacy_devices devices;
};

struct ghcb;

struct x86_hyper_runtime {
	void (*pin_vcpu)(int);
	void (*sev_es_hcall_prepare)(struct ghcb *, struct pt_regs *);
	bool (*sev_es_hcall_finish)(struct ghcb *, struct pt_regs *);
};

struct x86_platform_ops {
	long unsigned int (*calibrate_cpu)();
	long unsigned int (*calibrate_tsc)();
	void (*get_wallclock)(struct timespec64 *);
	int (*set_wallclock)(const struct timespec64 *);
	void (*iommu_shutdown)();
	bool (*is_untracked_pat_range)(u64, u64);
	void (*nmi_init)();
	unsigned char (*get_nmi_reason)();
	void (*save_sched_clock_state)();
	void (*restore_sched_clock_state)();
	void (*apic_post_init)();
	struct x86_legacy_features legacy;
	void (*set_legacy_features)();
	struct x86_hyper_runtime hyper;
};

typedef signed char __s8;

typedef __s8 s8;

typedef __u32 __le32;

typedef long unsigned int irq_hw_number_t;

struct kernel_symbol {
	int value_offset;
	int name_offset;
	int namespace_offset;
};

typedef int (*initcall_t)();

typedef int initcall_entry_t;

struct super_block___2;

struct module___2;

struct file_system_type___2 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___2 * (*mount)(struct file_system_type___2 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___2 *);
	struct module___2 *owner;
	struct file_system_type___2 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct obs_kernel_param {
	const char *str;
	int (*setup_func)(char *);
	int early;
};

struct lockdep_map {};

struct static_key_mod;

struct jump_entry {
	s32 code;
	s32 target;
	long int key;
};

struct static_key {
	atomic_t enabled;
	union {
		long unsigned int type;
		struct jump_entry *entries;
		struct static_key_mod *next;
	};
};

struct static_key_true {
	struct static_key key;
};

struct static_key_false {
	struct static_key key;
};

struct _ddebug {
	const char *modname;
	const char *function;
	const char *filename;
	const char *format;
	unsigned int lineno: 18;
	unsigned int flags: 8;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	union {
		struct static_key_true dd_key_true;
		struct static_key_false dd_key_false;
	} key;
};

struct file___2;

struct kiocb___2;

struct iov_iter___2;

struct poll_table_struct___2;

struct vm_area_struct___2;

struct file_lock___2;

struct page___2;

struct seq_file___2;

struct file_operations___2 {
	struct module___2 *owner;
	loff_t (*llseek)(struct file___2 *, loff_t, int);
	ssize_t (*read)(struct file___2 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___2 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___2 *, struct iov_iter___2 *);
	ssize_t (*write_iter)(struct kiocb___2 *, struct iov_iter___2 *);
	int (*iopoll)(struct kiocb___2 *, bool);
	int (*iterate)(struct file___2 *, struct dir_context *);
	int (*iterate_shared)(struct file___2 *, struct dir_context *);
	__poll_t (*poll)(struct file___2 *, struct poll_table_struct___2 *);
	long int (*unlocked_ioctl)(struct file___2 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___2 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___2 *, struct vm_area_struct___2 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___2 *, struct file___2 *);
	int (*flush)(struct file___2 *, fl_owner_t);
	int (*release)(struct inode___2 *, struct file___2 *);
	int (*fsync)(struct file___2 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___2 *, int);
	int (*lock)(struct file___2 *, int, struct file_lock___2 *);
	ssize_t (*sendpage)(struct file___2 *, struct page___2 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___2 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___2 *, long unsigned int);
	int (*flock)(struct file___2 *, int, struct file_lock___2 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___2 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___2 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___2 *, long int, struct file_lock___2 **, void **);
	long int (*fallocate)(struct file___2 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___2 *, struct file___2 *);
	ssize_t (*copy_file_range)(struct file___2 *, loff_t, struct file___2 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___2 *, loff_t, struct file___2 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___2 *, loff_t, loff_t, int);
};

struct static_call_site {
	s32 addr;
	s32 key;
};

struct static_call_mod {
	struct static_call_mod *next;
	struct module___2 *mod;
	struct static_call_site *sites;
};

struct static_call_key {
	void *func;
	union {
		long unsigned int type;
		struct static_call_mod *mods;
		struct static_call_site *sites;
	};
};

enum system_states {
	SYSTEM_BOOTING = 0,
	SYSTEM_SCHEDULING = 1,
	SYSTEM_RUNNING = 2,
	SYSTEM_HALT = 3,
	SYSTEM_POWER_OFF = 4,
	SYSTEM_RESTART = 5,
	SYSTEM_SUSPEND = 6,
};

typedef struct page___2 *pgtable_t___2;

struct address_space___2;

struct mm_struct___2;

struct dev_pagemap___2;

struct page___2 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___2 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___2 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___2 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___2 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___2 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct task_struct___3;

struct pv_cpu_ops___2 {
	void (*io_delay)();
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	void (*write_cr4)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(long unsigned int);
	void (*invalidate_io_bitmap)();
	void (*update_io_bitmap)();
	void (*wbinvd)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int);
	void (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_msr_safe)(unsigned int, int *);
	int (*write_msr_safe)(unsigned int, unsigned int, unsigned int);
	u64 (*read_pmc)(int);
	void (*start_context_switch)(struct task_struct___3 *);
	void (*end_context_switch)(struct task_struct___3 *);
};

struct vmacache___2 {
	u64 seqnum;
	struct vm_area_struct___2 *vmas[4];
};

struct page_frag___2 {
	struct page___2 *page;
	__u32 offset;
	__u32 size;
};

struct nsproxy___2;

struct signal_struct___2;

struct css_set___2;

struct perf_event_context___2;

struct vm_struct___2;

struct task_struct___3 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___3 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___2 *mm;
	struct mm_struct___2 *active_mm;
	struct vmacache___2 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int restore_sigmask: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___3 *real_parent;
	struct task_struct___3 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___3 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	struct posix_cputimers_work posix_cputimers_work;
	const struct cred *ptracer_cred;
	const struct cred *real_cred;
	const struct cred *cred;
	struct key *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___2 *nsproxy;
	struct signal_struct___2 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___3 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___2 *cgroups;
	struct list_head cg_list;
	u32 closid;
	u32 rmid;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	long: 64;
	long: 64;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___2 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup *active_memcg;
	struct request_queue *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___3 *oom_reaper_list;
	struct vm_struct___2 *stack_vm_area;
	refcount_t stack_refcount;
	int patch_state;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	void *mce_vaddr;
	__u64 mce_kflags;
	u64 mce_addr;
	__u64 mce_ripv: 1;
	__u64 mce_whole_page: 1;
	__u64 __mce_reserved: 62;
	long: 2;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct callback_head mce_kill_me;
	int mce_count;
	struct llist_head kretprobe_instances;
	struct callback_head l1d_flush_kill;
	long: 64;
	struct thread_struct thread;
};

struct flush_tlb_info___2;

struct pv_mmu_ops___2 {
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_one_user)(long unsigned int);
	void (*flush_tlb_multi)(const struct cpumask *, const struct flush_tlb_info___2 *);
	void (*tlb_remove_table)(struct mmu_gather *, void *);
	void (*exit_mmap)(struct mm_struct___2 *);
	struct paravirt_callee_save read_cr2;
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___2 *, struct mm_struct___2 *);
	void (*dup_mmap)(struct mm_struct___2 *, struct mm_struct___2 *);
	int (*pgd_alloc)(struct mm_struct___2 *);
	void (*pgd_free)(struct mm_struct___2 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___2 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___2 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___2 *, long unsigned int);
	void (*alloc_p4d)(struct mm_struct___2 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*release_p4d)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	pte_t (*ptep_modify_prot_start)(struct vm_area_struct___2 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct vm_area_struct___2 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_p4d)(p4d_t *, p4d_t);
	struct paravirt_callee_save p4d_val;
	struct paravirt_callee_save make_p4d;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

struct flush_tlb_info___2 {
	struct mm_struct___2 *mm;
	long unsigned int start;
	long unsigned int end;
	u64 new_tlb_gen;
	unsigned int initiating_cpu;
	u8 stride_shift;
	u8 freed_tables;
};

struct core_state___2;

struct mm_struct___2 {
	struct {
		struct vm_area_struct___2 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___2 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int mmap_compat_base;
		long unsigned int mmap_compat_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[48];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___2 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___3 *owner;
		struct user_namespace *user_ns;
		struct file___2 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		bool tlb_flush_batched;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct vm_operations_struct___2;

struct vm_area_struct___2 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___2 *vm_next;
	struct vm_area_struct___2 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___2 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___2 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___2 *vm_file;
	struct file___2 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct paravirt_patch_template___2 {
	struct pv_cpu_ops___2 cpu;
	struct pv_irq_ops irq;
	struct pv_mmu_ops___2 mmu;
	struct pv_lock_ops lock;
};

struct bug_entry {
	int bug_addr_disp;
	int file_disp;
	short unsigned int line;
	short unsigned int flags;
};

typedef struct cpumask *cpumask_var_t;

struct tracepoint_func {
	void *func;
	void *data;
	int prio;
};

struct tracepoint {
	const char *name;
	struct static_key key;
	struct static_call_key *static_call_key;
	void *static_call_tramp;
	void *iterator;
	int (*regfunc)();
	void (*unregfunc)();
	struct tracepoint_func *funcs;
};

typedef const int tracepoint_ptr_t;

struct bpf_raw_event_map {
	struct tracepoint *tp;
	void *bpf_func;
	u32 num_args;
	u32 writable_size;
	long: 64;
};

struct seq_operations {
	void * (*start)(struct seq_file___2 *, loff_t *);
	void (*stop)(struct seq_file___2 *, void *);
	void * (*next)(struct seq_file___2 *, void *, loff_t *);
	int (*show)(struct seq_file___2 *, void *);
};

struct fixed_percpu_data {
	char gs_base[40];
	long unsigned int stack_canary;
};

enum perf_event_state {
	PERF_EVENT_STATE_DEAD = 4294967292,
	PERF_EVENT_STATE_EXIT = 4294967293,
	PERF_EVENT_STATE_ERROR = 4294967294,
	PERF_EVENT_STATE_OFF = 4294967295,
	PERF_EVENT_STATE_INACTIVE = 0,
	PERF_EVENT_STATE_ACTIVE = 1,
};

typedef struct {
	atomic_long_t a;
} local_t;

typedef struct {
	local_t a;
} local64_t;

struct perf_event_attr {
	__u32 type;
	__u32 size;
	__u64 config;
	union {
		__u64 sample_period;
		__u64 sample_freq;
	};
	__u64 sample_type;
	__u64 read_format;
	__u64 disabled: 1;
	__u64 inherit: 1;
	__u64 pinned: 1;
	__u64 exclusive: 1;
	__u64 exclude_user: 1;
	__u64 exclude_kernel: 1;
	__u64 exclude_hv: 1;
	__u64 exclude_idle: 1;
	__u64 mmap: 1;
	__u64 comm: 1;
	__u64 freq: 1;
	__u64 inherit_stat: 1;
	__u64 enable_on_exec: 1;
	__u64 task: 1;
	__u64 watermark: 1;
	__u64 precise_ip: 2;
	__u64 mmap_data: 1;
	__u64 sample_id_all: 1;
	__u64 exclude_host: 1;
	__u64 exclude_guest: 1;
	__u64 exclude_callchain_kernel: 1;
	__u64 exclude_callchain_user: 1;
	__u64 mmap2: 1;
	__u64 comm_exec: 1;
	__u64 use_clockid: 1;
	__u64 context_switch: 1;
	__u64 write_backward: 1;
	__u64 namespaces: 1;
	__u64 ksymbol: 1;
	__u64 bpf_event: 1;
	__u64 aux_output: 1;
	__u64 cgroup: 1;
	__u64 text_poke: 1;
	__u64 build_id: 1;
	__u64 inherit_thread: 1;
	__u64 remove_on_exec: 1;
	__u64 sigtrap: 1;
	__u64 __reserved_1: 26;
	long: 38;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	union {
		__u32 wakeup_events;
		__u32 wakeup_watermark;
	};
	__u32 bp_type;
	union {
		__u64 bp_addr;
		__u64 kprobe_func;
		__u64 uprobe_path;
		__u64 config1;
	};
	union {
		__u64 bp_len;
		__u64 kprobe_addr;
		__u64 probe_offset;
		__u64 config2;
	};
	__u64 branch_sample_type;
	__u64 sample_regs_user;
	__u32 sample_stack_user;
	__s32 clockid;
	__u64 sample_regs_intr;
	__u32 aux_watermark;
	__u16 sample_max_stack;
	__u16 __reserved_2;
	__u32 aux_sample_size;
	__u32 __reserved_3;
	__u64 sig_data;
};

struct hw_perf_event_extra {
	u64 config;
	unsigned int reg;
	int alloc;
	int idx;
};

struct arch_hw_breakpoint {
	long unsigned int address;
	long unsigned int mask;
	u8 len;
	u8 type;
};

struct hw_perf_event {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___3 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	union {
		struct {
			u64 last_period;
			local64_t period_left;
		};
		struct {
			u64 saved_metric;
			u64 saved_slots;
		};
	};
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

struct perf_buffer;

struct irq_work {
	struct __call_single_node node;
	void (*func)(struct irq_work *);
};

struct perf_addr_filters_head {
	struct list_head list;
	raw_spinlock_t lock;
	unsigned int nr_file_filters;
};

struct perf_sample_data;

typedef void (*perf_overflow_handler_t)(struct perf_event *, struct perf_sample_data *, struct pt_regs *);

struct event_filter;

struct ftrace_ops;

struct ftrace_regs;

typedef void (*ftrace_func_t)(long unsigned int, long unsigned int, struct ftrace_ops *, struct ftrace_regs *);

struct ftrace_hash;

struct ftrace_ops_hash {
	struct ftrace_hash *notrace_hash;
	struct ftrace_hash *filter_hash;
	struct mutex regex_lock;
};

struct ftrace_ops {
	ftrace_func_t func;
	struct ftrace_ops *next;
	long unsigned int flags;
	void *private;
	ftrace_func_t saved_func;
	struct ftrace_ops_hash local_hash;
	struct ftrace_ops_hash *func_hash;
	struct ftrace_ops_hash old_hash;
	long unsigned int trampoline;
	long unsigned int trampoline_size;
	struct list_head list;
};

struct pmu;

struct fasync_struct___2;

struct perf_addr_filter_range;

struct bpf_prog;

struct trace_event_call;

struct perf_cgroup;

struct perf_event {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event *group_leader;
	struct pmu *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event hw;
	struct perf_event_context___2 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___3 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct perf_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___2 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	long unsigned int pending_addr;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	struct perf_addr_filter_range *addr_filter_ranges;
	long unsigned int addr_filters_gen;
	struct perf_event *aux_event;
	void (*destroy)(struct perf_event *);
	struct callback_head callback_head;
	struct pid_namespace *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t orig_overflow_handler;
	struct bpf_prog *prog;
	u64 bpf_cookie;
	struct trace_event_call *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup *cgrp;
	void *security;
	struct list_head sb_list;
};

struct uid_gid_extent {
	u32 first;
	u32 lower_first;
	u32 count;
};

struct uid_gid_map {
	u32 nr_extents;
	union {
		struct uid_gid_extent extent[5];
		struct {
			struct uid_gid_extent *forward;
			struct uid_gid_extent *reverse;
		};
	};
};

struct proc_ns_operations;

struct ns_common {
	atomic_long_t stashed;
	const struct proc_ns_operations *ops;
	unsigned int inum;
	refcount_t count;
};

struct ctl_table;

struct ctl_table_root;

struct ctl_table_set;

struct ctl_dir;

struct ctl_node;

struct ctl_table_header {
	union {
		struct {
			struct ctl_table *ctl_table;
			int used;
			int count;
			int nreg;
		};
		struct callback_head rcu;
	};
	struct completion *unregistering;
	struct ctl_table *ctl_table_arg;
	struct ctl_table_root *root;
	struct ctl_table_set *set;
	struct ctl_dir *parent;
	struct ctl_node *node;
	struct hlist_head inodes;
};

struct ctl_dir {
	struct ctl_table_header header;
	struct rb_root root;
};

struct ctl_table_set {
	int (*is_seen)(struct ctl_table_set *);
	struct ctl_dir dir;
};

struct user_namespace {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	struct user_namespace *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common ns;
	long unsigned int flags;
	bool parent_could_setfcap;
	struct list_head keyring_name_list;
	struct key *user_keyring_register;
	struct rw_semaphore keyring_sem;
	struct key *persistent_keyring_register;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts *ucounts;
	long int ucount_max[16];
};

struct pollfd {
	int fd;
	short int events;
	short int revents;
};

typedef void (*smp_call_func_t)(void *);

struct __call_single_data {
	struct __call_single_node node;
	smp_call_func_t func;
	void *info;
};

struct smp_ops {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*crash_stop_other_cpus)();
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___3 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct wait_queue_entry;

typedef int (*wait_queue_func_t)(struct wait_queue_entry *, unsigned int, int, void *);

struct wait_queue_entry {
	unsigned int flags;
	void *private;
	wait_queue_func_t func;
	struct list_head entry;
};

typedef struct wait_queue_entry wait_queue_entry_t;

struct timer_list {
	struct hlist_node entry;
	long unsigned int expires;
	void (*function)(struct timer_list *);
	u32 flags;
};

struct delayed_work {
	struct work_struct work;
	struct timer_list timer;
	struct workqueue_struct *wq;
	int cpu;
};

struct rcu_work {
	struct work_struct work;
	struct callback_head rcu;
	struct workqueue_struct *wq;
};

struct rcu_segcblist {
	struct callback_head *head;
	struct callback_head **tails[4];
	long unsigned int gp_seq[4];
	long int len;
	long int seglen[4];
	u8 flags;
};

struct srcu_node;

struct srcu_struct;

struct srcu_data {
	long unsigned int srcu_lock_count[2];
	long unsigned int srcu_unlock_count[2];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t lock;
	struct rcu_segcblist srcu_cblist;
	long unsigned int srcu_gp_seq_needed;
	long unsigned int srcu_gp_seq_needed_exp;
	bool srcu_cblist_invoking;
	struct timer_list delay_work;
	struct work_struct work;
	struct callback_head srcu_barrier_head;
	struct srcu_node *mynode;
	long unsigned int grpmask;
	int cpu;
	struct srcu_struct *ssp;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct srcu_node {
	spinlock_t lock;
	long unsigned int srcu_have_cbs[4];
	long unsigned int srcu_data_have_cbs[4];
	long unsigned int srcu_gp_seq_needed_exp;
	struct srcu_node *srcu_parent;
	int grplo;
	int grphi;
};

struct srcu_struct {
	struct srcu_node node[521];
	struct srcu_node *level[4];
	struct mutex srcu_cb_mutex;
	spinlock_t lock;
	struct mutex srcu_gp_mutex;
	unsigned int srcu_idx;
	long unsigned int srcu_gp_seq;
	long unsigned int srcu_gp_seq_needed;
	long unsigned int srcu_gp_seq_needed_exp;
	long unsigned int srcu_last_gp_end;
	struct srcu_data *sda;
	long unsigned int srcu_barrier_seq;
	struct mutex srcu_barrier_mutex;
	struct completion srcu_barrier_completion;
	atomic_t srcu_barrier_cpu_cnt;
	struct delayed_work work;
	struct lockdep_map dep_map;
};

struct ldt_struct {
	struct desc_struct *entries;
	unsigned int nr_entries;
	int slot;
};

struct address_space_operations___2;

struct address_space___2 {
	struct inode___2 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___2 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct dev_pagemap_ops___2;

struct dev_pagemap___2 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___2 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vfsmount___2;

struct path___2 {
	struct vfsmount___2 *mnt;
	struct dentry___2 *dentry;
};

struct file___2 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	long: 64;
	long: 64;
	struct path___2 f_path;
	struct inode___2 *f_inode;
	const struct file_operations___2 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct f_owner;
	const struct cred *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___2 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct anon_vma {
	struct anon_vma *root;
	struct rw_semaphore rwsem;
	atomic_t refcount;
	unsigned int degree;
	struct anon_vma *parent;
	struct rb_root_cached rb_root;
};

struct vm_fault___2;

struct vm_operations_struct___2 {
	void (*open)(struct vm_area_struct___2 *);
	void (*close)(struct vm_area_struct___2 *);
	int (*may_split)(struct vm_area_struct___2 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___2 *);
	int (*mprotect)(struct vm_area_struct___2 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___2 *);
	vm_fault_t (*huge_fault)(struct vm_fault___2 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___2 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___2 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___2 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___2 *);
	int (*access)(struct vm_area_struct___2 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___2 *);
	int (*set_policy)(struct vm_area_struct___2 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___2 *, long unsigned int);
	struct page___2 * (*find_special_page)(struct vm_area_struct___2 *, long unsigned int);
};

struct mempolicy {
	atomic_t refcnt;
	short unsigned int mode;
	short unsigned int flags;
	nodemask_t nodes;
	union {
		nodemask_t cpuset_mems_allowed;
		nodemask_t user_nodemask;
	} w;
};

struct core_thread___2 {
	struct task_struct___3 *task;
	struct core_thread___2 *next;
};

struct core_state___2 {
	atomic_t nr_threads;
	struct core_thread___2 dumper;
	struct completion startup;
};

struct linux_binprm;

struct coredump_params;

struct linux_binfmt {
	struct list_head lh;
	struct module___2 *module;
	int (*load_binary)(struct linux_binprm *);
	int (*load_shlib)(struct file___2 *);
	int (*core_dump)(struct coredump_params *);
	long unsigned int min_coredump;
};

struct vm_fault___2 {
	const struct {
		struct vm_area_struct___2 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___2 *cow_page;
	struct page___2 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___2 prealloc_pte;
};

struct free_area {
	struct list_head free_list[5];
	long unsigned int nr_free;
};

struct zone_padding {
	char x[0];
};

struct pglist_data;

struct lruvec {
	struct list_head lists[5];
	spinlock_t lru_lock;
	long unsigned int anon_cost;
	long unsigned int file_cost;
	atomic_long_t nonresident_age;
	long unsigned int refaults[2];
	long unsigned int flags;
	struct pglist_data *pgdat;
};

struct per_cpu_pages;

struct per_cpu_zonestat;

struct zone {
	long unsigned int _watermark[3];
	long unsigned int watermark_boost;
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[5];
	int node;
	struct pglist_data *zone_pgdat;
	struct per_cpu_pages *per_cpu_pageset;
	struct per_cpu_zonestat *per_cpu_zonestats;
	int pageset_high;
	int pageset_batch;
	long unsigned int zone_start_pfn;
	atomic_long_t managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int present_early_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	seqlock_t span_seqlock;
	int initialized;
	int: 32;
	struct zone_padding _pad1_;
	struct free_area free_area[11];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	long unsigned int compact_init_migrate_pfn;
	long unsigned int compact_init_free_pfn;
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	short: 16;
	struct zone_padding _pad3_;
	atomic_long_t vm_stat[11];
	atomic_long_t vm_numa_event[6];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref {
	struct zone *zone;
	int zone_idx;
};

struct zonelist {
	struct zoneref _zonerefs[5121];
};

enum zone_type {
	ZONE_DMA = 0,
	ZONE_DMA32 = 1,
	ZONE_NORMAL = 2,
	ZONE_MOVABLE = 3,
	ZONE_DEVICE = 4,
	__MAX_NR_ZONES = 5,
};

struct deferred_split {
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
};

struct per_cpu_nodestat;

struct pglist_data {
	struct zone node_zones[5];
	struct zonelist node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___3 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_highest_zoneidx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_highest_zoneidx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___3 *kcompactd;
	bool proactive_compact_trigger;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct deferred_split deferred_split_queue;
	struct lruvec __lruvec;
	long unsigned int flags;
	long: 64;
	struct zone_padding _pad2_;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[39];
};

struct per_cpu_pages {
	int count;
	int high;
	int batch;
	short int free_factor;
	short int expire;
	struct list_head lists[15];
};

struct per_cpu_zonestat {
	s8 vm_stat_diff[11];
	s8 stat_threshold;
	long unsigned int vm_numa_event[6];
};

struct per_cpu_nodestat {
	s8 stat_threshold;
	s8 vm_node_stat_diff[39];
};

typedef struct pglist_data pg_data_t;

enum irq_domain_bus_token {
	DOMAIN_BUS_ANY = 0,
	DOMAIN_BUS_WIRED = 1,
	DOMAIN_BUS_GENERIC_MSI = 2,
	DOMAIN_BUS_PCI_MSI = 3,
	DOMAIN_BUS_PLATFORM_MSI = 4,
	DOMAIN_BUS_NEXUS = 5,
	DOMAIN_BUS_IPI = 6,
	DOMAIN_BUS_FSL_MC_MSI = 7,
	DOMAIN_BUS_TI_SCI_INTA_MSI = 8,
	DOMAIN_BUS_WAKEUP = 9,
	DOMAIN_BUS_VMD_MSI = 10,
};

struct irq_domain_ops;

struct fwnode_handle;

struct irq_domain_chip_generic;

struct irq_data;

struct irq_domain {
	struct list_head link;
	const char *name;
	const struct irq_domain_ops *ops;
	void *host_data;
	unsigned int flags;
	unsigned int mapcount;
	struct fwnode_handle *fwnode;
	enum irq_domain_bus_token bus_token;
	struct irq_domain_chip_generic *gc;
	struct irq_domain *parent;
	irq_hw_number_t hwirq_max;
	unsigned int revmap_size;
	struct xarray revmap_tree;
	struct mutex revmap_mutex;
	struct irq_data *revmap[0];
};

typedef int proc_handler(struct ctl_table *, int, void *, size_t *, loff_t *);

struct ctl_table_poll;

struct ctl_table {
	const char *procname;
	void *data;
	int maxlen;
	umode_t mode;
	struct ctl_table *child;
	proc_handler *proc_handler;
	struct ctl_table_poll *poll;
	void *extra1;
	void *extra2;
};

struct ctl_table_poll {
	atomic_t event;
	wait_queue_head_t wait;
};

struct ctl_node {
	struct rb_node node;
	struct ctl_table_header *header;
};

struct ctl_table_root {
	struct ctl_table_set default_set;
	struct ctl_table_set * (*lookup)(struct ctl_table_root *);
	void (*set_ownership)(struct ctl_table_header *, struct ctl_table *, kuid_t *, kgid_t *);
	int (*permissions)(struct ctl_table_header *, struct ctl_table *);
};

typedef __u64 Elf64_Addr;

typedef __u16 Elf64_Half;

typedef __u64 Elf64_Off;

typedef __u32 Elf64_Word;

typedef __u64 Elf64_Xword;

struct elf64_sym {
	Elf64_Word st_name;
	unsigned char st_info;
	unsigned char st_other;
	Elf64_Half st_shndx;
	Elf64_Addr st_value;
	Elf64_Xword st_size;
};

typedef struct elf64_sym Elf64_Sym;

struct elf64_hdr {
	unsigned char e_ident[16];
	Elf64_Half e_type;
	Elf64_Half e_machine;
	Elf64_Word e_version;
	Elf64_Addr e_entry;
	Elf64_Off e_phoff;
	Elf64_Off e_shoff;
	Elf64_Word e_flags;
	Elf64_Half e_ehsize;
	Elf64_Half e_phentsize;
	Elf64_Half e_phnum;
	Elf64_Half e_shentsize;
	Elf64_Half e_shnum;
	Elf64_Half e_shstrndx;
};

typedef struct elf64_hdr Elf64_Ehdr;

struct elf64_shdr {
	Elf64_Word sh_name;
	Elf64_Word sh_type;
	Elf64_Xword sh_flags;
	Elf64_Addr sh_addr;
	Elf64_Off sh_offset;
	Elf64_Xword sh_size;
	Elf64_Word sh_link;
	Elf64_Word sh_info;
	Elf64_Xword sh_addralign;
	Elf64_Xword sh_entsize;
};

typedef struct elf64_shdr Elf64_Shdr;

struct idr {
	struct xarray idr_rt;
	unsigned int idr_base;
	unsigned int idr_next;
};

struct kernfs_root;

struct kernfs_elem_dir {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root *root;
	long unsigned int rev;
};

struct kernfs_node;

struct kernfs_syscall_ops;

struct kernfs_root {
	struct kernfs_node *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink {
	struct kernfs_node *target_kn;
};

struct kernfs_open_node;

struct kernfs_ops;

struct kernfs_elem_attr {
	const struct kernfs_ops *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node *notify_next;
};

struct kernfs_iattrs;

struct kernfs_node {
	atomic_t count;
	atomic_t active;
	struct kernfs_node *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir dir;
		struct kernfs_elem_symlink symlink;
		struct kernfs_elem_attr attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file;

struct kernfs_ops {
	int (*open)(struct kernfs_open_file *);
	void (*release)(struct kernfs_open_file *);
	int (*seq_show)(struct seq_file___2 *, void *);
	void * (*seq_start)(struct seq_file___2 *, loff_t *);
	void * (*seq_next)(struct seq_file___2 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___2 *, void *);
	ssize_t (*read)(struct kernfs_open_file *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file *, struct poll_table_struct___2 *);
	int (*mmap)(struct kernfs_open_file *, struct vm_area_struct___2 *);
};

struct kernfs_syscall_ops {
	int (*show_options)(struct seq_file___2 *, struct kernfs_root *);
	int (*mkdir)(struct kernfs_node *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node *);
	int (*rename)(struct kernfs_node *, struct kernfs_node *, const char *);
	int (*show_path)(struct seq_file___2 *, struct kernfs_node *, struct kernfs_root *);
};

struct seq_file___2 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations *op;
	int poll_event;
	const struct file___2 *file;
	void *private;
};

struct kernfs_open_file {
	struct kernfs_node *kn;
	struct file___2 *file;
	struct seq_file___2 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___2 *vm_ops;
};

typedef void (*poll_queue_proc)(struct file___2 *, wait_queue_head_t *, struct poll_table_struct___2 *);

struct poll_table_struct___2 {
	poll_queue_proc _qproc;
	__poll_t _key;
};

enum kobj_ns_type {
	KOBJ_NS_TYPE_NONE = 0,
	KOBJ_NS_TYPE_NET = 1,
	KOBJ_NS_TYPES = 2,
};

struct sock;

struct kobj_ns_type_operations {
	enum kobj_ns_type type;
	bool (*current_may_mount)();
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

struct attribute {
	const char *name;
	umode_t mode;
};

struct kobject;

struct bin_attribute;

struct attribute_group {
	const char *name;
	umode_t (*is_visible)(struct kobject *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject *, struct bin_attribute *, int);
	struct attribute **attrs;
	struct bin_attribute **bin_attrs;
};

struct kref {
	refcount_t refcount;
};

struct kset;

struct kobj_type;

struct kobject {
	const char *name;
	struct list_head entry;
	struct kobject *parent;
	struct kset *kset;
	struct kobj_type *ktype;
	struct kernfs_node *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bin_attribute {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___2 * (*f_mapping)();
	ssize_t (*read)(struct file___2 *, struct kobject *, struct bin_attribute *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___2 *, struct kobject *, struct bin_attribute *, char *, loff_t, size_t);
	int (*mmap)(struct file___2 *, struct kobject *, struct bin_attribute *, struct vm_area_struct___2 *);
};

struct sysfs_ops {
	ssize_t (*show)(struct kobject *, struct attribute *, char *);
	ssize_t (*store)(struct kobject *, struct attribute *, const char *, size_t);
};

enum refcount_saturation_type {
	REFCOUNT_ADD_NOT_ZERO_OVF = 0,
	REFCOUNT_ADD_OVF = 1,
	REFCOUNT_ADD_UAF = 2,
	REFCOUNT_SUB_UAF = 3,
	REFCOUNT_DEC_LEAK = 4,
};

struct kset_uevent_ops;

struct kset {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject kobj;
	const struct kset_uevent_ops *uevent_ops;
};

struct kobj_type {
	void (*release)(struct kobject *);
	const struct sysfs_ops *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group **default_groups;
	const struct kobj_ns_type_operations * (*child_ns_type)(struct kobject *);
	const void * (*namespace)(struct kobject *);
	void (*get_ownership)(struct kobject *, kuid_t *, kgid_t *);
};

struct kobj_uevent_env {
	char *argv[3];
	char *envp[64];
	int envp_idx;
	char buf[2048];
	int buflen;
};

struct kset_uevent_ops {
	int (* const filter)(struct kset *, struct kobject *);
	const char * (* const name)(struct kset *, struct kobject *);
	int (* const uevent)(struct kset *, struct kobject *, struct kobj_uevent_env *);
};

struct kernel_param;

struct kernel_param_ops {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param *);
	int (*get)(char *, const struct kernel_param *);
	void (*free)(void *);
};

struct kparam_string;

struct kparam_array;

struct kernel_param {
	const char *name;
	struct module___2 *mod;
	const struct kernel_param_ops *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array *arr;
	};
};

struct kparam_string {
	unsigned int maxlen;
	char *string;
};

struct kparam_array {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops *ops;
	void *elem;
};

enum module_state {
	MODULE_STATE_LIVE = 0,
	MODULE_STATE_COMING = 1,
	MODULE_STATE_GOING = 2,
	MODULE_STATE_UNFORMED = 3,
};

struct module_param_attrs;

struct module_kobject {
	struct kobject kobj;
	struct module___2 *mod;
	struct kobject *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct latch_tree_node {
	struct rb_node node[2];
};

struct mod_tree_node {
	struct module___2 *mod;
	struct latch_tree_node node;
};

struct module_layout {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node mtn;
};

struct mod_arch_specific {};

struct mod_kallsyms {
	Elf64_Sym *symtab;
	unsigned int num_symtab;
	char *strtab;
	char *typetab;
};

struct module_sect_attrs;

struct module_notes_attrs;

struct module_attribute;

struct exception_table_entry;

struct trace_eval_map;

struct klp_modinfo;

struct error_injection_entry;

struct module___2 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject mkobj;
	struct module_attribute *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout core_layout;
	struct module_layout init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	int num_static_call_sites;
	struct static_call_site *static_call_sites;
	bool klp;
	bool klp_alive;
	struct klp_modinfo *klp_info;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct error_injection_entry {
	long unsigned int addr;
	int etype;
};

struct module_attribute {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute *, struct module_kobject *, char *);
	ssize_t (*store)(struct module_attribute *, struct module_kobject *, const char *, size_t);
	void (*setup)(struct module___2 *, const char *);
	int (*test)(struct module___2 *);
	void (*free)(struct module___2 *);
};

struct klp_modinfo {
	Elf64_Ehdr hdr;
	Elf64_Shdr *sechdrs;
	char *secstrings;
	unsigned int symndx;
};

struct exception_table_entry {
	int insn;
	int fixup;
	int type;
};

struct trace_event_functions;

struct trace_event {
	struct hlist_node node;
	struct list_head list;
	int type;
	struct trace_event_functions *funcs;
};

struct trace_event_class;

struct bpf_prog_array;

struct trace_event_call {
	struct list_head list;
	struct trace_event_class *class;
	union {
		char *name;
		struct tracepoint *tp;
	};
	struct trace_event event;
	char *print_fmt;
	struct event_filter *filter;
	union {
		void *module;
		atomic_t refcnt;
	};
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
	struct bpf_prog_array *prog_array;
	int (*perf_perm)(struct trace_event_call *, struct perf_event *);
};

struct trace_eval_map {
	const char *system;
	const char *eval_string;
	long unsigned int eval_value;
};

struct dentry_operations___2;

struct dentry___2 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___2 *d_parent;
	struct qstr d_name;
	struct inode___2 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___2 *d_op;
	struct super_block___2 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___2;

struct inode___2 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___2 *i_op;
	struct super_block___2 *i_sb;
	struct address_space___2 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	long: 64;
	long: 64;
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___2 *i_fop;
		void (*free_inode)(struct inode___2 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___2 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct cdev *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___2 {
	int (*d_revalidate)(struct dentry___2 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___2 *, unsigned int);
	int (*d_hash)(const struct dentry___2 *, struct qstr *);
	int (*d_compare)(const struct dentry___2 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___2 *);
	int (*d_init)(struct dentry___2 *);
	void (*d_release)(struct dentry___2 *);
	void (*d_prune)(struct dentry___2 *);
	void (*d_iput)(struct dentry___2 *, struct inode___2 *);
	char * (*d_dname)(struct dentry___2 *, char *, int);
	struct vfsmount___2 * (*d_automount)(struct path___2 *);
	int (*d_manage)(const struct path___2 *, bool);
	struct dentry___2 * (*d_real)(struct dentry___2 *, const struct inode___2 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___2;

struct mem_dqinfo___2 {
	struct quota_format_type___2 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___2;

struct quota_info___2 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___2 *files[3];
	struct mem_dqinfo___2 info[3];
	const struct quota_format_ops___2 *ops[3];
};

struct rcuwait___2 {
	struct task_struct___3 *task;
};

struct percpu_rw_semaphore___2 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___2 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___2 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___2 rw_sem[3];
};

struct super_operations___2;

struct dquot_operations___2;

struct quotactl_ops___2;

struct super_block___2 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___2 *s_type;
	const struct super_operations___2 *s_op;
	const struct dquot_operations___2 *dq_op;
	const struct quotactl_ops___2 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___2 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device *s_bdev;
	struct backing_dev_info *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___2 s_dquot;
	struct sb_writers___2 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___2 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___2 {
	struct dentry___2 *mnt_root;
	struct super_block___2 *mnt_sb;
	int mnt_flags;
	struct user_namespace *mnt_userns;
};

struct cgroup;

struct cgroup_subsys;

struct cgroup_subsys_state {
	struct cgroup *cgroup;
	struct cgroup_subsys *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state *parent;
};

struct mem_cgroup_id {
	int id;
	refcount_t ref;
};

struct page_counter {
	atomic_long_t usage;
	long unsigned int min;
	long unsigned int low;
	long unsigned int high;
	long unsigned int max;
	long unsigned int emin;
	atomic_long_t min_usage;
	atomic_long_t children_min_usage;
	long unsigned int elow;
	atomic_long_t low_usage;
	atomic_long_t children_low_usage;
	long unsigned int watermark;
	long unsigned int failcnt;
	struct page_counter *parent;
};

struct vmpressure {
	long unsigned int scanned;
	long unsigned int reclaimed;
	long unsigned int tree_scanned;
	long unsigned int tree_reclaimed;
	spinlock_t sr_lock;
	struct list_head events;
	struct mutex events_lock;
	struct work_struct work;
};

struct cgroup_file {
	struct kernfs_node *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct mem_cgroup_threshold_ary;

struct mem_cgroup_thresholds {
	struct mem_cgroup_threshold_ary *primary;
	struct mem_cgroup_threshold_ary *spare;
};

struct memcg_padding {
	char x[0];
};

struct memcg_vmstats {
	long int state[42];
	long unsigned int events[100];
	long int state_pending[42];
	long unsigned int events_pending[100];
};

enum memcg_kmem_state {
	KMEM_NONE = 0,
	KMEM_ALLOCATED = 1,
	KMEM_ONLINE = 2,
};

struct fprop_global {
	struct percpu_counter events;
	unsigned int period;
	seqcount_t sequence;
};

struct wb_domain {
	spinlock_t lock;
	struct fprop_global completions;
	struct timer_list period_timer;
	long unsigned int period_time;
	long unsigned int dirty_limit_tstamp;
	long unsigned int dirty_limit;
};

struct wb_completion {
	atomic_t cnt;
	wait_queue_head_t *waitq;
};

struct memcg_cgwb_frn {
	u64 bdi_id;
	int memcg_id;
	u64 at;
	struct wb_completion done;
};

struct obj_cgroup;

struct memcg_vmstats_percpu;

struct mem_cgroup_per_node;

struct mem_cgroup {
	struct cgroup_subsys_state css;
	struct mem_cgroup_id id;
	struct page_counter memory;
	union {
		struct page_counter swap;
		struct page_counter memsw;
	};
	struct page_counter kmem;
	struct page_counter tcpmem;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool oom_group;
	bool oom_lock;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file events_file;
	struct cgroup_file events_local_file;
	struct cgroup_file swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	struct memcg_vmstats vmstats;
	atomic_long_t memory_events[8];
	atomic_long_t memory_events_local[8];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct obj_cgroup *objcg;
	struct list_head objcg_list;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad2_;
	atomic_t moving_account;
	struct task_struct___3 *move_lock_task;
	struct memcg_vmstats_percpu *vmstats_percpu;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct memcg_cgwb_frn cgwb_frn[4];
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct deferred_split deferred_split_queue;
	struct mem_cgroup_per_node *nodeinfo[0];
	long: 64;
};

struct fs_pin;

struct pid_namespace {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___3 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace *parent;
	struct fs_pin *bacct;
	struct user_namespace *user_ns;
	struct ucounts *ucounts;
	int reboot;
	struct ns_common ns;
};

struct ucounts {
	struct hlist_node node;
	struct user_namespace *ns;
	kuid_t uid;
	atomic_t count;
	atomic_long_t ucount[16];
};

struct task_cputime {
	u64 stime;
	u64 utime;
	long long unsigned int sum_exec_runtime;
};

struct signal_struct___2 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___3 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___3 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid *pids[4];
	struct pid *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___2 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct mnt_namespace;

struct uts_namespace;

struct ipc_namespace;

struct net;

struct time_namespace;

struct cgroup_namespace;

struct nsproxy___2 {
	atomic_t count;
	struct uts_namespace *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace *pid_ns_for_children;
	struct net *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace *cgroup_ns;
};

struct bio;

struct bio_list {
	struct bio *head;
	struct bio *tail;
};

struct blk_plug {
	struct list_head mq_list;
	struct list_head cb_list;
	short unsigned int rq_count;
	bool multiple_queues;
	bool nowait;
};

struct reclaim_state {
	long unsigned int reclaimed_slab;
};

struct fprop_local_percpu {
	struct percpu_counter events;
	unsigned int period;
	raw_spinlock_t lock;
};

enum wb_reason {
	WB_REASON_BACKGROUND = 0,
	WB_REASON_VMSCAN = 1,
	WB_REASON_SYNC = 2,
	WB_REASON_PERIODIC = 3,
	WB_REASON_LAPTOP_TIMER = 4,
	WB_REASON_FS_FREE_SPACE = 5,
	WB_REASON_FORKER_THREAD = 6,
	WB_REASON_FOREIGN_FLUSH = 7,
	WB_REASON_MAX = 8,
};

struct bdi_writeback {
	struct backing_dev_info *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	atomic_t writeback_inodes;
	struct percpu_counter stat[4];
	long unsigned int congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	struct delayed_work bw_dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state *memcg_css;
	struct cgroup_subsys_state *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	struct list_head b_attached;
	struct list_head offline_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
};

struct device;

struct backing_dev_info {
	u64 id;
	struct rb_node rb_node;
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct mutex cgwb_release_mutex;
	struct rw_semaphore wb_switch_rwsem;
	wait_queue_head_t wb_waitq;
	struct device *dev;
	char dev_name[64];
	struct device *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___2 *debug_dir;
};

struct css_set___2 {
	struct cgroup_subsys_state *subsys[14];
	refcount_t refcount;
	struct css_set___2 *dom_cset;
	struct cgroup *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup *mg_src_cgrp;
	struct cgroup *mg_dst_cgrp;
	struct css_set___2 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

typedef u32 compat_uptr_t;

struct compat_robust_list {
	compat_uptr_t next;
};

typedef s32 compat_long_t;

struct compat_robust_list_head {
	struct compat_robust_list list;
	compat_long_t futex_offset;
	compat_uptr_t list_op_pending;
};

struct perf_event_groups {
	struct rb_root tree;
	u64 index;
};

struct perf_event_context___2 {
	struct pmu *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	int rotate_necessary;
	refcount_t refcount;
	struct task_struct___3 *task;
	u64 time;
	u64 timestamp;
	u64 timeoffset;
	struct perf_event_context___2 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

struct task_delay_info {
	raw_spinlock_t lock;
	unsigned int flags;
	u64 blkio_start;
	u64 blkio_delay;
	u64 swapin_delay;
	u32 blkio_count;
	u32 swapin_count;
	u64 freepages_start;
	u64 freepages_delay;
	u64 thrashing_start;
	u64 thrashing_delay;
	u32 freepages_count;
	u32 thrashing_count;
};

struct ftrace_ret_stack {
	long unsigned int ret;
	long unsigned int func;
	long long unsigned int calltime;
	long long unsigned int subtime;
	long unsigned int *retp;
};

struct blk_queue_stats;

struct rq_qos;

struct blk_mq_ops;

struct blk_mq_ctx;

struct blk_mq_hw_ctx;

struct blk_integrity_profile;

struct blk_integrity {
	const struct blk_integrity_profile *profile;
	unsigned char flags;
	unsigned char tuple_size;
	unsigned char interval_exp;
	unsigned char tag_size;
};

enum rpm_status {
	RPM_ACTIVE = 0,
	RPM_RESUMING = 1,
	RPM_SUSPENDED = 2,
	RPM_SUSPENDING = 3,
};

struct blk_keyslot_manager;

struct blk_stat_callback;

struct blk_rq_stat {
	u64 mean;
	u64 min;
	u64 max;
	u32 nr_samples;
	u64 batch;
};

struct sbitmap_word;

struct sbitmap {
	unsigned int depth;
	unsigned int shift;
	unsigned int map_nr;
	bool round_robin;
	struct sbitmap_word *map;
	unsigned int *alloc_hint;
};

struct sbq_wait_state;

struct sbitmap_queue {
	struct sbitmap sb;
	unsigned int wake_batch;
	atomic_t wake_index;
	struct sbq_wait_state *ws;
	atomic_t ws_active;
	unsigned int min_shallow_depth;
};

enum blk_bounce {
	BLK_BOUNCE_NONE = 0,
	BLK_BOUNCE_HIGH = 1,
};

enum blk_zoned_model {
	BLK_ZONED_NONE = 0,
	BLK_ZONED_HA = 1,
	BLK_ZONED_HM = 2,
};

struct queue_limits {
	enum blk_bounce bounce;
	long unsigned int seg_boundary_mask;
	long unsigned int virt_boundary_mask;
	unsigned int max_hw_sectors;
	unsigned int max_dev_sectors;
	unsigned int chunk_sectors;
	unsigned int max_sectors;
	unsigned int max_segment_size;
	unsigned int physical_block_size;
	unsigned int logical_block_size;
	unsigned int alignment_offset;
	unsigned int io_min;
	unsigned int io_opt;
	unsigned int max_discard_sectors;
	unsigned int max_hw_discard_sectors;
	unsigned int max_write_same_sectors;
	unsigned int max_write_zeroes_sectors;
	unsigned int max_zone_append_sectors;
	unsigned int discard_granularity;
	unsigned int discard_alignment;
	unsigned int zone_write_granularity;
	short unsigned int max_segments;
	short unsigned int max_integrity_segments;
	short unsigned int max_discard_segments;
	unsigned char misaligned;
	unsigned char discard_misaligned;
	unsigned char raid_partial_stripes_expensive;
	enum blk_zoned_model zoned;
};

struct blk_trace;

struct blk_flush_queue;

struct throtl_data;

struct blk_mq_tag_set;

struct bio_alloc_cache;

typedef void *mempool_alloc_t(gfp_t, void *);

typedef void mempool_free_t(void *, void *);

struct mempool_s {
	spinlock_t lock;
	int min_nr;
	int curr_nr;
	void **elements;
	void *pool_data;
	mempool_alloc_t *alloc;
	mempool_free_t *free;
	wait_queue_head_t wait;
};

typedef struct mempool_s mempool_t;

struct bio_set {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	struct bio_alloc_cache *cache;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	unsigned int back_pad;
	spinlock_t rescue_lock;
	struct bio_list rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	struct hlist_node cpuhp_dead;
};

struct request;

struct elevator_queue;

struct gendisk;

struct blkcg_gq;

struct request_queue {
	struct request *last_merge;
	struct elevator_queue *elevator;
	struct percpu_ref q_usage_counter;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	const struct blk_mq_ops *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx **queue_hw_ctx;
	unsigned int nr_hw_queues;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	spinlock_t queue_lock;
	struct gendisk *disk;
	struct kobject kobj;
	struct kobject *mq_kobj;
	struct blk_integrity integrity;
	struct device *dev;
	enum rpm_status rpm_status;
	long unsigned int nr_requests;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_keyslot_manager *ksm;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	atomic_t nr_active_requests_shared_sbitmap;
	struct sbitmap_queue sched_bitmap_tags;
	struct sbitmap_queue sched_breserved_tags;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int required_elevator_features;
	unsigned int nr_zones;
	long unsigned int *conv_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int max_open_zones;
	unsigned int max_active_zones;
	int node;
	struct mutex debugfs_mutex;
	struct blk_trace *blk_trace;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	struct mutex sysfs_dir_lock;
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	int mq_freeze_depth;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct mutex mq_freeze_lock;
	struct blk_mq_tag_set *tag_set;
	struct list_head tag_set_list;
	struct bio_set bio_split;
	struct dentry___2 *debugfs_dir;
	struct dentry___2 *sched_debugfs_dir;
	struct dentry___2 *rqos_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	u64 write_hints[5];
};

struct vm_struct___2 {
	struct vm_struct___2 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___2 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct bpf_run_ctx {};

struct cgroup_base_stat {
	struct task_cputime cputime;
};

struct psi_group_cpu;

struct psi_group {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___3 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_bpf {
	struct bpf_prog_array *effective[23];
	struct list_head progs[23];
	u32 flags[23];
	struct list_head storages;
	struct bpf_prog_array *inactive;
	struct percpu_ref refcnt;
	struct work_struct release_work;
};

struct cgroup_freezer_state {
	bool freeze;
	int e_freeze;
	int nr_frozen_descendants;
	int nr_frozen_tasks;
};

struct cgroup_root;

struct cgroup_rstat_cpu;

struct cgroup {
	struct cgroup_subsys_state self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node *kn;
	struct cgroup_file procs_file;
	struct cgroup_file events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state *subsys[14];
	struct cgroup_root *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup *dom_cgrp;
	struct cgroup *old_dom_cgrp;
	struct cgroup_rstat_cpu *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group psi;
	struct cgroup_bpf bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct taskstats {
	__u16 version;
	__u32 ac_exitcode;
	__u8 ac_flag;
	__u8 ac_nice;
	__u64 cpu_count;
	__u64 cpu_delay_total;
	__u64 blkio_count;
	__u64 blkio_delay_total;
	__u64 swapin_count;
	__u64 swapin_delay_total;
	__u64 cpu_run_real_total;
	__u64 cpu_run_virtual_total;
	char ac_comm[32];
	__u8 ac_sched;
	__u8 ac_pad[3];
	int: 32;
	__u32 ac_uid;
	__u32 ac_gid;
	__u32 ac_pid;
	__u32 ac_ppid;
	__u32 ac_btime;
	__u64 ac_etime;
	__u64 ac_utime;
	__u64 ac_stime;
	__u64 ac_minflt;
	__u64 ac_majflt;
	__u64 coremem;
	__u64 virtmem;
	__u64 hiwater_rss;
	__u64 hiwater_vm;
	__u64 read_char;
	__u64 write_char;
	__u64 read_syscalls;
	__u64 write_syscalls;
	__u64 read_bytes;
	__u64 write_bytes;
	__u64 cancelled_write_bytes;
	__u64 nvcsw;
	__u64 nivcsw;
	__u64 ac_utimescaled;
	__u64 ac_stimescaled;
	__u64 cpu_scaled_run_real_total;
	__u64 freepages_count;
	__u64 freepages_delay_total;
	__u64 thrashing_count;
	__u64 thrashing_delay_total;
	__u64 ac_btime64;
};

typedef struct {
	__u8 b[16];
} guid_t;

struct kiocb___2 {
	struct file___2 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___2 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue *ki_waitq;
	};
};

struct iattr___2 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___2 *ia_file;
};

struct dquot___2 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___2 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___2 {
	int qf_fmt_id;
	const struct quota_format_ops___2 *qf_ops;
	struct module___2 *qf_owner;
	struct quota_format_type___2 *qf_next;
};

struct quota_format_ops___2 {
	int (*check_quota_file)(struct super_block___2 *, int);
	int (*read_file_info)(struct super_block___2 *, int);
	int (*write_file_info)(struct super_block___2 *, int);
	int (*free_file_info)(struct super_block___2 *, int);
	int (*read_dqblk)(struct dquot___2 *);
	int (*commit_dqblk)(struct dquot___2 *);
	int (*release_dqblk)(struct dquot___2 *);
	int (*get_next_id)(struct super_block___2 *, struct kqid *);
};

struct dquot_operations___2 {
	int (*write_dquot)(struct dquot___2 *);
	struct dquot___2 * (*alloc_dquot)(struct super_block___2 *, int);
	void (*destroy_dquot)(struct dquot___2 *);
	int (*acquire_dquot)(struct dquot___2 *);
	int (*release_dquot)(struct dquot___2 *);
	int (*mark_dirty)(struct dquot___2 *);
	int (*write_info)(struct super_block___2 *, int);
	qsize_t * (*get_reserved_space)(struct inode___2 *);
	int (*get_projid)(struct inode___2 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___2 *, qsize_t *);
	int (*get_next_id)(struct super_block___2 *, struct kqid *);
};

struct quotactl_ops___2 {
	int (*quota_on)(struct super_block___2 *, int, int, const struct path___2 *);
	int (*quota_off)(struct super_block___2 *, int);
	int (*quota_enable)(struct super_block___2 *, unsigned int);
	int (*quota_disable)(struct super_block___2 *, unsigned int);
	int (*quota_sync)(struct super_block___2 *, int);
	int (*set_info)(struct super_block___2 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___2 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___2 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___2 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___2 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___2 *, unsigned int);
};

struct wait_page_queue {
	struct page___2 *page;
	int bit_nr;
	wait_queue_entry_t wait;
};

struct address_space_operations___2 {
	int (*writepage)(struct page___2 *, struct writeback_control *);
	int (*readpage)(struct file___2 *, struct page___2 *);
	int (*writepages)(struct address_space___2 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___2 *);
	int (*readpages)(struct file___2 *, struct address_space___2 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control *);
	int (*write_begin)(struct file___2 *, struct address_space___2 *, loff_t, unsigned int, unsigned int, struct page___2 **, void **);
	int (*write_end)(struct file___2 *, struct address_space___2 *, loff_t, unsigned int, unsigned int, struct page___2 *, void *);
	sector_t (*bmap)(struct address_space___2 *, sector_t);
	void (*invalidatepage)(struct page___2 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___2 *, gfp_t);
	void (*freepage)(struct page___2 *);
	ssize_t (*direct_IO)(struct kiocb___2 *, struct iov_iter___2 *);
	int (*migratepage)(struct address_space___2 *, struct page___2 *, struct page___2 *, enum migrate_mode);
	bool (*isolate_page)(struct page___2 *, isolate_mode_t);
	void (*putback_page)(struct page___2 *);
	int (*launder_page)(struct page___2 *);
	int (*is_partially_uptodate)(struct page___2 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___2 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___2 *, struct page___2 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___2 *, sector_t *);
	void (*swap_deactivate)(struct file___2 *);
};

enum writeback_sync_modes {
	WB_SYNC_NONE = 0,
	WB_SYNC_ALL = 1,
};

struct writeback_control {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	unsigned int no_cgroup_owner: 1;
	unsigned int punt_to_cgroup: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bdi_writeback *wb;
	struct inode___2 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
};

struct readahead_control {
	struct file___2 *file;
	struct address_space___2 *mapping;
	struct file_ra_state *ra;
	long unsigned int _index;
	unsigned int _nr_pages;
	unsigned int _batch_count;
};

struct iovec;

struct kvec;

struct bio_vec;

struct iov_iter___2 {
	u8 iter_type;
	bool data_source;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec *bvec;
		struct xarray *xarray;
		struct pipe_inode_info *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			unsigned int head;
			unsigned int start_head;
		};
		loff_t xarray_start;
	};
};

struct swap_cluster_info {
	spinlock_t lock;
	unsigned int data: 24;
	unsigned int flags: 8;
	long: 56;
};

struct swap_cluster_list {
	struct swap_cluster_info head;
	struct swap_cluster_info tail;
};

struct percpu_cluster;

struct swap_info_struct {
	struct percpu_ref users;
	long unsigned int flags;
	short int prio;
	struct plist_node list;
	signed char type;
	unsigned int max;
	unsigned char *swap_map;
	struct swap_cluster_info *cluster_info;
	struct swap_cluster_list free_clusters;
	unsigned int lowest_bit;
	unsigned int highest_bit;
	unsigned int pages;
	unsigned int inuse_pages;
	unsigned int cluster_next;
	unsigned int cluster_nr;
	unsigned int *cluster_next_cpu;
	struct percpu_cluster *percpu_cluster;
	struct rb_root swap_extent_root;
	struct block_device *bdev;
	struct file___2 *swap_file;
	unsigned int old_block_size;
	struct completion comp;
	long unsigned int *frontswap_map;
	atomic_t frontswap_pages;
	spinlock_t lock;
	spinlock_t cont_lock;
	struct work_struct discard_work;
	struct swap_cluster_list discard_clusters;
	struct plist_node avail_lists[0];
};

struct cdev {
	struct kobject kobj;
	struct module___2 *owner;
	const struct file_operations___2 *ops;
	struct list_head list;
	dev_t dev;
	unsigned int count;
};

struct inode_operations___2 {
	struct dentry___2 * (*lookup)(struct inode___2 *, struct dentry___2 *, unsigned int);
	const char * (*get_link)(struct dentry___2 *, struct inode___2 *, struct delayed_call *);
	int (*permission)(struct user_namespace *, struct inode___2 *, int);
	struct posix_acl * (*get_acl)(struct inode___2 *, int, bool);
	int (*readlink)(struct dentry___2 *, char *, int);
	int (*create)(struct user_namespace *, struct inode___2 *, struct dentry___2 *, umode_t, bool);
	int (*link)(struct dentry___2 *, struct inode___2 *, struct dentry___2 *);
	int (*unlink)(struct inode___2 *, struct dentry___2 *);
	int (*symlink)(struct user_namespace *, struct inode___2 *, struct dentry___2 *, const char *);
	int (*mkdir)(struct user_namespace *, struct inode___2 *, struct dentry___2 *, umode_t);
	int (*rmdir)(struct inode___2 *, struct dentry___2 *);
	int (*mknod)(struct user_namespace *, struct inode___2 *, struct dentry___2 *, umode_t, dev_t);
	int (*rename)(struct user_namespace *, struct inode___2 *, struct dentry___2 *, struct inode___2 *, struct dentry___2 *, unsigned int);
	int (*setattr)(struct user_namespace *, struct dentry___2 *, struct iattr___2 *);
	int (*getattr)(struct user_namespace *, const struct path___2 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___2 *, char *, size_t);
	int (*fiemap)(struct inode___2 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___2 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___2 *, struct dentry___2 *, struct file___2 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace *, struct inode___2 *, struct dentry___2 *, umode_t);
	int (*set_acl)(struct user_namespace *, struct inode___2 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace *, struct dentry___2 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___2 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___2 {
	void (*fl_copy_lock)(struct file_lock___2 *, struct file_lock___2 *);
	void (*fl_release_private)(struct file_lock___2 *);
};

struct lock_manager_operations___2;

struct file_lock___2 {
	struct file_lock___2 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___2 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___2 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___2 *fl_ops;
	const struct lock_manager_operations___2 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___2 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___2 *);
	int (*lm_grant)(struct file_lock___2 *, int);
	bool (*lm_break)(struct file_lock___2 *);
	int (*lm_change)(struct file_lock___2 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___2 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___2 *);
};

struct fasync_struct___2 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___2 *fa_next;
	struct file___2 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___2 {
	struct inode___2 * (*alloc_inode)(struct super_block___2 *);
	void (*destroy_inode)(struct inode___2 *);
	void (*free_inode)(struct inode___2 *);
	void (*dirty_inode)(struct inode___2 *, int);
	int (*write_inode)(struct inode___2 *, struct writeback_control *);
	int (*drop_inode)(struct inode___2 *);
	void (*evict_inode)(struct inode___2 *);
	void (*put_super)(struct super_block___2 *);
	int (*sync_fs)(struct super_block___2 *, int);
	int (*freeze_super)(struct super_block___2 *);
	int (*freeze_fs)(struct super_block___2 *);
	int (*thaw_super)(struct super_block___2 *);
	int (*unfreeze_fs)(struct super_block___2 *);
	int (*statfs)(struct dentry___2 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___2 *, int *, char *);
	void (*umount_begin)(struct super_block___2 *);
	int (*show_options)(struct seq_file___2 *, struct dentry___2 *);
	int (*show_devname)(struct seq_file___2 *, struct dentry___2 *);
	int (*show_path)(struct seq_file___2 *, struct dentry___2 *);
	int (*show_stats)(struct seq_file___2 *, struct dentry___2 *);
	ssize_t (*quota_read)(struct super_block___2 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___2 *, int, const char *, size_t, loff_t);
	struct dquot___2 ** (*get_dquots)(struct inode___2 *);
	long int (*nr_cached_objects)(struct super_block___2 *, struct shrink_control *);
	long int (*free_cached_objects)(struct super_block___2 *, struct shrink_control *);
	struct file___2 * (*real_loop)(struct file___2 *);
};

struct disk_stats;

struct device_private;

enum dl_dev_state {
	DL_DEV_NO_DRIVER = 0,
	DL_DEV_PROBING = 1,
	DL_DEV_DRIVER_BOUND = 2,
	DL_DEV_UNBINDING = 3,
};

struct dev_links_info {
	struct list_head suppliers;
	struct list_head consumers;
	struct list_head defer_sync;
	enum dl_dev_state status;
};

struct pm_message {
	int event;
};

typedef struct pm_message pm_message_t;

struct wake_irq;

enum rpm_request {
	RPM_REQ_NONE = 0,
	RPM_REQ_IDLE = 1,
	RPM_REQ_SUSPEND = 2,
	RPM_REQ_AUTOSUSPEND = 3,
	RPM_REQ_RESUME = 4,
};

struct wakeup_source;

struct pm_subsys_data;

struct dev_pm_qos;

struct dev_pm_info {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device *, s32);
	struct dev_pm_qos *qos;
};

struct dev_pin_info;

struct dev_archdata {};

struct iommu_group;

enum device_removable {
	DEVICE_REMOVABLE_NOT_SUPPORTED = 0,
	DEVICE_REMOVABLE_UNKNOWN = 1,
	DEVICE_FIXED = 2,
	DEVICE_REMOVABLE = 3,
};

struct device_type;

struct bus_type;

struct device_driver;

struct dev_pm_domain;

struct em_perf_domain;

struct dma_map_ops;

struct bus_dma_region;

struct device_dma_parameters;

struct io_tlb_mem;

struct device_node;

struct class;

struct dev_iommu;

struct device {
	struct kobject kobj;
	struct device *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type *type;
	struct bus_type *bus;
	struct device_driver *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info power;
	struct dev_pm_domain *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node *of_node;
	struct fwnode_handle *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class *class;
	const struct attribute_group **groups;
	void (*release)(struct device *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct partition_meta_info;

struct block_device {
	sector_t bd_start_sect;
	struct disk_stats *bd_stats;
	long unsigned int bd_stamp;
	bool bd_read_only;
	dev_t bd_dev;
	int bd_openers;
	struct inode___2 *bd_inode;
	struct super_block___2 *bd_super;
	void *bd_claiming;
	struct device bd_device;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct kobject *bd_holder_dir;
	u8 bd_partno;
	spinlock_t bd_size_lock;
	struct gendisk *bd_disk;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	struct super_block___2 *bd_fsfreeze_sb;
	struct partition_meta_info *bd_meta_info;
};

struct fc_log;

struct p_log {
	const char *prefix;
	struct fc_log *log;
};

enum fs_context_purpose {
	FS_CONTEXT_FOR_MOUNT = 0,
	FS_CONTEXT_FOR_SUBMOUNT = 1,
	FS_CONTEXT_FOR_RECONFIGURE = 2,
};

enum fs_context_phase {
	FS_CONTEXT_CREATE_PARAMS = 0,
	FS_CONTEXT_CREATING = 1,
	FS_CONTEXT_AWAITING_MOUNT = 2,
	FS_CONTEXT_AWAITING_RECONF = 3,
	FS_CONTEXT_RECONF_PARAMS = 4,
	FS_CONTEXT_RECONFIGURING = 5,
	FS_CONTEXT_FAILED = 6,
};

struct fs_context_operations;

struct fs_context {
	const struct fs_context_operations *ops;
	struct mutex uapi_mutex;
	struct file_system_type___2 *fs_type;
	void *fs_private;
	void *sget_key;
	struct dentry___2 *root;
	struct user_namespace *user_ns;
	struct net *net_ns;
	const struct cred *cred;
	struct p_log log;
	const char *source;
	void *security;
	void *s_fs_info;
	unsigned int sb_flags;
	unsigned int sb_flags_mask;
	unsigned int s_iflags;
	unsigned int lsm_flags;
	enum fs_context_purpose purpose: 8;
	enum fs_context_phase phase: 8;
	bool need_free: 1;
	bool global: 1;
	bool oldapi: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct audit_names;

struct filename {
	const char *name;
	const char *uptr;
	int refcnt;
	struct audit_names *aname;
	const char iname[0];
};

typedef u8 blk_status_t;

struct bvec_iter {
	sector_t bi_sector;
	unsigned int bi_size;
	unsigned int bi_idx;
	unsigned int bi_bvec_done;
};

typedef void bio_end_io_t(struct bio *);

struct bio_issue {
	u64 value;
};

struct bio_crypt_ctx;

struct bio_vec {
	struct page___2 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload;

struct bio {
	struct bio *bi_next;
	struct block_device *bi_bdev;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	atomic_t __bi_remaining;
	struct bvec_iter bi_iter;
	bio_end_io_t *bi_end_io;
	void *bi_private;
	struct blkcg_gq *bi_blkg;
	struct bio_issue bi_issue;
	u64 bi_iocost_cost;
	struct bio_crypt_ctx *bi_crypt_context;
	union {
		struct bio_integrity_payload *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec *bi_io_vec;
	struct bio_set *bi_pool;
	struct bio_vec bi_inline_vecs[0];
};

struct linux_binprm {
	struct vm_area_struct___2 *vma;
	long unsigned int vma_pages;
	struct mm_struct___2 *mm;
	long unsigned int p;
	long unsigned int argmin;
	unsigned int have_execfd: 1;
	unsigned int execfd_creds: 1;
	unsigned int secureexec: 1;
	unsigned int point_of_no_return: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct file___2 *executable;
	struct file___2 *interpreter;
	struct file___2 *file;
	struct cred *cred;
	int unsafe;
	unsigned int per_clear;
	int argc;
	int envc;
	const char *filename;
	const char *interp;
	const char *fdpath;
	unsigned int interp_flags;
	int execfd;
	long unsigned int loader;
	long unsigned int exec;
	struct rlimit rlim_stack;
	char buf[256];
};

struct coredump_params {
	const kernel_siginfo_t *siginfo;
	struct pt_regs *regs;
	struct file___2 *file;
	long unsigned int limit;
	long unsigned int mm_flags;
	loff_t written;
	loff_t pos;
	loff_t to_skip;
};

struct em_perf_state {
	long unsigned int frequency;
	long unsigned int power;
	long unsigned int cost;
};

struct em_perf_domain {
	struct em_perf_state *table;
	int nr_perf_states;
	int milliwatts;
	long unsigned int cpus[0];
};

struct dev_pm_ops {
	int (*prepare)(struct device *);
	void (*complete)(struct device *);
	int (*suspend)(struct device *);
	int (*resume)(struct device *);
	int (*freeze)(struct device *);
	int (*thaw)(struct device *);
	int (*poweroff)(struct device *);
	int (*restore)(struct device *);
	int (*suspend_late)(struct device *);
	int (*resume_early)(struct device *);
	int (*freeze_late)(struct device *);
	int (*thaw_early)(struct device *);
	int (*poweroff_late)(struct device *);
	int (*restore_early)(struct device *);
	int (*suspend_noirq)(struct device *);
	int (*resume_noirq)(struct device *);
	int (*freeze_noirq)(struct device *);
	int (*thaw_noirq)(struct device *);
	int (*poweroff_noirq)(struct device *);
	int (*restore_noirq)(struct device *);
	int (*runtime_suspend)(struct device *);
	int (*runtime_resume)(struct device *);
	int (*runtime_idle)(struct device *);
};

struct pm_domain_data;

struct pm_subsys_data {
	spinlock_t lock;
	unsigned int refcount;
	unsigned int clock_op_might_sleep;
	struct mutex clock_mutex;
	struct list_head clock_list;
	struct pm_domain_data *domain_data;
};

struct wakeup_source {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device *dev;
	bool active: 1;
	bool autosleep_enabled: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain {
	struct dev_pm_ops ops;
	int (*start)(struct device *);
	void (*detach)(struct device *, bool);
	int (*activate)(struct device *);
	void (*sync)(struct device *);
	void (*dismiss)(struct device *);
};

struct subsys_private;

struct iommu_ops;

struct bus_type {
	const char *name;
	const char *dev_name;
	struct device *dev_root;
	const struct attribute_group **bus_groups;
	const struct attribute_group **dev_groups;
	const struct attribute_group **drv_groups;
	int (*match)(struct device *, struct device_driver *);
	int (*uevent)(struct device *, struct kobj_uevent_env *);
	int (*probe)(struct device *);
	void (*sync_state)(struct device *);
	void (*remove)(struct device *);
	void (*shutdown)(struct device *);
	int (*online)(struct device *);
	int (*offline)(struct device *);
	int (*suspend)(struct device *, pm_message_t);
	int (*resume)(struct device *);
	int (*num_vf)(struct device *);
	int (*dma_configure)(struct device *);
	const struct dev_pm_ops *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

enum probe_type {
	PROBE_DEFAULT_STRATEGY = 0,
	PROBE_PREFER_ASYNCHRONOUS = 1,
	PROBE_FORCE_SYNCHRONOUS = 2,
};

struct driver_private;

struct of_device_id;

struct acpi_device_id;

struct device_driver {
	const char *name;
	struct bus_type *bus;
	struct module___2 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device *);
	void (*sync_state)(struct device *);
	int (*remove)(struct device *);
	void (*shutdown)(struct device *);
	int (*suspend)(struct device *, pm_message_t);
	int (*resume)(struct device *);
	const struct attribute_group **groups;
	const struct attribute_group **dev_groups;
	const struct dev_pm_ops *pm;
	void (*coredump)(struct device *);
	struct driver_private *p;
};

enum iommu_cap {
	IOMMU_CAP_CACHE_COHERENCY = 0,
	IOMMU_CAP_INTR_REMAP = 1,
	IOMMU_CAP_NOEXEC = 2,
};

typedef u64 dma_addr_t;

enum iommu_dev_features {
	IOMMU_DEV_FEAT_AUX = 0,
	IOMMU_DEV_FEAT_SVA = 1,
	IOMMU_DEV_FEAT_IOPF = 2,
};

struct iommu_domain;

struct device___2;

struct iommu_iotlb_gather;

struct iommu_device;

struct iommu_resv_region;

struct of_phandle_args;

struct iommu_sva;

struct mm_struct___3;

struct iommu_fault_event;

struct iommu_page_response;

struct iommu_cache_invalidate_info;

struct iommu_gpasid_bind_data;

struct module___3;

struct iommu_ops {
	bool (*capable)(enum iommu_cap);
	struct iommu_domain * (*domain_alloc)(unsigned int);
	void (*domain_free)(struct iommu_domain *);
	int (*attach_dev)(struct iommu_domain *, struct device___2 *);
	void (*detach_dev)(struct iommu_domain *, struct device___2 *);
	int (*map)(struct iommu_domain *, long unsigned int, phys_addr_t, size_t, int, gfp_t);
	int (*map_pages)(struct iommu_domain *, long unsigned int, phys_addr_t, size_t, size_t, int, gfp_t, size_t *);
	size_t (*unmap)(struct iommu_domain *, long unsigned int, size_t, struct iommu_iotlb_gather *);
	size_t (*unmap_pages)(struct iommu_domain *, long unsigned int, size_t, size_t, struct iommu_iotlb_gather *);
	void (*flush_iotlb_all)(struct iommu_domain *);
	void (*iotlb_sync_map)(struct iommu_domain *, long unsigned int, size_t);
	void (*iotlb_sync)(struct iommu_domain *, struct iommu_iotlb_gather *);
	phys_addr_t (*iova_to_phys)(struct iommu_domain *, dma_addr_t);
	struct iommu_device * (*probe_device)(struct device___2 *);
	void (*release_device)(struct device___2 *);
	void (*probe_finalize)(struct device___2 *);
	struct iommu_group * (*device_group)(struct device___2 *);
	int (*enable_nesting)(struct iommu_domain *);
	int (*set_pgtable_quirks)(struct iommu_domain *, long unsigned int);
	void (*get_resv_regions)(struct device___2 *, struct list_head *);
	void (*put_resv_regions)(struct device___2 *, struct list_head *);
	void (*apply_resv_region)(struct device___2 *, struct iommu_domain *, struct iommu_resv_region *);
	int (*of_xlate)(struct device___2 *, struct of_phandle_args *);
	bool (*is_attach_deferred)(struct iommu_domain *, struct device___2 *);
	bool (*dev_has_feat)(struct device___2 *, enum iommu_dev_features);
	bool (*dev_feat_enabled)(struct device___2 *, enum iommu_dev_features);
	int (*dev_enable_feat)(struct device___2 *, enum iommu_dev_features);
	int (*dev_disable_feat)(struct device___2 *, enum iommu_dev_features);
	int (*aux_attach_dev)(struct iommu_domain *, struct device___2 *);
	void (*aux_detach_dev)(struct iommu_domain *, struct device___2 *);
	int (*aux_get_pasid)(struct iommu_domain *, struct device___2 *);
	struct iommu_sva * (*sva_bind)(struct device___2 *, struct mm_struct___3 *, void *);
	void (*sva_unbind)(struct iommu_sva *);
	u32 (*sva_get_pasid)(struct iommu_sva *);
	int (*page_response)(struct device___2 *, struct iommu_fault_event *, struct iommu_page_response *);
	int (*cache_invalidate)(struct iommu_domain *, struct device___2 *, struct iommu_cache_invalidate_info *);
	int (*sva_bind_gpasid)(struct iommu_domain *, struct device___2 *, struct iommu_gpasid_bind_data *);
	int (*sva_unbind_gpasid)(struct device___2 *, u32);
	int (*def_domain_type)(struct device___2 *);
	long unsigned int pgsize_bitmap;
	struct module___3 *owner;
};

struct device_type {
	const char *name;
	const struct attribute_group **groups;
	int (*uevent)(struct device *, struct kobj_uevent_env *);
	char * (*devnode)(struct device *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device *);
	const struct dev_pm_ops *pm;
};

struct class {
	const char *name;
	struct module___2 *owner;
	const struct attribute_group **class_groups;
	const struct attribute_group **dev_groups;
	struct kobject *dev_kobj;
	int (*dev_uevent)(struct device *, struct kobj_uevent_env *);
	char * (*devnode)(struct device *, umode_t *);
	void (*class_release)(struct class *);
	void (*dev_release)(struct device *);
	int (*shutdown_pre)(struct device *);
	const struct kobj_ns_type_operations *ns_type;
	const void * (*namespace)(struct device *);
	void (*get_ownership)(struct device *, kuid_t *, kgid_t *);
	const struct dev_pm_ops *pm;
	struct subsys_private *p;
};

struct of_device_id {
	char name[32];
	char type[32];
	char compatible[128];
	const void *data;
};

typedef long unsigned int kernel_ulong_t;

struct acpi_device_id {
	__u8 id[9];
	kernel_ulong_t driver_data;
	__u32 cls;
	__u32 cls_msk;
};

struct device_dma_parameters {
	unsigned int max_segment_size;
	unsigned int min_align_mask;
	long unsigned int segment_boundary_mask;
};

enum dma_data_direction {
	DMA_BIDIRECTIONAL = 0,
	DMA_TO_DEVICE = 1,
	DMA_FROM_DEVICE = 2,
	DMA_NONE = 3,
};

struct device___3;

struct page___3;

struct sg_table;

struct vm_area_struct___3;

struct scatterlist;

struct dma_map_ops {
	void * (*alloc)(struct device___3 *, size_t, dma_addr_t *, gfp_t, long unsigned int);
	void (*free)(struct device___3 *, size_t, void *, dma_addr_t, long unsigned int);
	struct page___3 * (*alloc_pages)(struct device___3 *, size_t, dma_addr_t *, enum dma_data_direction, gfp_t);
	void (*free_pages)(struct device___3 *, size_t, struct page___3 *, dma_addr_t, enum dma_data_direction);
	struct sg_table * (*alloc_noncontiguous)(struct device___3 *, size_t, enum dma_data_direction, gfp_t, long unsigned int);
	void (*free_noncontiguous)(struct device___3 *, size_t, struct sg_table *, enum dma_data_direction);
	int (*mmap)(struct device___3 *, struct vm_area_struct___3 *, void *, dma_addr_t, size_t, long unsigned int);
	int (*get_sgtable)(struct device___3 *, struct sg_table *, void *, dma_addr_t, size_t, long unsigned int);
	dma_addr_t (*map_page)(struct device___3 *, struct page___3 *, long unsigned int, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_page)(struct device___3 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	int (*map_sg)(struct device___3 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	void (*unmap_sg)(struct device___3 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	dma_addr_t (*map_resource)(struct device___3 *, phys_addr_t, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_resource)(struct device___3 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	void (*sync_single_for_cpu)(struct device___3 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___3 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___3 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___3 *, struct scatterlist *, int, enum dma_data_direction);
	void (*cache_sync)(struct device___3 *, void *, size_t, enum dma_data_direction);
	int (*dma_supported)(struct device___3 *, u64);
	u64 (*get_required_mask)(struct device___3 *);
	size_t (*max_mapping_size)(struct device___3 *);
	long unsigned int (*get_merge_boundary)(struct device___3 *);
};

struct bus_dma_region {
	phys_addr_t cpu_start;
	dma_addr_t dma_start;
	u64 size;
	u64 offset;
};

typedef u32 phandle;

struct fwnode_operations;

struct fwnode_handle {
	struct fwnode_handle *secondary;
	const struct fwnode_operations *ops;
	struct device *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct property;

struct device_node {
	const char *name;
	phandle phandle;
	const char *full_name;
	struct fwnode_handle fwnode;
	struct property *properties;
	struct property *deadprops;
	struct device_node *parent;
	struct device_node *child;
	struct device_node *sibling;
	long unsigned int _flags;
	void *data;
};

enum cpuhp_state {
	CPUHP_INVALID = 4294967295,
	CPUHP_OFFLINE = 0,
	CPUHP_CREATE_THREADS = 1,
	CPUHP_PERF_PREPARE = 2,
	CPUHP_PERF_X86_PREPARE = 3,
	CPUHP_PERF_X86_AMD_UNCORE_PREP = 4,
	CPUHP_PERF_POWER = 5,
	CPUHP_PERF_SUPERH = 6,
	CPUHP_X86_HPET_DEAD = 7,
	CPUHP_X86_APB_DEAD = 8,
	CPUHP_X86_MCE_DEAD = 9,
	CPUHP_VIRT_NET_DEAD = 10,
	CPUHP_SLUB_DEAD = 11,
	CPUHP_DEBUG_OBJ_DEAD = 12,
	CPUHP_MM_WRITEBACK_DEAD = 13,
	CPUHP_MM_DEMOTION_DEAD = 14,
	CPUHP_MM_VMSTAT_DEAD = 15,
	CPUHP_SOFTIRQ_DEAD = 16,
	CPUHP_NET_MVNETA_DEAD = 17,
	CPUHP_CPUIDLE_DEAD = 18,
	CPUHP_ARM64_FPSIMD_DEAD = 19,
	CPUHP_ARM_OMAP_WAKE_DEAD = 20,
	CPUHP_IRQ_POLL_DEAD = 21,
	CPUHP_BLOCK_SOFTIRQ_DEAD = 22,
	CPUHP_BIO_DEAD = 23,
	CPUHP_ACPI_CPUDRV_DEAD = 24,
	CPUHP_S390_PFAULT_DEAD = 25,
	CPUHP_BLK_MQ_DEAD = 26,
	CPUHP_FS_BUFF_DEAD = 27,
	CPUHP_PRINTK_DEAD = 28,
	CPUHP_MM_MEMCQ_DEAD = 29,
	CPUHP_XFS_DEAD = 30,
	CPUHP_PERCPU_CNT_DEAD = 31,
	CPUHP_RADIX_DEAD = 32,
	CPUHP_PAGE_ALLOC = 33,
	CPUHP_NET_DEV_DEAD = 34,
	CPUHP_PCI_XGENE_DEAD = 35,
	CPUHP_IOMMU_IOVA_DEAD = 36,
	CPUHP_LUSTRE_CFS_DEAD = 37,
	CPUHP_AP_ARM_CACHE_B15_RAC_DEAD = 38,
	CPUHP_PADATA_DEAD = 39,
	CPUHP_WORKQUEUE_PREP = 40,
	CPUHP_POWER_NUMA_PREPARE = 41,
	CPUHP_HRTIMERS_PREPARE = 42,
	CPUHP_PROFILE_PREPARE = 43,
	CPUHP_X2APIC_PREPARE = 44,
	CPUHP_SMPCFD_PREPARE = 45,
	CPUHP_RELAY_PREPARE = 46,
	CPUHP_SLAB_PREPARE = 47,
	CPUHP_MD_RAID5_PREPARE = 48,
	CPUHP_RCUTREE_PREP = 49,
	CPUHP_CPUIDLE_COUPLED_PREPARE = 50,
	CPUHP_POWERPC_PMAC_PREPARE = 51,
	CPUHP_POWERPC_MMU_CTX_PREPARE = 52,
	CPUHP_XEN_PREPARE = 53,
	CPUHP_XEN_EVTCHN_PREPARE = 54,
	CPUHP_ARM_SHMOBILE_SCU_PREPARE = 55,
	CPUHP_SH_SH3X_PREPARE = 56,
	CPUHP_NET_FLOW_PREPARE = 57,
	CPUHP_TOPOLOGY_PREPARE = 58,
	CPUHP_NET_IUCV_PREPARE = 59,
	CPUHP_ARM_BL_PREPARE = 60,
	CPUHP_TRACE_RB_PREPARE = 61,
	CPUHP_MM_ZS_PREPARE = 62,
	CPUHP_MM_ZSWP_MEM_PREPARE = 63,
	CPUHP_MM_ZSWP_POOL_PREPARE = 64,
	CPUHP_KVM_PPC_BOOK3S_PREPARE = 65,
	CPUHP_ZCOMP_PREPARE = 66,
	CPUHP_TIMERS_PREPARE = 67,
	CPUHP_MIPS_SOC_PREPARE = 68,
	CPUHP_BP_PREPARE_DYN = 69,
	CPUHP_BP_PREPARE_DYN_END = 89,
	CPUHP_BRINGUP_CPU = 90,
	CPUHP_AP_IDLE_DEAD = 91,
	CPUHP_AP_OFFLINE = 92,
	CPUHP_AP_SCHED_STARTING = 93,
	CPUHP_AP_RCUTREE_DYING = 94,
	CPUHP_AP_CPU_PM_STARTING = 95,
	CPUHP_AP_IRQ_GIC_STARTING = 96,
	CPUHP_AP_IRQ_HIP04_STARTING = 97,
	CPUHP_AP_IRQ_APPLE_AIC_STARTING = 98,
	CPUHP_AP_IRQ_ARMADA_XP_STARTING = 99,
	CPUHP_AP_IRQ_BCM2836_STARTING = 100,
	CPUHP_AP_IRQ_MIPS_GIC_STARTING = 101,
	CPUHP_AP_IRQ_RISCV_STARTING = 102,
	CPUHP_AP_IRQ_SIFIVE_PLIC_STARTING = 103,
	CPUHP_AP_ARM_MVEBU_COHERENCY = 104,
	CPUHP_AP_MICROCODE_LOADER = 105,
	CPUHP_AP_PERF_X86_AMD_UNCORE_STARTING = 106,
	CPUHP_AP_PERF_X86_STARTING = 107,
	CPUHP_AP_PERF_X86_AMD_IBS_STARTING = 108,
	CPUHP_AP_PERF_X86_CQM_STARTING = 109,
	CPUHP_AP_PERF_X86_CSTATE_STARTING = 110,
	CPUHP_AP_PERF_XTENSA_STARTING = 111,
	CPUHP_AP_MIPS_OP_LOONGSON3_STARTING = 112,
	CPUHP_AP_ARM_SDEI_STARTING = 113,
	CPUHP_AP_ARM_VFP_STARTING = 114,
	CPUHP_AP_ARM64_DEBUG_MONITORS_STARTING = 115,
	CPUHP_AP_PERF_ARM_HW_BREAKPOINT_STARTING = 116,
	CPUHP_AP_PERF_ARM_ACPI_STARTING = 117,
	CPUHP_AP_PERF_ARM_STARTING = 118,
	CPUHP_AP_ARM_L2X0_STARTING = 119,
	CPUHP_AP_EXYNOS4_MCT_TIMER_STARTING = 120,
	CPUHP_AP_ARM_ARCH_TIMER_STARTING = 121,
	CPUHP_AP_ARM_GLOBAL_TIMER_STARTING = 122,
	CPUHP_AP_JCORE_TIMER_STARTING = 123,
	CPUHP_AP_ARM_TWD_STARTING = 124,
	CPUHP_AP_QCOM_TIMER_STARTING = 125,
	CPUHP_AP_TEGRA_TIMER_STARTING = 126,
	CPUHP_AP_ARMADA_TIMER_STARTING = 127,
	CPUHP_AP_MARCO_TIMER_STARTING = 128,
	CPUHP_AP_MIPS_GIC_TIMER_STARTING = 129,
	CPUHP_AP_ARC_TIMER_STARTING = 130,
	CPUHP_AP_RISCV_TIMER_STARTING = 131,
	CPUHP_AP_CLINT_TIMER_STARTING = 132,
	CPUHP_AP_CSKY_TIMER_STARTING = 133,
	CPUHP_AP_TI_GP_TIMER_STARTING = 134,
	CPUHP_AP_HYPERV_TIMER_STARTING = 135,
	CPUHP_AP_KVM_STARTING = 136,
	CPUHP_AP_KVM_ARM_VGIC_INIT_STARTING = 137,
	CPUHP_AP_KVM_ARM_VGIC_STARTING = 138,
	CPUHP_AP_KVM_ARM_TIMER_STARTING = 139,
	CPUHP_AP_DUMMY_TIMER_STARTING = 140,
	CPUHP_AP_ARM_XEN_STARTING = 141,
	CPUHP_AP_ARM_CORESIGHT_STARTING = 142,
	CPUHP_AP_ARM_CORESIGHT_CTI_STARTING = 143,
	CPUHP_AP_ARM64_ISNDEP_STARTING = 144,
	CPUHP_AP_SMPCFD_DYING = 145,
	CPUHP_AP_X86_TBOOT_DYING = 146,
	CPUHP_AP_ARM_CACHE_B15_RAC_DYING = 147,
	CPUHP_AP_ONLINE = 148,
	CPUHP_TEARDOWN_CPU = 149,
	CPUHP_AP_ONLINE_IDLE = 150,
	CPUHP_AP_SCHED_WAIT_EMPTY = 151,
	CPUHP_AP_SMPBOOT_THREADS = 152,
	CPUHP_AP_X86_VDSO_VMA_ONLINE = 153,
	CPUHP_AP_IRQ_AFFINITY_ONLINE = 154,
	CPUHP_AP_BLK_MQ_ONLINE = 155,
	CPUHP_AP_ARM_MVEBU_SYNC_CLOCKS = 156,
	CPUHP_AP_X86_INTEL_EPB_ONLINE = 157,
	CPUHP_AP_PERF_ONLINE = 158,
	CPUHP_AP_PERF_X86_ONLINE = 159,
	CPUHP_AP_PERF_X86_UNCORE_ONLINE = 160,
	CPUHP_AP_PERF_X86_AMD_UNCORE_ONLINE = 161,
	CPUHP_AP_PERF_X86_AMD_POWER_ONLINE = 162,
	CPUHP_AP_PERF_X86_RAPL_ONLINE = 163,
	CPUHP_AP_PERF_X86_CQM_ONLINE = 164,
	CPUHP_AP_PERF_X86_CSTATE_ONLINE = 165,
	CPUHP_AP_PERF_X86_IDXD_ONLINE = 166,
	CPUHP_AP_PERF_S390_CF_ONLINE = 167,
	CPUHP_AP_PERF_S390_SF_ONLINE = 168,
	CPUHP_AP_PERF_ARM_CCI_ONLINE = 169,
	CPUHP_AP_PERF_ARM_CCN_ONLINE = 170,
	CPUHP_AP_PERF_ARM_HISI_DDRC_ONLINE = 171,
	CPUHP_AP_PERF_ARM_HISI_HHA_ONLINE = 172,
	CPUHP_AP_PERF_ARM_HISI_L3_ONLINE = 173,
	CPUHP_AP_PERF_ARM_HISI_PA_ONLINE = 174,
	CPUHP_AP_PERF_ARM_HISI_SLLC_ONLINE = 175,
	CPUHP_AP_PERF_ARM_L2X0_ONLINE = 176,
	CPUHP_AP_PERF_ARM_QCOM_L2_ONLINE = 177,
	CPUHP_AP_PERF_ARM_QCOM_L3_ONLINE = 178,
	CPUHP_AP_PERF_ARM_APM_XGENE_ONLINE = 179,
	CPUHP_AP_PERF_ARM_CAVIUM_TX2_UNCORE_ONLINE = 180,
	CPUHP_AP_PERF_POWERPC_NEST_IMC_ONLINE = 181,
	CPUHP_AP_PERF_POWERPC_CORE_IMC_ONLINE = 182,
	CPUHP_AP_PERF_POWERPC_THREAD_IMC_ONLINE = 183,
	CPUHP_AP_PERF_POWERPC_TRACE_IMC_ONLINE = 184,
	CPUHP_AP_PERF_POWERPC_HV_24x7_ONLINE = 185,
	CPUHP_AP_PERF_POWERPC_HV_GPCI_ONLINE = 186,
	CPUHP_AP_PERF_CSKY_ONLINE = 187,
	CPUHP_AP_WATCHDOG_ONLINE = 188,
	CPUHP_AP_WORKQUEUE_ONLINE = 189,
	CPUHP_AP_RCUTREE_ONLINE = 190,
	CPUHP_AP_BASE_CACHEINFO_ONLINE = 191,
	CPUHP_AP_ONLINE_DYN = 192,
	CPUHP_AP_ONLINE_DYN_END = 222,
	CPUHP_AP_MM_DEMOTION_ONLINE = 223,
	CPUHP_AP_X86_HPET_ONLINE = 224,
	CPUHP_AP_X86_KVM_CLK_ONLINE = 225,
	CPUHP_AP_DTPM_CPU_ONLINE = 226,
	CPUHP_AP_ACTIVE = 227,
	CPUHP_ONLINE = 228,
};

struct dev_pagemap_ops___2 {
	void (*page_free)(struct page___2 *);
	void (*kill)(struct dev_pagemap___2 *);
	void (*cleanup)(struct dev_pagemap___2 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___2 *);
};

struct ring_buffer_event {
	u32 type_len: 5;
	u32 time_delta: 27;
	u32 array[0];
};

struct seq_buf {
	char *buffer;
	size_t size;
	size_t len;
	loff_t readpos;
};

struct trace_seq {
	char buffer[4096];
	struct seq_buf seq;
	int full;
};

enum perf_sw_ids {
	PERF_COUNT_SW_CPU_CLOCK = 0,
	PERF_COUNT_SW_TASK_CLOCK = 1,
	PERF_COUNT_SW_PAGE_FAULTS = 2,
	PERF_COUNT_SW_CONTEXT_SWITCHES = 3,
	PERF_COUNT_SW_CPU_MIGRATIONS = 4,
	PERF_COUNT_SW_PAGE_FAULTS_MIN = 5,
	PERF_COUNT_SW_PAGE_FAULTS_MAJ = 6,
	PERF_COUNT_SW_ALIGNMENT_FAULTS = 7,
	PERF_COUNT_SW_EMULATION_FAULTS = 8,
	PERF_COUNT_SW_DUMMY = 9,
	PERF_COUNT_SW_BPF_OUTPUT = 10,
	PERF_COUNT_SW_CGROUP_SWITCHES = 11,
	PERF_COUNT_SW_MAX = 12,
};

union perf_mem_data_src {
	__u64 val;
	struct {
		__u64 mem_op: 5;
		__u64 mem_lvl: 14;
		__u64 mem_snoop: 5;
		__u64 mem_lock: 2;
		__u64 mem_dtlb: 7;
		__u64 mem_lvl_num: 4;
		__u64 mem_remote: 1;
		__u64 mem_snoopx: 2;
		__u64 mem_blk: 3;
		__u64 mem_rsvd: 21;
	};
};

struct perf_branch_entry {
	__u64 from;
	__u64 to;
	__u64 mispred: 1;
	__u64 predicted: 1;
	__u64 in_tx: 1;
	__u64 abort: 1;
	__u64 cycles: 16;
	__u64 type: 4;
	__u64 reserved: 40;
	long: 24;
	long: 64;
	long: 64;
};

union perf_sample_weight {
	__u64 full;
	struct {
		__u32 var1_dw;
		__u16 var2_w;
		__u16 var3_w;
	};
};

struct new_utsname {
	char sysname[65];
	char nodename[65];
	char release[65];
	char version[65];
	char machine[65];
	char domainname[65];
};

struct uts_namespace {
	struct new_utsname name;
	struct user_namespace *user_ns;
	struct ucounts *ucounts;
	struct ns_common ns;
};

struct cgroup_namespace {
	struct ns_common ns;
	struct user_namespace *user_ns;
	struct ucounts *ucounts;
	struct css_set___2 *root_cset;
};

struct nsset {
	unsigned int flags;
	struct nsproxy___2 *nsproxy;
	struct fs_struct *fs;
	const struct cred *cred;
};

struct proc_ns_operations {
	const char *name;
	const char *real_ns_name;
	int type;
	struct ns_common * (*get)(struct task_struct___3 *);
	void (*put)(struct ns_common *);
	int (*install)(struct nsset *, struct ns_common *);
	struct user_namespace * (*owner)(struct ns_common *);
	struct ns_common * (*get_parent)(struct ns_common *);
};

struct perf_cpu_context;

struct perf_output_handle;

struct pmu {
	struct list_head entry;
	struct module___2 *module;
	struct device *dev;
	const struct attribute_group **attr_groups;
	const struct attribute_group **attr_update;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu *);
	void (*pmu_disable)(struct pmu *);
	int (*event_init)(struct perf_event *);
	void (*event_mapped)(struct perf_event *, struct mm_struct___2 *);
	void (*event_unmapped)(struct perf_event *, struct mm_struct___2 *);
	int (*add)(struct perf_event *, int);
	void (*del)(struct perf_event *, int);
	void (*start)(struct perf_event *, int);
	void (*stop)(struct perf_event *, int);
	void (*read)(struct perf_event *);
	void (*start_txn)(struct pmu *, unsigned int);
	int (*commit_txn)(struct pmu *);
	void (*cancel_txn)(struct pmu *);
	int (*event_idx)(struct perf_event *);
	void (*sched_task)(struct perf_event_context___2 *, bool);
	struct kmem_cache *task_ctx_cache;
	void (*swap_task_ctx)(struct perf_event_context___2 *, struct perf_event_context___2 *);
	void * (*setup_aux)(struct perf_event *, void **, int, bool);
	void (*free_aux)(void *);
	long int (*snapshot_aux)(struct perf_event *, struct perf_output_handle *, long unsigned int);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event *);
	int (*aux_output_match)(struct perf_event *);
	int (*filter_match)(struct perf_event *);
	int (*check_period)(struct perf_event *, u64);
};

struct ftrace_regs {
	struct pt_regs regs;
};

struct iovec {
	void *iov_base;
	__kernel_size_t iov_len;
};

struct kvec {
	void *iov_base;
	size_t iov_len;
};

struct perf_regs {
	__u64 abi;
	struct pt_regs *regs;
};

struct u64_stats_sync {};

struct bpf_cgroup_storage_key {
	__u64 cgroup_inode_id;
	__u32 attach_type;
};

enum kmalloc_cache_type {
	KMALLOC_NORMAL = 0,
	KMALLOC_CGROUP = 1,
	KMALLOC_RECLAIM = 2,
	KMALLOC_DMA = 3,
	NR_KMALLOC_TYPES = 4,
};

struct bpf_cgroup_storage_map;

struct bpf_storage_buffer;

struct bpf_cgroup_storage {
	union {
		struct bpf_storage_buffer *buf;
		void *percpu_buf;
	};
	struct bpf_cgroup_storage_map *map;
	struct bpf_cgroup_storage_key key;
	struct list_head list_map;
	struct list_head list_cg;
	struct rb_node node;
	struct callback_head rcu;
};

struct bpf_prog_array_item {
	struct bpf_prog *prog;
	union {
		struct bpf_cgroup_storage *cgroup_storage[2];
		u64 bpf_cookie;
	};
};

struct bpf_prog_array {
	struct callback_head rcu;
	struct bpf_prog_array_item items[0];
};

struct bpf_storage_buffer {
	struct callback_head rcu;
	char data[0];
};

struct psi_group_cpu {
	seqcount_t seq;
	unsigned int tasks[5];
	u32 state_mask;
	u32 times[7];
	u64 state_start;
	u32 times_prev[14];
	long: 64;
};

struct cgroup_taskset;

struct cftype;

struct cgroup_subsys {
	struct cgroup_subsys_state * (*css_alloc)(struct cgroup_subsys_state *);
	int (*css_online)(struct cgroup_subsys_state *);
	void (*css_offline)(struct cgroup_subsys_state *);
	void (*css_released)(struct cgroup_subsys_state *);
	void (*css_free)(struct cgroup_subsys_state *);
	void (*css_reset)(struct cgroup_subsys_state *);
	void (*css_rstat_flush)(struct cgroup_subsys_state *, int);
	int (*css_extra_stat_show)(struct seq_file___2 *, struct cgroup_subsys_state *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___3 *, struct css_set___2 *);
	void (*cancel_fork)(struct task_struct___3 *, struct css_set___2 *);
	void (*fork)(struct task_struct___3 *);
	void (*exit)(struct task_struct___3 *);
	void (*release)(struct task_struct___3 *);
	void (*bind)(struct cgroup_subsys_state *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype *dfl_cftypes;
	struct cftype *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup *updated_children;
	struct cgroup *updated_next;
};

struct cgroup_root {
	struct kernfs_root *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys *ss;
	struct list_head node;
	struct kernfs_ops *kf_ops;
	int (*open)(struct kernfs_open_file *);
	void (*release)(struct kernfs_open_file *);
	u64 (*read_u64)(struct cgroup_subsys_state *, struct cftype *);
	s64 (*read_s64)(struct cgroup_subsys_state *, struct cftype *);
	int (*seq_show)(struct seq_file___2 *, void *);
	void * (*seq_start)(struct seq_file___2 *, loff_t *);
	void * (*seq_next)(struct seq_file___2 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___2 *, void *);
	int (*write_u64)(struct cgroup_subsys_state *, struct cftype *, u64);
	int (*write_s64)(struct cgroup_subsys_state *, struct cftype *, s64);
	ssize_t (*write)(struct kernfs_open_file *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file *, struct poll_table_struct___2 *);
};

struct perf_callchain_entry {
	__u64 nr;
	__u64 ip[0];
};

typedef long unsigned int (*perf_copy_f)(void *, const void *, long unsigned int, long unsigned int);

struct perf_raw_frag {
	union {
		struct perf_raw_frag *next;
		long unsigned int pad;
	};
	perf_copy_f copy;
	void *data;
	u32 size;
} __attribute__((packed));

struct perf_raw_record {
	struct perf_raw_frag frag;
	u32 size;
};

struct perf_branch_stack {
	__u64 nr;
	__u64 hw_idx;
	struct perf_branch_entry entries[0];
};

struct perf_cpu_context {
	struct perf_event_context___2 ctx;
	struct perf_event_context___2 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
	int heap_size;
	struct perf_event **heap;
	struct perf_event *heap_default[2];
};

struct perf_output_handle {
	struct perf_event *event;
	struct perf_buffer *rb;
	long unsigned int wakeup;
	long unsigned int size;
	u64 aux_flags;
	union {
		void *addr;
		long unsigned int head;
	};
	int page;
};

struct perf_addr_filter_range {
	long unsigned int start;
	long unsigned int size;
};

struct perf_sample_data {
	u64 addr;
	struct perf_raw_record *raw;
	struct perf_branch_stack *br_stack;
	u64 period;
	union perf_sample_weight weight;
	u64 txn;
	union perf_mem_data_src data_src;
	u64 type;
	u64 ip;
	struct {
		u32 pid;
		u32 tid;
	} tid_entry;
	u64 time;
	u64 id;
	u64 stream_id;
	struct {
		u32 cpu;
		u32 reserved;
	} cpu_entry;
	struct perf_callchain_entry *callchain;
	u64 aux_size;
	struct perf_regs regs_user;
	struct perf_regs regs_intr;
	u64 stack_user_size;
	u64 phys_addr;
	u64 cgroup;
	u64 data_page_size;
	u64 code_page_size;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct perf_cgroup_info;

struct perf_cgroup {
	struct cgroup_subsys_state css;
	struct perf_cgroup_info *info;
};

struct perf_cgroup_info {
	u64 time;
	u64 timestamp;
	u64 timeoffset;
	int active;
};

struct trace_entry {
	short unsigned int type;
	unsigned char flags;
	unsigned char preempt_count;
	int pid;
};

struct trace_array;

struct tracer;

struct array_buffer;

struct ring_buffer_iter;

struct trace_iterator {
	struct trace_array *tr;
	struct tracer *trace;
	struct array_buffer *array_buffer;
	void *private;
	int cpu_file;
	struct mutex mutex;
	struct ring_buffer_iter **buffer_iter;
	long unsigned int iter_flags;
	void *temp;
	unsigned int temp_size;
	char *fmt;
	unsigned int fmt_size;
	struct trace_seq tmp_seq;
	cpumask_var_t started;
	bool snapshot;
	struct trace_seq seq;
	struct trace_entry *ent;
	long unsigned int lost_events;
	int leftover;
	int ent_size;
	int cpu;
	u64 ts;
	loff_t pos;
	long int idx;
};

enum print_line_t {
	TRACE_TYPE_PARTIAL_LINE = 0,
	TRACE_TYPE_HANDLED = 1,
	TRACE_TYPE_UNHANDLED = 2,
	TRACE_TYPE_NO_CONSUME = 3,
};

typedef enum print_line_t (*trace_print_func)(struct trace_iterator *, int, struct trace_event *);

struct trace_event_functions {
	trace_print_func trace;
	trace_print_func raw;
	trace_print_func hex;
	trace_print_func binary;
};

enum trace_reg {
	TRACE_REG_REGISTER = 0,
	TRACE_REG_UNREGISTER = 1,
	TRACE_REG_PERF_REGISTER = 2,
	TRACE_REG_PERF_UNREGISTER = 3,
	TRACE_REG_PERF_OPEN = 4,
	TRACE_REG_PERF_CLOSE = 5,
	TRACE_REG_PERF_ADD = 6,
	TRACE_REG_PERF_DEL = 7,
};

struct trace_event_fields {
	const char *type;
	union {
		struct {
			const char *name;
			const int size;
			const int align;
			const int is_signed;
			const int filter_type;
		};
		int (*define_fields)(struct trace_event_call *);
	};
};

struct trace_event_class {
	const char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct trace_event_call *, enum trace_reg, void *);
	struct trace_event_fields *fields_array;
	struct list_head * (*get_fields)(struct trace_event_call *);
	struct list_head fields;
	int (*raw_init)(struct trace_event_call *);
};

struct trace_buffer;

struct trace_event_file;

struct trace_event_buffer {
	struct trace_buffer *buffer;
	struct ring_buffer_event *event;
	struct trace_event_file *trace_file;
	void *entry;
	unsigned int trace_ctx;
	struct pt_regs *regs;
};

struct trace_subsystem_dir;

struct trace_event_file {
	struct list_head list;
	struct trace_event_call *event_call;
	struct event_filter *filter;
	struct dentry___2 *dir;
	struct trace_array *tr;
	struct trace_subsystem_dir *system;
	struct list_head triggers;
	long unsigned int flags;
	atomic_t sm_ref;
	atomic_t tm_ref;
};

enum {
	TRACE_EVENT_FL_FILTERED_BIT = 0,
	TRACE_EVENT_FL_CAP_ANY_BIT = 1,
	TRACE_EVENT_FL_NO_SET_FILTER_BIT = 2,
	TRACE_EVENT_FL_IGNORE_ENABLE_BIT = 3,
	TRACE_EVENT_FL_TRACEPOINT_BIT = 4,
	TRACE_EVENT_FL_DYNAMIC_BIT = 5,
	TRACE_EVENT_FL_KPROBE_BIT = 6,
	TRACE_EVENT_FL_UPROBE_BIT = 7,
	TRACE_EVENT_FL_EPROBE_BIT = 8,
};

enum {
	TRACE_EVENT_FL_FILTERED = 1,
	TRACE_EVENT_FL_CAP_ANY = 2,
	TRACE_EVENT_FL_NO_SET_FILTER = 4,
	TRACE_EVENT_FL_IGNORE_ENABLE = 8,
	TRACE_EVENT_FL_TRACEPOINT = 16,
	TRACE_EVENT_FL_DYNAMIC = 32,
	TRACE_EVENT_FL_KPROBE = 64,
	TRACE_EVENT_FL_UPROBE = 128,
	TRACE_EVENT_FL_EPROBE = 256,
};

enum {
	EVENT_FILE_FL_ENABLED_BIT = 0,
	EVENT_FILE_FL_RECORDED_CMD_BIT = 1,
	EVENT_FILE_FL_RECORDED_TGID_BIT = 2,
	EVENT_FILE_FL_FILTERED_BIT = 3,
	EVENT_FILE_FL_NO_SET_FILTER_BIT = 4,
	EVENT_FILE_FL_SOFT_MODE_BIT = 5,
	EVENT_FILE_FL_SOFT_DISABLED_BIT = 6,
	EVENT_FILE_FL_TRIGGER_MODE_BIT = 7,
	EVENT_FILE_FL_TRIGGER_COND_BIT = 8,
	EVENT_FILE_FL_PID_FILTER_BIT = 9,
	EVENT_FILE_FL_WAS_ENABLED_BIT = 10,
};

enum {
	EVENT_FILE_FL_ENABLED = 1,
	EVENT_FILE_FL_RECORDED_CMD = 2,
	EVENT_FILE_FL_RECORDED_TGID = 4,
	EVENT_FILE_FL_FILTERED = 8,
	EVENT_FILE_FL_NO_SET_FILTER = 16,
	EVENT_FILE_FL_SOFT_MODE = 32,
	EVENT_FILE_FL_SOFT_DISABLED = 64,
	EVENT_FILE_FL_TRIGGER_MODE = 128,
	EVENT_FILE_FL_TRIGGER_COND = 256,
	EVENT_FILE_FL_PID_FILTER = 512,
	EVENT_FILE_FL_WAS_ENABLED = 1024,
};

enum event_trigger_type {
	ETT_NONE = 0,
	ETT_TRACE_ONOFF = 1,
	ETT_SNAPSHOT = 2,
	ETT_STACKTRACE = 4,
	ETT_EVENT_ENABLE = 8,
	ETT_EVENT_HIST = 16,
	ETT_HIST_ENABLE = 32,
	ETT_EVENT_EPROBE = 64,
};

enum {
	FILTER_OTHER = 0,
	FILTER_STATIC_STRING = 1,
	FILTER_DYN_STRING = 2,
	FILTER_PTR_STRING = 3,
	FILTER_TRACE_FN = 4,
	FILTER_COMM = 5,
	FILTER_CPU = 6,
};

struct fwnode_reference_args;

struct fwnode_endpoint;

struct fwnode_operations {
	struct fwnode_handle * (*get)(struct fwnode_handle *);
	void (*put)(struct fwnode_handle *);
	bool (*device_is_available)(const struct fwnode_handle *);
	const void * (*device_get_match_data)(const struct fwnode_handle *, const struct device *);
	bool (*property_present)(const struct fwnode_handle *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle *);
	const char * (*get_name_prefix)(const struct fwnode_handle *);
	struct fwnode_handle * (*get_parent)(const struct fwnode_handle *);
	struct fwnode_handle * (*get_next_child_node)(const struct fwnode_handle *, struct fwnode_handle *);
	struct fwnode_handle * (*get_named_child_node)(const struct fwnode_handle *, const char *);
	int (*get_reference_args)(const struct fwnode_handle *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args *);
	struct fwnode_handle * (*graph_get_next_endpoint)(const struct fwnode_handle *, struct fwnode_handle *);
	struct fwnode_handle * (*graph_get_remote_endpoint)(const struct fwnode_handle *);
	struct fwnode_handle * (*graph_get_port_parent)(struct fwnode_handle *);
	int (*graph_parse_endpoint)(const struct fwnode_handle *, struct fwnode_endpoint *);
	int (*add_links)(struct fwnode_handle *);
};

struct fwnode_endpoint {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle *local_fwnode;
};

struct fwnode_reference_args {
	struct fwnode_handle *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct property {
	char *name;
	int length;
	void *value;
	struct property *next;
};

struct irq_fwspec {
	struct fwnode_handle *fwnode;
	int param_count;
	u32 param[16];
};

struct irq_domain_ops {
	int (*match)(struct irq_domain *, struct device_node *, enum irq_domain_bus_token);
	int (*select)(struct irq_domain *, struct irq_fwspec *, enum irq_domain_bus_token);
	int (*map)(struct irq_domain *, unsigned int, irq_hw_number_t);
	void (*unmap)(struct irq_domain *, unsigned int);
	int (*xlate)(struct irq_domain *, struct device_node *, const u32 *, unsigned int, long unsigned int *, unsigned int *);
	int (*alloc)(struct irq_domain *, unsigned int, unsigned int, void *);
	void (*free)(struct irq_domain *, unsigned int, unsigned int);
	int (*activate)(struct irq_domain *, struct irq_data *, bool);
	void (*deactivate)(struct irq_domain *, struct irq_data *);
	int (*translate)(struct irq_domain *, struct irq_fwspec *, long unsigned int *, unsigned int *);
};

struct xbc_node {
	u16 next;
	u16 child;
	u16 parent;
	u16 data;
};

enum wb_stat_item {
	WB_RECLAIMABLE = 0,
	WB_WRITEBACK = 1,
	WB_DIRTIED = 2,
	WB_WRITTEN = 3,
	NR_WB_STAT_ITEMS = 4,
};

struct timer_rand_state;

struct disk_events;

struct cdrom_device_info;

struct badblocks;

struct block_device_operations;

struct gendisk {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	short unsigned int events;
	short unsigned int event_flags;
	struct xarray part_tbl;
	struct block_device *part0;
	const struct block_device_operations *fops;
	struct request_queue *queue;
	void *private_data;
	int flags;
	long unsigned int state;
	struct mutex open_mutex;
	unsigned int open_partitions;
	struct backing_dev_info *bdi;
	struct kobject *slave_dir;
	struct list_head slave_bdevs;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject integrity_kobj;
	struct cdrom_device_info *cdi;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	u64 diskseq;
};

struct partition_meta_info {
	char uuid[37];
	u8 volname[64];
};

struct bio_integrity_payload {
	struct bio *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec *bip_vec;
	struct bio_vec bip_inline_vecs[0];
};

struct blkg_iostat {
	u64 bytes[3];
	u64 ios[3];
};

struct blkg_iostat_set {
	struct u64_stats_sync sync;
	struct blkg_iostat cur;
	struct blkg_iostat last;
};

struct blkcg;

struct blkg_policy_data;

struct blkcg_gq {
	struct request_queue *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg *blkcg;
	struct blkcg_gq *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_iostat_set *iostat_cpu;
	struct blkg_iostat_set iostat;
	struct blkg_policy_data *pd[6];
	spinlock_t async_bio_lock;
	struct bio_list async_bios;
	struct work_struct async_bio_work;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
	struct callback_head callback_head;
};

typedef unsigned int blk_qc_t;

struct blk_integrity_iter;

typedef blk_status_t integrity_processing_fn(struct blk_integrity_iter *);

typedef void integrity_prepare_fn(struct request *);

typedef void integrity_complete_fn(struct request *, unsigned int);

struct blk_integrity_profile {
	integrity_processing_fn *generate_fn;
	integrity_processing_fn *verify_fn;
	integrity_prepare_fn *prepare_fn;
	integrity_complete_fn *complete_fn;
	const char *name;
};

struct hd_geometry;

struct blk_zone;

typedef int (*report_zones_cb)(struct blk_zone *, unsigned int, void *);

struct pr_ops;

struct block_device_operations {
	blk_qc_t (*submit_bio)(struct bio *);
	int (*open)(struct block_device *, fmode_t);
	void (*release)(struct gendisk *, fmode_t);
	int (*rw_page)(struct block_device *, sector_t, struct page___2 *, unsigned int);
	int (*ioctl)(struct block_device *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk *, unsigned int);
	void (*unlock_native_capacity)(struct gendisk *);
	int (*getgeo)(struct block_device *, struct hd_geometry *);
	int (*set_read_only)(struct block_device *, bool);
	void (*swap_slot_free_notify)(struct block_device *, long unsigned int);
	int (*report_zones)(struct gendisk *, sector_t, unsigned int, report_zones_cb, void *);
	char * (*devnode)(struct gendisk *, umode_t *);
	struct module___2 *owner;
	const struct pr_ops *pr_ops;
	int (*alternative_gpt_sector)(struct gendisk *, sector_t *);
};

struct blk_zone {
	__u64 start;
	__u64 len;
	__u64 wp;
	__u8 type;
	__u8 cond;
	__u8 non_seq;
	__u8 reset;
	__u8 resv[4];
	__u64 capacity;
	__u8 reserved[24];
};

struct sbitmap_word {
	long unsigned int depth;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int word;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int cleared;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct sbq_wait_state {
	atomic_t wait_cnt;
	wait_queue_head_t wait;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef void rq_end_io_fn(struct request *, blk_status_t);

typedef __u32 req_flags_t;

struct blk_ksm_keyslot;

enum mq_rq_state {
	MQ_RQ_IDLE = 0,
	MQ_RQ_IN_FLIGHT = 1,
	MQ_RQ_COMPLETE = 2,
};

struct request {
	struct request_queue *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int tag;
	int internal_tag;
	unsigned int __data_len;
	sector_t __sector;
	struct bio *bio;
	struct bio *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct llist_node ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn *saved_end_io;
		} flush;
	};
	struct gendisk *rq_disk;
	struct block_device *part;
	u64 alloc_time_ns;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int stats_sectors;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	struct bio_crypt_ctx *crypt_ctx;
	struct blk_ksm_keyslot *crypt_keyslot;
	short unsigned int write_hint;
	short unsigned int ioprio;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn *end_io;
	void *end_io_data;
};

enum elv_merge {
	ELEVATOR_NO_MERGE = 0,
	ELEVATOR_FRONT_MERGE = 1,
	ELEVATOR_BACK_MERGE = 2,
	ELEVATOR_DISCARD_MERGE = 3,
};

struct blk_mq_alloc_data;

struct elevator_type;

struct elevator_mq_ops {
	int (*init_sched)(struct request_queue *, struct elevator_type *);
	void (*exit_sched)(struct elevator_queue *);
	int (*init_hctx)(struct blk_mq_hw_ctx *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx *, unsigned int);
	void (*depth_updated)(struct blk_mq_hw_ctx *);
	bool (*allow_merge)(struct request_queue *, struct request *, struct bio *);
	bool (*bio_merge)(struct request_queue *, struct bio *, unsigned int);
	int (*request_merge)(struct request_queue *, struct request **, struct bio *);
	void (*request_merged)(struct request_queue *, struct request *, enum elv_merge);
	void (*requests_merged)(struct request_queue *, struct request *, struct request *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request *);
	void (*finish_request)(struct request *);
	void (*insert_requests)(struct blk_mq_hw_ctx *, struct list_head *, bool);
	struct request * (*dispatch_request)(struct blk_mq_hw_ctx *);
	bool (*has_work)(struct blk_mq_hw_ctx *);
	void (*completed_request)(struct request *, u64);
	void (*requeue_request)(struct request *);
	struct request * (*former_request)(struct request_queue *, struct request *);
	struct request * (*next_request)(struct request_queue *, struct request *);
	void (*init_icq)(struct io_cq *);
	void (*exit_icq)(struct io_cq *);
};

struct blk_mq_debugfs_attr;

struct elv_fs_entry;

struct elevator_type {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry *elevator_attrs;
	const char *elevator_name;
	const char *elevator_alias;
	const unsigned int elevator_features;
	struct module___2 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
};

struct elevator_queue {
	struct elevator_type *type;
	void *elevator_data;
	struct kobject kobj;
	struct mutex sysfs_lock;
	unsigned int registered: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hlist_head hash[64];
};

struct elv_fs_entry {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue *, char *);
	ssize_t (*store)(struct elevator_queue *, const char *, size_t);
};

struct blk_integrity_iter {
	void *prot_buf;
	void *data_buf;
	sector_t seed;
	unsigned int data_size;
	short unsigned int interval;
	const char *disk_name;
};

enum blkg_iostat_type {
	BLKG_IOSTAT_READ = 0,
	BLKG_IOSTAT_WRITE = 1,
	BLKG_IOSTAT_DISCARD = 2,
	BLKG_IOSTAT_NR = 3,
};

struct blkcg_policy_data;

struct blkcg {
	struct cgroup_subsys_state css;
	spinlock_t lock;
	refcount_t online_pin;
	struct xarray blkg_tree;
	struct blkcg_gq *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data *cpd[6];
	struct list_head all_blkcgs_node;
	char fc_app_id[129];
	struct list_head cgwb_list;
};

struct blkcg_policy_data {
	struct blkcg *blkcg;
	int plid;
};

struct blkg_policy_data {
	struct blkcg_gq *blkg;
	int plid;
};

typedef long unsigned int efi_status_t;

typedef u8 efi_bool_t;

typedef u16 efi_char16_t;

typedef guid_t efi_guid_t;

typedef struct {
	u64 signature;
	u32 revision;
	u32 headersize;
	u32 crc32;
	u32 reserved;
} efi_table_hdr_t;

typedef struct {
	u32 type;
	u32 pad;
	u64 phys_addr;
	u64 virt_addr;
	u64 num_pages;
	u64 attribute;
} efi_memory_desc_t;

typedef struct {
	efi_guid_t guid;
	u32 headersize;
	u32 flags;
	u32 imagesize;
} efi_capsule_header_t;

typedef struct {
	u16 year;
	u8 month;
	u8 day;
	u8 hour;
	u8 minute;
	u8 second;
	u8 pad1;
	u32 nanosecond;
	s16 timezone;
	u8 daylight;
	u8 pad2;
} efi_time_t;

typedef struct {
	u32 resolution;
	u32 accuracy;
	u8 sets_to_zero;
} efi_time_cap_t;

typedef struct {
	efi_table_hdr_t hdr;
	u32 get_time;
	u32 set_time;
	u32 get_wakeup_time;
	u32 set_wakeup_time;
	u32 set_virtual_address_map;
	u32 convert_pointer;
	u32 get_variable;
	u32 get_next_variable;
	u32 set_variable;
	u32 get_next_high_mono_count;
	u32 reset_system;
	u32 update_capsule;
	u32 query_capsule_caps;
	u32 query_variable_info;
} efi_runtime_services_32_t;

typedef efi_status_t efi_get_time_t(efi_time_t *, efi_time_cap_t *);

typedef efi_status_t efi_set_time_t(efi_time_t *);

typedef efi_status_t efi_get_wakeup_time_t(efi_bool_t *, efi_bool_t *, efi_time_t *);

typedef efi_status_t efi_set_wakeup_time_t(efi_bool_t, efi_time_t *);

typedef efi_status_t efi_get_variable_t(efi_char16_t *, efi_guid_t *, u32 *, long unsigned int *, void *);

typedef efi_status_t efi_get_next_variable_t(long unsigned int *, efi_char16_t *, efi_guid_t *);

typedef efi_status_t efi_set_variable_t(efi_char16_t *, efi_guid_t *, u32, long unsigned int, void *);

typedef efi_status_t efi_get_next_high_mono_count_t(u32 *);

typedef void efi_reset_system_t(int, efi_status_t, long unsigned int, efi_char16_t *);

typedef efi_status_t efi_query_variable_info_t(u32, u64 *, u64 *, u64 *);

typedef efi_status_t efi_update_capsule_t(efi_capsule_header_t **, long unsigned int, long unsigned int);

typedef efi_status_t efi_query_capsule_caps_t(efi_capsule_header_t **, long unsigned int, u64 *, int *);

typedef union {
	struct {
		efi_table_hdr_t hdr;
		efi_status_t (*get_time)(efi_time_t *, efi_time_cap_t *);
		efi_status_t (*set_time)(efi_time_t *);
		efi_status_t (*get_wakeup_time)(efi_bool_t *, efi_bool_t *, efi_time_t *);
		efi_status_t (*set_wakeup_time)(efi_bool_t, efi_time_t *);
		efi_status_t (*set_virtual_address_map)(long unsigned int, long unsigned int, u32, efi_memory_desc_t *);
		void *convert_pointer;
		efi_status_t (*get_variable)(efi_char16_t *, efi_guid_t *, u32 *, long unsigned int *, void *);
		efi_status_t (*get_next_variable)(long unsigned int *, efi_char16_t *, efi_guid_t *);
		efi_status_t (*set_variable)(efi_char16_t *, efi_guid_t *, u32, long unsigned int, void *);
		efi_status_t (*get_next_high_mono_count)(u32 *);
		void (*reset_system)(int, efi_status_t, long unsigned int, efi_char16_t *);
		efi_status_t (*update_capsule)(efi_capsule_header_t **, long unsigned int, long unsigned int);
		efi_status_t (*query_capsule_caps)(efi_capsule_header_t **, long unsigned int, u64 *, int *);
		efi_status_t (*query_variable_info)(u32, u64 *, u64 *, u64 *);
	};
	efi_runtime_services_32_t mixed_mode;
} efi_runtime_services_t;

struct efi_memory_map {
	phys_addr_t phys_map;
	void *map;
	void *map_end;
	int nr_map;
	long unsigned int desc_version;
	long unsigned int desc_size;
	long unsigned int flags;
};

struct efi {
	const efi_runtime_services_t *runtime;
	unsigned int runtime_version;
	unsigned int runtime_supported_mask;
	long unsigned int acpi;
	long unsigned int acpi20;
	long unsigned int smbios;
	long unsigned int smbios3;
	long unsigned int esrt;
	long unsigned int tpm_log;
	long unsigned int tpm_final_log;
	long unsigned int mokvar_table;
	efi_get_time_t *get_time;
	efi_set_time_t *set_time;
	efi_get_wakeup_time_t *get_wakeup_time;
	efi_set_wakeup_time_t *set_wakeup_time;
	efi_get_variable_t *get_variable;
	efi_get_next_variable_t *get_next_variable;
	efi_set_variable_t *set_variable;
	efi_set_variable_t *set_variable_nonblocking;
	efi_query_variable_info_t *query_variable_info;
	efi_query_variable_info_t *query_variable_info_nonblocking;
	efi_update_capsule_t *update_capsule;
	efi_query_capsule_caps_t *query_capsule_caps;
	efi_get_next_high_mono_count_t *get_next_high_mono_count;
	efi_reset_system_t *reset_system;
	struct efi_memory_map memmap;
	long unsigned int flags;
};

enum memcg_stat_item {
	MEMCG_SWAP = 39,
	MEMCG_SOCK = 40,
	MEMCG_PERCPU_B = 41,
	MEMCG_NR_STAT = 42,
};

enum memcg_memory_event {
	MEMCG_LOW = 0,
	MEMCG_HIGH = 1,
	MEMCG_MAX = 2,
	MEMCG_OOM = 3,
	MEMCG_OOM_KILL = 4,
	MEMCG_SWAP_HIGH = 5,
	MEMCG_SWAP_MAX = 6,
	MEMCG_SWAP_FAIL = 7,
	MEMCG_NR_MEMORY_EVENTS = 8,
};

enum mem_cgroup_events_target {
	MEM_CGROUP_TARGET_THRESH = 0,
	MEM_CGROUP_TARGET_SOFTLIMIT = 1,
	MEM_CGROUP_NTARGETS = 2,
};

struct memcg_vmstats_percpu {
	long int state[42];
	long unsigned int events[100];
	long int state_prev[42];
	long unsigned int events_prev[100];
	long unsigned int nr_page_events;
	long unsigned int targets[2];
};

struct mem_cgroup_reclaim_iter {
	struct mem_cgroup *position;
	unsigned int generation;
};

struct shrinker_info {
	struct callback_head rcu;
	atomic_long_t *nr_deferred;
	long unsigned int *map;
};

struct lruvec_stats_percpu {
	long int state[39];
	long int state_prev[39];
};

struct lruvec_stats {
	long int state[39];
	long int state_pending[39];
};

struct mem_cgroup_per_node {
	struct lruvec lruvec;
	struct lruvec_stats_percpu *lruvec_stats_percpu;
	struct lruvec_stats lruvec_stats;
	long unsigned int lru_zone_size[25];
	struct mem_cgroup_reclaim_iter iter;
	struct shrinker_info *shrinker_info;
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	struct mem_cgroup *memcg;
};

struct eventfd_ctx;

struct mem_cgroup_threshold {
	struct eventfd_ctx *eventfd;
	long unsigned int threshold;
};

struct mem_cgroup_threshold_ary {
	int current_threshold;
	unsigned int size;
	struct mem_cgroup_threshold entries[0];
};

struct obj_cgroup {
	struct percpu_ref refcnt;
	struct mem_cgroup *memcg;
	atomic_t nr_charged_bytes;
	union {
		struct list_head list;
		struct callback_head rcu;
	};
};

struct percpu_cluster {
	struct swap_cluster_info index;
	unsigned int next;
};

enum fs_value_type {
	fs_value_is_undefined = 0,
	fs_value_is_flag = 1,
	fs_value_is_string = 2,
	fs_value_is_blob = 3,
	fs_value_is_filename = 4,
	fs_value_is_file = 5,
};

struct fs_parameter {
	const char *key;
	enum fs_value_type type: 8;
	long: 56;
	long: 64;
	union {
		char *string;
		void *blob;
		struct filename *name;
		struct file___2 *file;
	};
	size_t size;
	int dirfd;
};

struct fc_log {
	refcount_t usage;
	u8 head;
	u8 tail;
	u8 need_free;
	struct module___2 *owner;
	char *buffer[8];
};

struct fs_context_operations {
	void (*free)(struct fs_context *);
	int (*dup)(struct fs_context *, struct fs_context *);
	int (*parse_param)(struct fs_context *, struct fs_parameter *);
	int (*parse_monolithic)(struct fs_context *, void *);
	int (*get_tree)(struct fs_context *);
	int (*reconfigure)(struct fs_context *);
};

struct fs_parse_result {
	bool negated;
	union {
		bool boolean;
		int int_32;
		unsigned int uint_32;
		u64 uint_64;
	};
};

struct trace_event_raw_initcall_level {
	struct trace_entry ent;
	u32 __data_loc_level;
	char __data[0];
};

struct trace_event_raw_initcall_start {
	struct trace_entry ent;
	initcall_t func;
	char __data[0];
};

struct trace_event_raw_initcall_finish {
	struct trace_entry ent;
	initcall_t func;
	int ret;
	char __data[0];
};

struct trace_event_data_offsets_initcall_level {
	u32 level;
};

struct trace_event_data_offsets_initcall_start {};

struct trace_event_data_offsets_initcall_finish {};

typedef void (*btf_trace_initcall_level)(void *, const char *);

typedef void (*btf_trace_initcall_start)(void *, initcall_t);

typedef void (*btf_trace_initcall_finish)(void *, initcall_t, int);

struct blacklist_entry {
	struct list_head next;
	char *buf;
};

typedef __u32 Elf32_Word;

struct elf32_note {
	Elf32_Word n_namesz;
	Elf32_Word n_descsz;
	Elf32_Word n_type;
};

struct mm_struct___4;

struct cred___2;

struct nsproxy___3;

struct signal_struct___3;

struct io_context___2;

struct vm_struct___3;

struct task_struct___4 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___4 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___4 *mm;
	struct mm_struct___4 *active_mm;
	struct vmacache vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int restore_sigmask: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___4 *real_parent;
	struct task_struct___4 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___4 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	struct posix_cputimers_work posix_cputimers_work;
	const struct cred___2 *ptracer_cred;
	const struct cred___2 *real_cred;
	const struct cred___2 *cred;
	struct key *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___3 *nsproxy;
	struct signal_struct___3 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___4 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context___2 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set *cgroups;
	struct list_head cg_list;
	u32 closid;
	u32 rmid;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	struct pipe_inode_info *splice_pipe;
	struct page_frag task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup *active_memcg;
	struct request_queue *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___4 *oom_reaper_list;
	struct vm_struct___3 *stack_vm_area;
	refcount_t stack_refcount;
	int patch_state;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	void *mce_vaddr;
	__u64 mce_kflags;
	u64 mce_addr;
	__u64 mce_ripv: 1;
	__u64 mce_whole_page: 1;
	__u64 __mce_reserved: 62;
	long: 2;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct callback_head mce_kill_me;
	int mce_count;
	struct llist_head kretprobe_instances;
	struct callback_head l1d_flush_kill;
	long: 64;
	struct thread_struct thread;
};

struct user_namespace___2;

struct ucounts___2;

struct cred___2 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key *session_keyring;
	struct key *process_keyring;
	struct key *thread_keyring;
	struct key *request_key_auth;
	void *security;
	struct user_struct *user;
	struct user_namespace___2 *user_ns;
	struct ucounts___2 *ucounts;
	struct group_info *group_info;
	union {
		int non_rcu;
		struct callback_head rcu;
	};
};

struct uts_namespace___2;

struct cgroup_namespace___2;

struct nsproxy___3 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace *pid_ns_for_children;
	struct net *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___2 *cgroup_ns;
};

struct proc_ns_operations___2;

struct ns_common___2 {
	atomic_long_t stashed;
	const struct proc_ns_operations___2 *ops;
	unsigned int inum;
	refcount_t count;
};

struct uts_namespace___2 {
	struct new_utsname name;
	struct user_namespace *user_ns;
	struct ucounts *ucounts;
	struct ns_common___2 ns;
};

struct nsset___2 {
	unsigned int flags;
	struct nsproxy___3 *nsproxy;
	struct fs_struct *fs;
	const struct cred___2 *cred;
};

struct proc_ns_operations___2 {
	const char *name;
	const char *real_ns_name;
	int type;
	struct ns_common___2 * (*get)(struct task_struct___4 *);
	void (*put)(struct ns_common___2 *);
	int (*install)(struct nsset___2 *, struct ns_common___2 *);
	struct user_namespace * (*owner)(struct ns_common___2 *);
	struct ns_common___2 * (*get_parent)(struct ns_common___2 *);
};

enum {
	PROC_ROOT_INO = 1,
	PROC_IPC_INIT_INO = 4026531839,
	PROC_UTS_INIT_INO = 4026531838,
	PROC_USER_INIT_INO = 4026531837,
	PROC_PID_INIT_INO = 4026531836,
	PROC_CGROUP_INIT_INO = 4026531835,
	PROC_TIME_INIT_INO = 4026531834,
};

typedef __u16 __le16;

typedef __u16 __be16;

typedef __u32 __be32;

typedef __u64 __be64;

typedef __u32 __wsum;

typedef unsigned int slab_flags_t;

struct fs_context___2;

struct fs_parameter_spec___2;

struct dentry___3;

struct super_block___3;

struct module___4;

struct file_system_type___3 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context___2 *);
	const struct fs_parameter_spec___2 *parameters;
	struct dentry___3 * (*mount)(struct file_system_type___3 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___3 *);
	struct module___4 *owner;
	struct file_system_type___3 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___3;

struct kiocb___3;

struct iov_iter___3;

struct poll_table_struct___3;

struct vm_area_struct___4;

struct inode___3;

struct file_lock___3;

struct page___4;

struct seq_file___3;

struct file_operations___3 {
	struct module___4 *owner;
	loff_t (*llseek)(struct file___3 *, loff_t, int);
	ssize_t (*read)(struct file___3 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___3 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___3 *, struct iov_iter___3 *);
	ssize_t (*write_iter)(struct kiocb___3 *, struct iov_iter___3 *);
	int (*iopoll)(struct kiocb___3 *, bool);
	int (*iterate)(struct file___3 *, struct dir_context *);
	int (*iterate_shared)(struct file___3 *, struct dir_context *);
	__poll_t (*poll)(struct file___3 *, struct poll_table_struct___3 *);
	long int (*unlocked_ioctl)(struct file___3 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___3 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___3 *, struct vm_area_struct___4 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___3 *, struct file___3 *);
	int (*flush)(struct file___3 *, fl_owner_t);
	int (*release)(struct inode___3 *, struct file___3 *);
	int (*fsync)(struct file___3 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___3 *, int);
	int (*lock)(struct file___3 *, int, struct file_lock___3 *);
	ssize_t (*sendpage)(struct file___3 *, struct page___4 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___3 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___3 *, long unsigned int);
	int (*flock)(struct file___3 *, int, struct file_lock___3 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___3 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___3 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___3 *, long int, struct file_lock___3 **, void **);
	long int (*fallocate)(struct file___3 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___3 *, struct file___3 *);
	ssize_t (*copy_file_range)(struct file___3 *, loff_t, struct file___3 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___3 *, loff_t, struct file___3 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___3 *, loff_t, loff_t, int);
};

struct static_call_mod___2 {
	struct static_call_mod___2 *next;
	struct module___4 *mod;
	struct static_call_site *sites;
};

struct static_call_key___2 {
	void *func;
	union {
		long unsigned int type;
		struct static_call_mod___2 *mods;
		struct static_call_site *sites;
	};
};

typedef struct page___4 *pgtable_t___3;

struct address_space___3;

struct mm_struct___5;

struct dev_pagemap___3;

struct page___4 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___3 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___4 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___3 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___5 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___3 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct perf_event___2;

struct thread_struct___2 {
	struct desc_struct tls_array[3];
	long unsigned int sp;
	short unsigned int es;
	short unsigned int ds;
	short unsigned int fsindex;
	short unsigned int gsindex;
	long unsigned int fsbase;
	long unsigned int gsbase;
	struct perf_event___2 *ptrace_bps[4];
	long unsigned int virtual_dr6;
	long unsigned int ptrace_dr7;
	long unsigned int cr2;
	long unsigned int trap_nr;
	long unsigned int error_code;
	struct io_bitmap *io_bitmap;
	long unsigned int iopl_emul;
	unsigned int iopl_warn: 1;
	unsigned int sig_on_uaccess_err: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u32 pkru;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct fpu fpu;
};

struct vmacache___3 {
	u64 seqnum;
	struct vm_area_struct___4 *vmas[4];
};

struct page_frag___3 {
	struct page___4 *page;
	__u32 offset;
	__u32 size;
};

struct pid___2;

struct fs_struct___2;

struct nsproxy___4;

struct signal_struct___4;

struct bio_list___2;

struct backing_dev_info___2;

struct io_context___3;

struct css_set___3;

struct perf_event_context___3;

struct mem_cgroup___2;

struct request_queue___2;

struct vm_struct___4;

struct task_struct___5 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___5 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___5 *mm;
	struct mm_struct___5 *active_mm;
	struct vmacache___3 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int restore_sigmask: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___5 *real_parent;
	struct task_struct___5 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___5 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___2 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	struct posix_cputimers_work posix_cputimers_work;
	const struct cred *ptracer_cred;
	const struct cred *real_cred;
	const struct cred *cred;
	struct key *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct___2 *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___4 *nsproxy;
	struct signal_struct___4 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___5 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___3 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___3 *cgroups;
	struct list_head cg_list;
	u32 closid;
	u32 rmid;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___3 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	struct pipe_inode_info *splice_pipe;
	struct page_frag___3 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___2 *active_memcg;
	struct request_queue___2 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___5 *oom_reaper_list;
	struct vm_struct___4 *stack_vm_area;
	refcount_t stack_refcount;
	int patch_state;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	void *mce_vaddr;
	__u64 mce_kflags;
	u64 mce_addr;
	__u64 mce_ripv: 1;
	__u64 mce_whole_page: 1;
	__u64 __mce_reserved: 62;
	long: 2;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct callback_head mce_kill_me;
	int mce_count;
	struct llist_head kretprobe_instances;
	struct callback_head l1d_flush_kill;
	long: 64;
	struct thread_struct___2 thread;
};

struct core_state___3;

struct mm_struct___5 {
	struct {
		struct vm_area_struct___4 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___3 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int mmap_compat_base;
		long unsigned int mmap_compat_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[48];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___3 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___5 *owner;
		struct user_namespace *user_ns;
		struct file___3 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		bool tlb_flush_batched;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct vm_operations_struct___3;

struct vm_area_struct___4 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___4 *vm_next;
	struct vm_area_struct___4 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___5 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___3 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___3 *vm_file;
	struct file___3 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct tracepoint___2 {
	const char *name;
	struct static_key key;
	struct static_call_key___2 *static_call_key;
	void *static_call_tramp;
	void *iterator;
	int (*regfunc)();
	void (*unregfunc)();
	struct tracepoint_func *funcs;
};

struct bpf_raw_event_map___2 {
	struct tracepoint___2 *tp;
	void *bpf_func;
	u32 num_args;
	u32 writable_size;
	long: 64;
};

struct seq_operations___2 {
	void * (*start)(struct seq_file___3 *, loff_t *);
	void (*stop)(struct seq_file___3 *, void *);
	void * (*next)(struct seq_file___3 *, void *, loff_t *);
	int (*show)(struct seq_file___3 *, void *);
};

struct hw_perf_event___2 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___5 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	union {
		struct {
			u64 last_period;
			local64_t period_left;
		};
		struct {
			u64 saved_metric;
			u64 saved_slots;
		};
	};
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

struct perf_sample_data___2;

typedef void (*perf_overflow_handler_t___2)(struct perf_event___2 *, struct perf_sample_data___2 *, struct pt_regs *);

struct pmu___2;

struct fasync_struct___3;

struct pid_namespace___2;

struct trace_event_call___2;

struct perf_cgroup___2;

struct perf_event___2 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___2 *group_leader;
	struct pmu___2 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___2 hw;
	struct perf_event_context___3 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___2 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___5 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct perf_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___3 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	long unsigned int pending_addr;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	struct perf_addr_filter_range *addr_filter_ranges;
	long unsigned int addr_filters_gen;
	struct perf_event___2 *aux_event;
	void (*destroy)(struct perf_event___2 *);
	struct callback_head callback_head;
	struct pid_namespace___2 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___2 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___2 orig_overflow_handler;
	struct bpf_prog *prog;
	u64 bpf_cookie;
	struct trace_event_call___2 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___2 *cgrp;
	void *security;
	struct list_head sb_list;
};

struct notifier_block;

typedef int (*notifier_fn_t)(struct notifier_block *, long unsigned int, void *);

struct notifier_block {
	notifier_fn_t notifier_call;
	struct notifier_block *next;
	int priority;
};

struct blocking_notifier_head {
	struct rw_semaphore rwsem;
	struct notifier_block *head;
};

struct raw_notifier_head {
	struct notifier_block *head;
};

struct address_space_operations___3;

struct address_space___3 {
	struct inode___3 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___3 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct device___4;

struct page_pool_params {
	unsigned int flags;
	unsigned int order;
	unsigned int pool_size;
	int nid;
	struct device___4 *dev;
	enum dma_data_direction dma_dir;
	unsigned int max_len;
	unsigned int offset;
};

struct pp_alloc_cache {
	u32 count;
	struct page___4 *cache[128];
};

struct ptr_ring {
	int producer;
	spinlock_t producer_lock;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int consumer_head;
	int consumer_tail;
	spinlock_t consumer_lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int size;
	int batch;
	void **queue;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct page_pool {
	struct page_pool_params p;
	struct delayed_work release_dw;
	void (*disconnect)(void *);
	long unsigned int defer_start;
	long unsigned int defer_warn;
	u32 pages_state_hold_cnt;
	unsigned int frag_offset;
	struct page___4 *frag_page;
	long int frag_users;
	long: 64;
	long: 64;
	struct pp_alloc_cache alloc;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct ptr_ring ring;
	atomic_t pages_state_release_cnt;
	refcount_t user_cnt;
	u64 destroy_cnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pagemap_ops___3;

struct dev_pagemap___3 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___3 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vfsmount___3;

struct path___3 {
	struct vfsmount___3 *mnt;
	struct dentry___3 *dentry;
};

struct fown_struct___2 {
	rwlock_t lock;
	struct pid___2 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___3 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___3 f_path;
	struct inode___3 *f_inode;
	const struct file_operations___3 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___2 f_owner;
	const struct cred *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___3 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___3;

struct vm_operations_struct___3 {
	void (*open)(struct vm_area_struct___4 *);
	void (*close)(struct vm_area_struct___4 *);
	int (*may_split)(struct vm_area_struct___4 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___4 *);
	int (*mprotect)(struct vm_area_struct___4 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___3 *);
	vm_fault_t (*huge_fault)(struct vm_fault___3 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___3 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___4 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___3 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___3 *);
	int (*access)(struct vm_area_struct___4 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___4 *);
	int (*set_policy)(struct vm_area_struct___4 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___4 *, long unsigned int);
	struct page___4 * (*find_special_page)(struct vm_area_struct___4 *, long unsigned int);
};

struct core_thread___3 {
	struct task_struct___5 *task;
	struct core_thread___3 *next;
};

struct core_state___3 {
	atomic_t nr_threads;
	struct core_thread___3 dumper;
	struct completion startup;
};

struct vm_fault___3 {
	const struct {
		struct vm_area_struct___4 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___4 *cow_page;
	struct page___4 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___3 prealloc_pte;
};

struct pglist_data___2;

struct lruvec___2 {
	struct list_head lists[5];
	spinlock_t lru_lock;
	long unsigned int anon_cost;
	long unsigned int file_cost;
	atomic_long_t nonresident_age;
	long unsigned int refaults[2];
	long unsigned int flags;
	struct pglist_data___2 *pgdat;
};

struct zone___2 {
	long unsigned int _watermark[3];
	long unsigned int watermark_boost;
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[5];
	int node;
	struct pglist_data___2 *zone_pgdat;
	struct per_cpu_pages *per_cpu_pageset;
	struct per_cpu_zonestat *per_cpu_zonestats;
	int pageset_high;
	int pageset_batch;
	long unsigned int zone_start_pfn;
	atomic_long_t managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int present_early_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	seqlock_t span_seqlock;
	int initialized;
	int: 32;
	struct zone_padding _pad1_;
	struct free_area free_area[11];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	long unsigned int compact_init_migrate_pfn;
	long unsigned int compact_init_free_pfn;
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	short: 16;
	struct zone_padding _pad3_;
	atomic_long_t vm_stat[11];
	atomic_long_t vm_numa_event[6];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___2 {
	struct zone___2 *zone;
	int zone_idx;
};

struct zonelist___2 {
	struct zoneref___2 _zonerefs[5121];
};

struct pglist_data___2 {
	struct zone___2 node_zones[5];
	struct zonelist___2 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___5 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_highest_zoneidx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_highest_zoneidx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___5 *kcompactd;
	bool proactive_compact_trigger;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct deferred_split deferred_split_queue;
	struct lruvec___2 __lruvec;
	long unsigned int flags;
	long: 64;
	struct zone_padding _pad2_;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[39];
};

struct kernfs_root___2;

struct kernfs_elem_dir___2 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___2 *root;
	long unsigned int rev;
};

struct kernfs_node___2;

struct kernfs_syscall_ops___2;

struct kernfs_root___2 {
	struct kernfs_node___2 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___2 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___2 {
	struct kernfs_node___2 *target_kn;
};

struct kernfs_ops___2;

struct kernfs_elem_attr___2 {
	const struct kernfs_ops___2 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___2 *notify_next;
};

struct kernfs_node___2 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___2 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___2 dir;
		struct kernfs_elem_symlink___2 symlink;
		struct kernfs_elem_attr___2 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___2;

struct kernfs_ops___2 {
	int (*open)(struct kernfs_open_file___2 *);
	void (*release)(struct kernfs_open_file___2 *);
	int (*seq_show)(struct seq_file___3 *, void *);
	void * (*seq_start)(struct seq_file___3 *, loff_t *);
	void * (*seq_next)(struct seq_file___3 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___3 *, void *);
	ssize_t (*read)(struct kernfs_open_file___2 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___2 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___2 *, struct poll_table_struct___3 *);
	int (*mmap)(struct kernfs_open_file___2 *, struct vm_area_struct___4 *);
};

struct kernfs_syscall_ops___2 {
	int (*show_options)(struct seq_file___3 *, struct kernfs_root___2 *);
	int (*mkdir)(struct kernfs_node___2 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___2 *);
	int (*rename)(struct kernfs_node___2 *, struct kernfs_node___2 *, const char *);
	int (*show_path)(struct seq_file___3 *, struct kernfs_node___2 *, struct kernfs_root___2 *);
};

struct seq_file___3 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___2 *op;
	int poll_event;
	const struct file___3 *file;
	void *private;
};

struct kernfs_open_file___2 {
	struct kernfs_node___2 *kn;
	struct file___3 *file;
	struct seq_file___3 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___3 *vm_ops;
};

typedef void (*poll_queue_proc___2)(struct file___3 *, wait_queue_head_t *, struct poll_table_struct___3 *);

struct poll_table_struct___3 {
	poll_queue_proc___2 _qproc;
	__poll_t _key;
};

typedef __u64 __addrpair;

typedef __u32 __portpair;

struct net___2;

typedef struct {
	struct net___2 *net;
} possible_net_t;

struct in6_addr {
	union {
		__u8 u6_addr8[16];
		__be16 u6_addr16[8];
		__be32 u6_addr32[4];
	} in6_u;
};

struct hlist_nulls_node {
	struct hlist_nulls_node *next;
	struct hlist_nulls_node **pprev;
};

struct proto;

struct inet_timewait_death_row;

struct sock_common {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 1;
	unsigned char skc_ipv6only: 1;
	unsigned char skc_net_refcnt: 1;
	long: 31;
	long: 64;
	long: 64;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_node skc_portaddr_node;
	};
	struct proto *skc_prot;
	possible_net_t skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	atomic64_t skc_cookie;
	union {
		long unsigned int skc_flags;
		struct sock *skc_listener;
		struct inet_timewait_death_row *skc_tw_dr;
	};
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	short unsigned int skc_tx_queue_mapping;
	short unsigned int skc_rx_queue_mapping;
	union {
		int skc_incoming_cpu;
		u32 skc_rcv_wnd;
		u32 skc_tw_rcv_nxt;
	};
	refcount_t skc_refcnt;
	int skc_dontcopy_end[0];
	union {
		u32 skc_rxhash;
		u32 skc_window_clamp;
		u32 skc_tw_snd_nxt;
	};
};

typedef struct {
	spinlock_t slock;
	int owned;
	wait_queue_head_t wq;
} socket_lock_t;

struct sk_buff;

struct sk_buff_head {
	struct sk_buff *next;
	struct sk_buff *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct xfrm_policy;

typedef u64 netdev_features_t;

struct cgroup___2;

struct sock_cgroup_data {
	struct cgroup___2 *cgroup;
	u32 classid;
	u16 prioidx;
};

struct sock_reuseport;

struct sk_filter;

struct socket_wq;

struct dst_entry;

struct socket;

struct net_device;

struct sock {
	struct sock_common __sk_common;
	socket_lock_t sk_lock;
	atomic_t sk_drops;
	int sk_rcvlowat;
	struct sk_buff_head sk_error_queue;
	struct sk_buff *sk_rx_skb_cache;
	struct sk_buff_head sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff *head;
		struct sk_buff *tail;
	} sk_backlog;
	int sk_forward_alloc;
	unsigned int sk_ll_usec;
	unsigned int sk_napi_id;
	int sk_rcvbuf;
	struct sk_filter *sk_filter;
	union {
		struct socket_wq *sk_wq;
		struct socket_wq *sk_wq_raw;
	};
	struct xfrm_policy *sk_policy[2];
	struct dst_entry *sk_rx_dst;
	int sk_rx_dst_ifindex;
	u32 sk_rx_dst_cookie;
	struct dst_entry *sk_dst_cache;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	int sk_wmem_queued;
	refcount_t sk_wmem_alloc;
	long unsigned int sk_tsq_flags;
	union {
		struct sk_buff *sk_send_head;
		struct rb_root tcp_rtx_queue;
	};
	struct sk_buff *sk_tx_skb_cache;
	struct sk_buff_head sk_write_queue;
	__s32 sk_peek_off;
	int sk_write_pending;
	__u32 sk_dst_pending_confirm;
	u32 sk_pacing_status;
	long int sk_sndtimeo;
	struct timer_list sk_timer;
	__u32 sk_priority;
	__u32 sk_mark;
	long unsigned int sk_pacing_rate;
	long unsigned int sk_max_pacing_rate;
	struct page_frag___3 sk_frag;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	netdev_features_t sk_route_forced_caps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	gfp_t sk_allocation;
	__u32 sk_txhash;
	u8 sk_padding: 1;
	u8 sk_kern_sock: 1;
	u8 sk_no_check_tx: 1;
	u8 sk_no_check_rx: 1;
	u8 sk_userlocks: 4;
	long: 4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u8 sk_pacing_shift;
	u16 sk_type;
	u16 sk_protocol;
	u16 sk_gso_max_segs;
	long unsigned int sk_lingertime;
	struct proto *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	u32 sk_ack_backlog;
	u32 sk_max_ack_backlog;
	kuid_t sk_uid;
	u8 sk_prefer_busy_poll;
	u16 sk_busy_poll_budget;
	spinlock_t sk_peer_lock;
	struct pid___2 *sk_peer_pid;
	const struct cred *sk_peer_cred;
	long int sk_rcvtimeo;
	ktime_t sk_stamp;
	u16 sk_tsflags;
	int sk_bind_phc;
	u8 sk_shutdown;
	atomic_t sk_tskey;
	atomic_t sk_zckey;
	u8 sk_clockid;
	u8 sk_txtime_deadline_mode: 1;
	u8 sk_txtime_report_errors: 1;
	u8 sk_txtime_unused: 6;
	long: 58;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct socket *sk_socket;
	void *sk_user_data;
	void *sk_security;
	struct sock_cgroup_data sk_cgrp_data;
	struct mem_cgroup___2 *sk_memcg;
	void (*sk_state_change)(struct sock *);
	void (*sk_data_ready)(struct sock *);
	void (*sk_write_space)(struct sock *);
	void (*sk_error_report)(struct sock *);
	int (*sk_backlog_rcv)(struct sock *, struct sk_buff *);
	struct sk_buff * (*sk_validate_xmit_skb)(struct sock *, struct net_device *, struct sk_buff *);
	void (*sk_destruct)(struct sock *);
	struct sock_reuseport *sk_reuseport_cb;
	struct bpf_local_storage *sk_bpf_storage;
	struct callback_head sk_rcu;
};

struct kobject___2;

struct bin_attribute___2;

struct attribute_group___2 {
	const char *name;
	umode_t (*is_visible)(struct kobject___2 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___2 *, struct bin_attribute___2 *, int);
	struct attribute **attrs;
	struct bin_attribute___2 **bin_attrs;
};

struct kset___2;

struct kobj_type___2;

struct kobject___2 {
	const char *name;
	struct list_head entry;
	struct kobject___2 *parent;
	struct kset___2 *kset;
	struct kobj_type___2 *ktype;
	struct kernfs_node___2 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bin_attribute___2 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___3 * (*f_mapping)();
	ssize_t (*read)(struct file___3 *, struct kobject___2 *, struct bin_attribute___2 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___3 *, struct kobject___2 *, struct bin_attribute___2 *, char *, loff_t, size_t);
	int (*mmap)(struct file___3 *, struct kobject___2 *, struct bin_attribute___2 *, struct vm_area_struct___4 *);
};

struct sysfs_ops___2 {
	ssize_t (*show)(struct kobject___2 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___2 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___2;

struct kset___2 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___2 kobj;
	const struct kset_uevent_ops___2 *uevent_ops;
};

struct kobj_type___2 {
	void (*release)(struct kobject___2 *);
	const struct sysfs_ops___2 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___2 **default_groups;
	const struct kobj_ns_type_operations * (*child_ns_type)(struct kobject___2 *);
	const void * (*namespace)(struct kobject___2 *);
	void (*get_ownership)(struct kobject___2 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___2 {
	int (* const filter)(struct kset___2 *, struct kobject___2 *);
	const char * (* const name)(struct kset___2 *, struct kobject___2 *);
	int (* const uevent)(struct kset___2 *, struct kobject___2 *, struct kobj_uevent_env *);
};

struct kernel_param___2;

struct kernel_param_ops___2 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___2 *);
	int (*get)(char *, const struct kernel_param___2 *);
	void (*free)(void *);
};

struct kparam_array___2;

struct kernel_param___2 {
	const char *name;
	struct module___4 *mod;
	const struct kernel_param_ops___2 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___2 *arr;
	};
};

struct kparam_array___2 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___2 *ops;
	void *elem;
};

struct module_kobject___2 {
	struct kobject___2 kobj;
	struct module___4 *mod;
	struct kobject___2 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___2 {
	struct module___4 *mod;
	struct latch_tree_node node;
};

struct module_layout___2 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___2 mtn;
};

struct module_attribute___2;

struct module___4 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___2 mkobj;
	struct module_attribute___2 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___2 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___2 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___2 core_layout;
	struct module_layout___2 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map___2 *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___2 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	int num_static_call_sites;
	struct static_call_site *static_call_sites;
	bool klp;
	bool klp_alive;
	struct klp_modinfo *klp_info;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_attribute___2 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___2 *, struct module_kobject___2 *, char *);
	ssize_t (*store)(struct module_attribute___2 *, struct module_kobject___2 *, const char *, size_t);
	void (*setup)(struct module___4 *, const char *);
	int (*test)(struct module___4 *);
	void (*free)(struct module___4 *);
};

struct trace_event_class___2;

struct trace_event_call___2 {
	struct list_head list;
	struct trace_event_class___2 *class;
	union {
		char *name;
		struct tracepoint___2 *tp;
	};
	struct trace_event event;
	char *print_fmt;
	struct event_filter *filter;
	union {
		void *module;
		atomic_t refcnt;
	};
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
	struct bpf_prog_array *prog_array;
	int (*perf_perm)(struct trace_event_call___2 *, struct perf_event___2 *);
};

struct upid___2 {
	int nr;
	struct pid_namespace___2 *ns;
};

struct pid_namespace___2 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___5 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___2 *parent;
	struct fs_pin *bacct;
	struct user_namespace *user_ns;
	struct ucounts *ucounts;
	int reboot;
	struct ns_common ns;
};

struct pid___2 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___2 numbers[1];
};

struct rhash_head {
	struct rhash_head *next;
};

struct rhashtable;

struct rhashtable_compare_arg {
	struct rhashtable *ht;
	const void *key;
};

struct bucket_table;

typedef u32 (*rht_hashfn_t)(const void *, u32, u32);

typedef u32 (*rht_obj_hashfn_t)(const void *, u32, u32);

typedef int (*rht_obj_cmpfn_t)(struct rhashtable_compare_arg *, const void *);

struct rhashtable_params {
	u16 nelem_hint;
	u16 key_len;
	u16 key_offset;
	u16 head_offset;
	unsigned int max_size;
	u16 min_size;
	bool automatic_shrinking;
	rht_hashfn_t hashfn;
	rht_obj_hashfn_t obj_hashfn;
	rht_obj_cmpfn_t obj_cmpfn;
};

struct rhashtable {
	struct bucket_table *tbl;
	unsigned int key_len;
	unsigned int max_elems;
	struct rhashtable_params p;
	bool rhlist;
	struct work_struct run_work;
	struct mutex mutex;
	spinlock_t lock;
	atomic_t nelems;
};

struct tty_struct___2;

struct signal_struct___4 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___5 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___5 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___2 *pids[4];
	struct pid___2 *tty_old_pgrp;
	int leader;
	struct tty_struct___2 *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___5 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct fs_struct___2 {
	int users;
	spinlock_t lock;
	seqcount_spinlock_t seq;
	int umask;
	int in_exec;
	struct path___3 root;
	struct path___3 pwd;
};

struct cgroup_namespace___3;

struct nsproxy___4 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___2 *pid_ns_for_children;
	struct net___2 *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___3 *cgroup_ns;
};

struct bio___2;

struct bio_list___2 {
	struct bio___2 *head;
	struct bio___2 *tail;
};

struct cgroup_subsys_state___2;

struct bdi_writeback___2 {
	struct backing_dev_info___2 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	atomic_t writeback_inodes;
	struct percpu_counter stat[4];
	long unsigned int congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	struct delayed_work bw_dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___2 *memcg_css;
	struct cgroup_subsys_state___2 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	struct list_head b_attached;
	struct list_head offline_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
};

struct backing_dev_info___2 {
	u64 id;
	struct rb_node rb_node;
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___2 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct mutex cgwb_release_mutex;
	struct rw_semaphore wb_switch_rwsem;
	wait_queue_head_t wb_waitq;
	struct device___4 *dev;
	char dev_name[64];
	struct device___4 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___3 *debug_dir;
};

struct io_cq___2;

struct io_context___3 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	struct xarray icq_tree;
	struct io_cq___2 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct css_set___3 {
	struct cgroup_subsys_state___2 *subsys[14];
	refcount_t refcount;
	struct css_set___3 *dom_cset;
	struct cgroup___2 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___2 *mg_src_cgrp;
	struct cgroup___2 *mg_dst_cgrp;
	struct css_set___3 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___3 {
	struct pmu___2 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	int rotate_necessary;
	refcount_t refcount;
	struct task_struct___5 *task;
	u64 time;
	u64 timestamp;
	u64 timeoffset;
	struct perf_event_context___3 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

struct watch_queue;

struct pipe_buffer;

struct pipe_inode_info {
	struct mutex mutex;
	wait_queue_head_t rd_wait;
	wait_queue_head_t wr_wait;
	unsigned int head;
	unsigned int tail;
	unsigned int max_usage;
	unsigned int ring_size;
	bool note_loss;
	unsigned int nr_accounted;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int r_counter;
	unsigned int w_counter;
	unsigned int poll_usage;
	struct page___4 *tmp_page;
	struct fasync_struct___3 *fasync_readers;
	struct fasync_struct___3 *fasync_writers;
	struct pipe_buffer *bufs;
	struct user_struct *user;
	struct watch_queue *watch_queue;
};

struct cgroup_subsys___2;

struct cgroup_subsys_state___2 {
	struct cgroup___2 *cgroup;
	struct cgroup_subsys___2 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___2 *parent;
};

struct cgroup_file___2 {
	struct kernfs_node___2 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct obj_cgroup___2;

struct mem_cgroup_per_node___2;

struct mem_cgroup___2 {
	struct cgroup_subsys_state___2 css;
	struct mem_cgroup_id id;
	struct page_counter memory;
	union {
		struct page_counter swap;
		struct page_counter memsw;
	};
	struct page_counter kmem;
	struct page_counter tcpmem;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool oom_group;
	bool oom_lock;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___2 events_file;
	struct cgroup_file___2 events_local_file;
	struct cgroup_file___2 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	struct memcg_vmstats vmstats;
	atomic_long_t memory_events[8];
	atomic_long_t memory_events_local[8];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct obj_cgroup___2 *objcg;
	struct list_head objcg_list;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad2_;
	atomic_t moving_account;
	struct task_struct___5 *move_lock_task;
	struct memcg_vmstats_percpu *vmstats_percpu;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct memcg_cgwb_frn cgwb_frn[4];
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct deferred_split deferred_split_queue;
	struct mem_cgroup_per_node___2 *nodeinfo[0];
	long: 64;
};

struct blk_integrity_profile___2;

struct blk_integrity___2 {
	const struct blk_integrity_profile___2 *profile;
	unsigned char flags;
	unsigned char tuple_size;
	unsigned char interval_exp;
	unsigned char tag_size;
};

struct bio_set___2 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	struct bio_alloc_cache *cache;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	unsigned int back_pad;
	spinlock_t rescue_lock;
	struct bio_list___2 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	struct hlist_node cpuhp_dead;
};

struct request___2;

struct elevator_queue___2;

struct gendisk___2;

struct blkcg_gq___2;

struct request_queue___2 {
	struct request___2 *last_merge;
	struct elevator_queue___2 *elevator;
	struct percpu_ref q_usage_counter;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	const struct blk_mq_ops *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx **queue_hw_ctx;
	unsigned int nr_hw_queues;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	spinlock_t queue_lock;
	struct gendisk___2 *disk;
	struct kobject___2 kobj;
	struct kobject___2 *mq_kobj;
	struct blk_integrity___2 integrity;
	struct device___4 *dev;
	enum rpm_status rpm_status;
	long unsigned int nr_requests;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_keyslot_manager *ksm;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	atomic_t nr_active_requests_shared_sbitmap;
	struct sbitmap_queue sched_bitmap_tags;
	struct sbitmap_queue sched_breserved_tags;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___2 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int required_elevator_features;
	unsigned int nr_zones;
	long unsigned int *conv_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int max_open_zones;
	unsigned int max_active_zones;
	int node;
	struct mutex debugfs_mutex;
	struct blk_trace *blk_trace;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	struct mutex sysfs_dir_lock;
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	int mq_freeze_depth;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct mutex mq_freeze_lock;
	struct blk_mq_tag_set *tag_set;
	struct list_head tag_set_list;
	struct bio_set___2 bio_split;
	struct dentry___3 *debugfs_dir;
	struct dentry___3 *sched_debugfs_dir;
	struct dentry___3 *rqos_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	u64 write_hints[5];
};

struct vm_struct___4 {
	struct vm_struct___4 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___4 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct bio_vec___2 {
	struct page___4 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct iov_iter___3 {
	u8 iter_type;
	bool data_source;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___2 *bvec;
		struct xarray *xarray;
		struct pipe_inode_info *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			unsigned int head;
			unsigned int start_head;
		};
		loff_t xarray_start;
	};
};

typedef short unsigned int __kernel_sa_family_t;

typedef __kernel_sa_family_t sa_family_t;

struct sockaddr {
	sa_family_t sa_family;
	char sa_data[14];
};

struct msghdr {
	void *msg_name;
	int msg_namelen;
	struct iov_iter___3 msg_iter;
	union {
		void *msg_control;
		void *msg_control_user;
	};
	bool msg_control_is_user: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__kernel_size_t msg_controllen;
	unsigned int msg_flags;
	struct kiocb___3 *msg_iocb;
};

struct wait_page_queue___2;

struct kiocb___3 {
	struct file___3 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___3 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___2 *ki_waitq;
	};
};

typedef struct {
	unsigned int clock_rate;
	unsigned int clock_type;
	short unsigned int loopback;
} sync_serial_settings;

typedef struct {
	unsigned int clock_rate;
	unsigned int clock_type;
	short unsigned int loopback;
	unsigned int slot_map;
} te1_settings;

typedef struct {
	short unsigned int encoding;
	short unsigned int parity;
} raw_hdlc_proto;

typedef struct {
	unsigned int t391;
	unsigned int t392;
	unsigned int n391;
	unsigned int n392;
	unsigned int n393;
	short unsigned int lmi;
	short unsigned int dce;
} fr_proto;

typedef struct {
	unsigned int dlci;
} fr_proto_pvc;

typedef struct {
	unsigned int dlci;
	char master[16];
} fr_proto_pvc_info;

typedef struct {
	unsigned int interval;
	unsigned int timeout;
} cisco_proto;

typedef struct {
	short unsigned int dce;
	unsigned int modulo;
	unsigned int window;
	unsigned int t1;
	unsigned int t2;
	unsigned int n2;
} x25_hdlc_proto;

struct ifmap {
	long unsigned int mem_start;
	long unsigned int mem_end;
	short unsigned int base_addr;
	unsigned char irq;
	unsigned char dma;
	unsigned char port;
};

struct if_settings {
	unsigned int type;
	unsigned int size;
	union {
		raw_hdlc_proto *raw_hdlc;
		cisco_proto *cisco;
		fr_proto *fr;
		fr_proto_pvc *fr_pvc;
		fr_proto_pvc_info *fr_pvc_info;
		x25_hdlc_proto *x25;
		sync_serial_settings *sync;
		te1_settings *te1;
	} ifs_ifsu;
};

struct ifreq {
	union {
		char ifrn_name[16];
	} ifr_ifrn;
	union {
		struct sockaddr ifru_addr;
		struct sockaddr ifru_dstaddr;
		struct sockaddr ifru_broadaddr;
		struct sockaddr ifru_netmask;
		struct sockaddr ifru_hwaddr;
		short int ifru_flags;
		int ifru_ivalue;
		int ifru_mtu;
		struct ifmap ifru_map;
		char ifru_slave[16];
		char ifru_newname[16];
		void *ifru_data;
		struct if_settings ifru_settings;
	} ifr_ifru;
};

struct dentry_operations___3;

struct dentry___3 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___3 *d_parent;
	struct qstr d_name;
	struct inode___3 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___3 *d_op;
	struct super_block___3 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___3;

struct cdev___2;

struct inode___3 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___3 *i_op;
	struct super_block___3 *i_sb;
	struct address_space___3 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___2 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___3 *i_fop;
		void (*free_inode)(struct inode___3 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___3 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct cdev___2 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___3 {
	int (*d_revalidate)(struct dentry___3 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___3 *, unsigned int);
	int (*d_hash)(const struct dentry___3 *, struct qstr *);
	int (*d_compare)(const struct dentry___3 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___3 *);
	int (*d_init)(struct dentry___3 *);
	void (*d_release)(struct dentry___3 *);
	void (*d_prune)(struct dentry___3 *);
	void (*d_iput)(struct dentry___3 *, struct inode___3 *);
	char * (*d_dname)(struct dentry___3 *, char *, int);
	struct vfsmount___3 * (*d_automount)(struct path___3 *);
	int (*d_manage)(const struct path___3 *, bool);
	struct dentry___3 * (*d_real)(struct dentry___3 *, const struct inode___3 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___3;

struct mem_dqinfo___3 {
	struct quota_format_type___3 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___3;

struct quota_info___3 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___3 *files[3];
	struct mem_dqinfo___3 info[3];
	const struct quota_format_ops___3 *ops[3];
};

struct rcuwait___3 {
	struct task_struct___5 *task;
};

struct percpu_rw_semaphore___3 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___3 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___3 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___3 rw_sem[3];
};

struct shrink_control___2;

struct shrinker___2 {
	long unsigned int (*count_objects)(struct shrinker___2 *, struct shrink_control___2 *);
	long unsigned int (*scan_objects)(struct shrinker___2 *, struct shrink_control___2 *);
	long int batch;
	int seeks;
	unsigned int flags;
	struct list_head list;
	int id;
	atomic_long_t *nr_deferred;
};

struct super_operations___3;

struct dquot_operations___3;

struct quotactl_ops___3;

struct xattr_handler___2;

struct block_device___2;

struct super_block___3 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___3 *s_type;
	const struct super_operations___3 *s_op;
	const struct dquot_operations___3 *dq_op;
	const struct quotactl_ops___3 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___3 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___2 **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___2 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___3 s_dquot;
	struct sb_writers___3 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___3 *s_d_op;
	int cleancache_poolid;
	struct shrinker___2 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___3 {
	struct dentry___3 *mnt_root;
	struct super_block___3 *mnt_sb;
	int mnt_flags;
	struct user_namespace *mnt_userns;
};

struct shrink_control___2 {
	gfp_t gfp_mask;
	int nid;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	struct mem_cgroup___2 *memcg;
};

struct psi_group___2 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___5 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___2;

struct cgroup_rstat_cpu___2;

struct cgroup___2 {
	struct cgroup_subsys_state___2 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___2 *kn;
	struct cgroup_file___2 procs_file;
	struct cgroup_file___2 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___2 *subsys[14];
	struct cgroup_root___2 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___2 *dom_cgrp;
	struct cgroup___2 *old_dom_cgrp;
	struct cgroup_rstat_cpu___2 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___2 psi;
	struct cgroup_bpf bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct ld_semaphore {
	atomic_long_t count;
	raw_spinlock_t wait_lock;
	unsigned int wait_readers;
	struct list_head read_wait;
	struct list_head write_wait;
};

typedef unsigned int tcflag_t;

typedef unsigned char cc_t;

typedef unsigned int speed_t;

struct ktermios {
	tcflag_t c_iflag;
	tcflag_t c_oflag;
	tcflag_t c_cflag;
	tcflag_t c_lflag;
	cc_t c_line;
	cc_t c_cc[19];
	speed_t c_ispeed;
	speed_t c_ospeed;
};

struct winsize {
	short unsigned int ws_row;
	short unsigned int ws_col;
	short unsigned int ws_xpixel;
	short unsigned int ws_ypixel;
};

struct tty_driver;

struct tty_operations;

struct tty_ldisc;

struct tty_port;

struct tty_struct___2 {
	int magic;
	struct kref kref;
	struct device___4 *dev;
	struct tty_driver *driver;
	const struct tty_operations *ops;
	int index;
	struct ld_semaphore ldisc_sem;
	struct tty_ldisc *ldisc;
	struct mutex atomic_write_lock;
	struct mutex legacy_mutex;
	struct mutex throttle_mutex;
	struct rw_semaphore termios_rwsem;
	struct mutex winsize_mutex;
	struct ktermios termios;
	struct ktermios termios_locked;
	char name[64];
	long unsigned int flags;
	int count;
	struct winsize winsize;
	struct {
		spinlock_t lock;
		bool stopped;
		bool tco_stopped;
		long unsigned int unused[0];
	} flow;
	struct {
		spinlock_t lock;
		struct pid___2 *pgrp;
		struct pid___2 *session;
		unsigned char pktstatus;
		bool packet;
		long unsigned int unused[0];
	} ctrl;
	int hw_stopped;
	unsigned int receive_room;
	int flow_change;
	struct tty_struct___2 *link;
	struct fasync_struct___3 *fasync;
	wait_queue_head_t write_wait;
	wait_queue_head_t read_wait;
	struct work_struct hangup_work;
	void *disc_data;
	void *driver_data;
	spinlock_t files_lock;
	struct list_head tty_files;
	int closing;
	unsigned char *write_buf;
	int write_cnt;
	struct work_struct SAK_work;
	struct tty_port *port;
};

struct io_cq___2 {
	struct request_queue___2 *q;
	struct io_context___3 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct iattr___3 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___3 *ia_file;
};

struct dquot___3 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___3 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___3 {
	int qf_fmt_id;
	const struct quota_format_ops___3 *qf_ops;
	struct module___4 *qf_owner;
	struct quota_format_type___3 *qf_next;
};

struct quota_format_ops___3 {
	int (*check_quota_file)(struct super_block___3 *, int);
	int (*read_file_info)(struct super_block___3 *, int);
	int (*write_file_info)(struct super_block___3 *, int);
	int (*free_file_info)(struct super_block___3 *, int);
	int (*read_dqblk)(struct dquot___3 *);
	int (*commit_dqblk)(struct dquot___3 *);
	int (*release_dqblk)(struct dquot___3 *);
	int (*get_next_id)(struct super_block___3 *, struct kqid *);
};

struct dquot_operations___3 {
	int (*write_dquot)(struct dquot___3 *);
	struct dquot___3 * (*alloc_dquot)(struct super_block___3 *, int);
	void (*destroy_dquot)(struct dquot___3 *);
	int (*acquire_dquot)(struct dquot___3 *);
	int (*release_dquot)(struct dquot___3 *);
	int (*mark_dirty)(struct dquot___3 *);
	int (*write_info)(struct super_block___3 *, int);
	qsize_t * (*get_reserved_space)(struct inode___3 *);
	int (*get_projid)(struct inode___3 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___3 *, qsize_t *);
	int (*get_next_id)(struct super_block___3 *, struct kqid *);
};

struct quotactl_ops___3 {
	int (*quota_on)(struct super_block___3 *, int, int, const struct path___3 *);
	int (*quota_off)(struct super_block___3 *, int);
	int (*quota_enable)(struct super_block___3 *, unsigned int);
	int (*quota_disable)(struct super_block___3 *, unsigned int);
	int (*quota_sync)(struct super_block___3 *, int);
	int (*set_info)(struct super_block___3 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___3 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___3 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___3 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___3 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___3 *, unsigned int);
};

struct wait_page_queue___2 {
	struct page___4 *page;
	int bit_nr;
	wait_queue_entry_t wait;
};

typedef struct {
	size_t written;
	size_t count;
	union {
		char *buf;
		void *data;
	} arg;
	int error;
} read_descriptor_t;

struct writeback_control___2;

struct readahead_control___2;

struct swap_info_struct___2;

struct address_space_operations___3 {
	int (*writepage)(struct page___4 *, struct writeback_control___2 *);
	int (*readpage)(struct file___3 *, struct page___4 *);
	int (*writepages)(struct address_space___3 *, struct writeback_control___2 *);
	int (*set_page_dirty)(struct page___4 *);
	int (*readpages)(struct file___3 *, struct address_space___3 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___2 *);
	int (*write_begin)(struct file___3 *, struct address_space___3 *, loff_t, unsigned int, unsigned int, struct page___4 **, void **);
	int (*write_end)(struct file___3 *, struct address_space___3 *, loff_t, unsigned int, unsigned int, struct page___4 *, void *);
	sector_t (*bmap)(struct address_space___3 *, sector_t);
	void (*invalidatepage)(struct page___4 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___4 *, gfp_t);
	void (*freepage)(struct page___4 *);
	ssize_t (*direct_IO)(struct kiocb___3 *, struct iov_iter___3 *);
	int (*migratepage)(struct address_space___3 *, struct page___4 *, struct page___4 *, enum migrate_mode);
	bool (*isolate_page)(struct page___4 *, isolate_mode_t);
	void (*putback_page)(struct page___4 *);
	int (*launder_page)(struct page___4 *);
	int (*is_partially_uptodate)(struct page___4 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___4 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___3 *, struct page___4 *);
	int (*swap_activate)(struct swap_info_struct___2 *, struct file___3 *, sector_t *);
	void (*swap_deactivate)(struct file___3 *);
};

struct writeback_control___2 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	unsigned int no_cgroup_owner: 1;
	unsigned int punt_to_cgroup: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bdi_writeback___2 *wb;
	struct inode___3 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
};

struct readahead_control___2 {
	struct file___3 *file;
	struct address_space___3 *mapping;
	struct file_ra_state *ra;
	long unsigned int _index;
	unsigned int _nr_pages;
	unsigned int _batch_count;
};

struct swap_info_struct___2 {
	struct percpu_ref users;
	long unsigned int flags;
	short int prio;
	struct plist_node list;
	signed char type;
	unsigned int max;
	unsigned char *swap_map;
	struct swap_cluster_info *cluster_info;
	struct swap_cluster_list free_clusters;
	unsigned int lowest_bit;
	unsigned int highest_bit;
	unsigned int pages;
	unsigned int inuse_pages;
	unsigned int cluster_next;
	unsigned int cluster_nr;
	unsigned int *cluster_next_cpu;
	struct percpu_cluster *percpu_cluster;
	struct rb_root swap_extent_root;
	struct block_device___2 *bdev;
	struct file___3 *swap_file;
	unsigned int old_block_size;
	struct completion comp;
	long unsigned int *frontswap_map;
	atomic_t frontswap_pages;
	spinlock_t lock;
	spinlock_t cont_lock;
	struct work_struct discard_work;
	struct swap_cluster_list discard_clusters;
	struct plist_node avail_lists[0];
};

struct cdev___2 {
	struct kobject___2 kobj;
	struct module___4 *owner;
	const struct file_operations___3 *ops;
	struct list_head list;
	dev_t dev;
	unsigned int count;
};

struct posix_acl_entry {
	short int e_tag;
	short unsigned int e_perm;
	union {
		kuid_t e_uid;
		kgid_t e_gid;
	};
};

struct posix_acl {
	refcount_t a_refcount;
	struct callback_head a_rcu;
	unsigned int a_count;
	struct posix_acl_entry a_entries[0];
};

struct inode_operations___3 {
	struct dentry___3 * (*lookup)(struct inode___3 *, struct dentry___3 *, unsigned int);
	const char * (*get_link)(struct dentry___3 *, struct inode___3 *, struct delayed_call *);
	int (*permission)(struct user_namespace *, struct inode___3 *, int);
	struct posix_acl * (*get_acl)(struct inode___3 *, int, bool);
	int (*readlink)(struct dentry___3 *, char *, int);
	int (*create)(struct user_namespace *, struct inode___3 *, struct dentry___3 *, umode_t, bool);
	int (*link)(struct dentry___3 *, struct inode___3 *, struct dentry___3 *);
	int (*unlink)(struct inode___3 *, struct dentry___3 *);
	int (*symlink)(struct user_namespace *, struct inode___3 *, struct dentry___3 *, const char *);
	int (*mkdir)(struct user_namespace *, struct inode___3 *, struct dentry___3 *, umode_t);
	int (*rmdir)(struct inode___3 *, struct dentry___3 *);
	int (*mknod)(struct user_namespace *, struct inode___3 *, struct dentry___3 *, umode_t, dev_t);
	int (*rename)(struct user_namespace *, struct inode___3 *, struct dentry___3 *, struct inode___3 *, struct dentry___3 *, unsigned int);
	int (*setattr)(struct user_namespace *, struct dentry___3 *, struct iattr___3 *);
	int (*getattr)(struct user_namespace *, const struct path___3 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___3 *, char *, size_t);
	int (*fiemap)(struct inode___3 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___3 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___3 *, struct dentry___3 *, struct file___3 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace *, struct inode___3 *, struct dentry___3 *, umode_t);
	int (*set_acl)(struct user_namespace *, struct inode___3 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace *, struct dentry___3 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___3 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___3 {
	void (*fl_copy_lock)(struct file_lock___3 *, struct file_lock___3 *);
	void (*fl_release_private)(struct file_lock___3 *);
};

struct lock_manager_operations___3;

struct file_lock___3 {
	struct file_lock___3 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___3 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___3 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___3 *fl_ops;
	const struct lock_manager_operations___3 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___3 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___3 *);
	int (*lm_grant)(struct file_lock___3 *, int);
	bool (*lm_break)(struct file_lock___3 *);
	int (*lm_change)(struct file_lock___3 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___3 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___3 *);
};

struct fasync_struct___3 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___3 *fa_next;
	struct file___3 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___3 {
	struct inode___3 * (*alloc_inode)(struct super_block___3 *);
	void (*destroy_inode)(struct inode___3 *);
	void (*free_inode)(struct inode___3 *);
	void (*dirty_inode)(struct inode___3 *, int);
	int (*write_inode)(struct inode___3 *, struct writeback_control___2 *);
	int (*drop_inode)(struct inode___3 *);
	void (*evict_inode)(struct inode___3 *);
	void (*put_super)(struct super_block___3 *);
	int (*sync_fs)(struct super_block___3 *, int);
	int (*freeze_super)(struct super_block___3 *);
	int (*freeze_fs)(struct super_block___3 *);
	int (*thaw_super)(struct super_block___3 *);
	int (*unfreeze_fs)(struct super_block___3 *);
	int (*statfs)(struct dentry___3 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___3 *, int *, char *);
	void (*umount_begin)(struct super_block___3 *);
	int (*show_options)(struct seq_file___3 *, struct dentry___3 *);
	int (*show_devname)(struct seq_file___3 *, struct dentry___3 *);
	int (*show_path)(struct seq_file___3 *, struct dentry___3 *);
	int (*show_stats)(struct seq_file___3 *, struct dentry___3 *);
	ssize_t (*quota_read)(struct super_block___3 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___3 *, int, const char *, size_t, loff_t);
	struct dquot___3 ** (*get_dquots)(struct inode___3 *);
	long int (*nr_cached_objects)(struct super_block___3 *, struct shrink_control___2 *);
	long int (*free_cached_objects)(struct super_block___3 *, struct shrink_control___2 *);
	struct file___3 * (*real_loop)(struct file___3 *);
};

struct xattr_handler___2 {
	const char *name;
	const char *prefix;
	int flags;
	bool (*list)(struct dentry___3 *);
	int (*get)(const struct xattr_handler___2 *, struct dentry___3 *, struct inode___3 *, const char *, void *, size_t);
	int (*set)(const struct xattr_handler___2 *, struct user_namespace *, struct dentry___3 *, struct inode___3 *, const char *, const void *, size_t, int);
};

struct wakeup_source___2;

struct dev_pm_info___2 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___2 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___4 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___2;

struct bus_type___2;

struct device_driver___2;

struct dev_pm_domain___2;

struct fwnode_handle___2;

struct class___2;

struct device___4 {
	struct kobject___2 kobj;
	struct device___4 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___2 *type;
	struct bus_type___2 *bus;
	struct device_driver___2 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___2 power;
	struct dev_pm_domain___2 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node *of_node;
	struct fwnode_handle___2 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___2 *class;
	const struct attribute_group___2 **groups;
	void (*release)(struct device___4 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct block_device___2 {
	sector_t bd_start_sect;
	struct disk_stats *bd_stats;
	long unsigned int bd_stamp;
	bool bd_read_only;
	dev_t bd_dev;
	int bd_openers;
	struct inode___3 *bd_inode;
	struct super_block___3 *bd_super;
	void *bd_claiming;
	struct device___4 bd_device;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct kobject___2 *bd_holder_dir;
	u8 bd_partno;
	spinlock_t bd_size_lock;
	struct gendisk___2 *bd_disk;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	struct super_block___3 *bd_fsfreeze_sb;
	struct partition_meta_info *bd_meta_info;
};

struct fc_log___2;

struct p_log___2 {
	const char *prefix;
	struct fc_log___2 *log;
};

struct fs_context_operations___2;

struct fs_context___2 {
	const struct fs_context_operations___2 *ops;
	struct mutex uapi_mutex;
	struct file_system_type___3 *fs_type;
	void *fs_private;
	void *sget_key;
	struct dentry___3 *root;
	struct user_namespace *user_ns;
	struct net___2 *net_ns;
	const struct cred *cred;
	struct p_log___2 log;
	const char *source;
	void *security;
	void *s_fs_info;
	unsigned int sb_flags;
	unsigned int sb_flags_mask;
	unsigned int s_iflags;
	unsigned int lsm_flags;
	enum fs_context_purpose purpose: 8;
	enum fs_context_phase phase: 8;
	bool need_free: 1;
	bool global: 1;
	bool oldapi: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fs_parameter___2;

typedef int fs_param_type___2(struct p_log___2 *, const struct fs_parameter_spec___2 *, struct fs_parameter___2 *, struct fs_parse_result *);

struct fs_parameter_spec___2 {
	const char *name;
	fs_param_type___2 *type;
	u8 opt;
	short unsigned int flags;
	const void *data;
};

typedef void bio_end_io_t___2(struct bio___2 *);

struct bio_integrity_payload___2;

struct bio___2 {
	struct bio___2 *bi_next;
	struct block_device___2 *bi_bdev;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	atomic_t __bi_remaining;
	struct bvec_iter bi_iter;
	bio_end_io_t___2 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___2 *bi_blkg;
	struct bio_issue bi_issue;
	u64 bi_iocost_cost;
	struct bio_crypt_ctx *bi_crypt_context;
	union {
		struct bio_integrity_payload___2 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___2 *bi_io_vec;
	struct bio_set___2 *bi_pool;
	struct bio_vec___2 bi_inline_vecs[0];
};

struct tty_buffer {
	union {
		struct tty_buffer *next;
		struct llist_node free;
	};
	int used;
	int size;
	int commit;
	int read;
	int flags;
	long unsigned int data[0];
};

struct tty_bufhead {
	struct tty_buffer *head;
	struct work_struct work;
	struct mutex lock;
	atomic_t priority;
	struct tty_buffer sentinel;
	struct llist_head free;
	atomic_t mem_used;
	int mem_limit;
	struct tty_buffer *tail;
};

struct dev_pm_ops___2 {
	int (*prepare)(struct device___4 *);
	void (*complete)(struct device___4 *);
	int (*suspend)(struct device___4 *);
	int (*resume)(struct device___4 *);
	int (*freeze)(struct device___4 *);
	int (*thaw)(struct device___4 *);
	int (*poweroff)(struct device___4 *);
	int (*restore)(struct device___4 *);
	int (*suspend_late)(struct device___4 *);
	int (*resume_early)(struct device___4 *);
	int (*freeze_late)(struct device___4 *);
	int (*thaw_early)(struct device___4 *);
	int (*poweroff_late)(struct device___4 *);
	int (*restore_early)(struct device___4 *);
	int (*suspend_noirq)(struct device___4 *);
	int (*resume_noirq)(struct device___4 *);
	int (*freeze_noirq)(struct device___4 *);
	int (*thaw_noirq)(struct device___4 *);
	int (*poweroff_noirq)(struct device___4 *);
	int (*restore_noirq)(struct device___4 *);
	int (*runtime_suspend)(struct device___4 *);
	int (*runtime_resume)(struct device___4 *);
	int (*runtime_idle)(struct device___4 *);
};

struct wakeup_source___2 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___4 *dev;
	bool active: 1;
	bool autosleep_enabled: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___2 {
	struct dev_pm_ops___2 ops;
	int (*start)(struct device___4 *);
	void (*detach)(struct device___4 *, bool);
	int (*activate)(struct device___4 *);
	void (*sync)(struct device___4 *);
	void (*dismiss)(struct device___4 *);
};

struct bus_type___2 {
	const char *name;
	const char *dev_name;
	struct device___4 *dev_root;
	const struct attribute_group___2 **bus_groups;
	const struct attribute_group___2 **dev_groups;
	const struct attribute_group___2 **drv_groups;
	int (*match)(struct device___4 *, struct device_driver___2 *);
	int (*uevent)(struct device___4 *, struct kobj_uevent_env *);
	int (*probe)(struct device___4 *);
	void (*sync_state)(struct device___4 *);
	void (*remove)(struct device___4 *);
	void (*shutdown)(struct device___4 *);
	int (*online)(struct device___4 *);
	int (*offline)(struct device___4 *);
	int (*suspend)(struct device___4 *, pm_message_t);
	int (*resume)(struct device___4 *);
	int (*num_vf)(struct device___4 *);
	int (*dma_configure)(struct device___4 *);
	const struct dev_pm_ops___2 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___2 {
	const char *name;
	struct bus_type___2 *bus;
	struct module___4 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___4 *);
	void (*sync_state)(struct device___4 *);
	int (*remove)(struct device___4 *);
	void (*shutdown)(struct device___4 *);
	int (*suspend)(struct device___4 *, pm_message_t);
	int (*resume)(struct device___4 *);
	const struct attribute_group___2 **groups;
	const struct attribute_group___2 **dev_groups;
	const struct dev_pm_ops___2 *pm;
	void (*coredump)(struct device___4 *);
	struct driver_private *p;
};

struct device_type___2 {
	const char *name;
	const struct attribute_group___2 **groups;
	int (*uevent)(struct device___4 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___4 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___4 *);
	const struct dev_pm_ops___2 *pm;
};

struct class___2 {
	const char *name;
	struct module___4 *owner;
	const struct attribute_group___2 **class_groups;
	const struct attribute_group___2 **dev_groups;
	struct kobject___2 *dev_kobj;
	int (*dev_uevent)(struct device___4 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___4 *, umode_t *);
	void (*class_release)(struct class___2 *);
	void (*dev_release)(struct device___4 *);
	int (*shutdown_pre)(struct device___4 *);
	const struct kobj_ns_type_operations *ns_type;
	const void * (*namespace)(struct device___4 *);
	void (*get_ownership)(struct device___4 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___2 *pm;
	struct subsys_private *p;
};

struct fwnode_operations___2;

struct fwnode_handle___2 {
	struct fwnode_handle___2 *secondary;
	const struct fwnode_operations___2 *ops;
	struct device___4 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct serial_icounter_struct;

struct serial_struct;

struct tty_operations {
	struct tty_struct___2 * (*lookup)(struct tty_driver *, struct file___3 *, int);
	int (*install)(struct tty_driver *, struct tty_struct___2 *);
	void (*remove)(struct tty_driver *, struct tty_struct___2 *);
	int (*open)(struct tty_struct___2 *, struct file___3 *);
	void (*close)(struct tty_struct___2 *, struct file___3 *);
	void (*shutdown)(struct tty_struct___2 *);
	void (*cleanup)(struct tty_struct___2 *);
	int (*write)(struct tty_struct___2 *, const unsigned char *, int);
	int (*put_char)(struct tty_struct___2 *, unsigned char);
	void (*flush_chars)(struct tty_struct___2 *);
	unsigned int (*write_room)(struct tty_struct___2 *);
	unsigned int (*chars_in_buffer)(struct tty_struct___2 *);
	int (*ioctl)(struct tty_struct___2 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct tty_struct___2 *, unsigned int, long unsigned int);
	void (*set_termios)(struct tty_struct___2 *, struct ktermios *);
	void (*throttle)(struct tty_struct___2 *);
	void (*unthrottle)(struct tty_struct___2 *);
	void (*stop)(struct tty_struct___2 *);
	void (*start)(struct tty_struct___2 *);
	void (*hangup)(struct tty_struct___2 *);
	int (*break_ctl)(struct tty_struct___2 *, int);
	void (*flush_buffer)(struct tty_struct___2 *);
	void (*set_ldisc)(struct tty_struct___2 *);
	void (*wait_until_sent)(struct tty_struct___2 *, int);
	void (*send_xchar)(struct tty_struct___2 *, char);
	int (*tiocmget)(struct tty_struct___2 *);
	int (*tiocmset)(struct tty_struct___2 *, unsigned int, unsigned int);
	int (*resize)(struct tty_struct___2 *, struct winsize *);
	int (*get_icount)(struct tty_struct___2 *, struct serial_icounter_struct *);
	int (*get_serial)(struct tty_struct___2 *, struct serial_struct *);
	int (*set_serial)(struct tty_struct___2 *, struct serial_struct *);
	void (*show_fdinfo)(struct tty_struct___2 *, struct seq_file___3 *);
	int (*poll_init)(struct tty_driver *, int, char *);
	int (*poll_get_char)(struct tty_driver *, int);
	void (*poll_put_char)(struct tty_driver *, int, char);
	int (*proc_show)(struct seq_file___3 *, void *);
};

struct proc_dir_entry;

struct tty_driver {
	int magic;
	struct kref kref;
	struct cdev___2 **cdevs;
	struct module___4 *owner;
	const char *driver_name;
	const char *name;
	int name_base;
	int major;
	int minor_start;
	unsigned int num;
	short int type;
	short int subtype;
	struct ktermios init_termios;
	long unsigned int flags;
	struct proc_dir_entry *proc_entry;
	struct tty_driver *other;
	struct tty_struct___2 **ttys;
	struct tty_port **ports;
	struct ktermios **termios;
	void *driver_state;
	const struct tty_operations *ops;
	struct list_head tty_drivers;
};

struct tty_port_operations;

struct tty_port_client_operations;

struct tty_port {
	struct tty_bufhead buf;
	struct tty_struct___2 *tty;
	struct tty_struct___2 *itty;
	const struct tty_port_operations *ops;
	const struct tty_port_client_operations *client_ops;
	spinlock_t lock;
	int blocked_open;
	int count;
	wait_queue_head_t open_wait;
	wait_queue_head_t delta_msr_wait;
	long unsigned int flags;
	long unsigned int iflags;
	unsigned char console: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct mutex mutex;
	struct mutex buf_mutex;
	unsigned char *xmit_buf;
	unsigned int close_delay;
	unsigned int closing_wait;
	int drain_delay;
	struct kref kref;
	void *client_data;
};

struct tty_ldisc_ops {
	char *name;
	int num;
	int flags;
	int (*open)(struct tty_struct___2 *);
	void (*close)(struct tty_struct___2 *);
	void (*flush_buffer)(struct tty_struct___2 *);
	ssize_t (*read)(struct tty_struct___2 *, struct file___3 *, unsigned char *, size_t, void **, long unsigned int);
	ssize_t (*write)(struct tty_struct___2 *, struct file___3 *, const unsigned char *, size_t);
	int (*ioctl)(struct tty_struct___2 *, struct file___3 *, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct tty_struct___2 *, struct file___3 *, unsigned int, long unsigned int);
	void (*set_termios)(struct tty_struct___2 *, struct ktermios *);
	__poll_t (*poll)(struct tty_struct___2 *, struct file___3 *, struct poll_table_struct___3 *);
	int (*hangup)(struct tty_struct___2 *);
	void (*receive_buf)(struct tty_struct___2 *, const unsigned char *, const char *, int);
	void (*write_wakeup)(struct tty_struct___2 *);
	void (*dcd_change)(struct tty_struct___2 *, unsigned int);
	int (*receive_buf2)(struct tty_struct___2 *, const unsigned char *, const char *, int);
	struct module___4 *owner;
};

struct tty_ldisc {
	struct tty_ldisc_ops *ops;
	struct tty_struct___2 *tty;
};

struct tty_port_operations {
	int (*carrier_raised)(struct tty_port *);
	void (*dtr_rts)(struct tty_port *, int);
	void (*shutdown)(struct tty_port *);
	int (*activate)(struct tty_port *, struct tty_struct___2 *);
	void (*destruct)(struct tty_port *);
};

struct tty_port_client_operations {
	int (*receive_buf)(struct tty_port *, const unsigned char *, const unsigned char *, size_t);
	void (*write_wakeup)(struct tty_port *);
};

struct uevent_sock;

struct prot_inuse;

struct netns_core {
	struct ctl_table_header *sysctl_hdr;
	int sysctl_somaxconn;
	int *sock_inuse;
	struct prot_inuse *prot_inuse;
};

struct mptcp_mib;

struct ipstats_mib;

struct tcp_mib;

struct linux_mib;

struct udp_mib;

struct linux_xfrm_mib;

struct linux_tls_mib;

struct icmp_mib;

struct icmpmsg_mib;

struct icmpv6_mib;

struct icmpv6msg_mib;

struct netns_mib {
	struct ipstats_mib *ip_statistics;
	struct ipstats_mib *ipv6_statistics;
	struct tcp_mib *tcp_statistics;
	struct linux_mib *net_statistics;
	struct udp_mib *udp_statistics;
	struct udp_mib *udp_stats_in6;
	struct linux_xfrm_mib *xfrm_statistics;
	struct linux_tls_mib *tls_statistics;
	struct mptcp_mib *mptcp_statistics;
	struct udp_mib *udplite_statistics;
	struct udp_mib *udplite_stats_in6;
	struct icmp_mib *icmp_statistics;
	struct icmpmsg_mib *icmpmsg_statistics;
	struct icmpv6_mib *icmpv6_statistics;
	struct icmpv6msg_mib *icmpv6msg_statistics;
	struct proc_dir_entry *proc_net_devsnmp6;
};

struct netns_packet {
	struct mutex sklist_lock;
	struct hlist_head sklist;
};

struct netns_unix {
	int sysctl_max_dgram_qlen;
	struct ctl_table_header *ctl;
};

struct netns_nexthop {
	struct rb_root rb_root;
	struct hlist_head *devhash;
	unsigned int seq;
	u32 last_id_allocated;
	struct blocking_notifier_head notifier_chain;
};

struct inet_hashinfo;

struct inet_timewait_death_row {
	atomic_t tw_count;
	char tw_pad[60];
	struct inet_hashinfo *hashinfo;
	int sysctl_max_tw_buckets;
};

struct ipv4_devconf;

struct ip_ra_chain;

struct fib_table;

struct inet_peer_base;

struct local_ports {
	seqlock_t lock;
	int range[2];
	bool warned;
};

struct tcp_congestion_ops;

struct tcp_fastopen_context;

struct ping_group_range {
	seqlock_t lock;
	kgid_t range[2];
};

typedef struct {
	u64 key[2];
} siphash_key_t;

struct fib_rules_ops;

struct fqdir;

struct fib_notifier_ops;

struct netns_ipv4 {
	struct inet_timewait_death_row tcp_death_row;
	struct ctl_table_header *forw_hdr;
	struct ctl_table_header *frags_hdr;
	struct ctl_table_header *ipv4_hdr;
	struct ctl_table_header *route_hdr;
	struct ctl_table_header *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct ip_ra_chain *ra_chain;
	struct mutex ra_mutex;
	struct fib_rules_ops *rules_ops;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	unsigned int fib_rules_require_fldissect;
	bool fib_has_custom_rules;
	bool fib_has_custom_local_routes;
	bool fib_offload_disabled;
	atomic_t fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	struct sock *fibnl;
	struct sock **icmp_sk;
	struct sock *mc_autojoin_sk;
	struct inet_peer_base *peers;
	struct sock **tcp_sk;
	struct fqdir *fqdir;
	u8 sysctl_icmp_echo_ignore_all;
	u8 sysctl_icmp_echo_enable_probe;
	u8 sysctl_icmp_echo_ignore_broadcasts;
	u8 sysctl_icmp_ignore_bogus_error_responses;
	u8 sysctl_icmp_errors_use_inbound_ifaddr;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	struct local_ports ip_local_ports;
	u8 sysctl_tcp_ecn;
	u8 sysctl_tcp_ecn_fallback;
	u8 sysctl_ip_default_ttl;
	u8 sysctl_ip_no_pmtu_disc;
	u8 sysctl_ip_fwd_use_pmtu;
	u8 sysctl_ip_fwd_update_priority;
	u8 sysctl_ip_nonlocal_bind;
	u8 sysctl_ip_autobind_reuse;
	u8 sysctl_ip_dynaddr;
	u8 sysctl_ip_early_demux;
	u8 sysctl_raw_l3mdev_accept;
	u8 sysctl_tcp_early_demux;
	u8 sysctl_udp_early_demux;
	u8 sysctl_nexthop_compat_mode;
	u8 sysctl_fwmark_reflect;
	u8 sysctl_tcp_fwmark_accept;
	u8 sysctl_tcp_l3mdev_accept;
	u8 sysctl_tcp_mtu_probing;
	int sysctl_tcp_mtu_probe_floor;
	int sysctl_tcp_base_mss;
	int sysctl_tcp_min_snd_mss;
	int sysctl_tcp_probe_threshold;
	u32 sysctl_tcp_probe_interval;
	int sysctl_tcp_keepalive_time;
	int sysctl_tcp_keepalive_intvl;
	u8 sysctl_tcp_keepalive_probes;
	u8 sysctl_tcp_syn_retries;
	u8 sysctl_tcp_synack_retries;
	u8 sysctl_tcp_syncookies;
	u8 sysctl_tcp_migrate_req;
	int sysctl_tcp_reordering;
	u8 sysctl_tcp_retries1;
	u8 sysctl_tcp_retries2;
	u8 sysctl_tcp_orphan_retries;
	u8 sysctl_tcp_tw_reuse;
	int sysctl_tcp_fin_timeout;
	unsigned int sysctl_tcp_notsent_lowat;
	u8 sysctl_tcp_sack;
	u8 sysctl_tcp_window_scaling;
	u8 sysctl_tcp_timestamps;
	u8 sysctl_tcp_early_retrans;
	u8 sysctl_tcp_recovery;
	u8 sysctl_tcp_thin_linear_timeouts;
	u8 sysctl_tcp_slow_start_after_idle;
	u8 sysctl_tcp_retrans_collapse;
	u8 sysctl_tcp_stdurg;
	u8 sysctl_tcp_rfc1337;
	u8 sysctl_tcp_abort_on_overflow;
	u8 sysctl_tcp_fack;
	int sysctl_tcp_max_reordering;
	int sysctl_tcp_adv_win_scale;
	u8 sysctl_tcp_dsack;
	u8 sysctl_tcp_app_win;
	u8 sysctl_tcp_frto;
	u8 sysctl_tcp_nometrics_save;
	u8 sysctl_tcp_no_ssthresh_metrics_save;
	u8 sysctl_tcp_moderate_rcvbuf;
	u8 sysctl_tcp_tso_win_divisor;
	u8 sysctl_tcp_workaround_signed_windows;
	int sysctl_tcp_limit_output_bytes;
	int sysctl_tcp_challenge_ack_limit;
	int sysctl_tcp_min_rtt_wlen;
	u8 sysctl_tcp_min_tso_segs;
	u8 sysctl_tcp_autocorking;
	u8 sysctl_tcp_reflect_tos;
	u8 sysctl_tcp_comp_sack_nr;
	int sysctl_tcp_invalid_ratelimit;
	int sysctl_tcp_pacing_ss_ratio;
	int sysctl_tcp_pacing_ca_ratio;
	int sysctl_tcp_wmem[3];
	int sysctl_tcp_rmem[3];
	long unsigned int sysctl_tcp_comp_sack_delay_ns;
	long unsigned int sysctl_tcp_comp_sack_slack_ns;
	int sysctl_max_syn_backlog;
	int sysctl_tcp_fastopen;
	const struct tcp_congestion_ops *tcp_congestion_control;
	struct tcp_fastopen_context *tcp_fastopen_ctx;
	unsigned int sysctl_tcp_fastopen_blackhole_timeout;
	atomic_t tfo_active_disable_times;
	long unsigned int tfo_active_disable_stamp;
	int sysctl_udp_wmem_min;
	int sysctl_udp_rmem_min;
	u8 sysctl_fib_notify_on_flag_change;
	u8 sysctl_udp_l3mdev_accept;
	u8 sysctl_igmp_llm_reports;
	int sysctl_igmp_max_memberships;
	int sysctl_igmp_max_msf;
	int sysctl_igmp_qrv;
	struct ping_group_range ping_group_range;
	atomic_t dev_addr_genid;
	long unsigned int *sysctl_local_reserved_ports;
	int sysctl_ip_prot_sock;
	struct list_head mr_tables;
	struct fib_rules_ops *mr_rules_ops;
	u32 sysctl_fib_multipath_hash_fields;
	u8 sysctl_fib_multipath_use_neigh;
	u8 sysctl_fib_multipath_hash_policy;
	struct fib_notifier_ops *notifier_ops;
	unsigned int fib_seq;
	struct fib_notifier_ops *ipmr_notifier_ops;
	unsigned int ipmr_seq;
	atomic_t rt_genid;
	siphash_key_t ip_id_key;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct neighbour;

struct dst_ops {
	short unsigned int family;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops *);
	struct dst_entry * (*check)(struct dst_entry *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry *);
	unsigned int (*mtu)(const struct dst_entry *);
	u32 * (*cow_metrics)(struct dst_entry *, long unsigned int);
	void (*destroy)(struct dst_entry *);
	void (*ifdown)(struct dst_entry *, struct net_device *, int);
	struct dst_entry * (*negative_advice)(struct dst_entry *);
	void (*link_failure)(struct sk_buff *);
	void (*update_pmtu)(struct dst_entry *, struct sock *, struct sk_buff *, u32, bool);
	void (*redirect)(struct dst_entry *, struct sock *, struct sk_buff *);
	int (*local_out)(struct net___2 *, struct sock *, struct sk_buff *);
	struct neighbour * (*neigh_lookup)(const struct dst_entry *, struct sk_buff *, const void *);
	void (*confirm_neigh)(const struct dst_entry *, const void *);
	struct kmem_cache *kmem_cachep;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_sysctl_ipv6 {
	struct ctl_table_header *hdr;
	struct ctl_table_header *route_hdr;
	struct ctl_table_header *icmp_hdr;
	struct ctl_table_header *frags_hdr;
	struct ctl_table_header *xfrm6_hdr;
	int flush_delay;
	int ip6_rt_max_size;
	int ip6_rt_gc_min_interval;
	int ip6_rt_gc_timeout;
	int ip6_rt_gc_interval;
	int ip6_rt_gc_elasticity;
	int ip6_rt_mtu_expires;
	int ip6_rt_min_advmss;
	u32 multipath_hash_fields;
	u8 multipath_hash_policy;
	u8 bindv6only;
	u8 flowlabel_consistency;
	u8 auto_flowlabels;
	int icmpv6_time;
	u8 icmpv6_echo_ignore_all;
	u8 icmpv6_echo_ignore_multicast;
	u8 icmpv6_echo_ignore_anycast;
	long unsigned int icmpv6_ratemask[4];
	long unsigned int *icmpv6_ratemask_ptr;
	u8 anycast_src_echo_reply;
	u8 ip_nonlocal_bind;
	u8 fwmark_reflect;
	u8 flowlabel_state_ranges;
	int idgen_retries;
	int idgen_delay;
	int flowlabel_reflect;
	int max_dst_opts_cnt;
	int max_hbh_opts_cnt;
	int max_dst_opts_len;
	int max_hbh_opts_len;
	int seg6_flowlabel;
	u32 ioam6_id;
	u64 ioam6_id_wide;
	bool skip_notify_on_dev_down;
	u8 fib_notify_on_flag_change;
};

struct fib6_info;

struct rt6_info;

struct rt6_statistics;

struct fib6_table;

struct seg6_pernet_data;

struct ioam6_pernet_data;

struct ipv6_devconf;

struct netns_ipv6 {
	struct dst_ops ip6_dst_ops;
	struct netns_sysctl_ipv6 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	struct fqdir *fqdir;
	struct fib6_info *fib6_null_entry;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	struct list_head fib6_walkers;
	rwlock_t fib6_walker_lock;
	spinlock_t fib6_gc_lock;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	unsigned char flowlabel_has_excl;
	bool fib6_has_custom_rules;
	unsigned int fib6_rules_require_fldissect;
	unsigned int fib6_routes_require_src;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops *fib6_rules_ops;
	struct sock **icmp_sk;
	struct sock *ndisc_sk;
	struct sock *tcp_sk;
	struct sock *igmp_sk;
	struct sock *mc_autojoin_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops *mr6_rules_ops;
	atomic_t dev_addr_genid;
	atomic_t fib6_sernum;
	struct seg6_pernet_data *seg6_data;
	struct fib_notifier_ops *notifier_ops;
	struct fib_notifier_ops *ip6mr_notifier_ops;
	unsigned int ipmr_seq;
	struct {
		struct hlist_head head;
		spinlock_t lock;
		u32 seq;
	} ip6addrlbl_table;
	struct ioam6_pernet_data *ioam6_data;
};

struct netns_sysctl_lowpan {
	struct ctl_table_header *frags_hdr;
};

struct netns_ieee802154_lowpan {
	struct netns_sysctl_lowpan sysctl;
	struct fqdir *fqdir;
};

struct sctp_mib;

struct netns_sctp {
	struct sctp_mib *sctp_statistics;
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header *sysctl_header;
	struct sock *ctl_sock;
	struct sock *udp4_sock;
	struct sock *udp6_sock;
	int udp_port;
	int encap_port;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	unsigned int probe_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int ps_retrans;
	int pf_enable;
	int pf_expose;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int reconf_enable;
	int auth_enable;
	int intl_enable;
	int ecn_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct nf_logger;

struct nf_hook_entries;

struct netns_nf {
	struct proc_dir_entry *proc_netfilter;
	const struct nf_logger *nf_loggers[13];
	struct ctl_table_header *nf_log_dir_header;
	struct nf_hook_entries *hooks_ipv4[5];
	struct nf_hook_entries *hooks_ipv6[5];
	struct nf_hook_entries *hooks_arp[3];
	struct nf_hook_entries *hooks_bridge[5];
	struct nf_hook_entries *hooks_decnet[7];
	unsigned int defrag_ipv4_users;
	unsigned int defrag_ipv6_users;
};

struct nf_ct_event_notifier;

struct nf_generic_net {
	unsigned int timeout;
};

struct nf_tcp_net {
	unsigned int timeouts[14];
	u8 tcp_loose;
	u8 tcp_be_liberal;
	u8 tcp_max_retrans;
	u8 tcp_ignore_invalid_rst;
	unsigned int offload_timeout;
};

struct nf_udp_net {
	unsigned int timeouts[2];
	unsigned int offload_timeout;
};

struct nf_icmp_net {
	unsigned int timeout;
};

struct nf_dccp_net {
	u8 dccp_loose;
	unsigned int dccp_timeout[10];
};

struct nf_sctp_net {
	unsigned int timeouts[10];
};

struct nf_gre_net {
	struct list_head keymap_list;
	unsigned int timeouts[2];
};

struct nf_ip_net {
	struct nf_generic_net generic;
	struct nf_tcp_net tcp;
	struct nf_udp_net udp;
	struct nf_icmp_net icmp;
	struct nf_icmp_net icmpv6;
	struct nf_dccp_net dccp;
	struct nf_sctp_net sctp;
	struct nf_gre_net gre;
};

struct ct_pcpu;

struct ip_conntrack_stat;

struct netns_ct {
	bool ecache_dwork_pending;
	u8 sysctl_log_invalid;
	u8 sysctl_events;
	u8 sysctl_acct;
	u8 sysctl_auto_assign_helper;
	u8 sysctl_tstamp;
	u8 sysctl_checksum;
	struct ct_pcpu *pcpu_lists;
	struct ip_conntrack_stat *stat;
	struct nf_ct_event_notifier *nf_conntrack_event_cb;
	struct nf_ip_net nf_ct_proto;
	unsigned int labels_used;
};

struct netns_nftables {
	u8 gencursor;
};

struct net_generic;

struct netns_bpf {
	struct bpf_prog_array *run_array[2];
	struct bpf_prog *progs[2];
	struct list_head links[2];
};

struct xfrm_policy_hash {
	struct hlist_head *table;
	unsigned int hmask;
	u8 dbits4;
	u8 sbits4;
	u8 dbits6;
	u8 sbits6;
};

struct xfrm_policy_hthresh {
	struct work_struct work;
	seqlock_t lock;
	u8 lbits4;
	u8 rbits4;
	u8 lbits6;
	u8 rbits6;
};

struct netns_xfrm {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	struct hlist_head *state_byseq;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[3];
	struct xfrm_policy_hash policy_bydst[3];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct xfrm_policy_hthresh policy_hthresh;
	struct list_head inexact_bins;
	struct sock *nlsk;
	struct sock *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	u8 policy_default;
	struct ctl_table_header *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops xfrm4_dst_ops;
	struct dst_ops xfrm6_dst_ops;
	spinlock_t xfrm_state_lock;
	seqcount_spinlock_t xfrm_state_hash_generation;
	seqcount_spinlock_t xfrm_policy_hash_generation;
	spinlock_t xfrm_policy_lock;
	struct mutex xfrm_cfg_mutex;
	long: 64;
	long: 64;
};

struct netns_ipvs;

struct mpls_route;

struct netns_mpls {
	int ip_ttl_propagate;
	int default_ttl;
	size_t platform_labels;
	struct mpls_route **platform_label;
	struct ctl_table_header *ctl;
};

struct can_dev_rcv_lists;

struct can_pkg_stats;

struct can_rcv_lists_stats;

struct netns_can {
	struct proc_dir_entry *proc_dir;
	struct proc_dir_entry *pde_stats;
	struct proc_dir_entry *pde_reset_stats;
	struct proc_dir_entry *pde_rcvlist_all;
	struct proc_dir_entry *pde_rcvlist_fil;
	struct proc_dir_entry *pde_rcvlist_inv;
	struct proc_dir_entry *pde_rcvlist_sff;
	struct proc_dir_entry *pde_rcvlist_eff;
	struct proc_dir_entry *pde_rcvlist_err;
	struct proc_dir_entry *bcmproc_dir;
	struct can_dev_rcv_lists *rx_alldev_list;
	spinlock_t rcvlists_lock;
	struct timer_list stattimer;
	struct can_pkg_stats *pkg_stats;
	struct can_rcv_lists_stats *rcv_lists_stats;
	struct hlist_head cgw_list;
};

struct netns_xdp {
	struct mutex lock;
	struct hlist_head list;
};

struct netns_mctp {
	struct list_head routes;
	struct mutex bind_lock;
	struct hlist_head binds;
	spinlock_t keys_lock;
	struct hlist_head keys;
	unsigned int default_net;
	struct mutex neigh_lock;
	struct list_head neighbours;
};

struct smc_stats;

struct smc_stats_rsn;

struct netns_smc {
	struct smc_stats *smc_stats;
	struct mutex mutex_fback_rsn;
	struct smc_stats_rsn *fback_rsn;
};

struct net___2 {
	refcount_t passive;
	spinlock_t rules_mod_lock;
	unsigned int dev_unreg_count;
	unsigned int dev_base_seq;
	int ifindex;
	spinlock_t nsid_lock;
	atomic_t fnhe_genid;
	struct list_head list;
	struct list_head exit_list;
	struct llist_node cleanup_list;
	struct key_tag *key_domain;
	struct user_namespace *user_ns;
	struct ucounts *ucounts;
	struct idr netns_ids;
	struct ns_common ns;
	struct list_head dev_base_head;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set sysctls;
	struct sock *rtnl;
	struct sock *genl_sock;
	struct uevent_sock *uevent_sock;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	struct raw_notifier_head netdev_chain;
	u32 hash_mix;
	struct net_device *loopback_dev;
	struct list_head rules_ops;
	struct netns_core core;
	struct netns_mib mib;
	struct netns_packet packet;
	struct netns_unix unx;
	struct netns_nexthop nexthop;
	struct netns_ipv4 ipv4;
	struct netns_ipv6 ipv6;
	struct netns_ieee802154_lowpan ieee802154_lowpan;
	struct netns_sctp sctp;
	struct netns_nf nf;
	struct netns_ct ct;
	struct netns_nftables nft;
	struct sk_buff_head wext_nlevents;
	struct net_generic *gen;
	struct netns_bpf bpf;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_xfrm xfrm;
	u64 net_cookie;
	struct netns_ipvs *ipvs;
	struct netns_mpls mpls;
	struct netns_can can;
	struct netns_xdp xdp;
	struct netns_mctp mctp;
	struct sock *crypto_nlsk;
	struct sock *diag_nlsk;
	struct netns_smc smc;
	long: 64;
};

struct cgroup_namespace___3 {
	struct ns_common ns;
	struct user_namespace *user_ns;
	struct ucounts *ucounts;
	struct css_set___3 *root_cset;
};

typedef struct {
	local64_t v;
} u64_stats_t;

struct bpf_insn {
	__u8 code;
	__u8 dst_reg: 4;
	__u8 src_reg: 4;
	__s16 off;
	__s32 imm;
};

enum bpf_map_type {
	BPF_MAP_TYPE_UNSPEC = 0,
	BPF_MAP_TYPE_HASH = 1,
	BPF_MAP_TYPE_ARRAY = 2,
	BPF_MAP_TYPE_PROG_ARRAY = 3,
	BPF_MAP_TYPE_PERF_EVENT_ARRAY = 4,
	BPF_MAP_TYPE_PERCPU_HASH = 5,
	BPF_MAP_TYPE_PERCPU_ARRAY = 6,
	BPF_MAP_TYPE_STACK_TRACE = 7,
	BPF_MAP_TYPE_CGROUP_ARRAY = 8,
	BPF_MAP_TYPE_LRU_HASH = 9,
	BPF_MAP_TYPE_LRU_PERCPU_HASH = 10,
	BPF_MAP_TYPE_LPM_TRIE = 11,
	BPF_MAP_TYPE_ARRAY_OF_MAPS = 12,
	BPF_MAP_TYPE_HASH_OF_MAPS = 13,
	BPF_MAP_TYPE_DEVMAP = 14,
	BPF_MAP_TYPE_SOCKMAP = 15,
	BPF_MAP_TYPE_CPUMAP = 16,
	BPF_MAP_TYPE_XSKMAP = 17,
	BPF_MAP_TYPE_SOCKHASH = 18,
	BPF_MAP_TYPE_CGROUP_STORAGE = 19,
	BPF_MAP_TYPE_REUSEPORT_SOCKARRAY = 20,
	BPF_MAP_TYPE_PERCPU_CGROUP_STORAGE = 21,
	BPF_MAP_TYPE_QUEUE = 22,
	BPF_MAP_TYPE_STACK = 23,
	BPF_MAP_TYPE_SK_STORAGE = 24,
	BPF_MAP_TYPE_DEVMAP_HASH = 25,
	BPF_MAP_TYPE_STRUCT_OPS = 26,
	BPF_MAP_TYPE_RINGBUF = 27,
	BPF_MAP_TYPE_INODE_STORAGE = 28,
	BPF_MAP_TYPE_TASK_STORAGE = 29,
};

enum bpf_prog_type {
	BPF_PROG_TYPE_UNSPEC = 0,
	BPF_PROG_TYPE_SOCKET_FILTER = 1,
	BPF_PROG_TYPE_KPROBE = 2,
	BPF_PROG_TYPE_SCHED_CLS = 3,
	BPF_PROG_TYPE_SCHED_ACT = 4,
	BPF_PROG_TYPE_TRACEPOINT = 5,
	BPF_PROG_TYPE_XDP = 6,
	BPF_PROG_TYPE_PERF_EVENT = 7,
	BPF_PROG_TYPE_CGROUP_SKB = 8,
	BPF_PROG_TYPE_CGROUP_SOCK = 9,
	BPF_PROG_TYPE_LWT_IN = 10,
	BPF_PROG_TYPE_LWT_OUT = 11,
	BPF_PROG_TYPE_LWT_XMIT = 12,
	BPF_PROG_TYPE_SOCK_OPS = 13,
	BPF_PROG_TYPE_SK_SKB = 14,
	BPF_PROG_TYPE_CGROUP_DEVICE = 15,
	BPF_PROG_TYPE_SK_MSG = 16,
	BPF_PROG_TYPE_RAW_TRACEPOINT = 17,
	BPF_PROG_TYPE_CGROUP_SOCK_ADDR = 18,
	BPF_PROG_TYPE_LWT_SEG6LOCAL = 19,
	BPF_PROG_TYPE_LIRC_MODE2 = 20,
	BPF_PROG_TYPE_SK_REUSEPORT = 21,
	BPF_PROG_TYPE_FLOW_DISSECTOR = 22,
	BPF_PROG_TYPE_CGROUP_SYSCTL = 23,
	BPF_PROG_TYPE_RAW_TRACEPOINT_WRITABLE = 24,
	BPF_PROG_TYPE_CGROUP_SOCKOPT = 25,
	BPF_PROG_TYPE_TRACING = 26,
	BPF_PROG_TYPE_STRUCT_OPS = 27,
	BPF_PROG_TYPE_EXT = 28,
	BPF_PROG_TYPE_LSM = 29,
	BPF_PROG_TYPE_SK_LOOKUP = 30,
	BPF_PROG_TYPE_SYSCALL = 31,
};

enum bpf_attach_type {
	BPF_CGROUP_INET_INGRESS = 0,
	BPF_CGROUP_INET_EGRESS = 1,
	BPF_CGROUP_INET_SOCK_CREATE = 2,
	BPF_CGROUP_SOCK_OPS = 3,
	BPF_SK_SKB_STREAM_PARSER = 4,
	BPF_SK_SKB_STREAM_VERDICT = 5,
	BPF_CGROUP_DEVICE = 6,
	BPF_SK_MSG_VERDICT = 7,
	BPF_CGROUP_INET4_BIND = 8,
	BPF_CGROUP_INET6_BIND = 9,
	BPF_CGROUP_INET4_CONNECT = 10,
	BPF_CGROUP_INET6_CONNECT = 11,
	BPF_CGROUP_INET4_POST_BIND = 12,
	BPF_CGROUP_INET6_POST_BIND = 13,
	BPF_CGROUP_UDP4_SENDMSG = 14,
	BPF_CGROUP_UDP6_SENDMSG = 15,
	BPF_LIRC_MODE2 = 16,
	BPF_FLOW_DISSECTOR = 17,
	BPF_CGROUP_SYSCTL = 18,
	BPF_CGROUP_UDP4_RECVMSG = 19,
	BPF_CGROUP_UDP6_RECVMSG = 20,
	BPF_CGROUP_GETSOCKOPT = 21,
	BPF_CGROUP_SETSOCKOPT = 22,
	BPF_TRACE_RAW_TP = 23,
	BPF_TRACE_FENTRY = 24,
	BPF_TRACE_FEXIT = 25,
	BPF_MODIFY_RETURN = 26,
	BPF_LSM_MAC = 27,
	BPF_TRACE_ITER = 28,
	BPF_CGROUP_INET4_GETPEERNAME = 29,
	BPF_CGROUP_INET6_GETPEERNAME = 30,
	BPF_CGROUP_INET4_GETSOCKNAME = 31,
	BPF_CGROUP_INET6_GETSOCKNAME = 32,
	BPF_XDP_DEVMAP = 33,
	BPF_CGROUP_INET_SOCK_RELEASE = 34,
	BPF_XDP_CPUMAP = 35,
	BPF_SK_LOOKUP = 36,
	BPF_XDP = 37,
	BPF_SK_SKB_VERDICT = 38,
	BPF_SK_REUSEPORT_SELECT = 39,
	BPF_SK_REUSEPORT_SELECT_OR_MIGRATE = 40,
	BPF_PERF_EVENT = 41,
	__MAX_BPF_ATTACH_TYPE = 42,
};

union bpf_attr {
	struct {
		__u32 map_type;
		__u32 key_size;
		__u32 value_size;
		__u32 max_entries;
		__u32 map_flags;
		__u32 inner_map_fd;
		__u32 numa_node;
		char map_name[16];
		__u32 map_ifindex;
		__u32 btf_fd;
		__u32 btf_key_type_id;
		__u32 btf_value_type_id;
		__u32 btf_vmlinux_value_type_id;
	};
	struct {
		__u32 map_fd;
		__u64 key;
		union {
			__u64 value;
			__u64 next_key;
		};
		__u64 flags;
	};
	struct {
		__u64 in_batch;
		__u64 out_batch;
		__u64 keys;
		__u64 values;
		__u32 count;
		__u32 map_fd;
		__u64 elem_flags;
		__u64 flags;
	} batch;
	struct {
		__u32 prog_type;
		__u32 insn_cnt;
		__u64 insns;
		__u64 license;
		__u32 log_level;
		__u32 log_size;
		__u64 log_buf;
		__u32 kern_version;
		__u32 prog_flags;
		char prog_name[16];
		__u32 prog_ifindex;
		__u32 expected_attach_type;
		__u32 prog_btf_fd;
		__u32 func_info_rec_size;
		__u64 func_info;
		__u32 func_info_cnt;
		__u32 line_info_rec_size;
		__u64 line_info;
		__u32 line_info_cnt;
		__u32 attach_btf_id;
		union {
			__u32 attach_prog_fd;
			__u32 attach_btf_obj_fd;
		};
		__u64 fd_array;
	};
	struct {
		__u64 pathname;
		__u32 bpf_fd;
		__u32 file_flags;
	};
	struct {
		__u32 target_fd;
		__u32 attach_bpf_fd;
		__u32 attach_type;
		__u32 attach_flags;
		__u32 replace_bpf_fd;
	};
	struct {
		__u32 prog_fd;
		__u32 retval;
		__u32 data_size_in;
		__u32 data_size_out;
		__u64 data_in;
		__u64 data_out;
		__u32 repeat;
		__u32 duration;
		__u32 ctx_size_in;
		__u32 ctx_size_out;
		__u64 ctx_in;
		__u64 ctx_out;
		__u32 flags;
		__u32 cpu;
	} test;
	struct {
		union {
			__u32 start_id;
			__u32 prog_id;
			__u32 map_id;
			__u32 btf_id;
			__u32 link_id;
		};
		__u32 next_id;
		__u32 open_flags;
	};
	struct {
		__u32 bpf_fd;
		__u32 info_len;
		__u64 info;
	} info;
	struct {
		__u32 target_fd;
		__u32 attach_type;
		__u32 query_flags;
		__u32 attach_flags;
		__u64 prog_ids;
		__u32 prog_cnt;
	} query;
	struct {
		__u64 name;
		__u32 prog_fd;
	} raw_tracepoint;
	struct {
		__u64 btf;
		__u64 btf_log_buf;
		__u32 btf_size;
		__u32 btf_log_size;
		__u32 btf_log_level;
	};
	struct {
		__u32 pid;
		__u32 fd;
		__u32 flags;
		__u32 buf_len;
		__u64 buf;
		__u32 prog_id;
		__u32 fd_type;
		__u64 probe_offset;
		__u64 probe_addr;
	} task_fd_query;
	struct {
		__u32 prog_fd;
		union {
			__u32 target_fd;
			__u32 target_ifindex;
		};
		__u32 attach_type;
		__u32 flags;
		union {
			__u32 target_btf_id;
			struct {
				__u64 iter_info;
				__u32 iter_info_len;
			};
			struct {
				__u64 bpf_cookie;
			} perf_event;
		};
	} link_create;
	struct {
		__u32 link_fd;
		__u32 new_prog_fd;
		__u32 flags;
		__u32 old_prog_fd;
	} link_update;
	struct {
		__u32 link_fd;
	} link_detach;
	struct {
		__u32 type;
	} enable_stats;
	struct {
		__u32 link_fd;
		__u32 flags;
	} iter_create;
	struct {
		__u32 prog_fd;
		__u32 map_fd;
		__u32 flags;
	} prog_bind_map;
};

struct bpf_func_info {
	__u32 insn_off;
	__u32 type_id;
};

struct bpf_line_info {
	__u32 insn_off;
	__u32 file_name_off;
	__u32 line_off;
	__u32 line_col;
};

struct dev_pagemap_ops___3 {
	void (*page_free)(struct page___4 *);
	void (*kill)(struct dev_pagemap___3 *);
	void (*cleanup)(struct dev_pagemap___3 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___3 *);
};

typedef struct {
	union {
		void *kernel;
		void *user;
	};
	bool is_kernel: 1;
	long: 63;
	long: 64;
} sockptr_t;

struct bpf_iter_aux_info;

typedef int (*bpf_iter_init_seq_priv_t)(void *, struct bpf_iter_aux_info *);

struct bpf_map;

struct bpf_iter_aux_info {
	struct bpf_map *map;
};

typedef void (*bpf_iter_fini_seq_priv_t)(void *);

struct bpf_iter_seq_info {
	const struct seq_operations___2 *seq_ops;
	bpf_iter_init_seq_priv_t init_seq_private;
	bpf_iter_fini_seq_priv_t fini_seq_private;
	u32 seq_priv_size;
};

struct btf;

struct btf_type;

struct bpf_local_storage_map;

struct bpf_verifier_env;

struct bpf_func_state;

struct bpf_prog_aux;

struct bpf_map_ops {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map *, struct file___3 *);
	void (*map_free)(struct bpf_map *);
	int (*map_get_next_key)(struct bpf_map *, void *, void *);
	void (*map_release_uref)(struct bpf_map *);
	void * (*map_lookup_elem_sys_only)(struct bpf_map *, void *);
	int (*map_lookup_batch)(struct bpf_map *, const union bpf_attr *, union bpf_attr *);
	int (*map_lookup_and_delete_elem)(struct bpf_map *, void *, void *, u64);
	int (*map_lookup_and_delete_batch)(struct bpf_map *, const union bpf_attr *, union bpf_attr *);
	int (*map_update_batch)(struct bpf_map *, const union bpf_attr *, union bpf_attr *);
	int (*map_delete_batch)(struct bpf_map *, const union bpf_attr *, union bpf_attr *);
	void * (*map_lookup_elem)(struct bpf_map *, void *);
	int (*map_update_elem)(struct bpf_map *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map *, void *);
	int (*map_push_elem)(struct bpf_map *, void *, u64);
	int (*map_pop_elem)(struct bpf_map *, void *);
	int (*map_peek_elem)(struct bpf_map *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map *, struct file___3 *, int);
	void (*map_fd_put_ptr)(void *);
	int (*map_gen_lookup)(struct bpf_map *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map *, void *, struct seq_file___3 *);
	int (*map_check_btf)(const struct bpf_map *, const struct btf *, const struct btf_type *, const struct btf_type *);
	int (*map_poke_track)(struct bpf_map *, struct bpf_prog_aux *);
	void (*map_poke_untrack)(struct bpf_map *, struct bpf_prog_aux *);
	void (*map_poke_run)(struct bpf_map *, u32, struct bpf_prog *, struct bpf_prog *);
	int (*map_direct_value_addr)(const struct bpf_map *, u64 *, u32);
	int (*map_direct_value_meta)(const struct bpf_map *, u64, u32 *);
	int (*map_mmap)(struct bpf_map *, struct vm_area_struct___4 *);
	__poll_t (*map_poll)(struct bpf_map *, struct file___3 *, struct poll_table_struct___3 *);
	int (*map_local_storage_charge)(struct bpf_local_storage_map *, void *, u32);
	void (*map_local_storage_uncharge)(struct bpf_local_storage_map *, void *, u32);
	struct bpf_local_storage ** (*map_owner_storage_ptr)(void *);
	int (*map_redirect)(struct bpf_map *, u32, u64);
	bool (*map_meta_equal)(const struct bpf_map *, const struct bpf_map *);
	int (*map_set_for_each_callback_args)(struct bpf_verifier_env *, struct bpf_func_state *, struct bpf_func_state *);
	int (*map_for_each_callback)(struct bpf_map *, void *, void *, u64);
	const char * const map_btf_name;
	int *map_btf_id;
	const struct bpf_iter_seq_info *iter_seq_info;
};

struct bpf_map {
	const struct bpf_map_ops *ops;
	struct bpf_map *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	int spin_lock_off;
	int timer_off;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	struct mem_cgroup___2 *memcg;
	char name[16];
	u32 btf_vmlinux_value_type_id;
	bool bypass_spec_v1;
	bool frozen;
	long: 16;
	long: 64;
	long: 64;
	atomic64_t refcnt;
	atomic64_t usercnt;
	struct work_struct work;
	struct mutex freeze_mutex;
	atomic64_t writecnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_kfunc_desc_tab;

struct bpf_ksym {
	long unsigned int start;
	long unsigned int end;
	char name[128];
	struct list_head lnode;
	struct latch_tree_node tnode;
	bool prog;
};

struct bpf_ctx_arg_aux;

struct bpf_trampoline;

struct bpf_jit_poke_descriptor;

struct bpf_prog_ops;

struct btf_mod_pair;

struct bpf_prog_offload;

struct bpf_func_info_aux;

struct bpf_prog_aux {
	atomic64_t refcnt;
	u32 used_map_cnt;
	u32 used_btf_cnt;
	u32 max_ctx_offset;
	u32 max_pkt_offset;
	u32 max_tp_access;
	u32 stack_depth;
	u32 id;
	u32 func_cnt;
	u32 func_idx;
	u32 attach_btf_id;
	u32 ctx_arg_info_size;
	u32 max_rdonly_access;
	u32 max_rdwr_access;
	struct btf *attach_btf;
	const struct bpf_ctx_arg_aux *ctx_arg_info;
	struct mutex dst_mutex;
	struct bpf_prog *dst_prog;
	struct bpf_trampoline *dst_trampoline;
	enum bpf_prog_type saved_dst_prog_type;
	enum bpf_attach_type saved_dst_attach_type;
	bool verifier_zext;
	bool offload_requested;
	bool attach_btf_trace;
	bool func_proto_unreliable;
	bool sleepable;
	bool tail_call_reachable;
	struct hlist_node tramp_hlist;
	const struct btf_type *attach_func_proto;
	const char *attach_func_name;
	struct bpf_prog **func;
	void *jit_data;
	struct bpf_jit_poke_descriptor *poke_tab;
	struct bpf_kfunc_desc_tab *kfunc_tab;
	u32 size_poke_tab;
	struct bpf_ksym ksym;
	const struct bpf_prog_ops *ops;
	struct bpf_map **used_maps;
	struct mutex used_maps_mutex;
	struct btf_mod_pair *used_btfs;
	struct bpf_prog *prog;
	struct user_struct *user;
	u64 load_time;
	struct bpf_map *cgroup_storage[2];
	char name[16];
	void *security;
	struct bpf_prog_offload *offload;
	struct btf *btf;
	struct bpf_func_info *func_info;
	struct bpf_func_info_aux *func_info_aux;
	struct bpf_line_info *linfo;
	void **jited_linfo;
	u32 func_info_cnt;
	u32 nr_linfo;
	u32 linfo_idx;
	u32 num_exentries;
	struct exception_table_entry *extable;
	union {
		struct work_struct work;
		struct callback_head rcu;
	};
};

struct sock_filter {
	__u16 code;
	__u8 jt;
	__u8 jf;
	__u32 k;
};

struct bpf_prog_stats;

struct sock_fprog_kern;

struct bpf_prog {
	u16 pages;
	u16 jited: 1;
	u16 jit_requested: 1;
	u16 gpl_compatible: 1;
	u16 cb_access: 1;
	u16 dst_needed: 1;
	u16 blinded: 1;
	u16 is_func: 1;
	u16 kprobe_override: 1;
	u16 has_callchain_buf: 1;
	u16 enforce_expected_attach_type: 1;
	u16 call_get_stack: 1;
	u16 call_get_func_ip: 1;
	enum bpf_prog_type type;
	enum bpf_attach_type expected_attach_type;
	u32 len;
	u32 jited_len;
	u8 tag[8];
	struct bpf_prog_stats *stats;
	int *active;
	unsigned int (*bpf_func)(const void *, const struct bpf_insn *);
	struct bpf_prog_aux *aux;
	struct sock_fprog_kern *orig_prog;
	struct sock_filter insns[0];
	struct bpf_insn insnsi[0];
};

struct bpf_offloaded_map;

struct bpf_map_dev_ops {
	int (*map_get_next_key)(struct bpf_offloaded_map *, void *, void *);
	int (*map_lookup_elem)(struct bpf_offloaded_map *, void *, void *);
	int (*map_update_elem)(struct bpf_offloaded_map *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_offloaded_map *, void *);
};

struct bpf_offloaded_map {
	struct bpf_map map;
	struct net_device *netdev;
	const struct bpf_map_dev_ops *dev_ops;
	void *dev_priv;
	struct list_head offloads;
	long: 64;
	long: 64;
	long: 64;
};

struct net_device_stats {
	long unsigned int rx_packets;
	long unsigned int tx_packets;
	long unsigned int rx_bytes;
	long unsigned int tx_bytes;
	long unsigned int rx_errors;
	long unsigned int tx_errors;
	long unsigned int rx_dropped;
	long unsigned int tx_dropped;
	long unsigned int multicast;
	long unsigned int collisions;
	long unsigned int rx_length_errors;
	long unsigned int rx_over_errors;
	long unsigned int rx_crc_errors;
	long unsigned int rx_frame_errors;
	long unsigned int rx_fifo_errors;
	long unsigned int rx_missed_errors;
	long unsigned int tx_aborted_errors;
	long unsigned int tx_carrier_errors;
	long unsigned int tx_fifo_errors;
	long unsigned int tx_heartbeat_errors;
	long unsigned int tx_window_errors;
	long unsigned int rx_compressed;
	long unsigned int tx_compressed;
};

struct iw_handler_def;

struct iw_public_data;

struct ethtool_ops;

struct tlsdev_ops;

struct netdev_hw_addr_list {
	struct list_head list;
	int count;
	struct rb_root tree;
};

struct vlan_info;

struct dsa_port;

struct tipc_bearer;

struct in_device;

struct dn_dev;

struct wireless_dev;

struct wpan_dev;

struct mpls_dev;

struct mctp_dev;

enum rx_handler_result {
	RX_HANDLER_CONSUMED = 0,
	RX_HANDLER_ANOTHER = 1,
	RX_HANDLER_EXACT = 2,
	RX_HANDLER_PASS = 3,
};

typedef enum rx_handler_result rx_handler_result_t;

typedef rx_handler_result_t rx_handler_func_t(struct sk_buff **);

struct cpu_rmap;

struct xdp_dev_bulk_queue;

struct netpoll_info;

enum netdev_ml_priv_type {
	ML_PRIV_NONE = 0,
	ML_PRIV_CAN = 1,
};

struct pcpu_dstats;

struct garp_port;

struct mrp_port;

struct netdev_tc_txq {
	u16 count;
	u16 offset;
};

struct phy_device;

struct sfp_bus;

struct macsec_ops;

struct udp_tunnel_nic_info;

struct udp_tunnel_nic;

struct bpf_xdp_link;

struct bpf_xdp_entity {
	struct bpf_prog *prog;
	struct bpf_xdp_link *link;
};

struct netdev_name_node;

struct dev_ifalias;

struct net_device_ops;

struct l3mdev_ops;

struct ndisc_ops;

struct xfrmdev_ops;

struct header_ops;

struct inet6_dev;

struct netdev_rx_queue;

struct mini_Qdisc;

struct netdev_queue;

struct Qdisc;

struct xps_dev_maps;

struct pcpu_lstats;

struct pcpu_sw_netstats;

struct rtnl_link_ops;

struct dcbnl_rtnl_ops;

struct netprio_map;

struct net_device {
	char name[16];
	struct netdev_name_node *name_node;
	struct dev_ifalias *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head close_list;
	struct list_head ptype_all;
	struct list_head ptype_specific;
	struct {
		struct list_head upper;
		struct list_head lower;
	} adj_list;
	unsigned int flags;
	unsigned int priv_flags;
	const struct net_device_ops *netdev_ops;
	int ifindex;
	short unsigned int gflags;
	short unsigned int hard_header_len;
	unsigned int mtu;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	netdev_features_t gso_partial_features;
	unsigned int min_mtu;
	unsigned int max_mtu;
	short unsigned int type;
	unsigned char min_header_len;
	unsigned char name_assign_type;
	int group;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	atomic_long_t tx_dropped;
	atomic_long_t rx_nohandler;
	atomic_t carrier_up_count;
	atomic_t carrier_down_count;
	const struct iw_handler_def *wireless_handlers;
	struct iw_public_data *wireless_data;
	const struct ethtool_ops *ethtool_ops;
	const struct l3mdev_ops *l3mdev_ops;
	const struct ndisc_ops *ndisc_ops;
	const struct xfrmdev_ops *xfrmdev_ops;
	const struct tlsdev_ops *tlsdev_ops;
	const struct header_ops *header_ops;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	unsigned char upper_level;
	unsigned char lower_level;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	short unsigned int padded;
	spinlock_t addr_list_lock;
	int irq;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___2 *queues_kset;
	unsigned int promiscuity;
	unsigned int allmulti;
	bool uc_promisc;
	struct vlan_info *vlan_info;
	struct dsa_port *dsa_ptr;
	struct tipc_bearer *tipc_ptr;
	void *atalk_ptr;
	struct in_device *ip_ptr;
	struct dn_dev *dn_ptr;
	struct inet6_dev *ip6_ptr;
	void *ax25_ptr;
	struct wireless_dev *ieee80211_ptr;
	struct wpan_dev *ieee802154_ptr;
	struct mpls_dev *mpls_ptr;
	struct mctp_dev *mctp_ptr;
	unsigned char *dev_addr;
	struct netdev_rx_queue *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	struct bpf_prog *xdp_prog;
	long unsigned int gro_flush_timeout;
	int napi_defer_hard_irqs;
	rx_handler_func_t *rx_handler;
	void *rx_handler_data;
	struct mini_Qdisc *miniq_ingress;
	struct netdev_queue *ingress_queue;
	struct nf_hook_entries *nf_hooks_ingress;
	unsigned char broadcast[32];
	struct cpu_rmap *rx_cpu_rmap;
	struct hlist_node index_hlist;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc *qdisc;
	unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	struct xdp_dev_bulk_queue *xdp_bulkq;
	struct xps_dev_maps *xps_maps[2];
	struct mini_Qdisc *miniq_egress;
	struct hlist_head qdisc_hash[16];
	struct timer_list watchdog_timer;
	int watchdog_timeo;
	u32 proto_down_reason;
	struct list_head todo_list;
	int *pcpu_refcnt;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED = 0,
		NETREG_REGISTERED = 1,
		NETREG_UNREGISTERING = 2,
		NETREG_UNREGISTERED = 3,
		NETREG_RELEASED = 4,
		NETREG_DUMMY = 5,
	} reg_state: 8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED = 0,
		RTNL_LINK_INITIALIZING = 1,
	} rtnl_link_state: 16;
	long: 16;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	bool needs_free_netdev;
	void (*priv_destructor)(struct net_device *);
	struct netpoll_info *npinfo;
	possible_net_t nd_net;
	void *ml_priv;
	enum netdev_ml_priv_type ml_priv_type;
	union {
		struct pcpu_lstats *lstats;
		struct pcpu_sw_netstats *tstats;
		struct pcpu_dstats *dstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___4 dev;
	const struct attribute_group___2 *sysfs_groups[4];
	const struct attribute_group___2 *sysfs_rx_queue_group;
	const struct rtnl_link_ops *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops *dcbnl_ops;
	s16 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	unsigned int fcoe_ddp_xid;
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct sfp_bus *sfp_bus;
	struct lock_class_key *qdisc_tx_busylock;
	struct lock_class_key *qdisc_running_key;
	bool proto_down;
	unsigned int wol_enabled: 1;
	unsigned int threaded: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct list_head net_notifier_list;
	const struct macsec_ops *macsec_ops;
	const struct udp_tunnel_nic_info *udp_tunnel_nic_info;
	struct udp_tunnel_nic *udp_tunnel_nic;
	struct bpf_xdp_entity xdp_state[3];
	long: 64;
	long: 64;
	long: 64;
};

enum bpf_reg_type {
	NOT_INIT = 0,
	SCALAR_VALUE = 1,
	PTR_TO_CTX = 2,
	CONST_PTR_TO_MAP = 3,
	PTR_TO_MAP_VALUE = 4,
	PTR_TO_MAP_VALUE_OR_NULL = 5,
	PTR_TO_STACK = 6,
	PTR_TO_PACKET_META = 7,
	PTR_TO_PACKET = 8,
	PTR_TO_PACKET_END = 9,
	PTR_TO_FLOW_KEYS = 10,
	PTR_TO_SOCKET = 11,
	PTR_TO_SOCKET_OR_NULL = 12,
	PTR_TO_SOCK_COMMON = 13,
	PTR_TO_SOCK_COMMON_OR_NULL = 14,
	PTR_TO_TCP_SOCK = 15,
	PTR_TO_TCP_SOCK_OR_NULL = 16,
	PTR_TO_TP_BUFFER = 17,
	PTR_TO_XDP_SOCK = 18,
	PTR_TO_BTF_ID = 19,
	PTR_TO_BTF_ID_OR_NULL = 20,
	PTR_TO_MEM = 21,
	PTR_TO_MEM_OR_NULL = 22,
	PTR_TO_RDONLY_BUF = 23,
	PTR_TO_RDONLY_BUF_OR_NULL = 24,
	PTR_TO_RDWR_BUF = 25,
	PTR_TO_RDWR_BUF_OR_NULL = 26,
	PTR_TO_PERCPU_BTF_ID = 27,
	PTR_TO_FUNC = 28,
	PTR_TO_MAP_KEY = 29,
	__BPF_REG_TYPE_MAX = 30,
};

struct bpf_prog_ops {
	int (*test_run)(struct bpf_prog *, const union bpf_attr *, union bpf_attr *);
};

struct bpf_offload_dev;

struct bpf_prog_offload {
	struct bpf_prog *prog;
	struct net_device *netdev;
	struct bpf_offload_dev *offdev;
	void *dev_priv;
	struct list_head offloads;
	bool dev_state;
	bool opt_failed;
	void *jited_image;
	u32 jited_len;
};

struct btf_func_model {
	u8 ret_size;
	u8 nr_args;
	u8 arg_size[12];
};

struct bpf_tramp_image {
	void *image;
	struct bpf_ksym ksym;
	struct percpu_ref pcref;
	void *ip_after_call;
	void *ip_epilogue;
	union {
		struct callback_head rcu;
		struct work_struct work;
	};
};

struct bpf_trampoline {
	struct hlist_node hlist;
	struct mutex mutex;
	refcount_t refcnt;
	u64 key;
	struct {
		struct btf_func_model model;
		void *addr;
		bool ftrace_managed;
	} func;
	struct bpf_prog *extension_prog;
	struct hlist_head progs_hlist[3];
	int progs_cnt[3];
	struct bpf_tramp_image *cur_image;
	u64 selector;
	struct module___4 *mod;
};

struct bpf_func_info_aux {
	u16 linkage;
	bool unreliable;
};

struct bpf_jit_poke_descriptor {
	void *tailcall_target;
	void *tailcall_bypass;
	void *bypass_addr;
	void *aux;
	union {
		struct {
			struct bpf_map *map;
			u32 key;
		} tail_call;
	};
	bool tailcall_target_stable;
	u8 adj_off;
	u16 reason;
	u32 insn_idx;
};

struct bpf_ctx_arg_aux {
	u32 offset;
	enum bpf_reg_type reg_type;
	u32 btf_id;
};

struct btf_mod_pair {
	struct btf *btf;
	struct module___4 *module;
};

typedef unsigned int sk_buff_data_t;

struct skb_ext;

struct sk_buff {
	union {
		struct {
			struct sk_buff *next;
			struct sk_buff *prev;
			union {
				struct net_device *dev;
				long unsigned int dev_scratch;
			};
		};
		struct rb_node rbnode;
		struct list_head list;
	};
	union {
		struct sock *sk;
		int ip_defrag_offset;
	};
	union {
		ktime_t tstamp;
		u64 skb_mstamp_ns;
	};
	char cb[48];
	union {
		struct {
			long unsigned int _skb_refdst;
			void (*destructor)(struct sk_buff *);
		};
		struct list_head tcp_tsorted_anchor;
		long unsigned int _sk_redir;
	};
	long unsigned int _nfct;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	__u16 queue_mapping;
	__u8 __cloned_offset[0];
	__u8 cloned: 1;
	__u8 nohdr: 1;
	__u8 fclone: 2;
	__u8 peeked: 1;
	__u8 head_frag: 1;
	__u8 pfmemalloc: 1;
	__u8 pp_recycle: 1;
	long: 55;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 active_extensions;
	__u32 headers_start[0];
	__u8 __pkt_type_offset[0];
	__u8 pkt_type: 3;
	__u8 ignore_df: 1;
	__u8 nf_trace: 1;
	__u8 ip_summed: 2;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 sw_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	long: 15;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 __pkt_vlan_present_offset[0];
	__u8 vlan_present: 1;
	__u8 csum_complete_sw: 1;
	__u8 csum_level: 2;
	__u8 csum_not_inet: 1;
	__u8 dst_pending_confirm: 1;
	__u8 ndisc_nodetype: 2;
	__u8 ipvs_property: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	__u8 offload_fwd_mark: 1;
	__u8 offload_l3_fwd_mark: 1;
	__u8 tc_skip_classify: 1;
	__u8 tc_at_ingress: 1;
	__u8 redirected: 1;
	__u8 from_ingress: 1;
	__u8 decrypted: 1;
	__u8 slow_gro: 1;
	long: 47;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u16 tc_index;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	int skb_iif;
	__u32 hash;
	__be16 vlan_proto;
	__u16 vlan_tci;
	union {
		unsigned int napi_id;
		unsigned int sender_cpu;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__be16 protocol;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	__u32 headers_end[0];
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	refcount_t users;
	struct skb_ext *extensions;
};

struct cftype___2;

struct cgroup_subsys___2 {
	struct cgroup_subsys_state___2 * (*css_alloc)(struct cgroup_subsys_state___2 *);
	int (*css_online)(struct cgroup_subsys_state___2 *);
	void (*css_offline)(struct cgroup_subsys_state___2 *);
	void (*css_released)(struct cgroup_subsys_state___2 *);
	void (*css_free)(struct cgroup_subsys_state___2 *);
	void (*css_reset)(struct cgroup_subsys_state___2 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___2 *, int);
	int (*css_extra_stat_show)(struct seq_file___3 *, struct cgroup_subsys_state___2 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___5 *, struct css_set___3 *);
	void (*cancel_fork)(struct task_struct___5 *, struct css_set___3 *);
	void (*fork)(struct task_struct___5 *);
	void (*exit)(struct task_struct___5 *);
	void (*release)(struct task_struct___5 *);
	void (*bind)(struct cgroup_subsys_state___2 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___2 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___2 *dfl_cftypes;
	struct cftype___2 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___2 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___2 *updated_children;
	struct cgroup___2 *updated_next;
};

struct cgroup_root___2 {
	struct kernfs_root___2 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___2 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___2 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___2 *ss;
	struct list_head node;
	struct kernfs_ops___2 *kf_ops;
	int (*open)(struct kernfs_open_file___2 *);
	void (*release)(struct kernfs_open_file___2 *);
	u64 (*read_u64)(struct cgroup_subsys_state___2 *, struct cftype___2 *);
	s64 (*read_s64)(struct cgroup_subsys_state___2 *, struct cftype___2 *);
	int (*seq_show)(struct seq_file___3 *, void *);
	void * (*seq_start)(struct seq_file___3 *, loff_t *);
	void * (*seq_next)(struct seq_file___3 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___3 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___2 *, struct cftype___2 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___2 *, struct cftype___2 *, s64);
	ssize_t (*write)(struct kernfs_open_file___2 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___2 *, struct poll_table_struct___3 *);
};

struct block_device_operations___2;

struct gendisk___2 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	short unsigned int events;
	short unsigned int event_flags;
	struct xarray part_tbl;
	struct block_device___2 *part0;
	const struct block_device_operations___2 *fops;
	struct request_queue___2 *queue;
	void *private_data;
	int flags;
	long unsigned int state;
	struct mutex open_mutex;
	unsigned int open_partitions;
	struct backing_dev_info___2 *bdi;
	struct kobject___2 *slave_dir;
	struct list_head slave_bdevs;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___2 integrity_kobj;
	struct cdrom_device_info *cdi;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	u64 diskseq;
};

struct bio_integrity_payload___2 {
	struct bio___2 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___2 *bip_vec;
	struct bio_vec___2 bip_inline_vecs[0];
};

struct blkcg___2;

struct blkg_policy_data___2;

struct blkcg_gq___2 {
	struct request_queue___2 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___2 *blkcg;
	struct blkcg_gq___2 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_iostat_set *iostat_cpu;
	struct blkg_iostat_set iostat;
	struct blkg_policy_data___2 *pd[6];
	spinlock_t async_bio_lock;
	struct bio_list___2 async_bios;
	struct work_struct async_bio_work;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
	struct callback_head callback_head;
};

typedef void integrity_prepare_fn___2(struct request___2 *);

typedef void integrity_complete_fn___2(struct request___2 *, unsigned int);

struct blk_integrity_profile___2 {
	integrity_processing_fn *generate_fn;
	integrity_processing_fn *verify_fn;
	integrity_prepare_fn___2 *prepare_fn;
	integrity_complete_fn___2 *complete_fn;
	const char *name;
};

struct block_device_operations___2 {
	blk_qc_t (*submit_bio)(struct bio___2 *);
	int (*open)(struct block_device___2 *, fmode_t);
	void (*release)(struct gendisk___2 *, fmode_t);
	int (*rw_page)(struct block_device___2 *, sector_t, struct page___4 *, unsigned int);
	int (*ioctl)(struct block_device___2 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___2 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___2 *, unsigned int);
	void (*unlock_native_capacity)(struct gendisk___2 *);
	int (*getgeo)(struct block_device___2 *, struct hd_geometry *);
	int (*set_read_only)(struct block_device___2 *, bool);
	void (*swap_slot_free_notify)(struct block_device___2 *, long unsigned int);
	int (*report_zones)(struct gendisk___2 *, sector_t, unsigned int, report_zones_cb, void *);
	char * (*devnode)(struct gendisk___2 *, umode_t *);
	struct module___4 *owner;
	const struct pr_ops *pr_ops;
	int (*alternative_gpt_sector)(struct gendisk___2 *, sector_t *);
};

struct fwnode_reference_args___2;

struct fwnode_endpoint___2;

struct fwnode_operations___2 {
	struct fwnode_handle___2 * (*get)(struct fwnode_handle___2 *);
	void (*put)(struct fwnode_handle___2 *);
	bool (*device_is_available)(const struct fwnode_handle___2 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___2 *, const struct device___4 *);
	bool (*property_present)(const struct fwnode_handle___2 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___2 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___2 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___2 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___2 *);
	struct fwnode_handle___2 * (*get_parent)(const struct fwnode_handle___2 *);
	struct fwnode_handle___2 * (*get_next_child_node)(const struct fwnode_handle___2 *, struct fwnode_handle___2 *);
	struct fwnode_handle___2 * (*get_named_child_node)(const struct fwnode_handle___2 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___2 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___2 *);
	struct fwnode_handle___2 * (*graph_get_next_endpoint)(const struct fwnode_handle___2 *, struct fwnode_handle___2 *);
	struct fwnode_handle___2 * (*graph_get_remote_endpoint)(const struct fwnode_handle___2 *);
	struct fwnode_handle___2 * (*graph_get_port_parent)(struct fwnode_handle___2 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___2 *, struct fwnode_endpoint___2 *);
	int (*add_links)(struct fwnode_handle___2 *);
};

struct fwnode_endpoint___2 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___2 *local_fwnode;
};

struct fwnode_reference_args___2 {
	struct fwnode_handle___2 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct scatterlist {
	long unsigned int page_link;
	unsigned int offset;
	unsigned int length;
	dma_addr_t dma_address;
	unsigned int dma_length;
};

typedef void rq_end_io_fn___2(struct request___2 *, blk_status_t);

struct request___2 {
	struct request_queue___2 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int tag;
	int internal_tag;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___2 *bio;
	struct bio___2 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct llist_node ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___2 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___2 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___2 *saved_end_io;
		} flush;
	};
	struct gendisk___2 *rq_disk;
	struct block_device___2 *part;
	u64 alloc_time_ns;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int stats_sectors;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	struct bio_crypt_ctx *crypt_ctx;
	struct blk_ksm_keyslot *crypt_keyslot;
	short unsigned int write_hint;
	short unsigned int ioprio;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___2 *end_io;
	void *end_io_data;
};

struct elevator_type___2;

struct elevator_mq_ops___2 {
	int (*init_sched)(struct request_queue___2 *, struct elevator_type___2 *);
	void (*exit_sched)(struct elevator_queue___2 *);
	int (*init_hctx)(struct blk_mq_hw_ctx *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx *, unsigned int);
	void (*depth_updated)(struct blk_mq_hw_ctx *);
	bool (*allow_merge)(struct request_queue___2 *, struct request___2 *, struct bio___2 *);
	bool (*bio_merge)(struct request_queue___2 *, struct bio___2 *, unsigned int);
	int (*request_merge)(struct request_queue___2 *, struct request___2 **, struct bio___2 *);
	void (*request_merged)(struct request_queue___2 *, struct request___2 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___2 *, struct request___2 *, struct request___2 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___2 *);
	void (*finish_request)(struct request___2 *);
	void (*insert_requests)(struct blk_mq_hw_ctx *, struct list_head *, bool);
	struct request___2 * (*dispatch_request)(struct blk_mq_hw_ctx *);
	bool (*has_work)(struct blk_mq_hw_ctx *);
	void (*completed_request)(struct request___2 *, u64);
	void (*requeue_request)(struct request___2 *);
	struct request___2 * (*former_request)(struct request_queue___2 *, struct request___2 *);
	struct request___2 * (*next_request)(struct request_queue___2 *, struct request___2 *);
	void (*init_icq)(struct io_cq___2 *);
	void (*exit_icq)(struct io_cq___2 *);
};

struct elv_fs_entry___2;

struct elevator_type___2 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___2 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___2 *elevator_attrs;
	const char *elevator_name;
	const char *elevator_alias;
	const unsigned int elevator_features;
	struct module___4 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
};

struct elevator_queue___2 {
	struct elevator_type___2 *type;
	void *elevator_data;
	struct kobject___2 kobj;
	struct mutex sysfs_lock;
	unsigned int registered: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hlist_head hash[64];
};

struct elv_fs_entry___2 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___2 *, char *);
	ssize_t (*store)(struct elevator_queue___2 *, const char *, size_t);
};

struct blkcg_policy_data___2;

struct blkcg___2 {
	struct cgroup_subsys_state___2 css;
	spinlock_t lock;
	refcount_t online_pin;
	struct xarray blkg_tree;
	struct blkcg_gq___2 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___2 *cpd[6];
	struct list_head all_blkcgs_node;
	char fc_app_id[129];
	struct list_head cgwb_list;
};

struct blkcg_policy_data___2 {
	struct blkcg___2 *blkcg;
	int plid;
};

struct blkg_policy_data___2 {
	struct blkcg_gq___2 *blkg;
	int plid;
};

struct mem_cgroup_reclaim_iter___2 {
	struct mem_cgroup___2 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___2 {
	struct lruvec___2 lruvec;
	struct lruvec_stats_percpu *lruvec_stats_percpu;
	struct lruvec_stats lruvec_stats;
	long unsigned int lru_zone_size[25];
	struct mem_cgroup_reclaim_iter___2 iter;
	struct shrinker_info *shrinker_info;
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	struct mem_cgroup___2 *memcg;
};

struct obj_cgroup___2 {
	struct percpu_ref refcnt;
	struct mem_cgroup___2 *memcg;
	atomic_t nr_charged_bytes;
	union {
		struct list_head list;
		struct callback_head rcu;
	};
};

enum {
	Root_NFS = 255,
	Root_CIFS = 254,
	Root_RAM0 = 1048576,
	Root_RAM1 = 1048577,
	Root_FD0 = 2097152,
	Root_HDA1 = 3145729,
	Root_HDA2 = 3145730,
	Root_SDA1 = 8388609,
	Root_SDA2 = 8388610,
	Root_HDC1 = 23068673,
	Root_SR0 = 11534336,
};

struct fs_parameter___2 {
	const char *key;
	enum fs_value_type type: 8;
	long: 56;
	long: 64;
	union {
		char *string;
		void *blob;
		struct filename *name;
		struct file___3 *file;
	};
	size_t size;
	int dirfd;
};

struct fc_log___2 {
	refcount_t usage;
	u8 head;
	u8 tail;
	u8 need_free;
	struct module___4 *owner;
	char *buffer[8];
};

struct fs_context_operations___2 {
	void (*free)(struct fs_context___2 *);
	int (*dup)(struct fs_context___2 *, struct fs_context___2 *);
	int (*parse_param)(struct fs_context___2 *, struct fs_parameter___2 *);
	int (*parse_monolithic)(struct fs_context___2 *, void *);
	int (*get_tree)(struct fs_context___2 *);
	int (*reconfigure)(struct fs_context___2 *);
};

struct flowi_tunnel {
	__be64 tun_id;
};

struct flowi_common {
	int flowic_oif;
	int flowic_iif;
	__u32 flowic_mark;
	__u8 flowic_tos;
	__u8 flowic_scope;
	__u8 flowic_proto;
	__u8 flowic_flags;
	__u32 flowic_secid;
	kuid_t flowic_uid;
	struct flowi_tunnel flowic_tun_key;
	__u32 flowic_multipath_hash;
};

union flowi_uli {
	struct {
		__be16 dport;
		__be16 sport;
	} ports;
	struct {
		__u8 type;
		__u8 code;
	} icmpt;
	struct {
		__le16 dport;
		__le16 sport;
	} dnports;
	__be32 gre_key;
	struct {
		__u8 type;
	} mht;
};

struct flowi4 {
	struct flowi_common __fl_common;
	__be32 saddr;
	__be32 daddr;
	union flowi_uli uli;
};

struct flowi6 {
	struct flowi_common __fl_common;
	struct in6_addr daddr;
	struct in6_addr saddr;
	__be32 flowlabel;
	union flowi_uli uli;
	__u32 mp_hash;
};

struct flowidn {
	struct flowi_common __fl_common;
	__le16 daddr;
	__le16 saddr;
	union flowi_uli uli;
};

struct flowi {
	union {
		struct flowi_common __fl_common;
		struct flowi4 ip4;
		struct flowi6 ip6;
		struct flowidn dn;
	} u;
};

struct ipstats_mib {
	u64 mibs[37];
	struct u64_stats_sync syncp;
};

struct icmp_mib {
	long unsigned int mibs[28];
};

struct icmpmsg_mib {
	atomic_long_t mibs[512];
};

struct icmpv6_mib {
	long unsigned int mibs[6];
};

struct icmpv6_mib_device {
	atomic_long_t mibs[6];
};

struct icmpv6msg_mib {
	atomic_long_t mibs[512];
};

struct icmpv6msg_mib_device {
	atomic_long_t mibs[512];
};

struct tcp_mib {
	long unsigned int mibs[16];
};

struct udp_mib {
	long unsigned int mibs[10];
};

struct linux_mib {
	long unsigned int mibs[126];
};

struct linux_xfrm_mib {
	long unsigned int mibs[29];
};

struct linux_tls_mib {
	long unsigned int mibs[11];
};

struct inet_frags;

struct fqdir {
	long int high_thresh;
	long int low_thresh;
	int timeout;
	int max_dist;
	struct inet_frags *f;
	struct net___2 *net;
	bool dead;
	long: 56;
	long: 64;
	long: 64;
	struct rhashtable rhashtable;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	atomic_long_t mem;
	struct work_struct destroy_work;
	struct llist_node free_list;
	long: 64;
	long: 64;
};

struct inet_frag_queue;

struct inet_frags {
	unsigned int qsize;
	void (*constructor)(struct inet_frag_queue *, const void *);
	void (*destructor)(struct inet_frag_queue *);
	void (*frag_expire)(struct timer_list *);
	struct kmem_cache *frags_cachep;
	const char *frags_cache_name;
	struct rhashtable_params rhash_params;
	refcount_t refcnt;
	struct completion completion;
};

struct frag_v4_compare_key {
	__be32 saddr;
	__be32 daddr;
	u32 user;
	u32 vif;
	__be16 id;
	u16 protocol;
};

struct frag_v6_compare_key {
	struct in6_addr saddr;
	struct in6_addr daddr;
	u32 user;
	__be32 id;
	u32 iif;
};

struct inet_frag_queue {
	struct rhash_head node;
	union {
		struct frag_v4_compare_key v4;
		struct frag_v6_compare_key v6;
	} key;
	struct timer_list timer;
	spinlock_t lock;
	refcount_t refcnt;
	struct rb_root rb_fragments;
	struct sk_buff *fragments_tail;
	struct sk_buff *last_run_head;
	ktime_t stamp;
	int len;
	int meat;
	__u8 flags;
	u16 max_size;
	struct fqdir *fqdir;
	struct callback_head rcu;
};

struct fib_rule;

struct fib_lookup_arg;

struct fib_rule_hdr;

struct nlattr;

struct netlink_ext_ack;

struct nla_policy;

struct fib_rules_ops {
	int family;
	struct list_head list;
	int rule_size;
	int addr_size;
	int unresolved_rules;
	int nr_goto_rules;
	unsigned int fib_rules_seq;
	int (*action)(struct fib_rule *, struct flowi *, int, struct fib_lookup_arg *);
	bool (*suppress)(struct fib_rule *, int, struct fib_lookup_arg *);
	int (*match)(struct fib_rule *, struct flowi *, int);
	int (*configure)(struct fib_rule *, struct sk_buff *, struct fib_rule_hdr *, struct nlattr **, struct netlink_ext_ack *);
	int (*delete)(struct fib_rule *);
	int (*compare)(struct fib_rule *, struct fib_rule_hdr *, struct nlattr **);
	int (*fill)(struct fib_rule *, struct sk_buff *, struct fib_rule_hdr *);
	size_t (*nlmsg_payload)(struct fib_rule *);
	void (*flush_cache)(struct fib_rules_ops *);
	int nlgroup;
	const struct nla_policy *policy;
	struct list_head rules_list;
	struct module___4 *owner;
	struct net___2 *fro_net;
	struct callback_head rcu;
};

struct fib_notifier_ops {
	int family;
	struct list_head list;
	unsigned int (*fib_seq_read)(struct net___2 *);
	int (*fib_dump)(struct net___2 *, struct notifier_block *, struct netlink_ext_ack *);
	struct module___4 *owner;
	struct callback_head rcu;
};

struct xfrm_state;

struct lwtunnel_state;

struct dst_entry {
	struct net_device *dev;
	struct dst_ops *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct xfrm_state *xfrm;
	int (*input)(struct sk_buff *);
	int (*output)(struct net___2 *, struct sock *, struct sk_buff *);
	short unsigned int flags;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	struct lwtunnel_state *lwtstate;
	struct callback_head callback_head;
	short int error;
	short int __pad;
	__u32 tclassid;
};

struct hh_cache {
	unsigned int hh_len;
	seqlock_t hh_lock;
	long unsigned int hh_data[16];
};

struct neigh_table;

struct neigh_parms;

struct neigh_ops;

struct neighbour {
	struct neighbour *next;
	struct neigh_table *tbl;
	struct neigh_parms *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	refcount_t refcnt;
	unsigned int arp_queue_len_bytes;
	struct sk_buff_head arp_queue;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	u8 protocol;
	seqlock_t ha_lock;
	int: 32;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour *, struct sk_buff *);
	const struct neigh_ops *ops;
	struct list_head gc_list;
	struct callback_head rcu;
	struct net_device *dev;
	u8 primary_key[0];
};

struct ipv6_stable_secret {
	bool initialized;
	struct in6_addr secret;
};

struct ipv6_devconf {
	__s32 forwarding;
	__s32 hop_limit;
	__s32 mtu6;
	__s32 accept_ra;
	__s32 accept_redirects;
	__s32 autoconf;
	__s32 dad_transmits;
	__s32 rtr_solicits;
	__s32 rtr_solicit_interval;
	__s32 rtr_solicit_max_interval;
	__s32 rtr_solicit_delay;
	__s32 force_mld_version;
	__s32 mldv1_unsolicited_report_interval;
	__s32 mldv2_unsolicited_report_interval;
	__s32 use_tempaddr;
	__s32 temp_valid_lft;
	__s32 temp_prefered_lft;
	__s32 regen_max_retry;
	__s32 max_desync_factor;
	__s32 max_addresses;
	__s32 accept_ra_defrtr;
	__u32 ra_defrtr_metric;
	__s32 accept_ra_min_hop_limit;
	__s32 accept_ra_pinfo;
	__s32 ignore_routes_with_linkdown;
	__s32 accept_ra_rtr_pref;
	__s32 rtr_probe_interval;
	__s32 accept_ra_rt_info_min_plen;
	__s32 accept_ra_rt_info_max_plen;
	__s32 proxy_ndp;
	__s32 accept_source_route;
	__s32 accept_ra_from_local;
	__s32 mc_forwarding;
	__s32 disable_ipv6;
	__s32 drop_unicast_in_l2_multicast;
	__s32 accept_dad;
	__s32 force_tllao;
	__s32 ndisc_notify;
	__s32 suppress_frag_ndisc;
	__s32 accept_ra_mtu;
	__s32 drop_unsolicited_na;
	struct ipv6_stable_secret stable_secret;
	__s32 use_oif_addrs_only;
	__s32 keep_addr_on_down;
	__s32 seg6_enabled;
	__s32 seg6_require_hmac;
	__u32 enhanced_dad;
	__u32 addr_gen_mode;
	__s32 disable_policy;
	__s32 ndisc_tclass;
	__s32 rpl_seg_enabled;
	__u32 ioam6_id;
	__u32 ioam6_id_wide;
	__u8 ioam6_enabled;
	struct ctl_table_header *sysctl_header;
};

struct hlist_nulls_head {
	struct hlist_nulls_node *first;
};

struct ip_conntrack_stat {
	unsigned int found;
	unsigned int invalid;
	unsigned int insert;
	unsigned int insert_failed;
	unsigned int clash_resolve;
	unsigned int drop;
	unsigned int early_drop;
	unsigned int error;
	unsigned int expect_new;
	unsigned int expect_create;
	unsigned int expect_delete;
	unsigned int search_restart;
	unsigned int chaintoolong;
};

struct ct_pcpu {
	spinlock_t lock;
	struct hlist_nulls_head unconfirmed;
	struct hlist_nulls_head dying;
};

typedef enum {
	SS_FREE = 0,
	SS_UNCONNECTED = 1,
	SS_CONNECTING = 2,
	SS_CONNECTED = 3,
	SS_DISCONNECTING = 4,
} socket_state;

struct socket_wq {
	wait_queue_head_t wait;
	struct fasync_struct___3 *fasync_list;
	long unsigned int flags;
	struct callback_head rcu;
	long: 64;
};

struct proto_ops;

struct socket {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct file___3 *file;
	struct sock *sk;
	const struct proto_ops *ops;
	long: 64;
	long: 64;
	long: 64;
	struct socket_wq wq;
};

typedef int (*sk_read_actor_t)(read_descriptor_t *, struct sk_buff *, unsigned int, size_t);

struct proto_ops {
	int family;
	struct module___4 *owner;
	int (*release)(struct socket *);
	int (*bind)(struct socket *, struct sockaddr *, int);
	int (*connect)(struct socket *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket *, struct socket *);
	int (*accept)(struct socket *, struct socket *, int, bool);
	int (*getname)(struct socket *, struct sockaddr *, int);
	__poll_t (*poll)(struct file___3 *, struct socket *, struct poll_table_struct___3 *);
	int (*ioctl)(struct socket *, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct socket *, unsigned int, long unsigned int);
	int (*gettstamp)(struct socket *, void *, bool, bool);
	int (*listen)(struct socket *, int);
	int (*shutdown)(struct socket *, int);
	int (*setsockopt)(struct socket *, int, int, sockptr_t, unsigned int);
	int (*getsockopt)(struct socket *, int, int, char *, int *);
	void (*show_fdinfo)(struct seq_file___3 *, struct socket *);
	int (*sendmsg)(struct socket *, struct msghdr *, size_t);
	int (*recvmsg)(struct socket *, struct msghdr *, size_t, int);
	int (*mmap)(struct file___3 *, struct socket *, struct vm_area_struct___4 *);
	ssize_t (*sendpage)(struct socket *, struct page___4 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*set_peek_off)(struct sock *, int);
	int (*peek_len)(struct socket *);
	int (*read_sock)(struct sock *, read_descriptor_t *, sk_read_actor_t);
	int (*sendpage_locked)(struct sock *, struct page___4 *, int, size_t, int);
	int (*sendmsg_locked)(struct sock *, struct msghdr *, size_t);
	int (*set_rcvlowat)(struct sock *, int);
};

struct pipe_buf_operations;

struct pipe_buffer {
	struct page___4 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations {
	int (*confirm)(struct pipe_inode_info *, struct pipe_buffer *);
	void (*release)(struct pipe_inode_info *, struct pipe_buffer *);
	bool (*try_steal)(struct pipe_inode_info *, struct pipe_buffer *);
	bool (*get)(struct pipe_inode_info *, struct pipe_buffer *);
};

struct skb_ext {
	refcount_t refcnt;
	u8 offset[4];
	u8 chunks;
	long: 56;
	char data[0];
};

struct dql {
	unsigned int num_queued;
	unsigned int adj_limit;
	unsigned int last_obj_cnt;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int limit;
	unsigned int num_completed;
	unsigned int prev_ovlimit;
	unsigned int prev_num_queued;
	unsigned int prev_last_obj_cnt;
	unsigned int lowest_slack;
	long unsigned int slack_start_time;
	unsigned int max_limit;
	unsigned int min_limit;
	unsigned int slack_hold_time;
	long: 32;
	long: 64;
	long: 64;
};

struct ieee_ets {
	__u8 willing;
	__u8 ets_cap;
	__u8 cbs;
	__u8 tc_tx_bw[8];
	__u8 tc_rx_bw[8];
	__u8 tc_tsa[8];
	__u8 prio_tc[8];
	__u8 tc_reco_bw[8];
	__u8 tc_reco_tsa[8];
	__u8 reco_prio_tc[8];
};

struct ieee_maxrate {
	__u64 tc_maxrate[8];
};

struct ieee_qcn {
	__u8 rpg_enable[8];
	__u32 rppp_max_rps[8];
	__u32 rpg_time_reset[8];
	__u32 rpg_byte_reset[8];
	__u32 rpg_threshold[8];
	__u32 rpg_max_rate[8];
	__u32 rpg_ai_rate[8];
	__u32 rpg_hai_rate[8];
	__u32 rpg_gd[8];
	__u32 rpg_min_dec_fac[8];
	__u32 rpg_min_rate[8];
	__u32 cndd_state_machine[8];
};

struct ieee_qcn_stats {
	__u64 rppp_rp_centiseconds[8];
	__u32 rppp_created_rps[8];
};

struct ieee_pfc {
	__u8 pfc_cap;
	__u8 pfc_en;
	__u8 mbc;
	__u16 delay;
	__u64 requests[8];
	__u64 indications[8];
};

struct dcbnl_buffer {
	__u8 prio2buffer[8];
	__u32 buffer_size[8];
	__u32 total_size;
};

struct cee_pg {
	__u8 willing;
	__u8 error;
	__u8 pg_en;
	__u8 tcs_supported;
	__u8 pg_bw[8];
	__u8 prio_pg[8];
};

struct cee_pfc {
	__u8 willing;
	__u8 error;
	__u8 pfc_en;
	__u8 tcs_supported;
};

struct dcb_app {
	__u8 selector;
	__u8 priority;
	__u16 protocol;
};

struct dcb_peer_app_info {
	__u8 willing;
	__u8 error;
};

struct dcbnl_rtnl_ops {
	int (*ieee_getets)(struct net_device *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device *, struct ieee_maxrate *);
	int (*ieee_getqcn)(struct net_device *, struct ieee_qcn *);
	int (*ieee_setqcn)(struct net_device *, struct ieee_qcn *);
	int (*ieee_getqcnstats)(struct net_device *, struct ieee_qcn_stats *);
	int (*ieee_getpfc)(struct net_device *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device *);
	u8 (*setstate)(struct net_device *, u8);
	void (*getpermhwaddr)(struct net_device *, u8 *);
	void (*setpgtccfgtx)(struct net_device *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device *, int, u8);
	void (*setpgtccfgrx)(struct net_device *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device *, int, u8);
	void (*getpgtccfgtx)(struct net_device *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device *, int, u8 *);
	void (*setpfccfg)(struct net_device *, int, u8);
	void (*getpfccfg)(struct net_device *, int, u8 *);
	u8 (*setall)(struct net_device *);
	u8 (*getcap)(struct net_device *, int, u8 *);
	int (*getnumtcs)(struct net_device *, int, u8 *);
	int (*setnumtcs)(struct net_device *, int, u8);
	u8 (*getpfcstate)(struct net_device *);
	void (*setpfcstate)(struct net_device *, u8);
	void (*getbcncfg)(struct net_device *, int, u32 *);
	void (*setbcncfg)(struct net_device *, int, u32);
	void (*getbcnrp)(struct net_device *, int, u8 *);
	void (*setbcnrp)(struct net_device *, int, u8);
	int (*setapp)(struct net_device *, u8, u16, u8);
	int (*getapp)(struct net_device *, u8, u16);
	u8 (*getfeatcfg)(struct net_device *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device *, int, u8);
	u8 (*getdcbx)(struct net_device *);
	u8 (*setdcbx)(struct net_device *, u8);
	int (*peer_getappinfo)(struct net_device *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device *, struct cee_pfc *);
	int (*dcbnl_getbuffer)(struct net_device *, struct dcbnl_buffer *);
	int (*dcbnl_setbuffer)(struct net_device *, struct dcbnl_buffer *);
};

struct netprio_map {
	struct callback_head rcu;
	u32 priomap_len;
	u32 priomap[0];
};

struct xdp_mem_info {
	u32 type;
	u32 id;
};

struct xdp_rxq_info {
	struct net_device *dev;
	u32 queue_index;
	u32 reg_state;
	struct xdp_mem_info mem;
	unsigned int napi_id;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct xdp_txq_info {
	struct net_device *dev;
};

struct xdp_buff {
	void *data;
	void *data_end;
	void *data_meta;
	void *data_hard_start;
	struct xdp_rxq_info *rxq;
	struct xdp_txq_info *txq;
	u32 frame_sz;
};

struct xdp_frame {
	void *data;
	u16 len;
	u16 headroom;
	u32 metasize: 8;
	u32 frame_sz: 24;
	long: 40;
	long: 64;
	struct xdp_mem_info mem;
	struct net_device *dev_rx;
};

struct nlmsghdr {
	__u32 nlmsg_len;
	__u16 nlmsg_type;
	__u16 nlmsg_flags;
	__u32 nlmsg_seq;
	__u32 nlmsg_pid;
};

struct nlattr {
	__u16 nla_len;
	__u16 nla_type;
};

struct netlink_ext_ack {
	const char *_msg;
	const struct nlattr *bad_attr;
	const struct nla_policy *policy;
	u8 cookie[20];
	u8 cookie_len;
};

struct netlink_range_validation;

struct netlink_range_validation_signed;

struct nla_policy {
	u8 type;
	u8 validation_type;
	u16 len;
	union {
		const u32 bitfield32_valid;
		const u32 mask;
		const char *reject_message;
		const struct nla_policy *nested_policy;
		struct netlink_range_validation *range;
		struct netlink_range_validation_signed *range_signed;
		struct {
			s16 min;
			s16 max;
		};
		int (*validate)(const struct nlattr *, struct netlink_ext_ack *);
		u16 strict_start_type;
	};
};

struct netlink_callback {
	struct sk_buff *skb;
	const struct nlmsghdr *nlh;
	int (*dump)(struct sk_buff *, struct netlink_callback *);
	int (*done)(struct netlink_callback *);
	void *data;
	struct module___4 *module;
	struct netlink_ext_ack *extack;
	u16 family;
	u16 answer_flags;
	u32 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	bool strict_check;
	union {
		u8 ctx[48];
		long int args[6];
	};
};

struct ndmsg {
	__u8 ndm_family;
	__u8 ndm_pad1;
	__u16 ndm_pad2;
	__s32 ndm_ifindex;
	__u16 ndm_state;
	__u8 ndm_flags;
	__u8 ndm_type;
};

struct rtnl_link_stats64 {
	__u64 rx_packets;
	__u64 tx_packets;
	__u64 rx_bytes;
	__u64 tx_bytes;
	__u64 rx_errors;
	__u64 tx_errors;
	__u64 rx_dropped;
	__u64 tx_dropped;
	__u64 multicast;
	__u64 collisions;
	__u64 rx_length_errors;
	__u64 rx_over_errors;
	__u64 rx_crc_errors;
	__u64 rx_frame_errors;
	__u64 rx_fifo_errors;
	__u64 rx_missed_errors;
	__u64 tx_aborted_errors;
	__u64 tx_carrier_errors;
	__u64 tx_fifo_errors;
	__u64 tx_heartbeat_errors;
	__u64 tx_window_errors;
	__u64 rx_compressed;
	__u64 tx_compressed;
	__u64 rx_nohandler;
};

struct ifla_vf_guid {
	__u32 vf;
	__u64 guid;
};

struct ifla_vf_stats {
	__u64 rx_packets;
	__u64 tx_packets;
	__u64 rx_bytes;
	__u64 tx_bytes;
	__u64 broadcast;
	__u64 multicast;
	__u64 rx_dropped;
	__u64 tx_dropped;
};

struct ifla_vf_info {
	__u32 vf;
	__u8 mac[32];
	__u32 vlan;
	__u32 qos;
	__u32 spoofchk;
	__u32 linkstate;
	__u32 min_tx_rate;
	__u32 max_tx_rate;
	__u32 rss_query_en;
	__u32 trusted;
	__be16 vlan_proto;
};

struct tc_stats {
	__u64 bytes;
	__u32 packets;
	__u32 drops;
	__u32 overlimits;
	__u32 bps;
	__u32 pps;
	__u32 qlen;
	__u32 backlog;
};

struct tc_sizespec {
	unsigned char cell_log;
	unsigned char size_log;
	short int cell_align;
	int overhead;
	unsigned int linklayer;
	unsigned int mpu;
	unsigned int mtu;
	unsigned int tsize;
};

enum netdev_tx {
	__NETDEV_TX_MIN = 2147483648,
	NETDEV_TX_OK = 0,
	NETDEV_TX_BUSY = 16,
};

typedef enum netdev_tx netdev_tx_t;

struct header_ops {
	int (*create)(struct sk_buff *, struct net_device *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff *, unsigned char *);
	int (*cache)(const struct neighbour *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device *, const unsigned char *);
	bool (*validate)(const char *, unsigned int);
	__be16 (*parse_protocol)(const struct sk_buff *);
};

struct xsk_buff_pool;

struct netdev_queue {
	struct net_device *dev;
	struct Qdisc *qdisc;
	struct Qdisc *qdisc_sleeping;
	struct kobject___2 kobj;
	int numa_node;
	long unsigned int tx_maxrate;
	long unsigned int trans_timeout;
	struct net_device *sb_dev;
	struct xsk_buff_pool *pool;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
};

struct net_rate_estimator;

struct qdisc_skb_head {
	struct sk_buff *head;
	struct sk_buff *tail;
	__u32 qlen;
	spinlock_t lock;
};

struct gnet_stats_basic_packed {
	__u64 bytes;
	__u64 packets;
};

struct gnet_stats_queue {
	__u32 qlen;
	__u32 backlog;
	__u32 drops;
	__u32 requeues;
	__u32 overlimits;
};

struct Qdisc_ops;

struct qdisc_size_table;

struct gnet_stats_basic_cpu;

struct Qdisc {
	int (*enqueue)(struct sk_buff *, struct Qdisc *, struct sk_buff **);
	struct sk_buff * (*dequeue)(struct Qdisc *);
	unsigned int flags;
	u32 limit;
	const struct Qdisc_ops *ops;
	struct qdisc_size_table *stab;
	struct hlist_node hash;
	u32 handle;
	u32 parent;
	struct netdev_queue *dev_queue;
	struct net_rate_estimator *rate_est;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	int pad;
	refcount_t refcnt;
	long: 64;
	long: 64;
	long: 64;
	struct sk_buff_head gso_skb;
	struct qdisc_skb_head q;
	struct gnet_stats_basic_packed bstats;
	seqcount_t running;
	struct gnet_stats_queue qstats;
	long unsigned int state;
	struct Qdisc *next_sched;
	struct sk_buff_head skb_bad_txq;
	spinlock_t busylock;
	spinlock_t seqlock;
	struct callback_head rcu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long int privdata[0];
};

struct rps_map {
	unsigned int len;
	struct callback_head rcu;
	u16 cpus[0];
};

struct rps_dev_flow {
	u16 cpu;
	u16 filter;
	unsigned int last_qtail;
};

struct rps_dev_flow_table {
	unsigned int mask;
	struct callback_head rcu;
	struct rps_dev_flow flows[0];
};

struct netdev_rx_queue {
	struct xdp_rxq_info xdp_rxq;
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___2 kobj;
	struct net_device *dev;
	struct xsk_buff_pool *pool;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct xps_map {
	unsigned int len;
	unsigned int alloc_len;
	struct callback_head rcu;
	u16 queues[0];
};

struct xps_dev_maps {
	struct callback_head rcu;
	unsigned int nr_ids;
	s16 num_tc;
	struct xps_map *attr_map[0];
};

struct netdev_fcoe_hbainfo {
	char manufacturer[64];
	char serial_number[64];
	char hardware_version[64];
	char driver_version[64];
	char optionrom_version[64];
	char firmware_version[64];
	char model[256];
	char model_description[256];
};

struct netdev_phys_item_id {
	unsigned char id[32];
	unsigned char id_len;
};

enum net_device_path_type {
	DEV_PATH_ETHERNET = 0,
	DEV_PATH_VLAN = 1,
	DEV_PATH_BRIDGE = 2,
	DEV_PATH_PPPOE = 3,
	DEV_PATH_DSA = 4,
};

struct net_device_path {
	enum net_device_path_type type;
	const struct net_device *dev;
	union {
		struct {
			u16 id;
			__be16 proto;
			u8 h_dest[6];
		} encap;
		struct {
			enum {
				DEV_PATH_BR_VLAN_KEEP = 0,
				DEV_PATH_BR_VLAN_TAG = 1,
				DEV_PATH_BR_VLAN_UNTAG = 2,
				DEV_PATH_BR_VLAN_UNTAG_HW = 3,
			} vlan_mode;
			u16 vlan_id;
			__be16 vlan_proto;
		} bridge;
		struct {
			int port;
			u16 proto;
		} dsa;
	};
};

struct net_device_path_ctx {
	const struct net_device *dev;
	const u8 *daddr;
	int num_vlans;
	struct {
		u16 id;
		__be16 proto;
	} vlan[2];
};

enum tc_setup_type {
	TC_SETUP_QDISC_MQPRIO = 0,
	TC_SETUP_CLSU32 = 1,
	TC_SETUP_CLSFLOWER = 2,
	TC_SETUP_CLSMATCHALL = 3,
	TC_SETUP_CLSBPF = 4,
	TC_SETUP_BLOCK = 5,
	TC_SETUP_QDISC_CBS = 6,
	TC_SETUP_QDISC_RED = 7,
	TC_SETUP_QDISC_PRIO = 8,
	TC_SETUP_QDISC_MQ = 9,
	TC_SETUP_QDISC_ETF = 10,
	TC_SETUP_ROOT_QDISC = 11,
	TC_SETUP_QDISC_GRED = 12,
	TC_SETUP_QDISC_TAPRIO = 13,
	TC_SETUP_FT = 14,
	TC_SETUP_QDISC_ETS = 15,
	TC_SETUP_QDISC_TBF = 16,
	TC_SETUP_QDISC_FIFO = 17,
	TC_SETUP_QDISC_HTB = 18,
};

enum bpf_netdev_command {
	XDP_SETUP_PROG = 0,
	XDP_SETUP_PROG_HW = 1,
	BPF_OFFLOAD_MAP_ALLOC = 2,
	BPF_OFFLOAD_MAP_FREE = 3,
	XDP_SETUP_XSK_POOL = 4,
};

struct netdev_bpf {
	enum bpf_netdev_command command;
	union {
		struct {
			u32 flags;
			struct bpf_prog *prog;
			struct netlink_ext_ack *extack;
		};
		struct {
			struct bpf_offloaded_map *offmap;
		};
		struct {
			struct xsk_buff_pool *pool;
			u16 queue_id;
		} xsk;
	};
};

struct xfrmdev_ops {
	int (*xdo_dev_state_add)(struct xfrm_state *);
	void (*xdo_dev_state_delete)(struct xfrm_state *);
	void (*xdo_dev_state_free)(struct xfrm_state *);
	bool (*xdo_dev_offload_ok)(struct sk_buff *, struct xfrm_state *);
	void (*xdo_dev_state_advance_esn)(struct xfrm_state *);
};

struct dev_ifalias {
	struct callback_head rcuhead;
	char ifalias[0];
};

struct netdev_name_node {
	struct hlist_node hlist;
	struct list_head list;
	struct net_device *dev;
	const char *name;
};

struct devlink_port;

struct ip_tunnel_parm;

struct net_device_ops {
	int (*ndo_init)(struct net_device *);
	void (*ndo_uninit)(struct net_device *);
	int (*ndo_open)(struct net_device *);
	int (*ndo_stop)(struct net_device *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff *, struct net_device *);
	netdev_features_t (*ndo_features_check)(struct sk_buff *, struct net_device *, netdev_features_t);
	u16 (*ndo_select_queue)(struct net_device *, struct sk_buff *, struct net_device *);
	void (*ndo_change_rx_flags)(struct net_device *, int);
	void (*ndo_set_rx_mode)(struct net_device *);
	int (*ndo_set_mac_address)(struct net_device *, void *);
	int (*ndo_validate_addr)(struct net_device *);
	int (*ndo_do_ioctl)(struct net_device *, struct ifreq *, int);
	int (*ndo_eth_ioctl)(struct net_device *, struct ifreq *, int);
	int (*ndo_siocbond)(struct net_device *, struct ifreq *, int);
	int (*ndo_siocwandev)(struct net_device *, struct if_settings *);
	int (*ndo_siocdevprivate)(struct net_device *, struct ifreq *, void *, int);
	int (*ndo_set_config)(struct net_device *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device *, int);
	int (*ndo_neigh_setup)(struct net_device *, struct neigh_parms *);
	void (*ndo_tx_timeout)(struct net_device *, unsigned int);
	void (*ndo_get_stats64)(struct net_device *, struct rtnl_link_stats64 *);
	bool (*ndo_has_offload_stats)(const struct net_device *, int);
	int (*ndo_get_offload_stats)(int, const struct net_device *, void *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device *);
	int (*ndo_vlan_rx_add_vid)(struct net_device *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device *);
	int (*ndo_netpoll_setup)(struct net_device *, struct netpoll_info *);
	void (*ndo_netpoll_cleanup)(struct net_device *);
	int (*ndo_set_vf_mac)(struct net_device *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device *, int, u16, u8, __be16);
	int (*ndo_set_vf_rate)(struct net_device *, int, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device *, int, bool);
	int (*ndo_set_vf_trust)(struct net_device *, int, bool);
	int (*ndo_get_vf_config)(struct net_device *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device *, int, int);
	int (*ndo_get_vf_stats)(struct net_device *, int, struct ifla_vf_stats *);
	int (*ndo_set_vf_port)(struct net_device *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device *, int, struct sk_buff *);
	int (*ndo_get_vf_guid)(struct net_device *, int, struct ifla_vf_guid *, struct ifla_vf_guid *);
	int (*ndo_set_vf_guid)(struct net_device *, int, u64, int);
	int (*ndo_set_vf_rss_query_en)(struct net_device *, int, bool);
	int (*ndo_setup_tc)(struct net_device *, enum tc_setup_type, void *);
	int (*ndo_fcoe_enable)(struct net_device *);
	int (*ndo_fcoe_disable)(struct net_device *);
	int (*ndo_fcoe_ddp_setup)(struct net_device *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_ddp_done)(struct net_device *, u16);
	int (*ndo_fcoe_ddp_target)(struct net_device *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_get_hbainfo)(struct net_device *, struct netdev_fcoe_hbainfo *);
	int (*ndo_fcoe_get_wwn)(struct net_device *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device *, const struct sk_buff *, u16, u32);
	int (*ndo_add_slave)(struct net_device *, struct net_device *, struct netlink_ext_ack *);
	int (*ndo_del_slave)(struct net_device *, struct net_device *);
	struct net_device * (*ndo_get_xmit_slave)(struct net_device *, struct sk_buff *, bool);
	struct net_device * (*ndo_sk_get_lower_dev)(struct net_device *, struct sock *);
	netdev_features_t (*ndo_fix_features)(struct net_device *, netdev_features_t);
	int (*ndo_set_features)(struct net_device *, netdev_features_t);
	int (*ndo_neigh_construct)(struct net_device *, struct neighbour *);
	void (*ndo_neigh_destroy)(struct net_device *, struct neighbour *);
	int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device *, const unsigned char *, u16, u16, struct netlink_ext_ack *);
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device *, const unsigned char *, u16);
	int (*ndo_fdb_dump)(struct sk_buff *, struct netlink_callback *, struct net_device *, struct net_device *, int *);
	int (*ndo_fdb_get)(struct sk_buff *, struct nlattr **, struct net_device *, const unsigned char *, u16, u32, u32, struct netlink_ext_ack *);
	int (*ndo_bridge_setlink)(struct net_device *, struct nlmsghdr *, u16, struct netlink_ext_ack *);
	int (*ndo_bridge_getlink)(struct sk_buff *, u32, u32, struct net_device *, u32, int);
	int (*ndo_bridge_dellink)(struct net_device *, struct nlmsghdr *, u16);
	int (*ndo_change_carrier)(struct net_device *, bool);
	int (*ndo_get_phys_port_id)(struct net_device *, struct netdev_phys_item_id *);
	int (*ndo_get_port_parent_id)(struct net_device *, struct netdev_phys_item_id *);
	int (*ndo_get_phys_port_name)(struct net_device *, char *, size_t);
	void * (*ndo_dfwd_add_station)(struct net_device *, struct net_device *);
	void (*ndo_dfwd_del_station)(struct net_device *, void *);
	int (*ndo_set_tx_maxrate)(struct net_device *, int, u32);
	int (*ndo_get_iflink)(const struct net_device *);
	int (*ndo_change_proto_down)(struct net_device *, bool);
	int (*ndo_fill_metadata_dst)(struct net_device *, struct sk_buff *);
	void (*ndo_set_rx_headroom)(struct net_device *, int);
	int (*ndo_bpf)(struct net_device *, struct netdev_bpf *);
	int (*ndo_xdp_xmit)(struct net_device *, int, struct xdp_frame **, u32);
	struct net_device * (*ndo_xdp_get_xmit_slave)(struct net_device *, struct xdp_buff *);
	int (*ndo_xsk_wakeup)(struct net_device *, u32, u32);
	struct devlink_port * (*ndo_get_devlink_port)(struct net_device *);
	int (*ndo_tunnel_ctl)(struct net_device *, struct ip_tunnel_parm *, int);
	struct net_device * (*ndo_get_peer_dev)(struct net_device *);
	int (*ndo_fill_forward_path)(struct net_device_path_ctx *, struct net_device_path *);
};

struct neigh_parms {
	possible_net_t net;
	struct net_device *dev;
	struct list_head list;
	int (*neigh_setup)(struct neighbour *);
	struct neigh_table *tbl;
	void *sysctl_table;
	int dead;
	refcount_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[13];
	long unsigned int data_state[1];
};

struct pcpu_lstats {
	u64_stats_t packets;
	u64_stats_t bytes;
	struct u64_stats_sync syncp;
};

struct pcpu_sw_netstats {
	u64 rx_packets;
	u64 rx_bytes;
	u64 tx_packets;
	u64 tx_bytes;
	struct u64_stats_sync syncp;
};

struct l3mdev_ops {
	u32 (*l3mdev_fib_table)(const struct net_device *);
	struct sk_buff * (*l3mdev_l3_rcv)(struct net_device *, struct sk_buff *, u16);
	struct sk_buff * (*l3mdev_l3_out)(struct net_device *, struct sock *, struct sk_buff *, u16);
	struct dst_entry * (*l3mdev_link_scope_lookup)(const struct net_device *, struct flowi6 *);
};

struct prefix_info;

struct nd_opt_hdr;

struct ndisc_options;

struct ndisc_ops {
	int (*is_useropt)(u8);
	int (*parse_options)(const struct net_device *, struct nd_opt_hdr *, struct ndisc_options *);
	void (*update)(const struct net_device *, struct neighbour *, u32, u8, const struct ndisc_options *);
	int (*opt_addr_space)(const struct net_device *, u8, struct neighbour *, u8 *, u8 **);
	void (*fill_addr_option)(const struct net_device *, struct sk_buff *, u8, const u8 *);
	void (*prefix_rcv_add_addr)(struct net___2 *, struct net_device *, const struct prefix_info *, struct inet6_dev *, struct in6_addr *, int, u32, bool, bool, __u32, u32, bool);
};

struct ipv6_devstat {
	struct proc_dir_entry *proc_dir_entry;
	struct ipstats_mib *ipv6;
	struct icmpv6_mib_device *icmpv6dev;
	struct icmpv6msg_mib_device *icmpv6msgdev;
};

struct ifmcaddr6;

struct ifacaddr6;

struct inet6_dev {
	struct net_device *dev;
	struct list_head addr_list;
	struct ifmcaddr6 *mc_list;
	struct ifmcaddr6 *mc_tomb;
	unsigned char mc_qrv;
	unsigned char mc_gq_running;
	unsigned char mc_ifc_count;
	unsigned char mc_dad_count;
	long unsigned int mc_v1_seen;
	long unsigned int mc_qi;
	long unsigned int mc_qri;
	long unsigned int mc_maxdelay;
	struct delayed_work mc_gq_work;
	struct delayed_work mc_ifc_work;
	struct delayed_work mc_dad_work;
	struct delayed_work mc_query_work;
	struct delayed_work mc_report_work;
	struct sk_buff_head mc_query_queue;
	struct sk_buff_head mc_report_queue;
	spinlock_t mc_query_lock;
	spinlock_t mc_report_lock;
	struct mutex mc_lock;
	struct ifacaddr6 *ac_list;
	rwlock_t lock;
	refcount_t refcnt;
	__u32 if_flags;
	int dead;
	u32 desync_factor;
	struct list_head tempaddr_list;
	struct in6_addr token;
	struct neigh_parms *nd_parms;
	struct ipv6_devconf cnf;
	struct ipv6_devstat stats;
	struct timer_list rs_timer;
	__s32 rs_interval;
	__u8 rs_probes;
	long unsigned int tstamp;
	struct callback_head rcu;
	unsigned int ra_mtu;
};

struct tcf_proto;

struct tcf_block;

struct mini_Qdisc {
	struct tcf_proto *filter_list;
	struct tcf_block *block;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	struct callback_head rcu;
};

struct rtnl_link_ops {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	struct net_device * (*alloc)(struct nlattr **, const char *, unsigned char, unsigned int, unsigned int);
	void (*setup)(struct net_device *);
	bool netns_refund;
	unsigned int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*newlink)(struct net___2 *, struct net_device *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*changelink)(struct net_device *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	void (*dellink)(struct net_device *, struct list_head *);
	size_t (*get_size)(const struct net_device *);
	int (*fill_info)(struct sk_buff *, const struct net_device *);
	size_t (*get_xstats_size)(const struct net_device *);
	int (*fill_xstats)(struct sk_buff *, const struct net_device *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	unsigned int slave_maxtype;
	const struct nla_policy *slave_policy;
	int (*slave_changelink)(struct net_device *, struct net_device *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	size_t (*get_slave_size)(const struct net_device *, const struct net_device *);
	int (*fill_slave_info)(struct sk_buff *, const struct net_device *, const struct net_device *);
	struct net___2 * (*get_link_net)(const struct net_device *);
	size_t (*get_linkxstats_size)(const struct net_device *, int);
	int (*fill_linkxstats)(struct sk_buff *, const struct net_device *, int *, int);
};

enum {
	RTAX_UNSPEC = 0,
	RTAX_LOCK = 1,
	RTAX_MTU = 2,
	RTAX_WINDOW = 3,
	RTAX_RTT = 4,
	RTAX_RTTVAR = 5,
	RTAX_SSTHRESH = 6,
	RTAX_CWND = 7,
	RTAX_ADVMSS = 8,
	RTAX_REORDERING = 9,
	RTAX_HOPLIMIT = 10,
	RTAX_INITCWND = 11,
	RTAX_FEATURES = 12,
	RTAX_RTO_MIN = 13,
	RTAX_INITRWND = 14,
	RTAX_QUICKACK = 15,
	RTAX_CC_ALGO = 16,
	RTAX_FASTOPEN_NO_COOKIE = 17,
	__RTAX_MAX = 18,
};

struct tcmsg {
	unsigned char tcm_family;
	unsigned char tcm__pad1;
	short unsigned int tcm__pad2;
	int tcm_ifindex;
	__u32 tcm_handle;
	__u32 tcm_parent;
	__u32 tcm_info;
};

struct gnet_stats_basic_cpu {
	struct gnet_stats_basic_packed bstats;
	struct u64_stats_sync syncp;
};

struct gnet_dump {
	spinlock_t *lock;
	struct sk_buff *skb;
	struct nlattr *tail;
	int compat_tc_stats;
	int compat_xstats;
	int padattr;
	void *xstats;
	int xstats_len;
	struct tc_stats tc_stats;
};

struct netlink_range_validation {
	u64 min;
	u64 max;
};

struct netlink_range_validation_signed {
	s64 min;
	s64 max;
};

enum flow_action_hw_stats_bit {
	FLOW_ACTION_HW_STATS_IMMEDIATE_BIT = 0,
	FLOW_ACTION_HW_STATS_DELAYED_BIT = 1,
	FLOW_ACTION_HW_STATS_DISABLED_BIT = 2,
	FLOW_ACTION_HW_STATS_NUM_BITS = 3,
};

struct flow_block {
	struct list_head cb_list;
};

typedef int flow_setup_cb_t(enum tc_setup_type, void *, void *);

struct qdisc_size_table {
	struct callback_head rcu;
	struct list_head list;
	struct tc_sizespec szopts;
	int refcnt;
	u16 data[0];
};

struct Qdisc_class_ops;

struct Qdisc_ops {
	struct Qdisc_ops *next;
	const struct Qdisc_class_ops *cl_ops;
	char id[16];
	int priv_size;
	unsigned int static_flags;
	int (*enqueue)(struct sk_buff *, struct Qdisc *, struct sk_buff **);
	struct sk_buff * (*dequeue)(struct Qdisc *);
	struct sk_buff * (*peek)(struct Qdisc *);
	int (*init)(struct Qdisc *, struct nlattr *, struct netlink_ext_ack *);
	void (*reset)(struct Qdisc *);
	void (*destroy)(struct Qdisc *);
	int (*change)(struct Qdisc *, struct nlattr *, struct netlink_ext_ack *);
	void (*attach)(struct Qdisc *);
	int (*change_tx_queue_len)(struct Qdisc *, unsigned int);
	void (*change_real_num_tx)(struct Qdisc *, unsigned int);
	int (*dump)(struct Qdisc *, struct sk_buff *);
	int (*dump_stats)(struct Qdisc *, struct gnet_dump *);
	void (*ingress_block_set)(struct Qdisc *, u32);
	void (*egress_block_set)(struct Qdisc *, u32);
	u32 (*ingress_block_get)(struct Qdisc *);
	u32 (*egress_block_get)(struct Qdisc *);
	struct module___4 *owner;
};

struct qdisc_walker;

struct Qdisc_class_ops {
	unsigned int flags;
	struct netdev_queue * (*select_queue)(struct Qdisc *, struct tcmsg *);
	int (*graft)(struct Qdisc *, long unsigned int, struct Qdisc *, struct Qdisc **, struct netlink_ext_ack *);
	struct Qdisc * (*leaf)(struct Qdisc *, long unsigned int);
	void (*qlen_notify)(struct Qdisc *, long unsigned int);
	long unsigned int (*find)(struct Qdisc *, u32);
	int (*change)(struct Qdisc *, u32, u32, struct nlattr **, long unsigned int *, struct netlink_ext_ack *);
	int (*delete)(struct Qdisc *, long unsigned int, struct netlink_ext_ack *);
	void (*walk)(struct Qdisc *, struct qdisc_walker *);
	struct tcf_block * (*tcf_block)(struct Qdisc *, long unsigned int, struct netlink_ext_ack *);
	long unsigned int (*bind_tcf)(struct Qdisc *, long unsigned int, u32);
	void (*unbind_tcf)(struct Qdisc *, long unsigned int);
	int (*dump)(struct Qdisc *, long unsigned int, struct sk_buff *, struct tcmsg *);
	int (*dump_stats)(struct Qdisc *, long unsigned int, struct gnet_dump *);
};

struct tcf_chain;

struct tcf_block {
	struct mutex lock;
	struct list_head chain_list;
	u32 index;
	u32 classid;
	refcount_t refcnt;
	struct net___2 *net;
	struct Qdisc *q;
	struct rw_semaphore cb_lock;
	struct flow_block flow_block;
	struct list_head owner_list;
	bool keep_dst;
	atomic_t offloadcnt;
	unsigned int nooffloaddevcnt;
	unsigned int lockeddevcnt;
	struct {
		struct tcf_chain *chain;
		struct list_head filter_chain_list;
	} chain0;
	struct callback_head rcu;
	struct hlist_head proto_destroy_ht[128];
	struct mutex proto_destroy_lock;
};

struct tcf_result;

struct tcf_proto_ops;

struct tcf_proto {
	struct tcf_proto *next;
	void *root;
	int (*classify)(struct sk_buff *, const struct tcf_proto *, struct tcf_result *);
	__be16 protocol;
	u32 prio;
	void *data;
	const struct tcf_proto_ops *ops;
	struct tcf_chain *chain;
	spinlock_t lock;
	bool deleting;
	refcount_t refcnt;
	struct callback_head rcu;
	struct hlist_node destroy_ht_node;
};

struct tcf_result {
	union {
		struct {
			long unsigned int class;
			u32 classid;
		};
		const struct tcf_proto *goto_tp;
		struct {
			bool ingress;
			struct gnet_stats_queue *qstats;
		};
	};
};

struct tcf_walker;

struct tcf_proto_ops {
	struct list_head head;
	char kind[16];
	int (*classify)(struct sk_buff *, const struct tcf_proto *, struct tcf_result *);
	int (*init)(struct tcf_proto *);
	void (*destroy)(struct tcf_proto *, bool, struct netlink_ext_ack *);
	void * (*get)(struct tcf_proto *, u32);
	void (*put)(struct tcf_proto *, void *);
	int (*change)(struct net___2 *, struct sk_buff *, struct tcf_proto *, long unsigned int, u32, struct nlattr **, void **, u32, struct netlink_ext_ack *);
	int (*delete)(struct tcf_proto *, void *, bool *, bool, struct netlink_ext_ack *);
	bool (*delete_empty)(struct tcf_proto *);
	void (*walk)(struct tcf_proto *, struct tcf_walker *, bool);
	int (*reoffload)(struct tcf_proto *, bool, flow_setup_cb_t *, void *, struct netlink_ext_ack *);
	void (*hw_add)(struct tcf_proto *, void *);
	void (*hw_del)(struct tcf_proto *, void *);
	void (*bind_class)(void *, u32, long unsigned int, void *, long unsigned int);
	void * (*tmplt_create)(struct net___2 *, struct tcf_chain *, struct nlattr **, struct netlink_ext_ack *);
	void (*tmplt_destroy)(void *);
	int (*dump)(struct net___2 *, struct tcf_proto *, void *, struct sk_buff *, struct tcmsg *, bool);
	int (*terse_dump)(struct net___2 *, struct tcf_proto *, void *, struct sk_buff *, struct tcmsg *, bool);
	int (*tmplt_dump)(struct sk_buff *, struct net___2 *, void *);
	struct module___4 *owner;
	int flags;
};

struct tcf_chain {
	struct mutex filter_chain_lock;
	struct tcf_proto *filter_chain;
	struct list_head list;
	struct tcf_block *block;
	u32 index;
	unsigned int refcnt;
	unsigned int action_refcnt;
	bool explicitly_created;
	bool flushing;
	const struct tcf_proto_ops *tmplt_ops;
	void *tmplt_priv;
	struct callback_head rcu;
};

struct sock_fprog_kern {
	u16 len;
	struct sock_filter *filter;
};

struct bpf_prog_stats {
	u64_stats_t cnt;
	u64_stats_t nsecs;
	u64_stats_t misses;
	struct u64_stats_sync syncp;
	long: 64;
};

struct sk_filter {
	refcount_t refcnt;
	struct callback_head rcu;
	struct bpf_prog *prog;
};

enum {
	NEIGH_VAR_MCAST_PROBES = 0,
	NEIGH_VAR_UCAST_PROBES = 1,
	NEIGH_VAR_APP_PROBES = 2,
	NEIGH_VAR_MCAST_REPROBES = 3,
	NEIGH_VAR_RETRANS_TIME = 4,
	NEIGH_VAR_BASE_REACHABLE_TIME = 5,
	NEIGH_VAR_DELAY_PROBE_TIME = 6,
	NEIGH_VAR_GC_STALETIME = 7,
	NEIGH_VAR_QUEUE_LEN_BYTES = 8,
	NEIGH_VAR_PROXY_QLEN = 9,
	NEIGH_VAR_ANYCAST_DELAY = 10,
	NEIGH_VAR_PROXY_DELAY = 11,
	NEIGH_VAR_LOCKTIME = 12,
	NEIGH_VAR_QUEUE_LEN = 13,
	NEIGH_VAR_RETRANS_TIME_MS = 14,
	NEIGH_VAR_BASE_REACHABLE_TIME_MS = 15,
	NEIGH_VAR_GC_INTERVAL = 16,
	NEIGH_VAR_GC_THRESH1 = 17,
	NEIGH_VAR_GC_THRESH2 = 18,
	NEIGH_VAR_GC_THRESH3 = 19,
	NEIGH_VAR_MAX = 20,
};

struct pneigh_entry;

struct neigh_statistics;

struct neigh_hash_table;

struct neigh_table {
	int family;
	unsigned int entry_size;
	unsigned int key_len;
	__be16 protocol;
	__u32 (*hash)(const void *, const struct net_device *, __u32 *);
	bool (*key_eq)(const struct neighbour *, const void *);
	int (*constructor)(struct neighbour *);
	int (*pconstructor)(struct pneigh_entry *);
	void (*pdestructor)(struct pneigh_entry *);
	void (*proxy_redo)(struct sk_buff *);
	int (*is_multicast)(const void *);
	bool (*allow_add)(const struct net_device *, struct netlink_ext_ack *);
	char *id;
	struct neigh_parms parms;
	struct list_head parms_list;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head proxy_queue;
	atomic_t entries;
	atomic_t gc_entries;
	struct list_head gc_list;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table *nht;
	struct pneigh_entry **phash_buckets;
};

struct neigh_statistics {
	long unsigned int allocs;
	long unsigned int destroys;
	long unsigned int hash_grows;
	long unsigned int res_failed;
	long unsigned int lookups;
	long unsigned int hits;
	long unsigned int rcv_probes_mcast;
	long unsigned int rcv_probes_ucast;
	long unsigned int periodic_gc_runs;
	long unsigned int forced_gc_runs;
	long unsigned int unres_discards;
	long unsigned int table_fulls;
};

struct neigh_ops {
	int family;
	void (*solicit)(struct neighbour *, struct sk_buff *);
	void (*error_report)(struct neighbour *, struct sk_buff *);
	int (*output)(struct neighbour *, struct sk_buff *);
	int (*connected_output)(struct neighbour *, struct sk_buff *);
};

struct pneigh_entry {
	struct pneigh_entry *next;
	possible_net_t net;
	struct net_device *dev;
	u8 flags;
	u8 protocol;
	u8 key[0];
};

struct neigh_hash_table {
	struct neighbour **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

enum {
	TCP_ESTABLISHED = 1,
	TCP_SYN_SENT = 2,
	TCP_SYN_RECV = 3,
	TCP_FIN_WAIT1 = 4,
	TCP_FIN_WAIT2 = 5,
	TCP_TIME_WAIT = 6,
	TCP_CLOSE = 7,
	TCP_CLOSE_WAIT = 8,
	TCP_LAST_ACK = 9,
	TCP_LISTEN = 10,
	TCP_CLOSING = 11,
	TCP_NEW_SYN_RECV = 12,
	TCP_MAX_STATES = 13,
};

struct fib_rule_hdr {
	__u8 family;
	__u8 dst_len;
	__u8 src_len;
	__u8 tos;
	__u8 table;
	__u8 res1;
	__u8 res2;
	__u8 action;
	__u32 flags;
};

struct fib_rule_port_range {
	__u16 start;
	__u16 end;
};

struct fib_kuid_range {
	kuid_t start;
	kuid_t end;
};

struct fib_rule {
	struct list_head list;
	int iifindex;
	int oifindex;
	u32 mark;
	u32 mark_mask;
	u32 flags;
	u32 table;
	u8 action;
	u8 l3mdev;
	u8 proto;
	u8 ip_proto;
	u32 target;
	__be64 tun_id;
	struct fib_rule *ctarget;
	struct net___2 *fr_net;
	refcount_t refcnt;
	u32 pref;
	int suppress_ifgroup;
	int suppress_prefixlen;
	char iifname[16];
	char oifname[16];
	struct fib_kuid_range uid_range;
	struct fib_rule_port_range sport_range;
	struct fib_rule_port_range dport_range;
	struct callback_head rcu;
};

struct fib_lookup_arg {
	void *lookup_ptr;
	const void *lookup_data;
	void *result;
	struct fib_rule *rule;
	u32 table;
	int flags;
};

struct sk_psock;

struct udp_table;

struct raw_hashinfo;

struct smc_hashinfo;

struct request_sock_ops;

struct timewait_sock_ops;

struct proto {
	void (*close)(struct sock *, long int);
	int (*pre_connect)(struct sock *, struct sockaddr *, int);
	int (*connect)(struct sock *, struct sockaddr *, int);
	int (*disconnect)(struct sock *, int);
	struct sock * (*accept)(struct sock *, int, int *, bool);
	int (*ioctl)(struct sock *, int, long unsigned int);
	int (*init)(struct sock *);
	void (*destroy)(struct sock *);
	void (*shutdown)(struct sock *, int);
	int (*setsockopt)(struct sock *, int, int, sockptr_t, unsigned int);
	int (*getsockopt)(struct sock *, int, int, char *, int *);
	void (*keepalive)(struct sock *, int);
	int (*compat_ioctl)(struct sock *, unsigned int, long unsigned int);
	int (*sendmsg)(struct sock *, struct msghdr *, size_t);
	int (*recvmsg)(struct sock *, struct msghdr *, size_t, int, int, int *);
	int (*sendpage)(struct sock *, struct page___4 *, int, size_t, int);
	int (*bind)(struct sock *, struct sockaddr *, int);
	int (*bind_add)(struct sock *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock *, struct sk_buff *);
	bool (*bpf_bypass_getsockopt)(int, int);
	void (*release_cb)(struct sock *);
	int (*hash)(struct sock *);
	void (*unhash)(struct sock *);
	void (*rehash)(struct sock *);
	int (*get_port)(struct sock *, short unsigned int);
	int (*psock_update_sk_prot)(struct sock *, struct sk_psock *, bool);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock *, int);
	bool (*sock_is_readable)(struct sock *);
	void (*enter_memory_pressure)(struct sock *);
	void (*leave_memory_pressure)(struct sock *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	long unsigned int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	u32 sysctl_wmem_offset;
	u32 sysctl_rmem_offset;
	int max_header;
	bool no_autobind;
	struct kmem_cache *slab;
	unsigned int obj_size;
	slab_flags_t slab_flags;
	unsigned int useroffset;
	unsigned int usersize;
	unsigned int *orphan_count;
	struct request_sock_ops *rsk_prot;
	struct timewait_sock_ops *twsk_prot;
	union {
		struct inet_hashinfo *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
		struct smc_hashinfo *smc_hash;
	} h;
	struct module___4 *owner;
	char name[32];
	struct list_head node;
	int (*diag_destroy)(struct sock *, int);
};

struct request_sock;

struct request_sock_ops {
	int family;
	unsigned int obj_size;
	struct kmem_cache *slab;
	char *slab_name;
	int (*rtx_syn_ack)(const struct sock *, struct request_sock *);
	void (*send_ack)(const struct sock *, struct sk_buff *, struct request_sock *);
	void (*send_reset)(const struct sock *, struct sk_buff *);
	void (*destructor)(struct request_sock *);
	void (*syn_ack_timeout)(const struct request_sock *);
};

struct timewait_sock_ops {
	struct kmem_cache *twsk_slab;
	char *twsk_slab_name;
	unsigned int twsk_obj_size;
	int (*twsk_unique)(struct sock *, struct sock *, void *);
	void (*twsk_destructor)(struct sock *);
};

struct saved_syn;

struct request_sock {
	struct sock_common __req_common;
	struct request_sock *dl_next;
	u16 mss;
	u8 num_retrans;
	u8 syncookie: 1;
	u8 num_timeout: 7;
	long: 25;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u32 ts_recent;
	struct timer_list rsk_timer;
	const struct request_sock_ops *rsk_ops;
	struct sock *sk;
	struct saved_syn *saved_syn;
	u32 secid;
	u32 peer_secid;
};

struct saved_syn {
	u32 mac_hdrlen;
	u32 network_hdrlen;
	u32 tcp_hdrlen;
	u8 data[0];
};

enum tsq_enum {
	TSQ_THROTTLED = 0,
	TSQ_QUEUED = 1,
	TCP_TSQ_DEFERRED = 2,
	TCP_WRITE_TIMER_DEFERRED = 3,
	TCP_DELACK_TIMER_DEFERRED = 4,
	TCP_MTU_REDUCED_DEFERRED = 5,
};

struct ip6_sf_list {
	struct ip6_sf_list *sf_next;
	struct in6_addr sf_addr;
	long unsigned int sf_count[2];
	unsigned char sf_gsresp;
	unsigned char sf_oldin;
	unsigned char sf_crcount;
	struct callback_head rcu;
};

struct ifmcaddr6 {
	struct in6_addr mca_addr;
	struct inet6_dev *idev;
	struct ifmcaddr6 *next;
	struct ip6_sf_list *mca_sources;
	struct ip6_sf_list *mca_tomb;
	unsigned int mca_sfmode;
	unsigned char mca_crcount;
	long unsigned int mca_sfcount[2];
	struct delayed_work mca_work;
	unsigned int mca_flags;
	int mca_users;
	refcount_t mca_refcnt;
	long unsigned int mca_cstamp;
	long unsigned int mca_tstamp;
	struct callback_head rcu;
};

struct ifacaddr6 {
	struct in6_addr aca_addr;
	struct fib6_info *aca_rt;
	struct ifacaddr6 *aca_next;
	struct hlist_node aca_addr_lst;
	int aca_users;
	refcount_t aca_refcnt;
	long unsigned int aca_cstamp;
	long unsigned int aca_tstamp;
	struct callback_head rcu;
};

enum {
	__ND_OPT_PREFIX_INFO_END = 0,
	ND_OPT_SOURCE_LL_ADDR = 1,
	ND_OPT_TARGET_LL_ADDR = 2,
	ND_OPT_PREFIX_INFO = 3,
	ND_OPT_REDIRECT_HDR = 4,
	ND_OPT_MTU = 5,
	ND_OPT_NONCE = 14,
	__ND_OPT_ARRAY_MAX = 15,
	ND_OPT_ROUTE_INFO = 24,
	ND_OPT_RDNSS = 25,
	ND_OPT_DNSSL = 31,
	ND_OPT_6CO = 34,
	ND_OPT_CAPTIVE_PORTAL = 37,
	ND_OPT_PREF64 = 38,
	__ND_OPT_MAX = 39,
};

struct nd_opt_hdr {
	__u8 nd_opt_type;
	__u8 nd_opt_len;
};

struct ndisc_options {
	struct nd_opt_hdr *nd_opt_array[15];
	struct nd_opt_hdr *nd_opts_ri;
	struct nd_opt_hdr *nd_opts_ri_end;
	struct nd_opt_hdr *nd_useropts;
	struct nd_opt_hdr *nd_useropts_end;
	struct nd_opt_hdr *nd_802154_opt_array[3];
};

enum nfs_opnum4 {
	OP_ACCESS = 3,
	OP_CLOSE = 4,
	OP_COMMIT = 5,
	OP_CREATE = 6,
	OP_DELEGPURGE = 7,
	OP_DELEGRETURN = 8,
	OP_GETATTR = 9,
	OP_GETFH = 10,
	OP_LINK = 11,
	OP_LOCK = 12,
	OP_LOCKT = 13,
	OP_LOCKU = 14,
	OP_LOOKUP = 15,
	OP_LOOKUPP = 16,
	OP_NVERIFY = 17,
	OP_OPEN = 18,
	OP_OPENATTR = 19,
	OP_OPEN_CONFIRM = 20,
	OP_OPEN_DOWNGRADE = 21,
	OP_PUTFH = 22,
	OP_PUTPUBFH = 23,
	OP_PUTROOTFH = 24,
	OP_READ = 25,
	OP_READDIR = 26,
	OP_READLINK = 27,
	OP_REMOVE = 28,
	OP_RENAME = 29,
	OP_RENEW = 30,
	OP_RESTOREFH = 31,
	OP_SAVEFH = 32,
	OP_SECINFO = 33,
	OP_SETATTR = 34,
	OP_SETCLIENTID = 35,
	OP_SETCLIENTID_CONFIRM = 36,
	OP_VERIFY = 37,
	OP_WRITE = 38,
	OP_RELEASE_LOCKOWNER = 39,
	OP_BACKCHANNEL_CTL = 40,
	OP_BIND_CONN_TO_SESSION = 41,
	OP_EXCHANGE_ID = 42,
	OP_CREATE_SESSION = 43,
	OP_DESTROY_SESSION = 44,
	OP_FREE_STATEID = 45,
	OP_GET_DIR_DELEGATION = 46,
	OP_GETDEVICEINFO = 47,
	OP_GETDEVICELIST = 48,
	OP_LAYOUTCOMMIT = 49,
	OP_LAYOUTGET = 50,
	OP_LAYOUTRETURN = 51,
	OP_SECINFO_NO_NAME = 52,
	OP_SEQUENCE = 53,
	OP_SET_SSV = 54,
	OP_TEST_STATEID = 55,
	OP_WANT_DELEGATION = 56,
	OP_DESTROY_CLIENTID = 57,
	OP_RECLAIM_COMPLETE = 58,
	OP_ALLOCATE = 59,
	OP_COPY = 60,
	OP_COPY_NOTIFY = 61,
	OP_DEALLOCATE = 62,
	OP_IO_ADVISE = 63,
	OP_LAYOUTERROR = 64,
	OP_LAYOUTSTATS = 65,
	OP_OFFLOAD_CANCEL = 66,
	OP_OFFLOAD_STATUS = 67,
	OP_READ_PLUS = 68,
	OP_SEEK = 69,
	OP_WRITE_SAME = 70,
	OP_CLONE = 71,
	OP_GETXATTR = 72,
	OP_SETXATTR = 73,
	OP_LISTXATTRS = 74,
	OP_REMOVEXATTR = 75,
	OP_ILLEGAL = 10044,
};

enum perf_branch_sample_type_shift {
	PERF_SAMPLE_BRANCH_USER_SHIFT = 0,
	PERF_SAMPLE_BRANCH_KERNEL_SHIFT = 1,
	PERF_SAMPLE_BRANCH_HV_SHIFT = 2,
	PERF_SAMPLE_BRANCH_ANY_SHIFT = 3,
	PERF_SAMPLE_BRANCH_ANY_CALL_SHIFT = 4,
	PERF_SAMPLE_BRANCH_ANY_RETURN_SHIFT = 5,
	PERF_SAMPLE_BRANCH_IND_CALL_SHIFT = 6,
	PERF_SAMPLE_BRANCH_ABORT_TX_SHIFT = 7,
	PERF_SAMPLE_BRANCH_IN_TX_SHIFT = 8,
	PERF_SAMPLE_BRANCH_NO_TX_SHIFT = 9,
	PERF_SAMPLE_BRANCH_COND_SHIFT = 10,
	PERF_SAMPLE_BRANCH_CALL_STACK_SHIFT = 11,
	PERF_SAMPLE_BRANCH_IND_JUMP_SHIFT = 12,
	PERF_SAMPLE_BRANCH_CALL_SHIFT = 13,
	PERF_SAMPLE_BRANCH_NO_FLAGS_SHIFT = 14,
	PERF_SAMPLE_BRANCH_NO_CYCLES_SHIFT = 15,
	PERF_SAMPLE_BRANCH_TYPE_SAVE_SHIFT = 16,
	PERF_SAMPLE_BRANCH_HW_INDEX_SHIFT = 17,
	PERF_SAMPLE_BRANCH_MAX_SHIFT = 18,
};

union perf_mem_data_src___2 {
	__u64 val;
	struct {
		__u64 mem_op: 5;
		__u64 mem_lvl: 14;
		__u64 mem_snoop: 5;
		__u64 mem_lock: 2;
		__u64 mem_dtlb: 7;
		__u64 mem_lvl_num: 4;
		__u64 mem_remote: 1;
		__u64 mem_snoopx: 2;
		__u64 mem_blk: 3;
		__u64 mem_rsvd: 21;
	};
};

union perf_sample_weight___2 {
	__u64 full;
	struct {
		__u32 var1_dw;
		__u16 var2_w;
		__u16 var3_w;
	};
};

enum exception_stack_ordering {
	ESTACK_DF = 0,
	ESTACK_NMI = 1,
	ESTACK_DB = 2,
	ESTACK_MCE = 3,
	ESTACK_VC = 4,
	ESTACK_VC2 = 5,
	N_EXCEPTION_STACKS = 6,
};

struct perf_cpu_context___2;

struct perf_output_handle___2;

struct pmu___2 {
	struct list_head entry;
	struct module___4 *module;
	struct device___4 *dev;
	const struct attribute_group___2 **attr_groups;
	const struct attribute_group___2 **attr_update;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___2 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___2 *);
	void (*pmu_disable)(struct pmu___2 *);
	int (*event_init)(struct perf_event___2 *);
	void (*event_mapped)(struct perf_event___2 *, struct mm_struct___5 *);
	void (*event_unmapped)(struct perf_event___2 *, struct mm_struct___5 *);
	int (*add)(struct perf_event___2 *, int);
	void (*del)(struct perf_event___2 *, int);
	void (*start)(struct perf_event___2 *, int);
	void (*stop)(struct perf_event___2 *, int);
	void (*read)(struct perf_event___2 *);
	void (*start_txn)(struct pmu___2 *, unsigned int);
	int (*commit_txn)(struct pmu___2 *);
	void (*cancel_txn)(struct pmu___2 *);
	int (*event_idx)(struct perf_event___2 *);
	void (*sched_task)(struct perf_event_context___3 *, bool);
	struct kmem_cache *task_ctx_cache;
	void (*swap_task_ctx)(struct perf_event_context___3 *, struct perf_event_context___3 *);
	void * (*setup_aux)(struct perf_event___2 *, void **, int, bool);
	void (*free_aux)(void *);
	long int (*snapshot_aux)(struct perf_event___2 *, struct perf_output_handle___2 *, long unsigned int);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___2 *);
	int (*aux_output_match)(struct perf_event___2 *);
	int (*filter_match)(struct perf_event___2 *);
	int (*check_period)(struct perf_event___2 *, u64);
};

enum {
	TSK_TRACE_FL_TRACE_BIT = 0,
	TSK_TRACE_FL_GRAPH_BIT = 1,
};

struct perf_cpu_context___2 {
	struct perf_event_context___3 ctx;
	struct perf_event_context___3 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___2 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
	int heap_size;
	struct perf_event___2 **heap;
	struct perf_event___2 *heap_default[2];
};

struct perf_output_handle___2 {
	struct perf_event___2 *event;
	struct perf_buffer *rb;
	long unsigned int wakeup;
	long unsigned int size;
	u64 aux_flags;
	union {
		void *addr;
		long unsigned int head;
	};
	int page;
};

struct perf_sample_data___2 {
	u64 addr;
	struct perf_raw_record *raw;
	struct perf_branch_stack *br_stack;
	u64 period;
	union perf_sample_weight___2 weight;
	long: 64;
	u64 txn;
	union perf_mem_data_src___2 data_src;
	long: 64;
	u64 type;
	u64 ip;
	struct {
		u32 pid;
		u32 tid;
	} tid_entry;
	u64 time;
	u64 id;
	u64 stream_id;
	struct {
		u32 cpu;
		u32 reserved;
	} cpu_entry;
	struct perf_callchain_entry *callchain;
	u64 aux_size;
	struct perf_regs regs_user;
	struct perf_regs regs_intr;
	u64 stack_user_size;
	u64 phys_addr;
	u64 cgroup;
	u64 data_page_size;
	u64 code_page_size;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct perf_cgroup___2 {
	struct cgroup_subsys_state___2 css;
	struct perf_cgroup_info *info;
};

struct trace_event_fields___2 {
	const char *type;
	union {
		struct {
			const char *name;
			const int size;
			const int align;
			const int is_signed;
			const int filter_type;
		};
		int (*define_fields)(struct trace_event_call___2 *);
	};
};

struct trace_event_class___2 {
	const char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct trace_event_call___2 *, enum trace_reg, void *);
	struct trace_event_fields___2 *fields_array;
	struct list_head * (*get_fields)(struct trace_event_call___2 *);
	struct list_head fields;
	int (*raw_init)(struct trace_event_call___2 *);
};

struct uuidcmp {
	const char *uuid;
	int len;
};

struct dentry___4;

struct super_block___4;

struct module___5;

struct file_system_type___4 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___4 * (*mount)(struct file_system_type___4 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___4 *);
	struct module___5 *owner;
	struct file_system_type___4 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___4;

struct kiocb___4;

struct iov_iter___4;

struct poll_table_struct___4;

struct vm_area_struct___5;

struct inode___4;

struct file_lock___4;

struct page___5;

struct file_operations___4 {
	struct module___5 *owner;
	loff_t (*llseek)(struct file___4 *, loff_t, int);
	ssize_t (*read)(struct file___4 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___4 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___4 *, struct iov_iter___4 *);
	ssize_t (*write_iter)(struct kiocb___4 *, struct iov_iter___4 *);
	int (*iopoll)(struct kiocb___4 *, bool);
	int (*iterate)(struct file___4 *, struct dir_context *);
	int (*iterate_shared)(struct file___4 *, struct dir_context *);
	__poll_t (*poll)(struct file___4 *, struct poll_table_struct___4 *);
	long int (*unlocked_ioctl)(struct file___4 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___4 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___4 *, struct vm_area_struct___5 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___4 *, struct file___4 *);
	int (*flush)(struct file___4 *, fl_owner_t);
	int (*release)(struct inode___4 *, struct file___4 *);
	int (*fsync)(struct file___4 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___4 *, int);
	int (*lock)(struct file___4 *, int, struct file_lock___4 *);
	ssize_t (*sendpage)(struct file___4 *, struct page___5 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___4 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___4 *, long unsigned int);
	int (*flock)(struct file___4 *, int, struct file_lock___4 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___4 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___4 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___4 *, long int, struct file_lock___4 **, void **);
	long int (*fallocate)(struct file___4 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file *, struct file___4 *);
	ssize_t (*copy_file_range)(struct file___4 *, loff_t, struct file___4 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___4 *, loff_t, struct file___4 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___4 *, loff_t, loff_t, int);
};

struct static_call_mod___3 {
	struct static_call_mod___3 *next;
	struct module___5 *mod;
	struct static_call_site *sites;
};

struct static_call_key___3 {
	void *func;
	union {
		long unsigned int type;
		struct static_call_mod___3 *mods;
		struct static_call_site *sites;
	};
};

struct vmacache___4 {
	u64 seqnum;
	struct vm_area_struct___5 *vmas[4];
};

struct page_frag___4 {
	struct page___5 *page;
	__u32 offset;
	__u32 size;
};

struct perf_event___3;

struct thread_struct___3 {
	struct desc_struct tls_array[3];
	long unsigned int sp;
	short unsigned int es;
	short unsigned int ds;
	short unsigned int fsindex;
	short unsigned int gsindex;
	long unsigned int fsbase;
	long unsigned int gsbase;
	struct perf_event___3 *ptrace_bps[4];
	long unsigned int virtual_dr6;
	long unsigned int ptrace_dr7;
	long unsigned int cr2;
	long unsigned int trap_nr;
	long unsigned int error_code;
	struct io_bitmap *io_bitmap;
	long unsigned int iopl_emul;
	unsigned int iopl_warn: 1;
	unsigned int sig_on_uaccess_err: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u32 pkru;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct fpu fpu;
};

struct mm_struct___6;

struct pid___3;

struct nsproxy___5;

struct signal_struct___5;

struct bio_list___3;

struct io_context___4;

struct css_set___4;

struct perf_event_context___4;

struct request_queue___3;

struct vm_struct___5;

struct task_struct___6 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___6 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___6 *mm;
	struct mm_struct___6 *active_mm;
	struct vmacache___4 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int restore_sigmask: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___6 *real_parent;
	struct task_struct___6 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___6 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___3 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	struct posix_cputimers_work posix_cputimers_work;
	const struct cred *ptracer_cred;
	const struct cred *real_cred;
	const struct cred *cred;
	struct key *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___5 *nsproxy;
	struct signal_struct___5 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___6 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___3 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context___4 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___4 *cgroups;
	struct list_head cg_list;
	u32 closid;
	u32 rmid;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___4 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	long: 64;
	long: 64;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___4 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup *active_memcg;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___6 *oom_reaper_list;
	struct vm_struct___5 *stack_vm_area;
	refcount_t stack_refcount;
	int patch_state;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	void *mce_vaddr;
	__u64 mce_kflags;
	u64 mce_addr;
	__u64 mce_ripv: 1;
	__u64 mce_whole_page: 1;
	__u64 __mce_reserved: 62;
	long: 2;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct callback_head mce_kill_me;
	int mce_count;
	struct llist_head kretprobe_instances;
	struct callback_head l1d_flush_kill;
	long: 64;
	struct thread_struct___3 thread;
};

typedef struct page___5 *pgtable_t___4;

struct address_space___4;

struct dev_pagemap___4;

struct page___5 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___4 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___5 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___4 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___6 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___4 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct core_state___4;

struct mm_struct___6 {
	struct {
		struct vm_area_struct___5 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___4 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int mmap_compat_base;
		long unsigned int mmap_compat_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[48];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___4 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___6 *owner;
		struct user_namespace *user_ns;
		struct file___4 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		bool tlb_flush_batched;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct vm_operations_struct___4;

struct vm_area_struct___5 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___5 *vm_next;
	struct vm_area_struct___5 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___6 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___4 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___4 *vm_file;
	struct file___4 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct tracepoint___3 {
	const char *name;
	struct static_key key;
	struct static_call_key___3 *static_call_key;
	void *static_call_tramp;
	void *iterator;
	int (*regfunc)();
	void (*unregfunc)();
	struct tracepoint_func *funcs;
};

struct bpf_raw_event_map___3 {
	struct tracepoint___3 *tp;
	void *bpf_func;
	u32 num_args;
	u32 writable_size;
	long: 64;
};

struct seq_operations___3 {
	void * (*start)(struct seq_file *, loff_t *);
	void (*stop)(struct seq_file *, void *);
	void * (*next)(struct seq_file *, void *, loff_t *);
	int (*show)(struct seq_file *, void *);
};

struct hw_perf_event___3 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___6 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	union {
		struct {
			u64 last_period;
			local64_t period_left;
		};
		struct {
			u64 saved_metric;
			u64 saved_slots;
		};
	};
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___3)(struct perf_event___3 *, struct perf_sample_data *, struct pt_regs *);

struct pmu___3;

struct fasync_struct___4;

struct pid_namespace___3;

struct trace_event_call___3;

struct perf_cgroup___3;

struct perf_event___3 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___3 *group_leader;
	struct pmu___3 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___3 hw;
	struct perf_event_context___4 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___3 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___6 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct perf_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___4 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	long unsigned int pending_addr;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	struct perf_addr_filter_range *addr_filter_ranges;
	long unsigned int addr_filters_gen;
	struct perf_event___3 *aux_event;
	void (*destroy)(struct perf_event___3 *);
	struct callback_head callback_head;
	struct pid_namespace___3 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___3 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___3 orig_overflow_handler;
	struct bpf_prog *prog;
	u64 bpf_cookie;
	struct trace_event_call___3 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___3 *cgrp;
	void *security;
	struct list_head sb_list;
};

struct dentry_operations___4;

struct dentry___4 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___4 *d_parent;
	struct qstr d_name;
	struct inode___4 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___4 *d_op;
	struct super_block___4 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct address_space_operations___4;

struct address_space___4 {
	struct inode___4 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___4 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct inode_operations___4;

struct inode___4 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___4 *i_op;
	struct super_block___4 *i_sb;
	struct address_space___4 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	long: 64;
	long: 64;
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___4 *i_fop;
		void (*free_inode)(struct inode___4 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___4 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct cdev___2 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct vfsmount___4;

struct path___4;

struct dentry_operations___4 {
	int (*d_revalidate)(struct dentry___4 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___4 *, unsigned int);
	int (*d_hash)(const struct dentry___4 *, struct qstr *);
	int (*d_compare)(const struct dentry___4 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___4 *);
	int (*d_init)(struct dentry___4 *);
	void (*d_release)(struct dentry___4 *);
	void (*d_prune)(struct dentry___4 *);
	void (*d_iput)(struct dentry___4 *, struct inode___4 *);
	char * (*d_dname)(struct dentry___4 *, char *, int);
	struct vfsmount___4 * (*d_automount)(struct path___4 *);
	int (*d_manage)(const struct path___4 *, bool);
	struct dentry___4 * (*d_real)(struct dentry___4 *, const struct inode___4 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___4;

struct mem_dqinfo___4 {
	struct quota_format_type___4 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___4;

struct quota_info___4 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___4 *files[3];
	struct mem_dqinfo___4 info[3];
	const struct quota_format_ops___4 *ops[3];
};

struct rcuwait___4 {
	struct task_struct___6 *task;
};

struct percpu_rw_semaphore___4 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___4 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___4 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___4 rw_sem[3];
};

struct super_operations___4;

struct dquot_operations___4;

struct quotactl_ops___4;

struct block_device___3;

struct super_block___4 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___4 *s_type;
	const struct super_operations___4 *s_op;
	const struct dquot_operations___4 *dq_op;
	const struct quotactl_ops___4 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___4 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___3 *s_bdev;
	struct backing_dev_info *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___4 s_dquot;
	struct sb_writers___4 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___4 *s_d_op;
	int cleancache_poolid;
	struct shrinker___2 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___4 {
	struct dentry___4 *mnt_root;
	struct super_block___4 *mnt_sb;
	int mnt_flags;
	struct user_namespace *mnt_userns;
};

struct path___4 {
	struct vfsmount___4 *mnt;
	struct dentry___4 *dentry;
};

struct dev_pagemap_ops___4;

struct dev_pagemap___4 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___4 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct fown_struct___3 {
	rwlock_t lock;
	struct pid___3 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___4 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	long: 64;
	long: 64;
	struct path___4 f_path;
	struct inode___4 *f_inode;
	const struct file_operations___4 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___3 f_owner;
	const struct cred *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___4 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___4;

struct vm_operations_struct___4 {
	void (*open)(struct vm_area_struct___5 *);
	void (*close)(struct vm_area_struct___5 *);
	int (*may_split)(struct vm_area_struct___5 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___5 *);
	int (*mprotect)(struct vm_area_struct___5 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___4 *);
	vm_fault_t (*huge_fault)(struct vm_fault___4 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___4 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___5 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___4 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___4 *);
	int (*access)(struct vm_area_struct___5 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___5 *);
	int (*set_policy)(struct vm_area_struct___5 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___5 *, long unsigned int);
	struct page___5 * (*find_special_page)(struct vm_area_struct___5 *, long unsigned int);
};

struct core_thread___4 {
	struct task_struct___6 *task;
	struct core_thread___4 *next;
};

struct core_state___4 {
	atomic_t nr_threads;
	struct core_thread___4 dumper;
	struct completion startup;
};

struct vm_fault___4 {
	const struct {
		struct vm_area_struct___5 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___5 *cow_page;
	struct page___5 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___4 prealloc_pte;
};

struct upid___3 {
	int nr;
	struct pid_namespace___3 *ns;
};

struct pid_namespace___3 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___6 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___3 *parent;
	struct fs_pin *bacct;
	struct user_namespace *user_ns;
	struct ucounts *ucounts;
	int reboot;
	struct ns_common ns;
};

struct pid___3 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___3 numbers[1];
};

struct signal_struct___5 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___6 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___6 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper;
	unsigned int has_child_subreaper;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___3 *pids[4];
	struct pid___3 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___6 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct nsproxy___5 {
	atomic_t count;
	struct uts_namespace *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___3 *pid_ns_for_children;
	struct net *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___2 *cgroup_ns;
};

struct bio___3;

struct bio_list___3 {
	struct bio___3 *head;
	struct bio___3 *tail;
};

struct io_cq___3;

struct io_context___4 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	struct xarray icq_tree;
	struct io_cq___3 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct cgroup_subsys_state___3;

struct cgroup___3;

struct css_set___4 {
	struct cgroup_subsys_state___3 *subsys[14];
	refcount_t refcount;
	struct css_set___4 *dom_cset;
	struct cgroup___3 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___3 *mg_src_cgrp;
	struct cgroup___3 *mg_dst_cgrp;
	struct css_set___4 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___4 {
	struct pmu___3 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	int rotate_necessary;
	refcount_t refcount;
	struct task_struct___6 *task;
	u64 time;
	u64 timestamp;
	u64 timeoffset;
	struct perf_event_context___4 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

struct kset___3;

struct kobj_type___3;

struct kernfs_node___3;

struct kobject___3 {
	const char *name;
	struct list_head entry;
	struct kobject___3 *parent;
	struct kset___3 *kset;
	struct kobj_type___3 *ktype;
	struct kernfs_node___3 *sd;
	struct kref kref;
	unsigned int state_initialized;
	unsigned int state_in_sysfs;
	unsigned int state_add_uevent_sent;
	unsigned int state_remove_uevent_sent;
	unsigned int uevent_suppress;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct blk_integrity_profile___3;

struct blk_integrity___3 {
	const struct blk_integrity_profile___3 *profile;
	unsigned char flags;
	unsigned char tuple_size;
	unsigned char interval_exp;
	unsigned char tag_size;
};

struct bio_set___3 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	struct bio_alloc_cache *cache;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	unsigned int back_pad;
	spinlock_t rescue_lock;
	struct bio_list___3 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	struct hlist_node cpuhp_dead;
};

struct request___3;

struct elevator_queue___3;

struct gendisk___3;

struct device___5;

struct blkcg_gq___3;

struct request_queue___3 {
	struct request___3 *last_merge;
	struct elevator_queue___3 *elevator;
	struct percpu_ref q_usage_counter;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	const struct blk_mq_ops *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx **queue_hw_ctx;
	unsigned int nr_hw_queues;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	spinlock_t queue_lock;
	struct gendisk___3 *disk;
	struct kobject___3 kobj;
	struct kobject___3 *mq_kobj;
	struct blk_integrity___3 integrity;
	struct device___5 *dev;
	enum rpm_status rpm_status;
	long unsigned int nr_requests;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_keyslot_manager *ksm;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	atomic_t nr_active_requests_shared_sbitmap;
	struct sbitmap_queue sched_bitmap_tags;
	struct sbitmap_queue sched_breserved_tags;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___3 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int required_elevator_features;
	unsigned int nr_zones;
	long unsigned int *conv_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int max_open_zones;
	unsigned int max_active_zones;
	int node;
	struct mutex debugfs_mutex;
	struct blk_trace *blk_trace;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	struct mutex sysfs_dir_lock;
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	int mq_freeze_depth;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct mutex mq_freeze_lock;
	struct blk_mq_tag_set *tag_set;
	struct list_head tag_set_list;
	struct bio_set___3 bio_split;
	struct dentry___4 *debugfs_dir;
	struct dentry___4 *sched_debugfs_dir;
	struct dentry___4 *rqos_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	u64 write_hints[5];
};

struct vm_struct___5 {
	struct vm_struct___5 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___5 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct cgroup_subsys___3;

struct cgroup_subsys_state___3 {
	struct cgroup___3 *cgroup;
	struct cgroup_subsys___3 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___3 *parent;
};

struct cgroup_file___3 {
	struct kernfs_node___3 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct psi_group___3 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___6 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___3;

struct cgroup_rstat_cpu___3;

struct cgroup___3 {
	struct cgroup_subsys_state___3 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___3 *kn;
	struct cgroup_file___3 procs_file;
	struct cgroup_file___3 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___3 *subsys[14];
	struct cgroup_root___3 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___3 *dom_cgrp;
	struct cgroup___3 *old_dom_cgrp;
	struct cgroup_rstat_cpu___3 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___3 psi;
	struct cgroup_bpf bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct io_cq___3 {
	struct request_queue___3 *q;
	struct io_context___4 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct kiocb___4 {
	struct file___4 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___4 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___2 *ki_waitq;
	};
};

struct iattr___4 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___4 *ia_file;
};

struct dquot___4 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___4 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___4 {
	int qf_fmt_id;
	const struct quota_format_ops___4 *qf_ops;
	struct module___5 *qf_owner;
	struct quota_format_type___4 *qf_next;
};

struct quota_format_ops___4 {
	int (*check_quota_file)(struct super_block___4 *, int);
	int (*read_file_info)(struct super_block___4 *, int);
	int (*write_file_info)(struct super_block___4 *, int);
	int (*free_file_info)(struct super_block___4 *, int);
	int (*read_dqblk)(struct dquot___4 *);
	int (*commit_dqblk)(struct dquot___4 *);
	int (*release_dqblk)(struct dquot___4 *);
	int (*get_next_id)(struct super_block___4 *, struct kqid *);
};

struct dquot_operations___4 {
	int (*write_dquot)(struct dquot___4 *);
	struct dquot___4 * (*alloc_dquot)(struct super_block___4 *, int);
	void (*destroy_dquot)(struct dquot___4 *);
	int (*acquire_dquot)(struct dquot___4 *);
	int (*release_dquot)(struct dquot___4 *);
	int (*mark_dirty)(struct dquot___4 *);
	int (*write_info)(struct super_block___4 *, int);
	qsize_t * (*get_reserved_space)(struct inode___4 *);
	int (*get_projid)(struct inode___4 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___4 *, qsize_t *);
	int (*get_next_id)(struct super_block___4 *, struct kqid *);
};

struct quotactl_ops___4 {
	int (*quota_on)(struct super_block___4 *, int, int, const struct path___4 *);
	int (*quota_off)(struct super_block___4 *, int);
	int (*quota_enable)(struct super_block___4 *, unsigned int);
	int (*quota_disable)(struct super_block___4 *, unsigned int);
	int (*quota_sync)(struct super_block___4 *, int);
	int (*set_info)(struct super_block___4 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___4 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___4 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___4 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___4 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___4 *, unsigned int);
};

struct module_kobject___3 {
	struct kobject___3 kobj;
	struct module___5 *mod;
	struct kobject___3 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___3 {
	struct module___5 *mod;
	struct latch_tree_node node;
};

struct module_layout___3 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___3 mtn;
};

struct module_attribute___3;

struct kernel_param___3;

struct module___5 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___3 mkobj;
	struct module_attribute___3 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___3 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___3 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___3 core_layout;
	struct module_layout___3 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map___3 *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___3 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	int num_static_call_sites;
	struct static_call_site *static_call_sites;
	bool klp;
	bool klp_alive;
	struct klp_modinfo *klp_info;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct address_space_operations___4 {
	int (*writepage)(struct page___5 *, struct writeback_control *);
	int (*readpage)(struct file___4 *, struct page___5 *);
	int (*writepages)(struct address_space___4 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___5 *);
	int (*readpages)(struct file___4 *, struct address_space___4 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control *);
	int (*write_begin)(struct file___4 *, struct address_space___4 *, loff_t, unsigned int, unsigned int, struct page___5 **, void **);
	int (*write_end)(struct file___4 *, struct address_space___4 *, loff_t, unsigned int, unsigned int, struct page___5 *, void *);
	sector_t (*bmap)(struct address_space___4 *, sector_t);
	void (*invalidatepage)(struct page___5 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___5 *, gfp_t);
	void (*freepage)(struct page___5 *);
	ssize_t (*direct_IO)(struct kiocb___4 *, struct iov_iter___4 *);
	int (*migratepage)(struct address_space___4 *, struct page___5 *, struct page___5 *, enum migrate_mode);
	bool (*isolate_page)(struct page___5 *, isolate_mode_t);
	void (*putback_page)(struct page___5 *);
	int (*launder_page)(struct page___5 *);
	int (*is_partially_uptodate)(struct page___5 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___5 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___4 *, struct page___5 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___4 *, sector_t *);
	void (*swap_deactivate)(struct file___4 *);
};

struct bio_vec___3;

struct iov_iter___4 {
	u8 iter_type;
	bool data_source;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___3 *bvec;
		struct xarray *xarray;
		struct pipe_inode_info *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			unsigned int head;
			unsigned int start_head;
		};
		loff_t xarray_start;
	};
};

struct inode_operations___4 {
	struct dentry___4 * (*lookup)(struct inode___4 *, struct dentry___4 *, unsigned int);
	const char * (*get_link)(struct dentry___4 *, struct inode___4 *, struct delayed_call *);
	int (*permission)(struct user_namespace *, struct inode___4 *, int);
	struct posix_acl * (*get_acl)(struct inode___4 *, int, bool);
	int (*readlink)(struct dentry___4 *, char *, int);
	int (*create)(struct user_namespace *, struct inode___4 *, struct dentry___4 *, umode_t, bool);
	int (*link)(struct dentry___4 *, struct inode___4 *, struct dentry___4 *);
	int (*unlink)(struct inode___4 *, struct dentry___4 *);
	int (*symlink)(struct user_namespace *, struct inode___4 *, struct dentry___4 *, const char *);
	int (*mkdir)(struct user_namespace *, struct inode___4 *, struct dentry___4 *, umode_t);
	int (*rmdir)(struct inode___4 *, struct dentry___4 *);
	int (*mknod)(struct user_namespace *, struct inode___4 *, struct dentry___4 *, umode_t, dev_t);
	int (*rename)(struct user_namespace *, struct inode___4 *, struct dentry___4 *, struct inode___4 *, struct dentry___4 *, unsigned int);
	int (*setattr)(struct user_namespace *, struct dentry___4 *, struct iattr___4 *);
	int (*getattr)(struct user_namespace *, const struct path___4 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___4 *, char *, size_t);
	int (*fiemap)(struct inode___4 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___4 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___4 *, struct dentry___4 *, struct file___4 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace *, struct inode___4 *, struct dentry___4 *, umode_t);
	int (*set_acl)(struct user_namespace *, struct inode___4 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace *, struct dentry___4 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___4 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___4 {
	void (*fl_copy_lock)(struct file_lock___4 *, struct file_lock___4 *);
	void (*fl_release_private)(struct file_lock___4 *);
};

struct lock_manager_operations___4;

struct file_lock___4 {
	struct file_lock___4 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___4 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___4 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___4 *fl_ops;
	const struct lock_manager_operations___4 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___4 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___4 *);
	int (*lm_grant)(struct file_lock___4 *, int);
	bool (*lm_break)(struct file_lock___4 *);
	int (*lm_change)(struct file_lock___4 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___4 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___4 *);
};

struct fasync_struct___4 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___4 *fa_next;
	struct file___4 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___4 {
	struct inode___4 * (*alloc_inode)(struct super_block___4 *);
	void (*destroy_inode)(struct inode___4 *);
	void (*free_inode)(struct inode___4 *);
	void (*dirty_inode)(struct inode___4 *, int);
	int (*write_inode)(struct inode___4 *, struct writeback_control *);
	int (*drop_inode)(struct inode___4 *);
	void (*evict_inode)(struct inode___4 *);
	void (*put_super)(struct super_block___4 *);
	int (*sync_fs)(struct super_block___4 *, int);
	int (*freeze_super)(struct super_block___4 *);
	int (*freeze_fs)(struct super_block___4 *);
	int (*thaw_super)(struct super_block___4 *);
	int (*unfreeze_fs)(struct super_block___4 *);
	int (*statfs)(struct dentry___4 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___4 *, int *, char *);
	void (*umount_begin)(struct super_block___4 *);
	int (*show_options)(struct seq_file *, struct dentry___4 *);
	int (*show_devname)(struct seq_file *, struct dentry___4 *);
	int (*show_path)(struct seq_file *, struct dentry___4 *);
	int (*show_stats)(struct seq_file *, struct dentry___4 *);
	ssize_t (*quota_read)(struct super_block___4 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___4 *, int, const char *, size_t, loff_t);
	struct dquot___4 ** (*get_dquots)(struct inode___4 *);
	long int (*nr_cached_objects)(struct super_block___4 *, struct shrink_control___2 *);
	long int (*free_cached_objects)(struct super_block___4 *, struct shrink_control___2 *);
	struct file___4 * (*real_loop)(struct file___4 *);
};

struct wakeup_source___3;

struct dev_pm_info___3 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___3 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___5 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___3;

struct bus_type___3;

struct device_driver___3;

struct dev_pm_domain___3;

struct fwnode_handle___3;

struct class___3;

struct attribute_group___3;

struct device___5 {
	struct kobject___3 kobj;
	struct device___5 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___3 *type;
	struct bus_type___3 *bus;
	struct device_driver___3 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___3 power;
	struct dev_pm_domain___3 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node *of_node;
	struct fwnode_handle___3 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___3 *class;
	const struct attribute_group___3 **groups;
	void (*release)(struct device___5 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct block_device___3 {
	sector_t bd_start_sect;
	struct disk_stats *bd_stats;
	long unsigned int bd_stamp;
	bool bd_read_only;
	dev_t bd_dev;
	int bd_openers;
	struct inode___4 *bd_inode;
	struct super_block___4 *bd_super;
	void *bd_claiming;
	struct device___5 bd_device;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct kobject___3 *bd_holder_dir;
	u8 bd_partno;
	spinlock_t bd_size_lock;
	struct gendisk___3 *bd_disk;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	struct super_block___4 *bd_fsfreeze_sb;
	struct partition_meta_info *bd_meta_info;
};

typedef void (*poll_queue_proc___3)(struct file___4 *, wait_queue_head_t *, struct poll_table_struct___4 *);

struct poll_table_struct___4 {
	poll_queue_proc___3 _qproc;
	__poll_t _key;
};

struct seq_file {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___3 *op;
	int poll_event;
	const struct file___4 *file;
	void *private;
};

typedef void bio_end_io_t___3(struct bio___3 *);

struct bio_vec___3 {
	struct page___5 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___3;

struct bio___3 {
	struct bio___3 *bi_next;
	struct block_device___3 *bi_bdev;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	atomic_t __bi_remaining;
	struct bvec_iter bi_iter;
	bio_end_io_t___3 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___3 *bi_blkg;
	struct bio_issue bi_issue;
	u64 bi_iocost_cost;
	struct bio_crypt_ctx *bi_crypt_context;
	union {
		struct bio_integrity_payload___3 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___3 *bi_io_vec;
	struct bio_set___3 *bi_pool;
	struct bio_vec___3 bi_inline_vecs[0];
};

struct subprocess_info {
	struct work_struct work;
	struct completion *complete;
	const char *path;
	char **argv;
	char **envp;
	int wait;
	int retval;
	int (*init)(struct subprocess_info *, struct cred *);
	void (*cleanup)(struct subprocess_info *);
	void *data;
};

struct dev_pagemap_ops___4 {
	void (*page_free)(struct page___5 *);
	void (*kill)(struct dev_pagemap___4 *);
	void (*cleanup)(struct dev_pagemap___4 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___4 *);
};

struct kernfs_root___3;

struct kernfs_elem_dir___3 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___3 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___3;

struct kernfs_root___3 {
	struct kernfs_node___3 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___3 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___3 {
	struct kernfs_node___3 *target_kn;
};

struct kernfs_ops___3;

struct kernfs_elem_attr___3 {
	const struct kernfs_ops___3 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___3 *notify_next;
};

struct kernfs_node___3 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___3 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___3 dir;
		struct kernfs_elem_symlink___3 symlink;
		struct kernfs_elem_attr___3 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___3;

struct kernfs_ops___3 {
	int (*open)(struct kernfs_open_file___3 *);
	void (*release)(struct kernfs_open_file___3 *);
	int (*seq_show)(struct seq_file *, void *);
	void * (*seq_start)(struct seq_file *, loff_t *);
	void * (*seq_next)(struct seq_file *, void *, loff_t *);
	void (*seq_stop)(struct seq_file *, void *);
	ssize_t (*read)(struct kernfs_open_file___3 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___3 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___3 *, struct poll_table_struct___4 *);
	int (*mmap)(struct kernfs_open_file___3 *, struct vm_area_struct___5 *);
};

struct kernfs_syscall_ops___3 {
	int (*show_options)(struct seq_file *, struct kernfs_root___3 *);
	int (*mkdir)(struct kernfs_node___3 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___3 *);
	int (*rename)(struct kernfs_node___3 *, struct kernfs_node___3 *, const char *);
	int (*show_path)(struct seq_file *, struct kernfs_node___3 *, struct kernfs_root___3 *);
};

struct kernfs_open_file___3 {
	struct kernfs_node___3 *kn;
	struct file___4 *file;
	struct seq_file *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped;
	bool released;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___4 *vm_ops;
};

struct bin_attribute___3;

struct attribute_group___3 {
	const char *name;
	umode_t (*is_visible)(struct kobject___3 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___3 *, struct bin_attribute___3 *, int);
	struct attribute **attrs;
	struct bin_attribute___3 **bin_attrs;
};

struct bin_attribute___3 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___4 * (*f_mapping)();
	ssize_t (*read)(struct file___4 *, struct kobject___3 *, struct bin_attribute___3 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___4 *, struct kobject___3 *, struct bin_attribute___3 *, char *, loff_t, size_t);
	int (*mmap)(struct file___4 *, struct kobject___3 *, struct bin_attribute___3 *, struct vm_area_struct___5 *);
};

struct sysfs_ops___3 {
	ssize_t (*show)(struct kobject___3 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___3 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___3;

struct kset___3 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___3 kobj;
	const struct kset_uevent_ops___3 *uevent_ops;
};

struct kobj_type___3 {
	void (*release)(struct kobject___3 *);
	const struct sysfs_ops___3 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___3 **default_groups;
	const struct kobj_ns_type_operations * (*child_ns_type)(struct kobject___3 *);
	const void * (*namespace)(struct kobject___3 *);
	void (*get_ownership)(struct kobject___3 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___3 {
	int (* const filter)(struct kset___3 *, struct kobject___3 *);
	const char * (* const name)(struct kset___3 *, struct kobject___3 *);
	int (* const uevent)(struct kset___3 *, struct kobject___3 *, struct kobj_uevent_env *);
};

struct dev_pm_ops___3 {
	int (*prepare)(struct device___5 *);
	void (*complete)(struct device___5 *);
	int (*suspend)(struct device___5 *);
	int (*resume)(struct device___5 *);
	int (*freeze)(struct device___5 *);
	int (*thaw)(struct device___5 *);
	int (*poweroff)(struct device___5 *);
	int (*restore)(struct device___5 *);
	int (*suspend_late)(struct device___5 *);
	int (*resume_early)(struct device___5 *);
	int (*freeze_late)(struct device___5 *);
	int (*thaw_early)(struct device___5 *);
	int (*poweroff_late)(struct device___5 *);
	int (*restore_early)(struct device___5 *);
	int (*suspend_noirq)(struct device___5 *);
	int (*resume_noirq)(struct device___5 *);
	int (*freeze_noirq)(struct device___5 *);
	int (*thaw_noirq)(struct device___5 *);
	int (*poweroff_noirq)(struct device___5 *);
	int (*restore_noirq)(struct device___5 *);
	int (*runtime_suspend)(struct device___5 *);
	int (*runtime_resume)(struct device___5 *);
	int (*runtime_idle)(struct device___5 *);
};

struct wakeup_source___3 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___5 *dev;
	bool active;
	bool autosleep_enabled;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___3 {
	struct dev_pm_ops___3 ops;
	int (*start)(struct device___5 *);
	void (*detach)(struct device___5 *, bool);
	int (*activate)(struct device___5 *);
	void (*sync)(struct device___5 *);
	void (*dismiss)(struct device___5 *);
};

struct bus_type___3 {
	const char *name;
	const char *dev_name;
	struct device___5 *dev_root;
	const struct attribute_group___3 **bus_groups;
	const struct attribute_group___3 **dev_groups;
	const struct attribute_group___3 **drv_groups;
	int (*match)(struct device___5 *, struct device_driver___3 *);
	int (*uevent)(struct device___5 *, struct kobj_uevent_env *);
	int (*probe)(struct device___5 *);
	void (*sync_state)(struct device___5 *);
	void (*remove)(struct device___5 *);
	void (*shutdown)(struct device___5 *);
	int (*online)(struct device___5 *);
	int (*offline)(struct device___5 *);
	int (*suspend)(struct device___5 *, pm_message_t);
	int (*resume)(struct device___5 *);
	int (*num_vf)(struct device___5 *);
	int (*dma_configure)(struct device___5 *);
	const struct dev_pm_ops___3 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___3 {
	const char *name;
	struct bus_type___3 *bus;
	struct module___5 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___5 *);
	void (*sync_state)(struct device___5 *);
	int (*remove)(struct device___5 *);
	void (*shutdown)(struct device___5 *);
	int (*suspend)(struct device___5 *, pm_message_t);
	int (*resume)(struct device___5 *);
	const struct attribute_group___3 **groups;
	const struct attribute_group___3 **dev_groups;
	const struct dev_pm_ops___3 *pm;
	void (*coredump)(struct device___5 *);
	struct driver_private *p;
};

struct device_type___3 {
	const char *name;
	const struct attribute_group___3 **groups;
	int (*uevent)(struct device___5 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___5 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___5 *);
	const struct dev_pm_ops___3 *pm;
};

struct class___3 {
	const char *name;
	struct module___5 *owner;
	const struct attribute_group___3 **class_groups;
	const struct attribute_group___3 **dev_groups;
	struct kobject___3 *dev_kobj;
	int (*dev_uevent)(struct device___5 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___5 *, umode_t *);
	void (*class_release)(struct class___3 *);
	void (*dev_release)(struct device___5 *);
	int (*shutdown_pre)(struct device___5 *);
	const struct kobj_ns_type_operations *ns_type;
	const void * (*namespace)(struct device___5 *);
	void (*get_ownership)(struct device___5 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___3 *pm;
	struct subsys_private *p;
};

struct fwnode_operations___3;

struct fwnode_handle___3 {
	struct fwnode_handle___3 *secondary;
	const struct fwnode_operations___3 *ops;
	struct device___5 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct block_device_operations___3;

struct gendisk___3 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	short unsigned int events;
	short unsigned int event_flags;
	struct xarray part_tbl;
	struct block_device___3 *part0;
	const struct block_device_operations___3 *fops;
	struct request_queue___3 *queue;
	void *private_data;
	int flags;
	long unsigned int state;
	struct mutex open_mutex;
	unsigned int open_partitions;
	struct backing_dev_info *bdi;
	struct kobject___3 *slave_dir;
	struct list_head slave_bdevs;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___3 integrity_kobj;
	struct cdrom_device_info *cdi;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	u64 diskseq;
};

struct bio_integrity_payload___3 {
	struct bio___3 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___3 *bip_vec;
	struct bio_vec___3 bip_inline_vecs[0];
};

typedef void integrity_prepare_fn___3(struct request___3 *);

typedef void integrity_complete_fn___3(struct request___3 *, unsigned int);

struct blk_integrity_profile___3 {
	integrity_processing_fn *generate_fn;
	integrity_processing_fn *verify_fn;
	integrity_prepare_fn___3 *prepare_fn;
	integrity_complete_fn___3 *complete_fn;
	const char *name;
};

struct block_device_operations___3 {
	blk_qc_t (*submit_bio)(struct bio___3 *);
	int (*open)(struct block_device___3 *, fmode_t);
	void (*release)(struct gendisk___3 *, fmode_t);
	int (*rw_page)(struct block_device___3 *, sector_t, struct page___5 *, unsigned int);
	int (*ioctl)(struct block_device___3 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___3 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___3 *, unsigned int);
	void (*unlock_native_capacity)(struct gendisk___3 *);
	int (*getgeo)(struct block_device___3 *, struct hd_geometry *);
	int (*set_read_only)(struct block_device___3 *, bool);
	void (*swap_slot_free_notify)(struct block_device___3 *, long unsigned int);
	int (*report_zones)(struct gendisk___3 *, sector_t, unsigned int, report_zones_cb, void *);
	char * (*devnode)(struct gendisk___3 *, umode_t *);
	struct module___5 *owner;
	const struct pr_ops *pr_ops;
	int (*alternative_gpt_sector)(struct gendisk___3 *, sector_t *);
};

struct fwnode_reference_args___3;

struct fwnode_endpoint___3;

struct fwnode_operations___3 {
	struct fwnode_handle___3 * (*get)(struct fwnode_handle___3 *);
	void (*put)(struct fwnode_handle___3 *);
	bool (*device_is_available)(const struct fwnode_handle___3 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___3 *, const struct device___5 *);
	bool (*property_present)(const struct fwnode_handle___3 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___3 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___3 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___3 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___3 *);
	struct fwnode_handle___3 * (*get_parent)(const struct fwnode_handle___3 *);
	struct fwnode_handle___3 * (*get_next_child_node)(const struct fwnode_handle___3 *, struct fwnode_handle___3 *);
	struct fwnode_handle___3 * (*get_named_child_node)(const struct fwnode_handle___3 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___3 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___3 *);
	struct fwnode_handle___3 * (*graph_get_next_endpoint)(const struct fwnode_handle___3 *, struct fwnode_handle___3 *);
	struct fwnode_handle___3 * (*graph_get_remote_endpoint)(const struct fwnode_handle___3 *);
	struct fwnode_handle___3 * (*graph_get_port_parent)(struct fwnode_handle___3 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___3 *, struct fwnode_endpoint___3 *);
	int (*add_links)(struct fwnode_handle___3 *);
};

struct fwnode_endpoint___3 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___3 *local_fwnode;
};

struct fwnode_reference_args___3 {
	struct fwnode_handle___3 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

typedef void rq_end_io_fn___3(struct request___3 *, blk_status_t);

struct request___3 {
	struct request_queue___3 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int tag;
	int internal_tag;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___3 *bio;
	struct bio___3 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct llist_node ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___3 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___3 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___3 *saved_end_io;
		} flush;
	};
	struct gendisk___3 *rq_disk;
	struct block_device___3 *part;
	u64 alloc_time_ns;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int stats_sectors;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	struct bio_crypt_ctx *crypt_ctx;
	struct blk_ksm_keyslot *crypt_keyslot;
	short unsigned int write_hint;
	short unsigned int ioprio;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___3 *end_io;
	void *end_io_data;
};

struct elevator_type___3;

struct elevator_mq_ops___3 {
	int (*init_sched)(struct request_queue___3 *, struct elevator_type___3 *);
	void (*exit_sched)(struct elevator_queue___3 *);
	int (*init_hctx)(struct blk_mq_hw_ctx *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx *, unsigned int);
	void (*depth_updated)(struct blk_mq_hw_ctx *);
	bool (*allow_merge)(struct request_queue___3 *, struct request___3 *, struct bio___3 *);
	bool (*bio_merge)(struct request_queue___3 *, struct bio___3 *, unsigned int);
	int (*request_merge)(struct request_queue___3 *, struct request___3 **, struct bio___3 *);
	void (*request_merged)(struct request_queue___3 *, struct request___3 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___3 *, struct request___3 *, struct request___3 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___3 *);
	void (*finish_request)(struct request___3 *);
	void (*insert_requests)(struct blk_mq_hw_ctx *, struct list_head *, bool);
	struct request___3 * (*dispatch_request)(struct blk_mq_hw_ctx *);
	bool (*has_work)(struct blk_mq_hw_ctx *);
	void (*completed_request)(struct request___3 *, u64);
	void (*requeue_request)(struct request___3 *);
	struct request___3 * (*former_request)(struct request_queue___3 *, struct request___3 *);
	struct request___3 * (*next_request)(struct request_queue___3 *, struct request___3 *);
	void (*init_icq)(struct io_cq___3 *);
	void (*exit_icq)(struct io_cq___3 *);
};

struct elv_fs_entry___3;

struct elevator_type___3 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___3 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___3 *elevator_attrs;
	const char *elevator_name;
	const char *elevator_alias;
	const unsigned int elevator_features;
	struct module___5 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
};

struct elevator_queue___3 {
	struct elevator_type___3 *type;
	void *elevator_data;
	struct kobject___3 kobj;
	struct mutex sysfs_lock;
	unsigned int registered;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hlist_head hash[64];
};

struct elv_fs_entry___3 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___3 *, char *);
	ssize_t (*store)(struct elevator_queue___3 *, const char *, size_t);
};

struct cgroup_namespace___2 {
	struct ns_common ns;
	struct user_namespace *user_ns;
	struct ucounts *ucounts;
	struct css_set___4 *root_cset;
};

struct perf_cpu_context___3;

struct perf_output_handle___3;

struct pmu___3 {
	struct list_head entry;
	struct module___5 *module;
	struct device___5 *dev;
	const struct attribute_group___3 **attr_groups;
	const struct attribute_group___3 **attr_update;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___3 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___3 *);
	void (*pmu_disable)(struct pmu___3 *);
	int (*event_init)(struct perf_event___3 *);
	void (*event_mapped)(struct perf_event___3 *, struct mm_struct___6 *);
	void (*event_unmapped)(struct perf_event___3 *, struct mm_struct___6 *);
	int (*add)(struct perf_event___3 *, int);
	void (*del)(struct perf_event___3 *, int);
	void (*start)(struct perf_event___3 *, int);
	void (*stop)(struct perf_event___3 *, int);
	void (*read)(struct perf_event___3 *);
	void (*start_txn)(struct pmu___3 *, unsigned int);
	int (*commit_txn)(struct pmu___3 *);
	void (*cancel_txn)(struct pmu___3 *);
	int (*event_idx)(struct perf_event___3 *);
	void (*sched_task)(struct perf_event_context___4 *, bool);
	struct kmem_cache *task_ctx_cache;
	void (*swap_task_ctx)(struct perf_event_context___4 *, struct perf_event_context___4 *);
	void * (*setup_aux)(struct perf_event___3 *, void **, int, bool);
	void (*free_aux)(void *);
	long int (*snapshot_aux)(struct perf_event___3 *, struct perf_output_handle___3 *, long unsigned int);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___3 *);
	int (*aux_output_match)(struct perf_event___3 *);
	int (*filter_match)(struct perf_event___3 *);
	int (*check_period)(struct perf_event___3 *, u64);
};

struct kernel_param_ops___3 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___3 *);
	int (*get)(char *, const struct kernel_param___3 *);
	void (*free)(void *);
};

struct kparam_array___3;

struct kernel_param___3 {
	const char *name;
	struct module___5 *mod;
	const struct kernel_param_ops___3 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___3 *arr;
	};
};

struct kparam_array___3 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___3 *ops;
	void *elem;
};

struct module_attribute___3 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___3 *, struct module_kobject___3 *, char *);
	ssize_t (*store)(struct module_attribute___3 *, struct module_kobject___3 *, const char *, size_t);
	void (*setup)(struct module___5 *, const char *);
	int (*test)(struct module___5 *);
	void (*free)(struct module___5 *);
};

struct trace_event_class___3;

struct trace_event_call___3 {
	struct list_head list;
	struct trace_event_class___3 *class;
	union {
		char *name;
		struct tracepoint___3 *tp;
	};
	struct trace_event event;
	char *print_fmt;
	struct event_filter *filter;
	union {
		void *module;
		atomic_t refcnt;
	};
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
	struct bpf_prog_array *prog_array;
	int (*perf_perm)(struct trace_event_call___3 *, struct perf_event___3 *);
};

struct cftype___3;

struct cgroup_subsys___3 {
	struct cgroup_subsys_state___3 * (*css_alloc)(struct cgroup_subsys_state___3 *);
	int (*css_online)(struct cgroup_subsys_state___3 *);
	void (*css_offline)(struct cgroup_subsys_state___3 *);
	void (*css_released)(struct cgroup_subsys_state___3 *);
	void (*css_free)(struct cgroup_subsys_state___3 *);
	void (*css_reset)(struct cgroup_subsys_state___3 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___3 *, int);
	int (*css_extra_stat_show)(struct seq_file *, struct cgroup_subsys_state___3 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___6 *, struct css_set___4 *);
	void (*cancel_fork)(struct task_struct___6 *, struct css_set___4 *);
	void (*fork)(struct task_struct___6 *);
	void (*exit)(struct task_struct___6 *);
	void (*release)(struct task_struct___6 *);
	void (*bind)(struct cgroup_subsys_state___3 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___3 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___3 *dfl_cftypes;
	struct cftype___3 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___3 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___3 *updated_children;
	struct cgroup___3 *updated_next;
};

struct cgroup_root___3 {
	struct kernfs_root___3 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___3 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___3 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___3 *ss;
	struct list_head node;
	struct kernfs_ops___3 *kf_ops;
	int (*open)(struct kernfs_open_file___3 *);
	void (*release)(struct kernfs_open_file___3 *);
	u64 (*read_u64)(struct cgroup_subsys_state___3 *, struct cftype___3 *);
	s64 (*read_s64)(struct cgroup_subsys_state___3 *, struct cftype___3 *);
	int (*seq_show)(struct seq_file *, void *);
	void * (*seq_start)(struct seq_file *, loff_t *);
	void * (*seq_next)(struct seq_file *, void *, loff_t *);
	void (*seq_stop)(struct seq_file *, void *);
	int (*write_u64)(struct cgroup_subsys_state___3 *, struct cftype___3 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___3 *, struct cftype___3 *, s64);
	ssize_t (*write)(struct kernfs_open_file___3 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___3 *, struct poll_table_struct___4 *);
};

struct perf_cpu_context___3 {
	struct perf_event_context___4 ctx;
	struct perf_event_context___4 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___3 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
	int heap_size;
	struct perf_event___3 **heap;
	struct perf_event___3 *heap_default[2];
};

struct perf_output_handle___3 {
	struct perf_event___3 *event;
	struct perf_buffer *rb;
	long unsigned int wakeup;
	long unsigned int size;
	u64 aux_flags;
	union {
		void *addr;
		long unsigned int head;
	};
	int page;
};

struct perf_cgroup___3 {
	struct cgroup_subsys_state___3 css;
	struct perf_cgroup_info *info;
};

struct trace_event_fields___3 {
	const char *type;
	union {
		struct {
			const char *name;
			const int size;
			const int align;
			const int is_signed;
			const int filter_type;
		};
		int (*define_fields)(struct trace_event_call___3 *);
	};
};

struct trace_event_class___3 {
	const char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct trace_event_call___3 *, enum trace_reg, void *);
	struct trace_event_fields___3 *fields_array;
	struct list_head * (*get_fields)(struct trace_event_call___3 *);
	struct list_head fields;
	int (*raw_init)(struct trace_event_call___3 *);
};

typedef phys_addr_t resource_size_t;

struct __va_list_tag {
	unsigned int gp_offset;
	unsigned int fp_offset;
	void *overflow_arg_area;
	void *reg_save_area;
};

typedef __builtin_va_list va_list;

struct resource {
	resource_size_t start;
	resource_size_t end;
	const char *name;
	long unsigned int flags;
	long unsigned int desc;
	struct resource *parent;
	struct resource *sibling;
	struct resource *child;
};

typedef u64 async_cookie_t;

typedef void (*async_func_t)(void *, async_cookie_t);

struct async_domain {
	struct list_head pending;
	unsigned int registered: 1;
	long: 63;
	long: 64;
	long: 64;
};

enum umh_disable_depth {
	UMH_ENABLED = 0,
	UMH_FREEZING = 1,
	UMH_DISABLED = 2,
};

struct hash {
	int ino;
	int minor;
	int major;
	umode_t mode;
	struct hash *next;
	char name[4098];
};

struct dir_entry {
	struct list_head list;
	char *name;
	time64_t mtime;
};

enum state {
	Start = 0,
	Collect = 1,
	GotHeader = 2,
	SkipIt = 3,
	GotName = 4,
	CopyFile = 5,
	GotSymlink = 6,
	Reset = 7,
};

typedef int (*decompress_fn)(unsigned char *, long int, long int (*)(void *, long unsigned int), long int (*)(void *, long unsigned int), unsigned char *, long int *, void (*)(char *));

struct dentry___5;

struct super_block___5;

struct module___6;

struct file_system_type___5 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___5 * (*mount)(struct file_system_type___5 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___5 *);
	struct module___6 *owner;
	struct file_system_type___5 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct page___6;

typedef struct page___6 *pgtable_t___5;

struct address_space___5;

struct page_pool___2;

struct mm_struct___7;

struct dev_pagemap___5;

struct page___6 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___5 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___2 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___6 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___5 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___7 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___5 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_area_struct___6;

struct vmacache___5 {
	u64 seqnum;
	struct vm_area_struct___6 *vmas[4];
};

struct page_frag___5 {
	struct page___6 *page;
	__u32 offset;
	__u32 size;
};

struct pid___4;

struct nsproxy___6;

struct signal_struct___6;

struct pipe_inode_info___2;

struct vm_struct___6;

struct task_struct___7 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___7 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___7 *mm;
	struct mm_struct___7 *active_mm;
	struct vmacache___5 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int restore_sigmask: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___7 *real_parent;
	struct task_struct___7 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___7 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___4 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	struct posix_cputimers_work posix_cputimers_work;
	const struct cred *ptracer_cred;
	const struct cred *real_cred;
	const struct cred *cred;
	struct key *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___6 *nsproxy;
	struct signal_struct___6 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___7 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context___4 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set *cgroups;
	struct list_head cg_list;
	u32 closid;
	u32 rmid;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	struct pipe_inode_info___2 *splice_pipe;
	struct page_frag___5 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup *active_memcg;
	struct request_queue *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___7 *oom_reaper_list;
	struct vm_struct___6 *stack_vm_area;
	refcount_t stack_refcount;
	int patch_state;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	void *mce_vaddr;
	__u64 mce_kflags;
	u64 mce_addr;
	__u64 mce_ripv: 1;
	__u64 mce_whole_page: 1;
	__u64 __mce_reserved: 62;
	long: 2;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct callback_head mce_kill_me;
	int mce_count;
	struct llist_head kretprobe_instances;
	struct callback_head l1d_flush_kill;
	long: 64;
	struct thread_struct___3 thread;
};

struct file___5;

struct core_state___5;

struct mm_struct___7 {
	struct {
		struct vm_area_struct___6 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___5 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int mmap_compat_base;
		long unsigned int mmap_compat_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[48];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___5 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___7 *owner;
		struct user_namespace *user_ns;
		struct file___5 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		bool tlb_flush_batched;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct vm_operations_struct___5;

struct vm_area_struct___6 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___6 *vm_next;
	struct vm_area_struct___6 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___7 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___5 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___5 *vm_file;
	struct file___5 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct kiocb___5;

struct iov_iter___5;

struct inode___5;

struct file_lock___5;

struct seq_file___4;

struct file_operations___5 {
	struct module___6 *owner;
	loff_t (*llseek)(struct file___5 *, loff_t, int);
	ssize_t (*read)(struct file___5 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___5 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___5 *, struct iov_iter___5 *);
	ssize_t (*write_iter)(struct kiocb___5 *, struct iov_iter___5 *);
	int (*iopoll)(struct kiocb___5 *, bool);
	int (*iterate)(struct file___5 *, struct dir_context *);
	int (*iterate_shared)(struct file___5 *, struct dir_context *);
	__poll_t (*poll)(struct file___5 *, struct poll_table_struct *);
	long int (*unlocked_ioctl)(struct file___5 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___5 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___5 *, struct vm_area_struct___6 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___5 *, struct file___5 *);
	int (*flush)(struct file___5 *, fl_owner_t);
	int (*release)(struct inode___5 *, struct file___5 *);
	int (*fsync)(struct file___5 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___5 *, int);
	int (*lock)(struct file___5 *, int, struct file_lock___5 *);
	ssize_t (*sendpage)(struct file___5 *, struct page___6 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___5 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___5 *, long unsigned int);
	int (*flock)(struct file___5 *, int, struct file_lock___5 *);
	ssize_t (*splice_write)(struct pipe_inode_info___2 *, struct file___5 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___5 *, loff_t *, struct pipe_inode_info___2 *, size_t, unsigned int);
	int (*setlease)(struct file___5 *, long int, struct file_lock___5 **, void **);
	long int (*fallocate)(struct file___5 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___4 *, struct file___5 *);
	ssize_t (*copy_file_range)(struct file___5 *, loff_t, struct file___5 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___5 *, loff_t, struct file___5 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___5 *, loff_t, loff_t, int);
};

struct seq_operations___4 {
	void * (*start)(struct seq_file___4 *, loff_t *);
	void (*stop)(struct seq_file___4 *, void *);
	void * (*next)(struct seq_file___4 *, void *, loff_t *);
	int (*show)(struct seq_file___4 *, void *);
};

struct pid_namespace___4;

struct upid___4 {
	int nr;
	struct pid_namespace___4 *ns;
};

struct pid_namespace___4 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___7 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___4 *parent;
	struct fs_pin *bacct;
	struct user_namespace *user_ns;
	struct ucounts *ucounts;
	int reboot;
	struct ns_common ns;
};

struct pid___4 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___4 numbers[1];
};

struct signal_struct___6 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___7 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___7 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper;
	unsigned int has_child_subreaper;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___4 *pids[4];
	struct pid___4 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___7 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct nsproxy___6 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___4 *pid_ns_for_children;
	struct net___2 *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___2 *cgroup_ns;
};

struct fasync_struct___5;

struct pipe_buffer___2;

struct pipe_inode_info___2 {
	struct mutex mutex;
	wait_queue_head_t rd_wait;
	wait_queue_head_t wr_wait;
	unsigned int head;
	unsigned int tail;
	unsigned int max_usage;
	unsigned int ring_size;
	bool note_loss;
	unsigned int nr_accounted;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int r_counter;
	unsigned int w_counter;
	unsigned int poll_usage;
	struct page___6 *tmp_page;
	struct fasync_struct___5 *fasync_readers;
	struct fasync_struct___5 *fasync_writers;
	struct pipe_buffer___2 *bufs;
	struct user_struct *user;
	struct watch_queue *watch_queue;
};

struct vm_struct___6 {
	struct vm_struct___6 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___6 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct address_space_operations___5;

struct address_space___5 {
	struct inode___5 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___5 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct device___6;

struct page_pool_params___2 {
	unsigned int flags;
	unsigned int order;
	unsigned int pool_size;
	int nid;
	struct device___6 *dev;
	enum dma_data_direction dma_dir;
	unsigned int max_len;
	unsigned int offset;
};

struct pp_alloc_cache___2 {
	u32 count;
	struct page___6 *cache[128];
};

struct page_pool___2 {
	struct page_pool_params___2 p;
	struct delayed_work release_dw;
	void (*disconnect)(void *);
	long unsigned int defer_start;
	long unsigned int defer_warn;
	u32 pages_state_hold_cnt;
	unsigned int frag_offset;
	struct page___6 *frag_page;
	long int frag_users;
	long: 64;
	long: 64;
	struct pp_alloc_cache___2 alloc;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct ptr_ring ring;
	atomic_t pages_state_release_cnt;
	refcount_t user_cnt;
	u64 destroy_cnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pagemap_ops___5;

struct dev_pagemap___5 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___5 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vfsmount___5;

struct path___5 {
	struct vfsmount___5 *mnt;
	struct dentry___5 *dentry;
};

struct fown_struct___4 {
	rwlock_t lock;
	struct pid___4 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___5 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___5 f_path;
	struct inode___5 *f_inode;
	const struct file_operations___5 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___4 f_owner;
	const struct cred *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___5 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___5;

struct vm_operations_struct___5 {
	void (*open)(struct vm_area_struct___6 *);
	void (*close)(struct vm_area_struct___6 *);
	int (*may_split)(struct vm_area_struct___6 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___6 *);
	int (*mprotect)(struct vm_area_struct___6 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___5 *);
	vm_fault_t (*huge_fault)(struct vm_fault___5 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___5 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___6 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___5 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___5 *);
	int (*access)(struct vm_area_struct___6 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___6 *);
	int (*set_policy)(struct vm_area_struct___6 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___6 *, long unsigned int);
	struct page___6 * (*find_special_page)(struct vm_area_struct___6 *, long unsigned int);
};

struct core_thread___5 {
	struct task_struct___7 *task;
	struct core_thread___5 *next;
};

struct core_state___5 {
	atomic_t nr_threads;
	struct core_thread___5 dumper;
	struct completion startup;
};

struct vm_fault___5 {
	const struct {
		struct vm_area_struct___6 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___6 *cow_page;
	struct page___6 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___5 prealloc_pte;
};

struct dev_pagemap_ops___5 {
	void (*page_free)(struct page___6 *);
	void (*kill)(struct dev_pagemap___5 *);
	void (*cleanup)(struct dev_pagemap___5 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___5 *);
};

struct dentry_operations___5;

struct dentry___5 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___5 *d_parent;
	struct qstr d_name;
	struct inode___5 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___5 *d_op;
	struct super_block___5 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___5;

struct inode___5 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___5 *i_op;
	struct super_block___5 *i_sb;
	struct address_space___5 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___5 *i_fop;
		void (*free_inode)(struct inode___5 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___5 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___2 *i_pipe;
		struct cdev *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___5 {
	int (*d_revalidate)(struct dentry___5 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___5 *, unsigned int);
	int (*d_hash)(const struct dentry___5 *, struct qstr *);
	int (*d_compare)(const struct dentry___5 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___5 *);
	int (*d_init)(struct dentry___5 *);
	void (*d_release)(struct dentry___5 *);
	void (*d_prune)(struct dentry___5 *);
	void (*d_iput)(struct dentry___5 *, struct inode___5 *);
	char * (*d_dname)(struct dentry___5 *, char *, int);
	struct vfsmount___5 * (*d_automount)(struct path___5 *);
	int (*d_manage)(const struct path___5 *, bool);
	struct dentry___5 * (*d_real)(struct dentry___5 *, const struct inode___5 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___5;

struct mem_dqinfo___5 {
	struct quota_format_type___5 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___5;

struct quota_info___5 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___5 *files[3];
	struct mem_dqinfo___5 info[3];
	const struct quota_format_ops___5 *ops[3];
};

struct rcuwait___5 {
	struct task_struct___7 *task;
};

struct percpu_rw_semaphore___5 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___5 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___5 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___5 rw_sem[3];
};

struct super_operations___5;

struct dquot_operations___5;

struct quotactl_ops___5;

struct super_block___5 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___5 *s_type;
	const struct super_operations___5 *s_op;
	const struct dquot_operations___5 *dq_op;
	const struct quotactl_ops___5 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___5 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device *s_bdev;
	struct backing_dev_info *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___5 s_dquot;
	struct sb_writers___5 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___5 *s_d_op;
	int cleancache_poolid;
	struct shrinker___2 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___5 {
	struct dentry___5 *mnt_root;
	struct super_block___5 *mnt_sb;
	int mnt_flags;
	struct user_namespace *mnt_userns;
};

struct kiocb___5 {
	struct file___5 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___5 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___2 *ki_waitq;
	};
};

struct iattr___5 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___5 *ia_file;
};

struct dquot___5 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___5 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___5 {
	int qf_fmt_id;
	const struct quota_format_ops___5 *qf_ops;
	struct module___6 *qf_owner;
	struct quota_format_type___5 *qf_next;
};

struct quota_format_ops___5 {
	int (*check_quota_file)(struct super_block___5 *, int);
	int (*read_file_info)(struct super_block___5 *, int);
	int (*write_file_info)(struct super_block___5 *, int);
	int (*free_file_info)(struct super_block___5 *, int);
	int (*read_dqblk)(struct dquot___5 *);
	int (*commit_dqblk)(struct dquot___5 *);
	int (*release_dqblk)(struct dquot___5 *);
	int (*get_next_id)(struct super_block___5 *, struct kqid *);
};

struct dquot_operations___5 {
	int (*write_dquot)(struct dquot___5 *);
	struct dquot___5 * (*alloc_dquot)(struct super_block___5 *, int);
	void (*destroy_dquot)(struct dquot___5 *);
	int (*acquire_dquot)(struct dquot___5 *);
	int (*release_dquot)(struct dquot___5 *);
	int (*mark_dirty)(struct dquot___5 *);
	int (*write_info)(struct super_block___5 *, int);
	qsize_t * (*get_reserved_space)(struct inode___5 *);
	int (*get_projid)(struct inode___5 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___5 *, qsize_t *);
	int (*get_next_id)(struct super_block___5 *, struct kqid *);
};

struct quotactl_ops___5 {
	int (*quota_on)(struct super_block___5 *, int, int, const struct path___5 *);
	int (*quota_off)(struct super_block___5 *, int);
	int (*quota_enable)(struct super_block___5 *, unsigned int);
	int (*quota_disable)(struct super_block___5 *, unsigned int);
	int (*quota_sync)(struct super_block___5 *, int);
	int (*set_info)(struct super_block___5 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___5 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___5 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___5 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___5 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___5 *, unsigned int);
};

struct kset___4;

struct kobj_type___4;

struct kernfs_node___4;

struct kobject___4 {
	const char *name;
	struct list_head entry;
	struct kobject___4 *parent;
	struct kset___4 *kset;
	struct kobj_type___4 *ktype;
	struct kernfs_node___4 *sd;
	struct kref kref;
	unsigned int state_initialized;
	unsigned int state_in_sysfs;
	unsigned int state_add_uevent_sent;
	unsigned int state_remove_uevent_sent;
	unsigned int uevent_suppress;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___4 {
	struct kobject___4 kobj;
	struct module___6 *mod;
	struct kobject___4 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___4 {
	struct module___6 *mod;
	struct latch_tree_node node;
};

struct module_layout___4 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___4 mtn;
};

struct module_attribute___4;

struct kernel_param___4;

struct trace_event_call___4;

struct module___6 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___4 mkobj;
	struct module_attribute___4 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___4 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___4 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___4 core_layout;
	struct module_layout___4 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map___3 *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___4 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	int num_static_call_sites;
	struct static_call_site *static_call_sites;
	bool klp;
	bool klp_alive;
	struct klp_modinfo *klp_info;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct address_space_operations___5 {
	int (*writepage)(struct page___6 *, struct writeback_control *);
	int (*readpage)(struct file___5 *, struct page___6 *);
	int (*writepages)(struct address_space___5 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___6 *);
	int (*readpages)(struct file___5 *, struct address_space___5 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control *);
	int (*write_begin)(struct file___5 *, struct address_space___5 *, loff_t, unsigned int, unsigned int, struct page___6 **, void **);
	int (*write_end)(struct file___5 *, struct address_space___5 *, loff_t, unsigned int, unsigned int, struct page___6 *, void *);
	sector_t (*bmap)(struct address_space___5 *, sector_t);
	void (*invalidatepage)(struct page___6 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___6 *, gfp_t);
	void (*freepage)(struct page___6 *);
	ssize_t (*direct_IO)(struct kiocb___5 *, struct iov_iter___5 *);
	int (*migratepage)(struct address_space___5 *, struct page___6 *, struct page___6 *, enum migrate_mode);
	bool (*isolate_page)(struct page___6 *, isolate_mode_t);
	void (*putback_page)(struct page___6 *);
	int (*launder_page)(struct page___6 *);
	int (*is_partially_uptodate)(struct page___6 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___6 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___5 *, struct page___6 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___5 *, sector_t *);
	void (*swap_deactivate)(struct file___5 *);
};

struct bio_vec___4;

struct iov_iter___5 {
	u8 iter_type;
	bool data_source;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___4 *bvec;
		struct xarray *xarray;
		struct pipe_inode_info___2 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			unsigned int head;
			unsigned int start_head;
		};
		loff_t xarray_start;
	};
};

struct inode_operations___5 {
	struct dentry___5 * (*lookup)(struct inode___5 *, struct dentry___5 *, unsigned int);
	const char * (*get_link)(struct dentry___5 *, struct inode___5 *, struct delayed_call *);
	int (*permission)(struct user_namespace *, struct inode___5 *, int);
	struct posix_acl * (*get_acl)(struct inode___5 *, int, bool);
	int (*readlink)(struct dentry___5 *, char *, int);
	int (*create)(struct user_namespace *, struct inode___5 *, struct dentry___5 *, umode_t, bool);
	int (*link)(struct dentry___5 *, struct inode___5 *, struct dentry___5 *);
	int (*unlink)(struct inode___5 *, struct dentry___5 *);
	int (*symlink)(struct user_namespace *, struct inode___5 *, struct dentry___5 *, const char *);
	int (*mkdir)(struct user_namespace *, struct inode___5 *, struct dentry___5 *, umode_t);
	int (*rmdir)(struct inode___5 *, struct dentry___5 *);
	int (*mknod)(struct user_namespace *, struct inode___5 *, struct dentry___5 *, umode_t, dev_t);
	int (*rename)(struct user_namespace *, struct inode___5 *, struct dentry___5 *, struct inode___5 *, struct dentry___5 *, unsigned int);
	int (*setattr)(struct user_namespace *, struct dentry___5 *, struct iattr___5 *);
	int (*getattr)(struct user_namespace *, const struct path___5 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___5 *, char *, size_t);
	int (*fiemap)(struct inode___5 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___5 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___5 *, struct dentry___5 *, struct file___5 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace *, struct inode___5 *, struct dentry___5 *, umode_t);
	int (*set_acl)(struct user_namespace *, struct inode___5 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace *, struct dentry___5 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___5 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___5 {
	void (*fl_copy_lock)(struct file_lock___5 *, struct file_lock___5 *);
	void (*fl_release_private)(struct file_lock___5 *);
};

struct lock_manager_operations___5;

struct file_lock___5 {
	struct file_lock___5 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___5 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___5 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___5 *fl_ops;
	const struct lock_manager_operations___5 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___5 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___5 *);
	int (*lm_grant)(struct file_lock___5 *, int);
	bool (*lm_break)(struct file_lock___5 *);
	int (*lm_change)(struct file_lock___5 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___5 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___5 *);
};

struct fasync_struct___5 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___5 *fa_next;
	struct file___5 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___5 {
	struct inode___5 * (*alloc_inode)(struct super_block___5 *);
	void (*destroy_inode)(struct inode___5 *);
	void (*free_inode)(struct inode___5 *);
	void (*dirty_inode)(struct inode___5 *, int);
	int (*write_inode)(struct inode___5 *, struct writeback_control *);
	int (*drop_inode)(struct inode___5 *);
	void (*evict_inode)(struct inode___5 *);
	void (*put_super)(struct super_block___5 *);
	int (*sync_fs)(struct super_block___5 *, int);
	int (*freeze_super)(struct super_block___5 *);
	int (*freeze_fs)(struct super_block___5 *);
	int (*thaw_super)(struct super_block___5 *);
	int (*unfreeze_fs)(struct super_block___5 *);
	int (*statfs)(struct dentry___5 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___5 *, int *, char *);
	void (*umount_begin)(struct super_block___5 *);
	int (*show_options)(struct seq_file___4 *, struct dentry___5 *);
	int (*show_devname)(struct seq_file___4 *, struct dentry___5 *);
	int (*show_path)(struct seq_file___4 *, struct dentry___5 *);
	int (*show_stats)(struct seq_file___4 *, struct dentry___5 *);
	ssize_t (*quota_read)(struct super_block___5 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___5 *, int, const char *, size_t, loff_t);
	struct dquot___5 ** (*get_dquots)(struct inode___5 *);
	long int (*nr_cached_objects)(struct super_block___5 *, struct shrink_control___2 *);
	long int (*free_cached_objects)(struct super_block___5 *, struct shrink_control___2 *);
	struct file___5 * (*real_loop)(struct file___5 *);
};

struct seq_file___4 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___4 *op;
	int poll_event;
	const struct file___5 *file;
	void *private;
};

struct kernfs_root___4;

struct kernfs_elem_dir___4 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___4 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___4;

struct kernfs_root___4 {
	struct kernfs_node___4 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___4 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___4 {
	struct kernfs_node___4 *target_kn;
};

struct kernfs_ops___4;

struct kernfs_elem_attr___4 {
	const struct kernfs_ops___4 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___4 *notify_next;
};

struct kernfs_node___4 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___4 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___4 dir;
		struct kernfs_elem_symlink___4 symlink;
		struct kernfs_elem_attr___4 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___4;

struct kernfs_ops___4 {
	int (*open)(struct kernfs_open_file___4 *);
	void (*release)(struct kernfs_open_file___4 *);
	int (*seq_show)(struct seq_file___4 *, void *);
	void * (*seq_start)(struct seq_file___4 *, loff_t *);
	void * (*seq_next)(struct seq_file___4 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___4 *, void *);
	ssize_t (*read)(struct kernfs_open_file___4 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___4 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___4 *, struct poll_table_struct *);
	int (*mmap)(struct kernfs_open_file___4 *, struct vm_area_struct___6 *);
};

struct kernfs_syscall_ops___4 {
	int (*show_options)(struct seq_file___4 *, struct kernfs_root___4 *);
	int (*mkdir)(struct kernfs_node___4 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___4 *);
	int (*rename)(struct kernfs_node___4 *, struct kernfs_node___4 *, const char *);
	int (*show_path)(struct seq_file___4 *, struct kernfs_node___4 *, struct kernfs_root___4 *);
};

struct kernfs_open_file___4 {
	struct kernfs_node___4 *kn;
	struct file___5 *file;
	struct seq_file___4 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped;
	bool released;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___5 *vm_ops;
};

struct bin_attribute___4;

struct attribute_group___4 {
	const char *name;
	umode_t (*is_visible)(struct kobject___4 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___4 *, struct bin_attribute___4 *, int);
	struct attribute **attrs;
	struct bin_attribute___4 **bin_attrs;
};

struct bin_attribute___4 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___5 * (*f_mapping)();
	ssize_t (*read)(struct file___5 *, struct kobject___4 *, struct bin_attribute___4 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___5 *, struct kobject___4 *, struct bin_attribute___4 *, char *, loff_t, size_t);
	int (*mmap)(struct file___5 *, struct kobject___4 *, struct bin_attribute___4 *, struct vm_area_struct___6 *);
};

struct sysfs_ops___4 {
	ssize_t (*show)(struct kobject___4 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___4 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___4;

struct kset___4 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___4 kobj;
	const struct kset_uevent_ops___4 *uevent_ops;
};

struct kobj_type___4 {
	void (*release)(struct kobject___4 *);
	const struct sysfs_ops___4 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___4 **default_groups;
	const struct kobj_ns_type_operations * (*child_ns_type)(struct kobject___4 *);
	const void * (*namespace)(struct kobject___4 *);
	void (*get_ownership)(struct kobject___4 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___4 {
	int (* const filter)(struct kset___4 *, struct kobject___4 *);
	const char * (* const name)(struct kset___4 *, struct kobject___4 *);
	int (* const uevent)(struct kset___4 *, struct kobject___4 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___4 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___4 *);
	int (*get)(char *, const struct kernel_param___4 *);
	void (*free)(void *);
};

struct kparam_array___4;

struct kernel_param___4 {
	const char *name;
	struct module___6 *mod;
	const struct kernel_param_ops___4 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___4 *arr;
	};
};

struct kparam_array___4 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___4 *ops;
	void *elem;
};

struct module_attribute___4 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___4 *, struct module_kobject___4 *, char *);
	ssize_t (*store)(struct module_attribute___4 *, struct module_kobject___4 *, const char *, size_t);
	void (*setup)(struct module___6 *, const char *);
	int (*test)(struct module___6 *);
	void (*free)(struct module___6 *);
};

struct bio_vec___4 {
	struct page___6 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct wakeup_source___4;

struct dev_pm_info___4 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___4 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___6 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___4;

struct bus_type___4;

struct device_driver___4;

struct dev_pm_domain___4;

struct fwnode_handle___4;

struct class___4;

struct device___6 {
	struct kobject___4 kobj;
	struct device___6 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___4 *type;
	struct bus_type___4 *bus;
	struct device_driver___4 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___4 power;
	struct dev_pm_domain___4 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node *of_node;
	struct fwnode_handle___4 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___4 *class;
	const struct attribute_group___4 **groups;
	void (*release)(struct device___6 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_ops___4 {
	int (*prepare)(struct device___6 *);
	void (*complete)(struct device___6 *);
	int (*suspend)(struct device___6 *);
	int (*resume)(struct device___6 *);
	int (*freeze)(struct device___6 *);
	int (*thaw)(struct device___6 *);
	int (*poweroff)(struct device___6 *);
	int (*restore)(struct device___6 *);
	int (*suspend_late)(struct device___6 *);
	int (*resume_early)(struct device___6 *);
	int (*freeze_late)(struct device___6 *);
	int (*thaw_early)(struct device___6 *);
	int (*poweroff_late)(struct device___6 *);
	int (*restore_early)(struct device___6 *);
	int (*suspend_noirq)(struct device___6 *);
	int (*resume_noirq)(struct device___6 *);
	int (*freeze_noirq)(struct device___6 *);
	int (*thaw_noirq)(struct device___6 *);
	int (*poweroff_noirq)(struct device___6 *);
	int (*restore_noirq)(struct device___6 *);
	int (*runtime_suspend)(struct device___6 *);
	int (*runtime_resume)(struct device___6 *);
	int (*runtime_idle)(struct device___6 *);
};

struct wakeup_source___4 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___6 *dev;
	bool active;
	bool autosleep_enabled;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___4 {
	struct dev_pm_ops___4 ops;
	int (*start)(struct device___6 *);
	void (*detach)(struct device___6 *, bool);
	int (*activate)(struct device___6 *);
	void (*sync)(struct device___6 *);
	void (*dismiss)(struct device___6 *);
};

struct bus_type___4 {
	const char *name;
	const char *dev_name;
	struct device___6 *dev_root;
	const struct attribute_group___4 **bus_groups;
	const struct attribute_group___4 **dev_groups;
	const struct attribute_group___4 **drv_groups;
	int (*match)(struct device___6 *, struct device_driver___4 *);
	int (*uevent)(struct device___6 *, struct kobj_uevent_env *);
	int (*probe)(struct device___6 *);
	void (*sync_state)(struct device___6 *);
	void (*remove)(struct device___6 *);
	void (*shutdown)(struct device___6 *);
	int (*online)(struct device___6 *);
	int (*offline)(struct device___6 *);
	int (*suspend)(struct device___6 *, pm_message_t);
	int (*resume)(struct device___6 *);
	int (*num_vf)(struct device___6 *);
	int (*dma_configure)(struct device___6 *);
	const struct dev_pm_ops___4 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___4 {
	const char *name;
	struct bus_type___4 *bus;
	struct module___6 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___6 *);
	void (*sync_state)(struct device___6 *);
	int (*remove)(struct device___6 *);
	void (*shutdown)(struct device___6 *);
	int (*suspend)(struct device___6 *, pm_message_t);
	int (*resume)(struct device___6 *);
	const struct attribute_group___4 **groups;
	const struct attribute_group___4 **dev_groups;
	const struct dev_pm_ops___4 *pm;
	void (*coredump)(struct device___6 *);
	struct driver_private *p;
};

struct device_type___4 {
	const char *name;
	const struct attribute_group___4 **groups;
	int (*uevent)(struct device___6 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___6 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___6 *);
	const struct dev_pm_ops___4 *pm;
};

struct class___4 {
	const char *name;
	struct module___6 *owner;
	const struct attribute_group___4 **class_groups;
	const struct attribute_group___4 **dev_groups;
	struct kobject___4 *dev_kobj;
	int (*dev_uevent)(struct device___6 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___6 *, umode_t *);
	void (*class_release)(struct class___4 *);
	void (*dev_release)(struct device___6 *);
	int (*shutdown_pre)(struct device___6 *);
	const struct kobj_ns_type_operations *ns_type;
	const void * (*namespace)(struct device___6 *);
	void (*get_ownership)(struct device___6 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___4 *pm;
	struct subsys_private *p;
};

struct fwnode_operations___4;

struct fwnode_handle___4 {
	struct fwnode_handle___4 *secondary;
	const struct fwnode_operations___4 *ops;
	struct device___6 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct fwnode_reference_args___4;

struct fwnode_endpoint___4;

struct fwnode_operations___4 {
	struct fwnode_handle___4 * (*get)(struct fwnode_handle___4 *);
	void (*put)(struct fwnode_handle___4 *);
	bool (*device_is_available)(const struct fwnode_handle___4 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___4 *, const struct device___6 *);
	bool (*property_present)(const struct fwnode_handle___4 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___4 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___4 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___4 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___4 *);
	struct fwnode_handle___4 * (*get_parent)(const struct fwnode_handle___4 *);
	struct fwnode_handle___4 * (*get_next_child_node)(const struct fwnode_handle___4 *, struct fwnode_handle___4 *);
	struct fwnode_handle___4 * (*get_named_child_node)(const struct fwnode_handle___4 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___4 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___4 *);
	struct fwnode_handle___4 * (*graph_get_next_endpoint)(const struct fwnode_handle___4 *, struct fwnode_handle___4 *);
	struct fwnode_handle___4 * (*graph_get_remote_endpoint)(const struct fwnode_handle___4 *);
	struct fwnode_handle___4 * (*graph_get_port_parent)(struct fwnode_handle___4 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___4 *, struct fwnode_endpoint___4 *);
	int (*add_links)(struct fwnode_handle___4 *);
};

struct fwnode_endpoint___4 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___4 *local_fwnode;
};

struct fwnode_reference_args___4 {
	struct fwnode_handle___4 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct pipe_buf_operations___2;

struct pipe_buffer___2 {
	struct page___6 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___2 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___2 {
	int (*confirm)(struct pipe_inode_info___2 *, struct pipe_buffer___2 *);
	void (*release)(struct pipe_inode_info___2 *, struct pipe_buffer___2 *);
	bool (*try_steal)(struct pipe_inode_info___2 *, struct pipe_buffer___2 *);
	bool (*get)(struct pipe_inode_info___2 *, struct pipe_buffer___2 *);
};

enum audit_ntp_type {
	AUDIT_NTP_OFFSET = 0,
	AUDIT_NTP_FREQ = 1,
	AUDIT_NTP_STATUS = 2,
	AUDIT_NTP_TAI = 3,
	AUDIT_NTP_TICK = 4,
	AUDIT_NTP_ADJUST = 5,
	AUDIT_NTP_NVALS = 6,
};

typedef long int (*sys_call_ptr_t)(const struct pt_regs *);

struct dentry___6;

struct super_block___6;

struct file_system_type___6 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___6 * (*mount)(struct file_system_type___6 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___6 *);
	struct module *owner;
	struct file_system_type___6 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___6;

struct kiocb___6;

struct vm_area_struct___7;

struct inode___6;

struct file_lock___6;

struct page___7;

struct seq_file___5;

struct file_operations___6 {
	struct module *owner;
	loff_t (*llseek)(struct file___6 *, loff_t, int);
	ssize_t (*read)(struct file___6 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___6 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___6 *, struct iov_iter *);
	ssize_t (*write_iter)(struct kiocb___6 *, struct iov_iter *);
	int (*iopoll)(struct kiocb___6 *, bool);
	int (*iterate)(struct file___6 *, struct dir_context *);
	int (*iterate_shared)(struct file___6 *, struct dir_context *);
	__poll_t (*poll)(struct file___6 *, struct poll_table_struct *);
	long int (*unlocked_ioctl)(struct file___6 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___6 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___6 *, struct vm_area_struct___7 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___6 *, struct file___6 *);
	int (*flush)(struct file___6 *, fl_owner_t);
	int (*release)(struct inode___6 *, struct file___6 *);
	int (*fsync)(struct file___6 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___6 *, int);
	int (*lock)(struct file___6 *, int, struct file_lock___6 *);
	ssize_t (*sendpage)(struct file___6 *, struct page___7 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___6 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___6 *, long unsigned int);
	int (*flock)(struct file___6 *, int, struct file_lock___6 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___6 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___6 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___6 *, long int, struct file_lock___6 **, void **);
	long int (*fallocate)(struct file___6 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___5 *, struct file___6 *);
	ssize_t (*copy_file_range)(struct file___6 *, loff_t, struct file___6 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___6 *, loff_t, struct file___6 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___6 *, loff_t, loff_t, int);
};

struct static_call_mod___4 {
	struct static_call_mod___4 *next;
	struct module *mod;
	struct static_call_site *sites;
};

struct static_call_key___4 {
	void *func;
	union {
		long unsigned int type;
		struct static_call_mod___4 *mods;
		struct static_call_site *sites;
	};
};

struct vmacache___6 {
	u64 seqnum;
	struct vm_area_struct___7 *vmas[4];
};

struct page_frag___6 {
	struct page___7 *page;
	__u32 offset;
	__u32 size;
};

struct perf_event___4;

struct thread_struct___4 {
	struct desc_struct tls_array[3];
	long unsigned int sp;
	short unsigned int es;
	short unsigned int ds;
	short unsigned int fsindex;
	short unsigned int gsindex;
	long unsigned int fsbase;
	long unsigned int gsbase;
	struct perf_event___4 *ptrace_bps[4];
	long unsigned int virtual_dr6;
	long unsigned int ptrace_dr7;
	long unsigned int cr2;
	long unsigned int trap_nr;
	long unsigned int error_code;
	struct io_bitmap *io_bitmap;
	long unsigned int iopl_emul;
	unsigned int iopl_warn: 1;
	unsigned int sig_on_uaccess_err: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u32 pkru;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct fpu fpu;
};

struct mm_struct___8;

struct pid___5;

struct signal_struct___7;

struct bio_list___4;

struct backing_dev_info___3;

struct io_context___5;

struct mem_cgroup___3;

struct request_queue___4;

struct task_struct___8 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___8 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___8 *mm;
	struct mm_struct___8 *active_mm;
	struct vmacache___6 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int restore_sigmask: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___8 *real_parent;
	struct task_struct___8 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___8 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___5 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	struct posix_cputimers_work posix_cputimers_work;
	const struct cred *ptracer_cred;
	const struct cred *real_cred;
	const struct cred *cred;
	struct key *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy *nsproxy;
	struct signal_struct___7 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___8 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___4 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___3 *backing_dev_info;
	struct io_context___5 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set *cgroups;
	struct list_head cg_list;
	u32 closid;
	u32 rmid;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	long: 64;
	long: 64;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___6 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___3 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___3 *active_memcg;
	struct request_queue___4 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___8 *oom_reaper_list;
	struct vm_struct___3 *stack_vm_area;
	refcount_t stack_refcount;
	int patch_state;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	void *mce_vaddr;
	__u64 mce_kflags;
	u64 mce_addr;
	__u64 mce_ripv: 1;
	__u64 mce_whole_page: 1;
	__u64 __mce_reserved: 62;
	long: 2;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct callback_head mce_kill_me;
	int mce_count;
	struct llist_head kretprobe_instances;
	struct callback_head l1d_flush_kill;
	long: 64;
	struct thread_struct___4 thread;
};

typedef struct page___7 *pgtable_t___6;

struct address_space___6;

struct dev_pagemap___6;

struct page___7 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___6 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___2 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___7 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___6 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___8 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___6 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct pv_cpu_ops___3 {
	void (*io_delay)();
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	void (*write_cr4)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___4 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(long unsigned int);
	void (*invalidate_io_bitmap)();
	void (*update_io_bitmap)();
	void (*wbinvd)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int);
	void (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_msr_safe)(unsigned int, int *);
	int (*write_msr_safe)(unsigned int, unsigned int, unsigned int);
	u64 (*read_pmc)(int);
	void (*start_context_switch)(struct task_struct___8 *);
	void (*end_context_switch)(struct task_struct___8 *);
};

struct flush_tlb_info___3;

struct pv_mmu_ops___3 {
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_one_user)(long unsigned int);
	void (*flush_tlb_multi)(const struct cpumask *, const struct flush_tlb_info___3 *);
	void (*tlb_remove_table)(struct mmu_gather *, void *);
	void (*exit_mmap)(struct mm_struct___8 *);
	struct paravirt_callee_save read_cr2;
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___8 *, struct mm_struct___8 *);
	void (*dup_mmap)(struct mm_struct___8 *, struct mm_struct___8 *);
	int (*pgd_alloc)(struct mm_struct___8 *);
	void (*pgd_free)(struct mm_struct___8 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___8 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___8 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___8 *, long unsigned int);
	void (*alloc_p4d)(struct mm_struct___8 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*release_p4d)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	pte_t (*ptep_modify_prot_start)(struct vm_area_struct___7 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct vm_area_struct___7 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_p4d)(p4d_t *, p4d_t);
	struct paravirt_callee_save p4d_val;
	struct paravirt_callee_save make_p4d;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

struct flush_tlb_info___3 {
	struct mm_struct___8 *mm;
	long unsigned int start;
	long unsigned int end;
	u64 new_tlb_gen;
	unsigned int initiating_cpu;
	u8 stride_shift;
	u8 freed_tables;
};

struct core_state___6;

struct mm_struct___8 {
	struct {
		struct vm_area_struct___7 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___6 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int mmap_compat_base;
		long unsigned int mmap_compat_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[48];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___6 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___8 *owner;
		struct user_namespace *user_ns;
		struct file___6 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		bool tlb_flush_batched;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct vm_operations_struct___6;

struct vm_area_struct___7 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___7 *vm_next;
	struct vm_area_struct___7 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___8 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___6 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___6 *vm_file;
	struct file___6 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct paravirt_patch_template___3 {
	struct pv_cpu_ops___3 cpu;
	struct pv_irq_ops irq;
	struct pv_mmu_ops___3 mmu;
	struct pv_lock_ops lock;
};

struct tracepoint___4 {
	const char *name;
	struct static_key key;
	struct static_call_key___4 *static_call_key;
	void *static_call_tramp;
	void *iterator;
	int (*regfunc)();
	void (*unregfunc)();
	struct tracepoint_func *funcs;
};

struct bpf_raw_event_map___4 {
	struct tracepoint___4 *tp;
	void *bpf_func;
	u32 num_args;
	u32 writable_size;
	long: 64;
};

struct seq_operations___5 {
	void * (*start)(struct seq_file___5 *, loff_t *);
	void (*stop)(struct seq_file___5 *, void *);
	void * (*next)(struct seq_file___5 *, void *, loff_t *);
	int (*show)(struct seq_file___5 *, void *);
};

struct hw_perf_event___4 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___8 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	union {
		struct {
			u64 last_period;
			local64_t period_left;
		};
		struct {
			u64 saved_metric;
			u64 saved_slots;
		};
	};
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___4)(struct perf_event___4 *, struct perf_sample_data *, struct pt_regs *);

struct pmu___4;

struct fasync_struct___6;

struct pid_namespace___5;

struct perf_cgroup___4;

struct perf_event___4 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___4 *group_leader;
	struct pmu___4 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___4 hw;
	struct perf_event_context *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___4 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___8 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct perf_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___6 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	long unsigned int pending_addr;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	struct perf_addr_filter_range *addr_filter_ranges;
	long unsigned int addr_filters_gen;
	struct perf_event___4 *aux_event;
	void (*destroy)(struct perf_event___4 *);
	struct callback_head callback_head;
	struct pid_namespace___5 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___4 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___4 orig_overflow_handler;
	struct bpf_prog *prog;
	u64 bpf_cookie;
	struct trace_event_call___4 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___4 *cgrp;
	void *security;
	struct list_head sb_list;
};

struct io_bitmap {
	u64 sequence;
	refcount_t refcnt;
	unsigned int max;
	long unsigned int bitmap[1024];
};

struct upid___5 {
	int nr;
	struct pid_namespace___5 *ns;
};

struct pid_namespace___5 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___8 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___5 *parent;
	struct fs_pin *bacct;
	struct user_namespace *user_ns;
	struct ucounts *ucounts;
	int reboot;
	struct ns_common ns;
};

struct pid___5 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___5 numbers[1];
};

struct signal_struct___7 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___8 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___8 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper;
	unsigned int has_child_subreaper;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___5 *pids[4];
	struct pid___5 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___8 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct cgroup_namespace___4;

struct nsproxy {
	atomic_t count;
	struct uts_namespace *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___5 *pid_ns_for_children;
	struct net *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___4 *cgroup_ns;
};

struct bio___4;

struct bio_list___4 {
	struct bio___4 *head;
	struct bio___4 *tail;
};

struct cgroup_subsys_state___4;

struct bdi_writeback___3 {
	struct backing_dev_info___3 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	atomic_t writeback_inodes;
	struct percpu_counter stat[4];
	long unsigned int congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	struct delayed_work bw_dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___4 *memcg_css;
	struct cgroup_subsys_state___4 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	struct list_head b_attached;
	struct list_head offline_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
};

struct device___7;

struct backing_dev_info___3 {
	u64 id;
	struct rb_node rb_node;
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___3 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct mutex cgwb_release_mutex;
	struct rw_semaphore wb_switch_rwsem;
	wait_queue_head_t wb_waitq;
	struct device___7 *dev;
	char dev_name[64];
	struct device___7 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___6 *debug_dir;
};

struct io_cq___4;

struct io_context___5 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	struct xarray icq_tree;
	struct io_cq___4 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct cgroup___4;

struct css_set {
	struct cgroup_subsys_state___4 *subsys[14];
	refcount_t refcount;
	struct css_set *dom_cset;
	struct cgroup___4 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___4 *mg_src_cgrp;
	struct cgroup___4 *mg_dst_cgrp;
	struct css_set *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context {
	struct pmu___4 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	int rotate_necessary;
	refcount_t refcount;
	struct task_struct___8 *task;
	u64 time;
	u64 timestamp;
	u64 timeoffset;
	struct perf_event_context *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

struct cgroup_subsys___4;

struct cgroup_subsys_state___4 {
	struct cgroup___4 *cgroup;
	struct cgroup_subsys___4 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___4 *parent;
};

struct kernfs_node___5;

struct cgroup_file___4 {
	struct kernfs_node___5 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct obj_cgroup___3;

struct mem_cgroup_per_node___3;

struct mem_cgroup___3 {
	struct cgroup_subsys_state___4 css;
	struct mem_cgroup_id id;
	struct page_counter memory;
	union {
		struct page_counter swap;
		struct page_counter memsw;
	};
	struct page_counter kmem;
	struct page_counter tcpmem;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool oom_group;
	bool oom_lock;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___4 events_file;
	struct cgroup_file___4 events_local_file;
	struct cgroup_file___4 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	struct memcg_vmstats vmstats;
	atomic_long_t memory_events[8];
	atomic_long_t memory_events_local[8];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct obj_cgroup___3 *objcg;
	struct list_head objcg_list;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad2_;
	atomic_t moving_account;
	struct task_struct___8 *move_lock_task;
	struct memcg_vmstats_percpu *vmstats_percpu;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct memcg_cgwb_frn cgwb_frn[4];
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct deferred_split deferred_split_queue;
	struct mem_cgroup_per_node___3 *nodeinfo[0];
	long: 64;
};

struct kset___5;

struct kobj_type___5;

struct kobject___5 {
	const char *name;
	struct list_head entry;
	struct kobject___5 *parent;
	struct kset___5 *kset;
	struct kobj_type___5 *ktype;
	struct kernfs_node___5 *sd;
	struct kref kref;
	unsigned int state_initialized;
	unsigned int state_in_sysfs;
	unsigned int state_add_uevent_sent;
	unsigned int state_remove_uevent_sent;
	unsigned int uevent_suppress;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct blk_integrity_profile___4;

struct blk_integrity___4 {
	const struct blk_integrity_profile___4 *profile;
	unsigned char flags;
	unsigned char tuple_size;
	unsigned char interval_exp;
	unsigned char tag_size;
};

struct bio_set___4 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	struct bio_alloc_cache *cache;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	unsigned int back_pad;
	spinlock_t rescue_lock;
	struct bio_list___4 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	struct hlist_node cpuhp_dead;
};

struct request___4;

struct elevator_queue___4;

struct gendisk___4;

struct blkcg_gq___4;

struct request_queue___4 {
	struct request___4 *last_merge;
	struct elevator_queue___4 *elevator;
	struct percpu_ref q_usage_counter;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	const struct blk_mq_ops *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx **queue_hw_ctx;
	unsigned int nr_hw_queues;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	spinlock_t queue_lock;
	struct gendisk___4 *disk;
	struct kobject___5 kobj;
	struct kobject___5 *mq_kobj;
	struct blk_integrity___4 integrity;
	struct device___7 *dev;
	enum rpm_status rpm_status;
	long unsigned int nr_requests;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_keyslot_manager *ksm;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	atomic_t nr_active_requests_shared_sbitmap;
	struct sbitmap_queue sched_bitmap_tags;
	struct sbitmap_queue sched_breserved_tags;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___4 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int required_elevator_features;
	unsigned int nr_zones;
	long unsigned int *conv_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int max_open_zones;
	unsigned int max_active_zones;
	int node;
	struct mutex debugfs_mutex;
	struct blk_trace *blk_trace;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	struct mutex sysfs_dir_lock;
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	int mq_freeze_depth;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct mutex mq_freeze_lock;
	struct blk_mq_tag_set *tag_set;
	struct list_head tag_set_list;
	struct bio_set___4 bio_split;
	struct dentry___6 *debugfs_dir;
	struct dentry___6 *sched_debugfs_dir;
	struct dentry___6 *rqos_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	u64 write_hints[5];
};

struct vm_struct___3 {
	struct vm_struct___3 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___7 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct psi_group___4 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___8 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___4;

struct cgroup_rstat_cpu___4;

struct cgroup___4 {
	struct cgroup_subsys_state___4 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___5 *kn;
	struct cgroup_file___4 procs_file;
	struct cgroup_file___4 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___4 *subsys[14];
	struct cgroup_root___4 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___4 *dom_cgrp;
	struct cgroup___4 *old_dom_cgrp;
	struct cgroup_rstat_cpu___4 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___4 psi;
	struct cgroup_bpf bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct address_space_operations___6;

struct address_space___6 {
	struct inode___6 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___6 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct dev_pagemap_ops___6;

struct dev_pagemap___6 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___6 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vfsmount___6;

struct path___6 {
	struct vfsmount___6 *mnt;
	struct dentry___6 *dentry;
};

struct fown_struct___5 {
	rwlock_t lock;
	struct pid___5 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___6 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	long: 64;
	long: 64;
	struct path___6 f_path;
	struct inode___6 *f_inode;
	const struct file_operations___6 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___5 f_owner;
	const struct cred *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___6 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___6;

struct vm_operations_struct___6 {
	void (*open)(struct vm_area_struct___7 *);
	void (*close)(struct vm_area_struct___7 *);
	int (*may_split)(struct vm_area_struct___7 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___7 *);
	int (*mprotect)(struct vm_area_struct___7 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___6 *);
	vm_fault_t (*huge_fault)(struct vm_fault___6 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___6 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___7 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___6 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___6 *);
	int (*access)(struct vm_area_struct___7 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___7 *);
	int (*set_policy)(struct vm_area_struct___7 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___7 *, long unsigned int);
	struct page___7 * (*find_special_page)(struct vm_area_struct___7 *, long unsigned int);
};

struct core_thread___6 {
	struct task_struct___8 *task;
	struct core_thread___6 *next;
};

struct core_state___6 {
	atomic_t nr_threads;
	struct core_thread___6 dumper;
	struct completion startup;
};

struct vm_fault___6 {
	const struct {
		struct vm_area_struct___7 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___7 *cow_page;
	struct page___7 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___6 prealloc_pte;
};

struct pglist_data___3;

struct lruvec___3 {
	struct list_head lists[5];
	spinlock_t lru_lock;
	long unsigned int anon_cost;
	long unsigned int file_cost;
	atomic_long_t nonresident_age;
	long unsigned int refaults[2];
	long unsigned int flags;
	struct pglist_data___3 *pgdat;
};

struct zone___3 {
	long unsigned int _watermark[3];
	long unsigned int watermark_boost;
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[5];
	int node;
	struct pglist_data___3 *zone_pgdat;
	struct per_cpu_pages *per_cpu_pageset;
	struct per_cpu_zonestat *per_cpu_zonestats;
	int pageset_high;
	int pageset_batch;
	long unsigned int zone_start_pfn;
	atomic_long_t managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int present_early_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	seqlock_t span_seqlock;
	int initialized;
	int: 32;
	struct zone_padding _pad1_;
	struct free_area free_area[11];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	long unsigned int compact_init_migrate_pfn;
	long unsigned int compact_init_free_pfn;
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	short: 16;
	struct zone_padding _pad3_;
	atomic_long_t vm_stat[11];
	atomic_long_t vm_numa_event[6];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___3 {
	struct zone___3 *zone;
	int zone_idx;
};

struct zonelist___3 {
	struct zoneref___3 _zonerefs[5121];
};

struct pglist_data___3 {
	struct zone___3 node_zones[5];
	struct zonelist___3 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___8 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_highest_zoneidx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_highest_zoneidx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___8 *kcompactd;
	bool proactive_compact_trigger;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct deferred_split deferred_split_queue;
	struct lruvec___3 __lruvec;
	long unsigned int flags;
	long: 64;
	struct zone_padding _pad2_;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[39];
};

struct irq_domain_ops___2;

struct fwnode_handle___5;

struct irq_domain___2 {
	struct list_head link;
	const char *name;
	const struct irq_domain_ops___2 *ops;
	void *host_data;
	unsigned int flags;
	unsigned int mapcount;
	struct fwnode_handle___5 *fwnode;
	enum irq_domain_bus_token bus_token;
	struct irq_domain_chip_generic *gc;
	struct irq_domain___2 *parent;
	irq_hw_number_t hwirq_max;
	unsigned int revmap_size;
	struct xarray revmap_tree;
	struct mutex revmap_mutex;
	struct irq_data *revmap[0];
};

struct shrink_control___3 {
	gfp_t gfp_mask;
	int nid;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	struct mem_cgroup___3 *memcg;
};

struct shrinker___3 {
	long unsigned int (*count_objects)(struct shrinker___3 *, struct shrink_control___3 *);
	long unsigned int (*scan_objects)(struct shrinker___3 *, struct shrink_control___3 *);
	long int batch;
	int seeks;
	unsigned int flags;
	struct list_head list;
	int id;
	atomic_long_t *nr_deferred;
};

struct dev_pagemap_ops___6 {
	void (*page_free)(struct page___7 *);
	void (*kill)(struct dev_pagemap___6 *);
	void (*cleanup)(struct dev_pagemap___6 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___6 *);
};

struct dentry_operations___6;

struct dentry___6 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___6 *d_parent;
	struct qstr d_name;
	struct inode___6 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___6 *d_op;
	struct super_block___6 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___6;

struct cdev___3;

struct inode___6 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___6 *i_op;
	struct super_block___6 *i_sb;
	struct address_space___6 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___3 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	long: 64;
	long: 64;
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___6 *i_fop;
		void (*free_inode)(struct inode___6 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___6 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___6 {
	int (*d_revalidate)(struct dentry___6 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___6 *, unsigned int);
	int (*d_hash)(const struct dentry___6 *, struct qstr *);
	int (*d_compare)(const struct dentry___6 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___6 *);
	int (*d_init)(struct dentry___6 *);
	void (*d_release)(struct dentry___6 *);
	void (*d_prune)(struct dentry___6 *);
	void (*d_iput)(struct dentry___6 *, struct inode___6 *);
	char * (*d_dname)(struct dentry___6 *, char *, int);
	struct vfsmount___6 * (*d_automount)(struct path___6 *);
	int (*d_manage)(const struct path___6 *, bool);
	struct dentry___6 * (*d_real)(struct dentry___6 *, const struct inode___6 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___6;

struct mem_dqinfo___6 {
	struct quota_format_type___6 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___6;

struct quota_info___6 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___6 *files[3];
	struct mem_dqinfo___6 info[3];
	const struct quota_format_ops___6 *ops[3];
};

struct rcuwait___6 {
	struct task_struct___8 *task;
};

struct percpu_rw_semaphore___6 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___6 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___6 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___6 rw_sem[3];
};

struct super_operations___6;

struct dquot_operations___6;

struct quotactl_ops___6;

struct block_device___4;

struct super_block___6 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___6 *s_type;
	const struct super_operations___6 *s_op;
	const struct dquot_operations___6 *dq_op;
	const struct quotactl_ops___6 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___6 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___4 *s_bdev;
	struct backing_dev_info___3 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___6 s_dquot;
	struct sb_writers___6 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___6 *s_d_op;
	int cleancache_poolid;
	struct shrinker___3 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___6 {
	struct dentry___6 *mnt_root;
	struct super_block___6 *mnt_sb;
	int mnt_flags;
	struct user_namespace *mnt_userns;
};

struct io_cq___4 {
	struct request_queue___4 *q;
	struct io_context___5 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct kiocb___6 {
	struct file___6 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___6 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___2 *ki_waitq;
	};
};

struct iattr___6 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___6 *ia_file;
};

struct dquot___6 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___6 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___6 {
	int qf_fmt_id;
	const struct quota_format_ops___6 *qf_ops;
	struct module *qf_owner;
	struct quota_format_type___6 *qf_next;
};

struct quota_format_ops___6 {
	int (*check_quota_file)(struct super_block___6 *, int);
	int (*read_file_info)(struct super_block___6 *, int);
	int (*write_file_info)(struct super_block___6 *, int);
	int (*free_file_info)(struct super_block___6 *, int);
	int (*read_dqblk)(struct dquot___6 *);
	int (*commit_dqblk)(struct dquot___6 *);
	int (*release_dqblk)(struct dquot___6 *);
	int (*get_next_id)(struct super_block___6 *, struct kqid *);
};

struct dquot_operations___6 {
	int (*write_dquot)(struct dquot___6 *);
	struct dquot___6 * (*alloc_dquot)(struct super_block___6 *, int);
	void (*destroy_dquot)(struct dquot___6 *);
	int (*acquire_dquot)(struct dquot___6 *);
	int (*release_dquot)(struct dquot___6 *);
	int (*mark_dirty)(struct dquot___6 *);
	int (*write_info)(struct super_block___6 *, int);
	qsize_t * (*get_reserved_space)(struct inode___6 *);
	int (*get_projid)(struct inode___6 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___6 *, qsize_t *);
	int (*get_next_id)(struct super_block___6 *, struct kqid *);
};

struct quotactl_ops___6 {
	int (*quota_on)(struct super_block___6 *, int, int, const struct path___6 *);
	int (*quota_off)(struct super_block___6 *, int);
	int (*quota_enable)(struct super_block___6 *, unsigned int);
	int (*quota_disable)(struct super_block___6 *, unsigned int);
	int (*quota_sync)(struct super_block___6 *, int);
	int (*set_info)(struct super_block___6 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___6 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___6 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___6 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___6 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___6 *, unsigned int);
};

struct module_kobject___5 {
	struct kobject___5 kobj;
	struct module *mod;
	struct kobject___5 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___5 {
	struct module *mod;
	struct latch_tree_node node;
};

struct module_layout___5 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___5 mtn;
};

struct module_attribute___5;

struct kernel_param___5;

struct module {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___5 mkobj;
	struct module_attribute___5 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___5 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___5 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___5 core_layout;
	struct module_layout___5 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map___4 *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___4 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	int num_static_call_sites;
	struct static_call_site *static_call_sites;
	bool klp;
	bool klp_alive;
	struct klp_modinfo *klp_info;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct writeback_control___3;

struct address_space_operations___6 {
	int (*writepage)(struct page___7 *, struct writeback_control___3 *);
	int (*readpage)(struct file___6 *, struct page___7 *);
	int (*writepages)(struct address_space___6 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___7 *);
	int (*readpages)(struct file___6 *, struct address_space___6 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control *);
	int (*write_begin)(struct file___6 *, struct address_space___6 *, loff_t, unsigned int, unsigned int, struct page___7 **, void **);
	int (*write_end)(struct file___6 *, struct address_space___6 *, loff_t, unsigned int, unsigned int, struct page___7 *, void *);
	sector_t (*bmap)(struct address_space___6 *, sector_t);
	void (*invalidatepage)(struct page___7 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___7 *, gfp_t);
	void (*freepage)(struct page___7 *);
	ssize_t (*direct_IO)(struct kiocb___6 *, struct iov_iter *);
	int (*migratepage)(struct address_space___6 *, struct page___7 *, struct page___7 *, enum migrate_mode);
	bool (*isolate_page)(struct page___7 *, isolate_mode_t);
	void (*putback_page)(struct page___7 *);
	int (*launder_page)(struct page___7 *);
	int (*is_partially_uptodate)(struct page___7 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___7 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___6 *, struct page___7 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___6 *, sector_t *);
	void (*swap_deactivate)(struct file___6 *);
};

struct writeback_control___3 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate;
	unsigned int for_background;
	unsigned int tagged_writepages;
	unsigned int for_reclaim;
	unsigned int range_cyclic;
	unsigned int for_sync;
	unsigned int no_cgroup_owner;
	unsigned int punt_to_cgroup;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bdi_writeback___3 *wb;
	struct inode___6 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
};

struct bio_vec___5;

struct iov_iter {
	u8 iter_type;
	bool data_source;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___5 *bvec;
		struct xarray *xarray;
		struct pipe_inode_info *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			unsigned int head;
			unsigned int start_head;
		};
		loff_t xarray_start;
	};
};

struct cdev___3 {
	struct kobject___5 kobj;
	struct module *owner;
	const struct file_operations___6 *ops;
	struct list_head list;
	dev_t dev;
	unsigned int count;
};

struct inode_operations___6 {
	struct dentry___6 * (*lookup)(struct inode___6 *, struct dentry___6 *, unsigned int);
	const char * (*get_link)(struct dentry___6 *, struct inode___6 *, struct delayed_call *);
	int (*permission)(struct user_namespace *, struct inode___6 *, int);
	struct posix_acl * (*get_acl)(struct inode___6 *, int, bool);
	int (*readlink)(struct dentry___6 *, char *, int);
	int (*create)(struct user_namespace *, struct inode___6 *, struct dentry___6 *, umode_t, bool);
	int (*link)(struct dentry___6 *, struct inode___6 *, struct dentry___6 *);
	int (*unlink)(struct inode___6 *, struct dentry___6 *);
	int (*symlink)(struct user_namespace *, struct inode___6 *, struct dentry___6 *, const char *);
	int (*mkdir)(struct user_namespace *, struct inode___6 *, struct dentry___6 *, umode_t);
	int (*rmdir)(struct inode___6 *, struct dentry___6 *);
	int (*mknod)(struct user_namespace *, struct inode___6 *, struct dentry___6 *, umode_t, dev_t);
	int (*rename)(struct user_namespace *, struct inode___6 *, struct dentry___6 *, struct inode___6 *, struct dentry___6 *, unsigned int);
	int (*setattr)(struct user_namespace *, struct dentry___6 *, struct iattr___6 *);
	int (*getattr)(struct user_namespace *, const struct path___6 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___6 *, char *, size_t);
	int (*fiemap)(struct inode___6 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___6 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___6 *, struct dentry___6 *, struct file___6 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace *, struct inode___6 *, struct dentry___6 *, umode_t);
	int (*set_acl)(struct user_namespace *, struct inode___6 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace *, struct dentry___6 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___6 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___6 {
	void (*fl_copy_lock)(struct file_lock___6 *, struct file_lock___6 *);
	void (*fl_release_private)(struct file_lock___6 *);
};

struct lock_manager_operations___6;

struct file_lock___6 {
	struct file_lock___6 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___6 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___6 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___6 *fl_ops;
	const struct lock_manager_operations___6 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___6 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___6 *);
	int (*lm_grant)(struct file_lock___6 *, int);
	bool (*lm_break)(struct file_lock___6 *);
	int (*lm_change)(struct file_lock___6 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___6 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___6 *);
};

struct fasync_struct___6 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___6 *fa_next;
	struct file___6 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___6 {
	struct inode___6 * (*alloc_inode)(struct super_block___6 *);
	void (*destroy_inode)(struct inode___6 *);
	void (*free_inode)(struct inode___6 *);
	void (*dirty_inode)(struct inode___6 *, int);
	int (*write_inode)(struct inode___6 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___6 *);
	void (*evict_inode)(struct inode___6 *);
	void (*put_super)(struct super_block___6 *);
	int (*sync_fs)(struct super_block___6 *, int);
	int (*freeze_super)(struct super_block___6 *);
	int (*freeze_fs)(struct super_block___6 *);
	int (*thaw_super)(struct super_block___6 *);
	int (*unfreeze_fs)(struct super_block___6 *);
	int (*statfs)(struct dentry___6 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___6 *, int *, char *);
	void (*umount_begin)(struct super_block___6 *);
	int (*show_options)(struct seq_file___5 *, struct dentry___6 *);
	int (*show_devname)(struct seq_file___5 *, struct dentry___6 *);
	int (*show_path)(struct seq_file___5 *, struct dentry___6 *);
	int (*show_stats)(struct seq_file___5 *, struct dentry___6 *);
	ssize_t (*quota_read)(struct super_block___6 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___6 *, int, const char *, size_t, loff_t);
	struct dquot___6 ** (*get_dquots)(struct inode___6 *);
	long int (*nr_cached_objects)(struct super_block___6 *, struct shrink_control___3 *);
	long int (*free_cached_objects)(struct super_block___6 *, struct shrink_control___3 *);
	struct file___6 * (*real_loop)(struct file___6 *);
};

struct wakeup_source___5;

struct dev_pm_info___5 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___5 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___7 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___5;

struct bus_type___5;

struct device_driver___5;

struct dev_pm_domain___5;

struct device_node___2;

struct class___5;

struct attribute_group___5;

struct device___7 {
	struct kobject___5 kobj;
	struct device___7 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___5 *type;
	struct bus_type___5 *bus;
	struct device_driver___5 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___5 power;
	struct dev_pm_domain___5 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___2 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___5 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___5 *class;
	const struct attribute_group___5 **groups;
	void (*release)(struct device___7 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct block_device___4 {
	sector_t bd_start_sect;
	struct disk_stats *bd_stats;
	long unsigned int bd_stamp;
	bool bd_read_only;
	dev_t bd_dev;
	int bd_openers;
	struct inode___6 *bd_inode;
	struct super_block___6 *bd_super;
	void *bd_claiming;
	struct device___7 bd_device;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct kobject___5 *bd_holder_dir;
	u8 bd_partno;
	spinlock_t bd_size_lock;
	struct gendisk___4 *bd_disk;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	struct super_block___6 *bd_fsfreeze_sb;
	struct partition_meta_info *bd_meta_info;
};

typedef void (*poll_queue_proc___4)(struct file___6 *, wait_queue_head_t *, struct poll_table_struct *);

struct poll_table_struct {
	poll_queue_proc___4 _qproc;
	__poll_t _key;
};

struct seq_file___5 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___5 *op;
	int poll_event;
	const struct file___6 *file;
	void *private;
};

typedef void bio_end_io_t___4(struct bio___4 *);

struct bio_vec___5 {
	struct page___7 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___4;

struct bio___4 {
	struct bio___4 *bi_next;
	struct block_device___4 *bi_bdev;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	atomic_t __bi_remaining;
	struct bvec_iter bi_iter;
	bio_end_io_t___4 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___4 *bi_blkg;
	struct bio_issue bi_issue;
	u64 bi_iocost_cost;
	struct bio_crypt_ctx *bi_crypt_context;
	union {
		struct bio_integrity_payload___4 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___5 *bi_io_vec;
	struct bio_set___4 *bi_pool;
	struct bio_vec___5 bi_inline_vecs[0];
};

struct cgroup_namespace___4 {
	struct ns_common ns;
	struct user_namespace *user_ns;
	struct ucounts *ucounts;
	struct css_set *root_cset;
};

struct kernfs_root___5;

struct kernfs_elem_dir___5 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___5 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___5;

struct kernfs_root___5 {
	struct kernfs_node___5 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___5 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___5 {
	struct kernfs_node___5 *target_kn;
};

struct kernfs_ops___5;

struct kernfs_elem_attr___5 {
	const struct kernfs_ops___5 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___5 *notify_next;
};

struct kernfs_node___5 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___5 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___5 dir;
		struct kernfs_elem_symlink___5 symlink;
		struct kernfs_elem_attr___5 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___5;

struct kernfs_ops___5 {
	int (*open)(struct kernfs_open_file___5 *);
	void (*release)(struct kernfs_open_file___5 *);
	int (*seq_show)(struct seq_file___5 *, void *);
	void * (*seq_start)(struct seq_file___5 *, loff_t *);
	void * (*seq_next)(struct seq_file___5 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___5 *, void *);
	ssize_t (*read)(struct kernfs_open_file___5 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___5 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___5 *, struct poll_table_struct *);
	int (*mmap)(struct kernfs_open_file___5 *, struct vm_area_struct___7 *);
};

struct kernfs_syscall_ops___5 {
	int (*show_options)(struct seq_file___5 *, struct kernfs_root___5 *);
	int (*mkdir)(struct kernfs_node___5 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___5 *);
	int (*rename)(struct kernfs_node___5 *, struct kernfs_node___5 *, const char *);
	int (*show_path)(struct seq_file___5 *, struct kernfs_node___5 *, struct kernfs_root___5 *);
};

struct kernfs_open_file___5 {
	struct kernfs_node___5 *kn;
	struct file___6 *file;
	struct seq_file___5 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped;
	bool released;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___6 *vm_ops;
};

enum irqreturn {
	IRQ_NONE = 0,
	IRQ_HANDLED = 1,
	IRQ_WAKE_THREAD = 2,
};

typedef enum irqreturn irqreturn_t;

typedef struct {
	u16 __softirq_pending;
	u8 kvm_cpu_l1tf_flush_l1d;
	unsigned int __nmi_count;
	unsigned int apic_timer_irqs;
	unsigned int irq_spurious_count;
	unsigned int icr_read_retry_count;
	unsigned int kvm_posted_intr_ipis;
	unsigned int kvm_posted_intr_wakeup_ipis;
	unsigned int kvm_posted_intr_nested_ipis;
	unsigned int x86_platform_ipis;
	unsigned int apic_perf_irqs;
	unsigned int apic_irq_work_irqs;
	unsigned int irq_resched_count;
	unsigned int irq_call_count;
	unsigned int irq_tlb_count;
	unsigned int irq_thermal_count;
	unsigned int irq_threshold_count;
	unsigned int irq_deferred_error_count;
	unsigned int irq_hv_callback_count;
	unsigned int irq_hv_reenlightenment_count;
	unsigned int hyperv_stimer0_count;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
} irq_cpustat_t;

typedef irqreturn_t (*irq_handler_t)(int, void *);

struct irqaction {
	irq_handler_t handler;
	void *dev_id;
	void *percpu_dev_id;
	struct irqaction *next;
	irq_handler_t thread_fn;
	struct task_struct___8 *thread;
	struct irqaction *secondary;
	unsigned int irq;
	unsigned int flags;
	long unsigned int thread_flags;
	long unsigned int thread_mask;
	const char *name;
	struct proc_dir_entry *dir;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irq_affinity_notify {
	unsigned int irq;
	struct kref kref;
	struct work_struct work;
	void (*notify)(struct irq_affinity_notify *, const cpumask_t *);
	void (*release)(struct kref *);
};

struct irq_affinity_desc {
	struct cpumask mask;
	unsigned int is_managed: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

enum irqchip_irq_state {
	IRQCHIP_STATE_PENDING = 0,
	IRQCHIP_STATE_ACTIVE = 1,
	IRQCHIP_STATE_MASKED = 2,
	IRQCHIP_STATE_LINE_LEVEL = 3,
};

struct bin_attribute___5;

struct attribute_group___5 {
	const char *name;
	umode_t (*is_visible)(struct kobject___5 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___5 *, struct bin_attribute___5 *, int);
	struct attribute **attrs;
	struct bin_attribute___5 **bin_attrs;
};

struct bin_attribute___5 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___6 * (*f_mapping)();
	ssize_t (*read)(struct file___6 *, struct kobject___5 *, struct bin_attribute___5 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___6 *, struct kobject___5 *, struct bin_attribute___5 *, char *, loff_t, size_t);
	int (*mmap)(struct file___6 *, struct kobject___5 *, struct bin_attribute___5 *, struct vm_area_struct___7 *);
};

struct sysfs_ops___5 {
	ssize_t (*show)(struct kobject___5 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___5 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___5;

struct kset___5 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___5 kobj;
	const struct kset_uevent_ops___5 *uevent_ops;
};

struct kobj_type___5 {
	void (*release)(struct kobject___5 *);
	const struct sysfs_ops___5 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___5 **default_groups;
	const struct kobj_ns_type_operations * (*child_ns_type)(struct kobject___5 *);
	const void * (*namespace)(struct kobject___5 *);
	void (*get_ownership)(struct kobject___5 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___5 {
	int (* const filter)(struct kset___5 *, struct kobject___5 *);
	const char * (* const name)(struct kset___5 *, struct kobject___5 *);
	int (* const uevent)(struct kset___5 *, struct kobject___5 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___5 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___5 *);
	int (*get)(char *, const struct kernel_param___5 *);
	void (*free)(void *);
};

struct kparam_array___5;

struct kernel_param___5 {
	const char *name;
	struct module *mod;
	const struct kernel_param_ops___5 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___5 *arr;
	};
};

struct kparam_array___5 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___5 *ops;
	void *elem;
};

enum {
	EI_ETYPE_NONE = 0,
	EI_ETYPE_NULL = 1,
	EI_ETYPE_ERRNO = 2,
	EI_ETYPE_ERRNO_NULL = 3,
	EI_ETYPE_TRUE = 4,
};

struct module_attribute___5 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___5 *, struct module_kobject___5 *, char *);
	ssize_t (*store)(struct module_attribute___5 *, struct module_kobject___5 *, const char *, size_t);
	void (*setup)(struct module *, const char *);
	int (*test)(struct module *);
	void (*free)(struct module *);
};

struct trace_event_class___4;

struct trace_event_call___4 {
	struct list_head list;
	struct trace_event_class___4 *class;
	union {
		char *name;
		struct tracepoint___4 *tp;
	};
	struct trace_event event;
	char *print_fmt;
	struct event_filter *filter;
	union {
		void *module;
		atomic_t refcnt;
	};
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
	struct bpf_prog_array *prog_array;
	int (*perf_perm)(struct trace_event_call___4 *, struct perf_event___4 *);
};

struct cftype___4;

struct cgroup_subsys___4 {
	struct cgroup_subsys_state___4 * (*css_alloc)(struct cgroup_subsys_state___4 *);
	int (*css_online)(struct cgroup_subsys_state___4 *);
	void (*css_offline)(struct cgroup_subsys_state___4 *);
	void (*css_released)(struct cgroup_subsys_state___4 *);
	void (*css_free)(struct cgroup_subsys_state___4 *);
	void (*css_reset)(struct cgroup_subsys_state___4 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___4 *, int);
	int (*css_extra_stat_show)(struct seq_file___5 *, struct cgroup_subsys_state___4 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___8 *, struct css_set *);
	void (*cancel_fork)(struct task_struct___8 *, struct css_set *);
	void (*fork)(struct task_struct___8 *);
	void (*exit)(struct task_struct___8 *);
	void (*release)(struct task_struct___8 *);
	void (*bind)(struct cgroup_subsys_state___4 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___4 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___4 *dfl_cftypes;
	struct cftype___4 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___4 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___4 *updated_children;
	struct cgroup___4 *updated_next;
};

struct cgroup_root___4 {
	struct kernfs_root___5 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___4 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___4 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___4 *ss;
	struct list_head node;
	struct kernfs_ops___5 *kf_ops;
	int (*open)(struct kernfs_open_file___5 *);
	void (*release)(struct kernfs_open_file___5 *);
	u64 (*read_u64)(struct cgroup_subsys_state___4 *, struct cftype___4 *);
	s64 (*read_s64)(struct cgroup_subsys_state___4 *, struct cftype___4 *);
	int (*seq_show)(struct seq_file___5 *, void *);
	void * (*seq_start)(struct seq_file___5 *, loff_t *);
	void * (*seq_next)(struct seq_file___5 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___5 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___4 *, struct cftype___4 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___4 *, struct cftype___4 *, s64);
	ssize_t (*write)(struct kernfs_open_file___5 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___5 *, struct poll_table_struct *);
};

struct dev_pm_ops___5 {
	int (*prepare)(struct device___7 *);
	void (*complete)(struct device___7 *);
	int (*suspend)(struct device___7 *);
	int (*resume)(struct device___7 *);
	int (*freeze)(struct device___7 *);
	int (*thaw)(struct device___7 *);
	int (*poweroff)(struct device___7 *);
	int (*restore)(struct device___7 *);
	int (*suspend_late)(struct device___7 *);
	int (*resume_early)(struct device___7 *);
	int (*freeze_late)(struct device___7 *);
	int (*thaw_early)(struct device___7 *);
	int (*poweroff_late)(struct device___7 *);
	int (*restore_early)(struct device___7 *);
	int (*suspend_noirq)(struct device___7 *);
	int (*resume_noirq)(struct device___7 *);
	int (*freeze_noirq)(struct device___7 *);
	int (*thaw_noirq)(struct device___7 *);
	int (*poweroff_noirq)(struct device___7 *);
	int (*restore_noirq)(struct device___7 *);
	int (*runtime_suspend)(struct device___7 *);
	int (*runtime_resume)(struct device___7 *);
	int (*runtime_idle)(struct device___7 *);
};

struct wakeup_source___5 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___7 *dev;
	bool active;
	bool autosleep_enabled;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___5 {
	struct dev_pm_ops___5 ops;
	int (*start)(struct device___7 *);
	void (*detach)(struct device___7 *, bool);
	int (*activate)(struct device___7 *);
	void (*sync)(struct device___7 *);
	void (*dismiss)(struct device___7 *);
};

struct bus_type___5 {
	const char *name;
	const char *dev_name;
	struct device___7 *dev_root;
	const struct attribute_group___5 **bus_groups;
	const struct attribute_group___5 **dev_groups;
	const struct attribute_group___5 **drv_groups;
	int (*match)(struct device___7 *, struct device_driver___5 *);
	int (*uevent)(struct device___7 *, struct kobj_uevent_env *);
	int (*probe)(struct device___7 *);
	void (*sync_state)(struct device___7 *);
	void (*remove)(struct device___7 *);
	void (*shutdown)(struct device___7 *);
	int (*online)(struct device___7 *);
	int (*offline)(struct device___7 *);
	int (*suspend)(struct device___7 *, pm_message_t);
	int (*resume)(struct device___7 *);
	int (*num_vf)(struct device___7 *);
	int (*dma_configure)(struct device___7 *);
	const struct dev_pm_ops___5 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___5 {
	const char *name;
	struct bus_type___5 *bus;
	struct module *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___7 *);
	void (*sync_state)(struct device___7 *);
	int (*remove)(struct device___7 *);
	void (*shutdown)(struct device___7 *);
	int (*suspend)(struct device___7 *, pm_message_t);
	int (*resume)(struct device___7 *);
	const struct attribute_group___5 **groups;
	const struct attribute_group___5 **dev_groups;
	const struct dev_pm_ops___5 *pm;
	void (*coredump)(struct device___7 *);
	struct driver_private *p;
};

struct device_type___5 {
	const char *name;
	const struct attribute_group___5 **groups;
	int (*uevent)(struct device___7 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___7 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___7 *);
	const struct dev_pm_ops___5 *pm;
};

struct class___5 {
	const char *name;
	struct module *owner;
	const struct attribute_group___5 **class_groups;
	const struct attribute_group___5 **dev_groups;
	struct kobject___5 *dev_kobj;
	int (*dev_uevent)(struct device___7 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___7 *, umode_t *);
	void (*class_release)(struct class___5 *);
	void (*dev_release)(struct device___7 *);
	int (*shutdown_pre)(struct device___7 *);
	const struct kobj_ns_type_operations *ns_type;
	const void * (*namespace)(struct device___7 *);
	void (*get_ownership)(struct device___7 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___5 *pm;
	struct subsys_private *p;
};

struct fwnode_operations___5;

struct fwnode_handle___5 {
	struct fwnode_handle___5 *secondary;
	const struct fwnode_operations___5 *ops;
	struct device___7 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct device_node___2 {
	const char *name;
	phandle phandle;
	const char *full_name;
	struct fwnode_handle___5 fwnode;
	struct property *properties;
	struct property *deadprops;
	struct device_node___2 *parent;
	struct device_node___2 *child;
	struct device_node___2 *sibling;
	long unsigned int _flags;
	void *data;
};

struct block_device_operations___4;

struct gendisk___4 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	short unsigned int events;
	short unsigned int event_flags;
	struct xarray part_tbl;
	struct block_device___4 *part0;
	const struct block_device_operations___4 *fops;
	struct request_queue___4 *queue;
	void *private_data;
	int flags;
	long unsigned int state;
	struct mutex open_mutex;
	unsigned int open_partitions;
	struct backing_dev_info___3 *bdi;
	struct kobject___5 *slave_dir;
	struct list_head slave_bdevs;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___5 integrity_kobj;
	struct cdrom_device_info *cdi;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	u64 diskseq;
};

struct bio_integrity_payload___4 {
	struct bio___4 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___5 *bip_vec;
	struct bio_vec___5 bip_inline_vecs[0];
};

struct blkcg___3;

struct blkg_policy_data___3;

struct blkcg_gq___4 {
	struct request_queue___4 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___3 *blkcg;
	struct blkcg_gq___4 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_iostat_set *iostat_cpu;
	struct blkg_iostat_set iostat;
	struct blkg_policy_data___3 *pd[6];
	spinlock_t async_bio_lock;
	struct bio_list___4 async_bios;
	struct work_struct async_bio_work;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
	struct callback_head callback_head;
};

typedef void integrity_prepare_fn___4(struct request___4 *);

typedef void integrity_complete_fn___4(struct request___4 *, unsigned int);

struct blk_integrity_profile___4 {
	integrity_processing_fn *generate_fn;
	integrity_processing_fn *verify_fn;
	integrity_prepare_fn___4 *prepare_fn;
	integrity_complete_fn___4 *complete_fn;
	const char *name;
};

struct block_device_operations___4 {
	blk_qc_t (*submit_bio)(struct bio___4 *);
	int (*open)(struct block_device___4 *, fmode_t);
	void (*release)(struct gendisk___4 *, fmode_t);
	int (*rw_page)(struct block_device___4 *, sector_t, struct page___7 *, unsigned int);
	int (*ioctl)(struct block_device___4 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___4 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___4 *, unsigned int);
	void (*unlock_native_capacity)(struct gendisk___4 *);
	int (*getgeo)(struct block_device___4 *, struct hd_geometry *);
	int (*set_read_only)(struct block_device___4 *, bool);
	void (*swap_slot_free_notify)(struct block_device___4 *, long unsigned int);
	int (*report_zones)(struct gendisk___4 *, sector_t, unsigned int, report_zones_cb, void *);
	char * (*devnode)(struct gendisk___4 *, umode_t *);
	struct module *owner;
	const struct pr_ops *pr_ops;
	int (*alternative_gpt_sector)(struct gendisk___4 *, sector_t *);
};

struct fwnode_reference_args___5;

struct fwnode_endpoint___5;

struct fwnode_operations___5 {
	struct fwnode_handle___5 * (*get)(struct fwnode_handle___5 *);
	void (*put)(struct fwnode_handle___5 *);
	bool (*device_is_available)(const struct fwnode_handle___5 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___5 *, const struct device___7 *);
	bool (*property_present)(const struct fwnode_handle___5 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___5 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___5 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___5 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___5 *);
	struct fwnode_handle___5 * (*get_parent)(const struct fwnode_handle___5 *);
	struct fwnode_handle___5 * (*get_next_child_node)(const struct fwnode_handle___5 *, struct fwnode_handle___5 *);
	struct fwnode_handle___5 * (*get_named_child_node)(const struct fwnode_handle___5 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___5 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___5 *);
	struct fwnode_handle___5 * (*graph_get_next_endpoint)(const struct fwnode_handle___5 *, struct fwnode_handle___5 *);
	struct fwnode_handle___5 * (*graph_get_remote_endpoint)(const struct fwnode_handle___5 *);
	struct fwnode_handle___5 * (*graph_get_port_parent)(struct fwnode_handle___5 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___5 *, struct fwnode_endpoint___5 *);
	int (*add_links)(struct fwnode_handle___5 *);
};

struct fwnode_endpoint___5 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___5 *local_fwnode;
};

struct fwnode_reference_args___5 {
	struct fwnode_handle___5 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

typedef void rq_end_io_fn___4(struct request___4 *, blk_status_t);

struct request___4 {
	struct request_queue___4 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int tag;
	int internal_tag;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___4 *bio;
	struct bio___4 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct llist_node ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___5 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___4 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___4 *saved_end_io;
		} flush;
	};
	struct gendisk___4 *rq_disk;
	struct block_device___4 *part;
	u64 alloc_time_ns;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int stats_sectors;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	struct bio_crypt_ctx *crypt_ctx;
	struct blk_ksm_keyslot *crypt_keyslot;
	short unsigned int write_hint;
	short unsigned int ioprio;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___4 *end_io;
	void *end_io_data;
};

struct elevator_type___4;

struct elevator_mq_ops___4 {
	int (*init_sched)(struct request_queue___4 *, struct elevator_type___4 *);
	void (*exit_sched)(struct elevator_queue___4 *);
	int (*init_hctx)(struct blk_mq_hw_ctx *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx *, unsigned int);
	void (*depth_updated)(struct blk_mq_hw_ctx *);
	bool (*allow_merge)(struct request_queue___4 *, struct request___4 *, struct bio___4 *);
	bool (*bio_merge)(struct request_queue___4 *, struct bio___4 *, unsigned int);
	int (*request_merge)(struct request_queue___4 *, struct request___4 **, struct bio___4 *);
	void (*request_merged)(struct request_queue___4 *, struct request___4 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___4 *, struct request___4 *, struct request___4 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___4 *);
	void (*finish_request)(struct request___4 *);
	void (*insert_requests)(struct blk_mq_hw_ctx *, struct list_head *, bool);
	struct request___4 * (*dispatch_request)(struct blk_mq_hw_ctx *);
	bool (*has_work)(struct blk_mq_hw_ctx *);
	void (*completed_request)(struct request___4 *, u64);
	void (*requeue_request)(struct request___4 *);
	struct request___4 * (*former_request)(struct request_queue___4 *, struct request___4 *);
	struct request___4 * (*next_request)(struct request_queue___4 *, struct request___4 *);
	void (*init_icq)(struct io_cq___4 *);
	void (*exit_icq)(struct io_cq___4 *);
};

struct elv_fs_entry___4;

struct elevator_type___4 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___4 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___4 *elevator_attrs;
	const char *elevator_name;
	const char *elevator_alias;
	const unsigned int elevator_features;
	struct module *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
};

struct elevator_queue___4 {
	struct elevator_type___4 *type;
	void *elevator_data;
	struct kobject___5 kobj;
	struct mutex sysfs_lock;
	unsigned int registered;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hlist_head hash[64];
};

struct elv_fs_entry___4 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___4 *, char *);
	ssize_t (*store)(struct elevator_queue___4 *, const char *, size_t);
};

struct blkcg_policy_data___3;

struct blkcg___3 {
	struct cgroup_subsys_state___4 css;
	spinlock_t lock;
	refcount_t online_pin;
	struct xarray blkg_tree;
	struct blkcg_gq___4 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___3 *cpd[6];
	struct list_head all_blkcgs_node;
	char fc_app_id[129];
	struct list_head cgwb_list;
};

struct blkcg_policy_data___3 {
	struct blkcg___3 *blkcg;
	int plid;
};

struct blkg_policy_data___3 {
	struct blkcg_gq___4 *blkg;
	int plid;
};

struct mem_cgroup_reclaim_iter___3 {
	struct mem_cgroup___3 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___3 {
	struct lruvec___3 lruvec;
	struct lruvec_stats_percpu *lruvec_stats_percpu;
	struct lruvec_stats lruvec_stats;
	long unsigned int lru_zone_size[25];
	struct mem_cgroup_reclaim_iter___3 iter;
	struct shrinker_info *shrinker_info;
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	struct mem_cgroup___3 *memcg;
};

struct obj_cgroup___3 {
	struct percpu_ref refcnt;
	struct mem_cgroup___3 *memcg;
	atomic_t nr_charged_bytes;
	union {
		struct list_head list;
		struct callback_head rcu;
	};
};

struct perf_cpu_context___4;

struct perf_output_handle___4;

struct pmu___4 {
	struct list_head entry;
	struct module *module;
	struct device___7 *dev;
	const struct attribute_group___5 **attr_groups;
	const struct attribute_group___5 **attr_update;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___4 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___4 *);
	void (*pmu_disable)(struct pmu___4 *);
	int (*event_init)(struct perf_event___4 *);
	void (*event_mapped)(struct perf_event___4 *, struct mm_struct___8 *);
	void (*event_unmapped)(struct perf_event___4 *, struct mm_struct___8 *);
	int (*add)(struct perf_event___4 *, int);
	void (*del)(struct perf_event___4 *, int);
	void (*start)(struct perf_event___4 *, int);
	void (*stop)(struct perf_event___4 *, int);
	void (*read)(struct perf_event___4 *);
	void (*start_txn)(struct pmu___4 *, unsigned int);
	int (*commit_txn)(struct pmu___4 *);
	void (*cancel_txn)(struct pmu___4 *);
	int (*event_idx)(struct perf_event___4 *);
	void (*sched_task)(struct perf_event_context *, bool);
	struct kmem_cache *task_ctx_cache;
	void (*swap_task_ctx)(struct perf_event_context *, struct perf_event_context *);
	void * (*setup_aux)(struct perf_event___4 *, void **, int, bool);
	void (*free_aux)(void *);
	long int (*snapshot_aux)(struct perf_event___4 *, struct perf_output_handle___4 *, long unsigned int);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___4 *);
	int (*aux_output_match)(struct perf_event___4 *);
	int (*filter_match)(struct perf_event___4 *);
	int (*check_period)(struct perf_event___4 *, u64);
};

struct perf_cpu_context___4 {
	struct perf_event_context ctx;
	struct perf_event_context *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___4 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
	int heap_size;
	struct perf_event___4 **heap;
	struct perf_event___4 *heap_default[2];
};

struct perf_output_handle___4 {
	struct perf_event___4 *event;
	struct perf_buffer *rb;
	long unsigned int wakeup;
	long unsigned int size;
	u64 aux_flags;
	union {
		void *addr;
		long unsigned int head;
	};
	int page;
};

struct perf_cgroup___4 {
	struct cgroup_subsys_state___4 css;
	struct perf_cgroup_info *info;
};

struct trace_event_fields___4 {
	const char *type;
	union {
		struct {
			const char *name;
			const int size;
			const int align;
			const int is_signed;
			const int filter_type;
		};
		int (*define_fields)(struct trace_event_call___4 *);
	};
};

struct trace_event_class___4 {
	const char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct trace_event_call___4 *, enum trace_reg, void *);
	struct trace_event_fields___4 *fields_array;
	struct list_head * (*get_fields)(struct trace_event_call___4 *);
	struct list_head fields;
	int (*raw_init)(struct trace_event_call___4 *);
};

struct syscall_metadata {
	const char *name;
	int syscall_nr;
	int nb_args;
	const char **types;
	const char **args;
	struct list_head enter_fields;
	struct trace_event_call___4 *enter_event;
	struct trace_event_call___4 *exit_event;
};

struct irqentry_state {
	union {
		bool exit_rcu;
		bool lockdep;
	};
};

typedef struct irqentry_state irqentry_state_t;

struct irq_desc;

typedef void (*irq_flow_handler_t)(struct irq_desc *);

struct msi_desc;

struct irq_common_data {
	unsigned int state_use_accessors;
	unsigned int node;
	void *handler_data;
	struct msi_desc *msi_desc;
	cpumask_var_t affinity;
	cpumask_var_t effective_affinity;
};

struct irq_chip;

struct irq_data {
	u32 mask;
	unsigned int irq;
	long unsigned int hwirq;
	struct irq_common_data *common;
	struct irq_chip *chip;
	struct irq_domain___2 *domain;
	struct irq_data *parent_data;
	void *chip_data;
};

struct irq_desc {
	struct irq_common_data irq_common_data;
	struct irq_data irq_data;
	unsigned int *kstat_irqs;
	irq_flow_handler_t handle_irq;
	struct irqaction *action;
	unsigned int status_use_accessors;
	unsigned int core_internal_state__do_not_mess_with_it;
	unsigned int depth;
	unsigned int wake_depth;
	unsigned int tot_count;
	unsigned int irq_count;
	long unsigned int last_unhandled;
	unsigned int irqs_unhandled;
	atomic_t threads_handled;
	int threads_handled_last;
	raw_spinlock_t lock;
	struct cpumask *percpu_enabled;
	const struct cpumask *percpu_affinity;
	const struct cpumask *affinity_hint;
	struct irq_affinity_notify *affinity_notify;
	cpumask_var_t pending_mask;
	long unsigned int threads_oneshot;
	atomic_t threads_active;
	wait_queue_head_t wait_for_threads;
	unsigned int nr_actions;
	unsigned int no_suspend_depth;
	unsigned int cond_suspend_depth;
	unsigned int force_resume_depth;
	struct proc_dir_entry *dir;
	struct callback_head rcu;
	struct kobject___5 kobj;
	struct mutex request_mutex;
	int parent_irq;
	struct module *owner;
	const char *name;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct x86_msi_addr_lo {
	union {
		struct {
			u32 reserved_0: 2;
			u32 dest_mode_logical: 1;
			u32 redirect_hint: 1;
			u32 reserved_1: 1;
			u32 virt_destid_8_14: 7;
			u32 destid_0_7: 8;
			u32 base_address: 12;
		};
		struct {
			u32 dmar_reserved_0: 2;
			u32 dmar_index_15: 1;
			u32 dmar_subhandle_valid: 1;
			u32 dmar_format: 1;
			u32 dmar_index_0_14: 15;
			u32 dmar_base_address: 12;
		};
	};
};

typedef struct x86_msi_addr_lo arch_msi_msg_addr_lo_t;

struct x86_msi_addr_hi {
	u32 reserved: 8;
	u32 destid_8_31: 24;
};

typedef struct x86_msi_addr_hi arch_msi_msg_addr_hi_t;

struct x86_msi_data {
	u32 vector: 8;
	u32 delivery_mode: 3;
	u32 dest_mode_logical: 1;
	u32 reserved: 2;
	u32 active_low: 1;
	u32 is_level: 1;
	short: 15;
	u32 dmar_subhandle;
} __attribute__((packed));

typedef struct x86_msi_data arch_msi_msg_data_t;

struct msi_msg {
	union {
		u32 address_lo;
		arch_msi_msg_addr_lo_t arch_addr_lo;
	};
	union {
		u32 address_hi;
		arch_msi_msg_addr_hi_t arch_addr_hi;
	};
	union {
		u32 data;
		arch_msi_msg_data_t arch_data;
	};
};

struct platform_msi_priv_data;

struct platform_msi_desc {
	struct platform_msi_priv_data *msi_priv_data;
	u16 msi_index;
};

struct fsl_mc_msi_desc {
	u16 msi_index;
};

struct ti_sci_inta_msi_desc {
	u16 dev_index;
};

struct msi_desc {
	struct list_head list;
	unsigned int irq;
	unsigned int nvec_used;
	struct device___7 *dev;
	struct msi_msg msg;
	struct irq_affinity_desc *affinity;
	const void *iommu_cookie;
	void (*write_msi_msg)(struct msi_desc *, void *);
	void *write_msi_msg_data;
	union {
		struct {
			union {
				u32 msi_mask;
				u32 msix_ctrl;
			};
			struct {
				u8 is_msix: 1;
				u8 multiple: 3;
				u8 multi_cap: 3;
				u8 can_mask: 1;
				u8 is_64: 1;
				u8 is_virtual: 1;
				u16 entry_nr;
				unsigned int default_irq;
			} msi_attrib;
			union {
				u8 mask_pos;
				void *mask_base;
			};
		};
		struct platform_msi_desc platform;
		struct fsl_mc_msi_desc fsl_mc;
		struct ti_sci_inta_msi_desc inta;
	};
};

struct irq_chip {
	struct device___7 *parent_device;
	const char *name;
	unsigned int (*irq_startup)(struct irq_data *);
	void (*irq_shutdown)(struct irq_data *);
	void (*irq_enable)(struct irq_data *);
	void (*irq_disable)(struct irq_data *);
	void (*irq_ack)(struct irq_data *);
	void (*irq_mask)(struct irq_data *);
	void (*irq_mask_ack)(struct irq_data *);
	void (*irq_unmask)(struct irq_data *);
	void (*irq_eoi)(struct irq_data *);
	int (*irq_set_affinity)(struct irq_data *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data *);
	int (*irq_set_type)(struct irq_data *, unsigned int);
	int (*irq_set_wake)(struct irq_data *, unsigned int);
	void (*irq_bus_lock)(struct irq_data *);
	void (*irq_bus_sync_unlock)(struct irq_data *);
	void (*irq_cpu_online)(struct irq_data *);
	void (*irq_cpu_offline)(struct irq_data *);
	void (*irq_suspend)(struct irq_data *);
	void (*irq_resume)(struct irq_data *);
	void (*irq_pm_shutdown)(struct irq_data *);
	void (*irq_calc_mask)(struct irq_data *);
	void (*irq_print_chip)(struct irq_data *, struct seq_file___5 *);
	int (*irq_request_resources)(struct irq_data *);
	void (*irq_release_resources)(struct irq_data *);
	void (*irq_compose_msi_msg)(struct irq_data *, struct msi_msg *);
	void (*irq_write_msi_msg)(struct irq_data *, struct msi_msg *);
	int (*irq_get_irqchip_state)(struct irq_data *, enum irqchip_irq_state, bool *);
	int (*irq_set_irqchip_state)(struct irq_data *, enum irqchip_irq_state, bool);
	int (*irq_set_vcpu_affinity)(struct irq_data *, void *);
	void (*ipi_send_single)(struct irq_data *, unsigned int);
	void (*ipi_send_mask)(struct irq_data *, const struct cpumask *);
	int (*irq_nmi_setup)(struct irq_data *);
	void (*irq_nmi_teardown)(struct irq_data *);
	long unsigned int flags;
};

struct irq_chip_regs {
	long unsigned int enable;
	long unsigned int disable;
	long unsigned int mask;
	long unsigned int ack;
	long unsigned int eoi;
	long unsigned int type;
	long unsigned int polarity;
};

struct irq_chip_type {
	struct irq_chip chip;
	struct irq_chip_regs regs;
	irq_flow_handler_t handler;
	u32 type;
	u32 mask_cache_priv;
	u32 *mask_cache;
};

struct irq_chip_generic {
	raw_spinlock_t lock;
	void *reg_base;
	u32 (*reg_readl)(void *);
	void (*reg_writel)(u32, void *);
	void (*suspend)(struct irq_chip_generic *);
	void (*resume)(struct irq_chip_generic *);
	unsigned int irq_base;
	unsigned int irq_cnt;
	u32 mask_cache;
	u32 type_cache;
	u32 polarity_cache;
	u32 wake_enabled;
	u32 wake_active;
	unsigned int num_ct;
	void *private;
	long unsigned int installed;
	long unsigned int unused;
	struct irq_domain___2 *domain;
	struct list_head list;
	struct irq_chip_type chip_types[0];
};

enum irq_gc_flags {
	IRQ_GC_INIT_MASK_CACHE = 1,
	IRQ_GC_INIT_NESTED_LOCK = 2,
	IRQ_GC_MASK_CACHE_PER_TYPE = 4,
	IRQ_GC_NO_MASK = 8,
	IRQ_GC_BE_IO = 16,
};

struct irq_domain_chip_generic {
	unsigned int irqs_per_chip;
	unsigned int num_chips;
	unsigned int irq_flags_to_clear;
	unsigned int irq_flags_to_set;
	enum irq_gc_flags gc_flags;
	struct irq_chip_generic *gc[0];
};

struct irq_fwspec___2 {
	struct fwnode_handle___5 *fwnode;
	int param_count;
	u32 param[16];
};

struct irq_domain_ops___2 {
	int (*match)(struct irq_domain___2 *, struct device_node___2 *, enum irq_domain_bus_token);
	int (*select)(struct irq_domain___2 *, struct irq_fwspec___2 *, enum irq_domain_bus_token);
	int (*map)(struct irq_domain___2 *, unsigned int, irq_hw_number_t);
	void (*unmap)(struct irq_domain___2 *, unsigned int);
	int (*xlate)(struct irq_domain___2 *, struct device_node___2 *, const u32 *, unsigned int, long unsigned int *, unsigned int *);
	int (*alloc)(struct irq_domain___2 *, unsigned int, unsigned int, void *);
	void (*free)(struct irq_domain___2 *, unsigned int, unsigned int);
	int (*activate)(struct irq_domain___2 *, struct irq_data *, bool);
	void (*deactivate)(struct irq_domain___2 *, struct irq_data *);
	int (*translate)(struct irq_domain___2 *, struct irq_fwspec___2 *, long unsigned int *, unsigned int *);
};

struct dentry___7;

struct super_block___7;

struct module___7;

struct file_system_type___7 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___7 * (*mount)(struct file_system_type___7 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___7 *);
	struct module___7 *owner;
	struct file_system_type___7 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___7;

struct kiocb___7;

struct iov_iter___6;

struct vm_area_struct___8;

struct inode___7;

struct file_lock___7;

struct page___8;

struct seq_file___6;

struct file_operations___7 {
	struct module___7 *owner;
	loff_t (*llseek)(struct file___7 *, loff_t, int);
	ssize_t (*read)(struct file___7 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___7 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___7 *, struct iov_iter___6 *);
	ssize_t (*write_iter)(struct kiocb___7 *, struct iov_iter___6 *);
	int (*iopoll)(struct kiocb___7 *, bool);
	int (*iterate)(struct file___7 *, struct dir_context *);
	int (*iterate_shared)(struct file___7 *, struct dir_context *);
	__poll_t (*poll)(struct file___7 *, struct poll_table_struct *);
	long int (*unlocked_ioctl)(struct file___7 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___7 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___7 *, struct vm_area_struct___8 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___7 *, struct file___7 *);
	int (*flush)(struct file___7 *, fl_owner_t);
	int (*release)(struct inode___7 *, struct file___7 *);
	int (*fsync)(struct file___7 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___7 *, int);
	int (*lock)(struct file___7 *, int, struct file_lock___7 *);
	ssize_t (*sendpage)(struct file___7 *, struct page___8 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___7 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___7 *, long unsigned int);
	int (*flock)(struct file___7 *, int, struct file_lock___7 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___7 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___7 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___7 *, long int, struct file_lock___7 **, void **);
	long int (*fallocate)(struct file___7 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___6 *, struct file___7 *);
	ssize_t (*copy_file_range)(struct file___7 *, loff_t, struct file___7 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___7 *, loff_t, struct file___7 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___7 *, loff_t, loff_t, int);
};

struct alt_instr {
	s32 instr_offset;
	s32 repl_offset;
	u16 cpuid;
	u8 instrlen;
	u8 replacementlen;
};

struct vmacache___7 {
	u64 seqnum;
	struct vm_area_struct___8 *vmas[4];
};

struct page_frag___7 {
	struct page___8 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___9;

struct pid___6;

struct nsproxy___7;

struct signal_struct___8;

struct bio_list___5;

struct backing_dev_info___4;

struct io_context___6;

struct css_set___5;

struct mem_cgroup___4;

struct request_queue___5;

struct vm_struct___7;

struct task_struct___9 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___9 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___9 *mm;
	struct mm_struct___9 *active_mm;
	struct vmacache___7 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int restore_sigmask: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___9 *real_parent;
	struct task_struct___9 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___9 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___6 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	struct posix_cputimers_work posix_cputimers_work;
	const struct cred *ptracer_cred;
	const struct cred *real_cred;
	const struct cred *cred;
	struct key *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___7 *nsproxy;
	struct signal_struct___8 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___9 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___5 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___4 *backing_dev_info;
	struct io_context___6 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___5 *cgroups;
	struct list_head cg_list;
	u32 closid;
	u32 rmid;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	long: 64;
	long: 64;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___7 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___4 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___4 *active_memcg;
	struct request_queue___5 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___9 *oom_reaper_list;
	struct vm_struct___7 *stack_vm_area;
	refcount_t stack_refcount;
	int patch_state;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	void *mce_vaddr;
	__u64 mce_kflags;
	u64 mce_addr;
	__u64 mce_ripv: 1;
	__u64 mce_whole_page: 1;
	__u64 __mce_reserved: 62;
	long: 2;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct callback_head mce_kill_me;
	int mce_count;
	struct llist_head kretprobe_instances;
	struct callback_head l1d_flush_kill;
	long: 64;
	struct thread_struct___4 thread;
};

typedef struct page___8 *pgtable_t___7;

struct address_space___7;

struct dev_pagemap___7;

struct page___8 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___7 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___2 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___8 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___7 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___9 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___7 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct core_state___7;

struct mm_struct___9 {
	struct {
		struct vm_area_struct___8 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___7 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int mmap_compat_base;
		long unsigned int mmap_compat_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[48];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___7 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___9 *owner;
		struct user_namespace *user_ns;
		struct file___7 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		bool tlb_flush_batched;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct vm_operations_struct___7;

struct vm_area_struct___8 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___8 *vm_next;
	struct vm_area_struct___8 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___9 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___7 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___7 *vm_file;
	struct file___7 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct seq_operations___6 {
	void * (*start)(struct seq_file___6 *, loff_t *);
	void (*stop)(struct seq_file___6 *, void *);
	void * (*next)(struct seq_file___6 *, void *, loff_t *);
	int (*show)(struct seq_file___6 *, void *);
};

struct timens_offset {
	s64 sec;
	u64 nsec;
};

struct address_space_operations___7;

struct address_space___7 {
	struct inode___7 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___7 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct dev_pagemap_ops___7;

struct dev_pagemap___7 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___7 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vfsmount___7;

struct path___7 {
	struct vfsmount___7 *mnt;
	struct dentry___7 *dentry;
};

struct fown_struct___6 {
	rwlock_t lock;
	struct pid___6 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___7 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	long: 64;
	long: 64;
	struct path___7 f_path;
	struct inode___7 *f_inode;
	const struct file_operations___7 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___6 f_owner;
	const struct cred *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___7 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___7;

struct vm_operations_struct___7 {
	void (*open)(struct vm_area_struct___8 *);
	void (*close)(struct vm_area_struct___8 *);
	int (*may_split)(struct vm_area_struct___8 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___8 *);
	int (*mprotect)(struct vm_area_struct___8 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___7 *);
	vm_fault_t (*huge_fault)(struct vm_fault___7 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___7 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___8 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___7 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___7 *);
	int (*access)(struct vm_area_struct___8 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___8 *);
	int (*set_policy)(struct vm_area_struct___8 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___8 *, long unsigned int);
	struct page___8 * (*find_special_page)(struct vm_area_struct___8 *, long unsigned int);
};

struct core_thread___7 {
	struct task_struct___9 *task;
	struct core_thread___7 *next;
};

struct core_state___7 {
	atomic_t nr_threads;
	struct core_thread___7 dumper;
	struct completion startup;
};

enum vm_fault_reason {
	VM_FAULT_OOM = 1,
	VM_FAULT_SIGBUS = 2,
	VM_FAULT_MAJOR = 4,
	VM_FAULT_WRITE = 8,
	VM_FAULT_HWPOISON = 16,
	VM_FAULT_HWPOISON_LARGE = 32,
	VM_FAULT_SIGSEGV = 64,
	VM_FAULT_NOPAGE = 256,
	VM_FAULT_LOCKED = 512,
	VM_FAULT_RETRY = 1024,
	VM_FAULT_FALLBACK = 2048,
	VM_FAULT_DONE_COW = 4096,
	VM_FAULT_NEEDDSYNC = 8192,
	VM_FAULT_HINDEX_MASK = 983040,
};

struct vm_special_mapping {
	const char *name;
	struct page___8 **pages;
	vm_fault_t (*fault)(const struct vm_special_mapping *, struct vm_area_struct___8 *, struct vm_fault___7 *);
	int (*mremap)(const struct vm_special_mapping *, struct vm_area_struct___8 *);
};

struct vm_fault___7 {
	const struct {
		struct vm_area_struct___8 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___8 *cow_page;
	struct page___8 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___7 prealloc_pte;
};

struct pglist_data___4;

struct lruvec___4 {
	struct list_head lists[5];
	spinlock_t lru_lock;
	long unsigned int anon_cost;
	long unsigned int file_cost;
	atomic_long_t nonresident_age;
	long unsigned int refaults[2];
	long unsigned int flags;
	struct pglist_data___4 *pgdat;
};

struct zone___4 {
	long unsigned int _watermark[3];
	long unsigned int watermark_boost;
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[5];
	int node;
	struct pglist_data___4 *zone_pgdat;
	struct per_cpu_pages *per_cpu_pageset;
	struct per_cpu_zonestat *per_cpu_zonestats;
	int pageset_high;
	int pageset_batch;
	long unsigned int zone_start_pfn;
	atomic_long_t managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int present_early_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	seqlock_t span_seqlock;
	int initialized;
	int: 32;
	struct zone_padding _pad1_;
	struct free_area free_area[11];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	long unsigned int compact_init_migrate_pfn;
	long unsigned int compact_init_free_pfn;
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	short: 16;
	struct zone_padding _pad3_;
	atomic_long_t vm_stat[11];
	atomic_long_t vm_numa_event[6];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___4 {
	struct zone___4 *zone;
	int zone_idx;
};

struct zonelist___4 {
	struct zoneref___4 _zonerefs[5121];
};

struct pglist_data___4 {
	struct zone___4 node_zones[5];
	struct zonelist___4 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___9 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_highest_zoneidx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_highest_zoneidx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___9 *kcompactd;
	bool proactive_compact_trigger;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct deferred_split deferred_split_queue;
	struct lruvec___4 __lruvec;
	long unsigned int flags;
	long: 64;
	struct zone_padding _pad2_;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[39];
};

struct irq_domain_ops___3;

struct fwnode_handle___6;

struct irq_domain___3 {
	struct list_head link;
	const char *name;
	const struct irq_domain_ops___3 *ops;
	void *host_data;
	unsigned int flags;
	unsigned int mapcount;
	struct fwnode_handle___6 *fwnode;
	enum irq_domain_bus_token bus_token;
	struct irq_domain_chip_generic *gc;
	struct irq_domain___3 *parent;
	irq_hw_number_t hwirq_max;
	unsigned int revmap_size;
	struct xarray revmap_tree;
	struct mutex revmap_mutex;
	struct irq_data *revmap[0];
};

struct shrink_control___4 {
	gfp_t gfp_mask;
	int nid;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	struct mem_cgroup___4 *memcg;
};

struct cgroup___5;

struct cgroup_subsys___5;

struct cgroup_subsys_state___5 {
	struct cgroup___5 *cgroup;
	struct cgroup_subsys___5 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___5 *parent;
};

struct kernfs_node___6;

struct cgroup_file___5 {
	struct kernfs_node___6 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct obj_cgroup___4;

struct mem_cgroup_per_node___4;

struct mem_cgroup___4 {
	struct cgroup_subsys_state___5 css;
	struct mem_cgroup_id id;
	struct page_counter memory;
	union {
		struct page_counter swap;
		struct page_counter memsw;
	};
	struct page_counter kmem;
	struct page_counter tcpmem;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool oom_group;
	bool oom_lock;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___5 events_file;
	struct cgroup_file___5 events_local_file;
	struct cgroup_file___5 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	struct memcg_vmstats vmstats;
	atomic_long_t memory_events[8];
	atomic_long_t memory_events_local[8];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct obj_cgroup___4 *objcg;
	struct list_head objcg_list;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad2_;
	atomic_t moving_account;
	struct task_struct___9 *move_lock_task;
	struct memcg_vmstats_percpu *vmstats_percpu;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct memcg_cgwb_frn cgwb_frn[4];
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct deferred_split deferred_split_queue;
	struct mem_cgroup_per_node___4 *nodeinfo[0];
	long: 64;
};

struct shrinker___4 {
	long unsigned int (*count_objects)(struct shrinker___4 *, struct shrink_control___4 *);
	long unsigned int (*scan_objects)(struct shrinker___4 *, struct shrink_control___4 *);
	long int batch;
	int seeks;
	unsigned int flags;
	struct list_head list;
	int id;
	atomic_long_t *nr_deferred;
};

struct dev_pagemap_ops___7 {
	void (*page_free)(struct page___8 *);
	void (*kill)(struct dev_pagemap___7 *);
	void (*cleanup)(struct dev_pagemap___7 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___7 *);
};

struct pid_namespace___6;

struct upid___6 {
	int nr;
	struct pid_namespace___6 *ns;
};

struct pid_namespace___6 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___9 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___6 *parent;
	struct fs_pin *bacct;
	struct user_namespace *user_ns;
	struct ucounts *ucounts;
	int reboot;
	struct ns_common ns;
};

struct pid___6 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___6 numbers[1];
};

struct signal_struct___8 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___9 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___9 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper;
	unsigned int has_child_subreaper;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___6 *pids[4];
	struct pid___6 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___9 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

enum perf_event_task_context___2 {
	perf_invalid_context___2 = 0,
	perf_hw_context___2 = 0,
	perf_sw_context___2 = 1,
	perf_nr_task_contexts___2 = 2,
};

struct cgroup_namespace___5;

struct nsproxy___7 {
	atomic_t count;
	struct uts_namespace *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___6 *pid_ns_for_children;
	struct net *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___5 *cgroup_ns;
};

struct bio___5;

struct bio_list___5 {
	struct bio___5 *head;
	struct bio___5 *tail;
};

struct bdi_writeback___4 {
	struct backing_dev_info___4 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	atomic_t writeback_inodes;
	struct percpu_counter stat[4];
	long unsigned int congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	struct delayed_work bw_dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___5 *memcg_css;
	struct cgroup_subsys_state___5 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	struct list_head b_attached;
	struct list_head offline_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
};

struct device___8;

struct backing_dev_info___4 {
	u64 id;
	struct rb_node rb_node;
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___4 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct mutex cgwb_release_mutex;
	struct rw_semaphore wb_switch_rwsem;
	wait_queue_head_t wb_waitq;
	struct device___8 *dev;
	char dev_name[64];
	struct device___8 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___7 *debug_dir;
};

struct io_cq___5;

struct io_context___6 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	struct xarray icq_tree;
	struct io_cq___5 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct css_set___5 {
	struct cgroup_subsys_state___5 *subsys[14];
	refcount_t refcount;
	struct css_set___5 *dom_cset;
	struct cgroup___5 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___5 *mg_src_cgrp;
	struct cgroup___5 *mg_dst_cgrp;
	struct css_set___5 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct kset___6;

struct kobj_type___6;

struct kobject___6 {
	const char *name;
	struct list_head entry;
	struct kobject___6 *parent;
	struct kset___6 *kset;
	struct kobj_type___6 *ktype;
	struct kernfs_node___6 *sd;
	struct kref kref;
	unsigned int state_initialized;
	unsigned int state_in_sysfs;
	unsigned int state_add_uevent_sent;
	unsigned int state_remove_uevent_sent;
	unsigned int uevent_suppress;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct blk_integrity_profile___5;

struct blk_integrity___5 {
	const struct blk_integrity_profile___5 *profile;
	unsigned char flags;
	unsigned char tuple_size;
	unsigned char interval_exp;
	unsigned char tag_size;
};

struct bio_set___5 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	struct bio_alloc_cache *cache;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	unsigned int back_pad;
	spinlock_t rescue_lock;
	struct bio_list___5 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	struct hlist_node cpuhp_dead;
};

struct request___5;

struct elevator_queue___5;

struct gendisk___5;

struct request_queue___5 {
	struct request___5 *last_merge;
	struct elevator_queue___5 *elevator;
	struct percpu_ref q_usage_counter;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	const struct blk_mq_ops *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx **queue_hw_ctx;
	unsigned int nr_hw_queues;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	spinlock_t queue_lock;
	struct gendisk___5 *disk;
	struct kobject___6 kobj;
	struct kobject___6 *mq_kobj;
	struct blk_integrity___5 integrity;
	struct device___8 *dev;
	enum rpm_status rpm_status;
	long unsigned int nr_requests;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_keyslot_manager *ksm;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	atomic_t nr_active_requests_shared_sbitmap;
	struct sbitmap_queue sched_bitmap_tags;
	struct sbitmap_queue sched_breserved_tags;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___3 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int required_elevator_features;
	unsigned int nr_zones;
	long unsigned int *conv_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int max_open_zones;
	unsigned int max_active_zones;
	int node;
	struct mutex debugfs_mutex;
	struct blk_trace *blk_trace;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	struct mutex sysfs_dir_lock;
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	int mq_freeze_depth;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct mutex mq_freeze_lock;
	struct blk_mq_tag_set *tag_set;
	struct list_head tag_set_list;
	struct bio_set___5 bio_split;
	struct dentry___7 *debugfs_dir;
	struct dentry___7 *sched_debugfs_dir;
	struct dentry___7 *rqos_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	u64 write_hints[5];
};

struct vm_struct___7 {
	struct vm_struct___7 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___8 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct dentry_operations___7;

struct dentry___7 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___7 *d_parent;
	struct qstr d_name;
	struct inode___7 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___7 *d_op;
	struct super_block___7 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___7;

struct inode___7 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___7 *i_op;
	struct super_block___7 *i_sb;
	struct address_space___7 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___4 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	long: 64;
	long: 64;
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___7 *i_fop;
		void (*free_inode)(struct inode___7 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___7 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___7 {
	int (*d_revalidate)(struct dentry___7 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___7 *, unsigned int);
	int (*d_hash)(const struct dentry___7 *, struct qstr *);
	int (*d_compare)(const struct dentry___7 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___7 *);
	int (*d_init)(struct dentry___7 *);
	void (*d_release)(struct dentry___7 *);
	void (*d_prune)(struct dentry___7 *);
	void (*d_iput)(struct dentry___7 *, struct inode___7 *);
	char * (*d_dname)(struct dentry___7 *, char *, int);
	struct vfsmount___7 * (*d_automount)(struct path___7 *);
	int (*d_manage)(const struct path___7 *, bool);
	struct dentry___7 * (*d_real)(struct dentry___7 *, const struct inode___7 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___7;

struct mem_dqinfo___7 {
	struct quota_format_type___7 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___7;

struct quota_info___7 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___7 *files[3];
	struct mem_dqinfo___7 info[3];
	const struct quota_format_ops___7 *ops[3];
};

struct rcuwait___7 {
	struct task_struct___9 *task;
};

struct percpu_rw_semaphore___7 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___7 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___7 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___7 rw_sem[3];
};

struct super_operations___7;

struct dquot_operations___7;

struct quotactl_ops___7;

struct block_device___5;

struct super_block___7 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___7 *s_type;
	const struct super_operations___7 *s_op;
	const struct dquot_operations___7 *dq_op;
	const struct quotactl_ops___7 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___7 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___5 *s_bdev;
	struct backing_dev_info___4 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___7 s_dquot;
	struct sb_writers___7 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___7 *s_d_op;
	int cleancache_poolid;
	struct shrinker___4 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___7 {
	struct dentry___7 *mnt_root;
	struct super_block___7 *mnt_sb;
	int mnt_flags;
	struct user_namespace *mnt_userns;
};

struct psi_group___5 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___9 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___5;

struct cgroup_rstat_cpu___5;

struct cgroup___5 {
	struct cgroup_subsys_state___5 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___6 *kn;
	struct cgroup_file___5 procs_file;
	struct cgroup_file___5 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___5 *subsys[14];
	struct cgroup_root___5 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___5 *dom_cgrp;
	struct cgroup___5 *old_dom_cgrp;
	struct cgroup_rstat_cpu___5 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___5 psi;
	struct cgroup_bpf bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct io_cq___5 {
	struct request_queue___5 *q;
	struct io_context___6 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct wait_page_queue___3;

struct kiocb___7 {
	struct file___7 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___7 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___3 *ki_waitq;
	};
};

struct iattr___7 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___7 *ia_file;
};

struct dquot___7 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___7 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___7 {
	int qf_fmt_id;
	const struct quota_format_ops___7 *qf_ops;
	struct module___7 *qf_owner;
	struct quota_format_type___7 *qf_next;
};

struct quota_format_ops___7 {
	int (*check_quota_file)(struct super_block___7 *, int);
	int (*read_file_info)(struct super_block___7 *, int);
	int (*write_file_info)(struct super_block___7 *, int);
	int (*free_file_info)(struct super_block___7 *, int);
	int (*read_dqblk)(struct dquot___7 *);
	int (*commit_dqblk)(struct dquot___7 *);
	int (*release_dqblk)(struct dquot___7 *);
	int (*get_next_id)(struct super_block___7 *, struct kqid *);
};

struct dquot_operations___7 {
	int (*write_dquot)(struct dquot___7 *);
	struct dquot___7 * (*alloc_dquot)(struct super_block___7 *, int);
	void (*destroy_dquot)(struct dquot___7 *);
	int (*acquire_dquot)(struct dquot___7 *);
	int (*release_dquot)(struct dquot___7 *);
	int (*mark_dirty)(struct dquot___7 *);
	int (*write_info)(struct super_block___7 *, int);
	qsize_t * (*get_reserved_space)(struct inode___7 *);
	int (*get_projid)(struct inode___7 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___7 *, qsize_t *);
	int (*get_next_id)(struct super_block___7 *, struct kqid *);
};

struct quotactl_ops___7 {
	int (*quota_on)(struct super_block___7 *, int, int, const struct path___7 *);
	int (*quota_off)(struct super_block___7 *, int);
	int (*quota_enable)(struct super_block___7 *, unsigned int);
	int (*quota_disable)(struct super_block___7 *, unsigned int);
	int (*quota_sync)(struct super_block___7 *, int);
	int (*set_info)(struct super_block___7 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___7 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___7 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___7 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___7 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___7 *, unsigned int);
};

struct module_kobject___6 {
	struct kobject___6 kobj;
	struct module___7 *mod;
	struct kobject___6 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___6 {
	struct module___7 *mod;
	struct latch_tree_node node;
};

struct module_layout___6 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___6 mtn;
};

struct module_attribute___6;

struct kernel_param___6;

struct module___7 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___6 mkobj;
	struct module_attribute___6 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___6 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___6 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___6 core_layout;
	struct module_layout___6 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map___4 *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___4 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	int num_static_call_sites;
	struct static_call_site *static_call_sites;
	bool klp;
	bool klp_alive;
	struct klp_modinfo *klp_info;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct wait_page_queue___3 {
	struct page___8 *page;
	int bit_nr;
	wait_queue_entry_t wait;
};

struct writeback_control___4;

struct readahead_control___3;

struct swap_info_struct___3;

struct address_space_operations___7 {
	int (*writepage)(struct page___8 *, struct writeback_control___4 *);
	int (*readpage)(struct file___7 *, struct page___8 *);
	int (*writepages)(struct address_space___7 *, struct writeback_control___4 *);
	int (*set_page_dirty)(struct page___8 *);
	int (*readpages)(struct file___7 *, struct address_space___7 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___3 *);
	int (*write_begin)(struct file___7 *, struct address_space___7 *, loff_t, unsigned int, unsigned int, struct page___8 **, void **);
	int (*write_end)(struct file___7 *, struct address_space___7 *, loff_t, unsigned int, unsigned int, struct page___8 *, void *);
	sector_t (*bmap)(struct address_space___7 *, sector_t);
	void (*invalidatepage)(struct page___8 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___8 *, gfp_t);
	void (*freepage)(struct page___8 *);
	ssize_t (*direct_IO)(struct kiocb___7 *, struct iov_iter___6 *);
	int (*migratepage)(struct address_space___7 *, struct page___8 *, struct page___8 *, enum migrate_mode);
	bool (*isolate_page)(struct page___8 *, isolate_mode_t);
	void (*putback_page)(struct page___8 *);
	int (*launder_page)(struct page___8 *);
	int (*is_partially_uptodate)(struct page___8 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___8 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___7 *, struct page___8 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___7 *, sector_t *);
	void (*swap_deactivate)(struct file___7 *);
};

struct writeback_control___4 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate;
	unsigned int for_background;
	unsigned int tagged_writepages;
	unsigned int for_reclaim;
	unsigned int range_cyclic;
	unsigned int for_sync;
	unsigned int no_cgroup_owner;
	unsigned int punt_to_cgroup;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bdi_writeback___4 *wb;
	struct inode___7 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
};

struct readahead_control___3 {
	struct file___7 *file;
	struct address_space___7 *mapping;
	struct file_ra_state *ra;
	long unsigned int _index;
	unsigned int _nr_pages;
	unsigned int _batch_count;
};

struct bio_vec___6;

struct iov_iter___6 {
	u8 iter_type;
	bool data_source;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___6 *bvec;
		struct xarray *xarray;
		struct pipe_inode_info *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			unsigned int head;
			unsigned int start_head;
		};
		loff_t xarray_start;
	};
};

struct swap_info_struct___3 {
	struct percpu_ref users;
	long unsigned int flags;
	short int prio;
	struct plist_node list;
	signed char type;
	unsigned int max;
	unsigned char *swap_map;
	struct swap_cluster_info *cluster_info;
	struct swap_cluster_list free_clusters;
	unsigned int lowest_bit;
	unsigned int highest_bit;
	unsigned int pages;
	unsigned int inuse_pages;
	unsigned int cluster_next;
	unsigned int cluster_nr;
	unsigned int *cluster_next_cpu;
	struct percpu_cluster *percpu_cluster;
	struct rb_root swap_extent_root;
	struct block_device___5 *bdev;
	struct file___7 *swap_file;
	unsigned int old_block_size;
	struct completion comp;
	long unsigned int *frontswap_map;
	atomic_t frontswap_pages;
	spinlock_t lock;
	spinlock_t cont_lock;
	struct work_struct discard_work;
	struct swap_cluster_list discard_clusters;
	struct plist_node avail_lists[0];
};

struct inode_operations___7 {
	struct dentry___7 * (*lookup)(struct inode___7 *, struct dentry___7 *, unsigned int);
	const char * (*get_link)(struct dentry___7 *, struct inode___7 *, struct delayed_call *);
	int (*permission)(struct user_namespace *, struct inode___7 *, int);
	struct posix_acl * (*get_acl)(struct inode___7 *, int, bool);
	int (*readlink)(struct dentry___7 *, char *, int);
	int (*create)(struct user_namespace *, struct inode___7 *, struct dentry___7 *, umode_t, bool);
	int (*link)(struct dentry___7 *, struct inode___7 *, struct dentry___7 *);
	int (*unlink)(struct inode___7 *, struct dentry___7 *);
	int (*symlink)(struct user_namespace *, struct inode___7 *, struct dentry___7 *, const char *);
	int (*mkdir)(struct user_namespace *, struct inode___7 *, struct dentry___7 *, umode_t);
	int (*rmdir)(struct inode___7 *, struct dentry___7 *);
	int (*mknod)(struct user_namespace *, struct inode___7 *, struct dentry___7 *, umode_t, dev_t);
	int (*rename)(struct user_namespace *, struct inode___7 *, struct dentry___7 *, struct inode___7 *, struct dentry___7 *, unsigned int);
	int (*setattr)(struct user_namespace *, struct dentry___7 *, struct iattr___7 *);
	int (*getattr)(struct user_namespace *, const struct path___7 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___7 *, char *, size_t);
	int (*fiemap)(struct inode___7 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___7 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___7 *, struct dentry___7 *, struct file___7 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace *, struct inode___7 *, struct dentry___7 *, umode_t);
	int (*set_acl)(struct user_namespace *, struct inode___7 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace *, struct dentry___7 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___7 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___7 {
	void (*fl_copy_lock)(struct file_lock___7 *, struct file_lock___7 *);
	void (*fl_release_private)(struct file_lock___7 *);
};

struct fasync_struct___7;

struct lock_manager_operations___7;

struct file_lock___7 {
	struct file_lock___7 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___7 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___7 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___7 *fl_ops;
	const struct lock_manager_operations___7 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___7 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___7 *);
	int (*lm_grant)(struct file_lock___7 *, int);
	bool (*lm_break)(struct file_lock___7 *);
	int (*lm_change)(struct file_lock___7 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___7 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___7 *);
};

struct fasync_struct___7 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___7 *fa_next;
	struct file___7 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___7 {
	struct inode___7 * (*alloc_inode)(struct super_block___7 *);
	void (*destroy_inode)(struct inode___7 *);
	void (*free_inode)(struct inode___7 *);
	void (*dirty_inode)(struct inode___7 *, int);
	int (*write_inode)(struct inode___7 *, struct writeback_control___4 *);
	int (*drop_inode)(struct inode___7 *);
	void (*evict_inode)(struct inode___7 *);
	void (*put_super)(struct super_block___7 *);
	int (*sync_fs)(struct super_block___7 *, int);
	int (*freeze_super)(struct super_block___7 *);
	int (*freeze_fs)(struct super_block___7 *);
	int (*thaw_super)(struct super_block___7 *);
	int (*unfreeze_fs)(struct super_block___7 *);
	int (*statfs)(struct dentry___7 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___7 *, int *, char *);
	void (*umount_begin)(struct super_block___7 *);
	int (*show_options)(struct seq_file___6 *, struct dentry___7 *);
	int (*show_devname)(struct seq_file___6 *, struct dentry___7 *);
	int (*show_path)(struct seq_file___6 *, struct dentry___7 *);
	int (*show_stats)(struct seq_file___6 *, struct dentry___7 *);
	ssize_t (*quota_read)(struct super_block___7 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___7 *, int, const char *, size_t, loff_t);
	struct dquot___7 ** (*get_dquots)(struct inode___7 *);
	long int (*nr_cached_objects)(struct super_block___7 *, struct shrink_control___4 *);
	long int (*free_cached_objects)(struct super_block___7 *, struct shrink_control___4 *);
	struct file___7 * (*real_loop)(struct file___7 *);
};

struct wakeup_source___6;

struct dev_pm_info___6 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___6 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___8 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___6;

struct bus_type___6;

struct device_driver___6;

struct dev_pm_domain___6;

struct device_node___3;

struct class___6;

struct attribute_group___6;

struct device___8 {
	struct kobject___6 kobj;
	struct device___8 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___6 *type;
	struct bus_type___6 *bus;
	struct device_driver___6 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___6 power;
	struct dev_pm_domain___6 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___3 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___3 *of_node;
	struct fwnode_handle___6 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___6 *class;
	const struct attribute_group___6 **groups;
	void (*release)(struct device___8 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct block_device___5 {
	sector_t bd_start_sect;
	struct disk_stats *bd_stats;
	long unsigned int bd_stamp;
	bool bd_read_only;
	dev_t bd_dev;
	int bd_openers;
	struct inode___7 *bd_inode;
	struct super_block___7 *bd_super;
	void *bd_claiming;
	struct device___8 bd_device;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct kobject___6 *bd_holder_dir;
	u8 bd_partno;
	spinlock_t bd_size_lock;
	struct gendisk___5 *bd_disk;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	struct super_block___7 *bd_fsfreeze_sb;
	struct partition_meta_info *bd_meta_info;
};

struct seq_file___6 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___6 *op;
	int poll_event;
	const struct file___7 *file;
	void *private;
};

typedef void bio_end_io_t___5(struct bio___5 *);

struct bio_vec___6 {
	struct page___8 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___5;

struct bio___5 {
	struct bio___5 *bi_next;
	struct block_device___5 *bi_bdev;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	atomic_t __bi_remaining;
	struct bvec_iter bi_iter;
	bio_end_io_t___5 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___3 *bi_blkg;
	struct bio_issue bi_issue;
	u64 bi_iocost_cost;
	struct bio_crypt_ctx *bi_crypt_context;
	union {
		struct bio_integrity_payload___5 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___6 *bi_io_vec;
	struct bio_set___5 *bi_pool;
	struct bio_vec___6 bi_inline_vecs[0];
};

struct kernfs_root___6;

struct kernfs_elem_dir___6 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___6 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___6;

struct kernfs_root___6 {
	struct kernfs_node___6 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___6 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___6 {
	struct kernfs_node___6 *target_kn;
};

struct kernfs_ops___6;

struct kernfs_elem_attr___6 {
	const struct kernfs_ops___6 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___6 *notify_next;
};

struct kernfs_node___6 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___6 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___6 dir;
		struct kernfs_elem_symlink___6 symlink;
		struct kernfs_elem_attr___6 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___6;

struct kernfs_ops___6 {
	int (*open)(struct kernfs_open_file___6 *);
	void (*release)(struct kernfs_open_file___6 *);
	int (*seq_show)(struct seq_file___6 *, void *);
	void * (*seq_start)(struct seq_file___6 *, loff_t *);
	void * (*seq_next)(struct seq_file___6 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___6 *, void *);
	ssize_t (*read)(struct kernfs_open_file___6 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___6 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___6 *, struct poll_table_struct *);
	int (*mmap)(struct kernfs_open_file___6 *, struct vm_area_struct___8 *);
};

struct kernfs_syscall_ops___6 {
	int (*show_options)(struct seq_file___6 *, struct kernfs_root___6 *);
	int (*mkdir)(struct kernfs_node___6 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___6 *);
	int (*rename)(struct kernfs_node___6 *, struct kernfs_node___6 *, const char *);
	int (*show_path)(struct seq_file___6 *, struct kernfs_node___6 *, struct kernfs_root___6 *);
};

struct kernfs_open_file___6 {
	struct kernfs_node___6 *kn;
	struct file___7 *file;
	struct seq_file___6 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped;
	bool released;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___7 *vm_ops;
};

struct bin_attribute___6;

struct attribute_group___6 {
	const char *name;
	umode_t (*is_visible)(struct kobject___6 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___6 *, struct bin_attribute___6 *, int);
	struct attribute **attrs;
	struct bin_attribute___6 **bin_attrs;
};

struct bin_attribute___6 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___7 * (*f_mapping)();
	ssize_t (*read)(struct file___7 *, struct kobject___6 *, struct bin_attribute___6 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___7 *, struct kobject___6 *, struct bin_attribute___6 *, char *, loff_t, size_t);
	int (*mmap)(struct file___7 *, struct kobject___6 *, struct bin_attribute___6 *, struct vm_area_struct___8 *);
};

struct sysfs_ops___6 {
	ssize_t (*show)(struct kobject___6 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___6 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___6;

struct kset___6 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___6 kobj;
	const struct kset_uevent_ops___6 *uevent_ops;
};

struct kobj_type___6 {
	void (*release)(struct kobject___6 *);
	const struct sysfs_ops___6 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___6 **default_groups;
	const struct kobj_ns_type_operations * (*child_ns_type)(struct kobject___6 *);
	const void * (*namespace)(struct kobject___6 *);
	void (*get_ownership)(struct kobject___6 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___6 {
	int (* const filter)(struct kset___6 *, struct kobject___6 *);
	const char * (* const name)(struct kset___6 *, struct kobject___6 *);
	int (* const uevent)(struct kset___6 *, struct kobject___6 *, struct kobj_uevent_env *);
};

struct dev_pm_ops___6 {
	int (*prepare)(struct device___8 *);
	void (*complete)(struct device___8 *);
	int (*suspend)(struct device___8 *);
	int (*resume)(struct device___8 *);
	int (*freeze)(struct device___8 *);
	int (*thaw)(struct device___8 *);
	int (*poweroff)(struct device___8 *);
	int (*restore)(struct device___8 *);
	int (*suspend_late)(struct device___8 *);
	int (*resume_early)(struct device___8 *);
	int (*freeze_late)(struct device___8 *);
	int (*thaw_early)(struct device___8 *);
	int (*poweroff_late)(struct device___8 *);
	int (*restore_early)(struct device___8 *);
	int (*suspend_noirq)(struct device___8 *);
	int (*resume_noirq)(struct device___8 *);
	int (*freeze_noirq)(struct device___8 *);
	int (*thaw_noirq)(struct device___8 *);
	int (*poweroff_noirq)(struct device___8 *);
	int (*restore_noirq)(struct device___8 *);
	int (*runtime_suspend)(struct device___8 *);
	int (*runtime_resume)(struct device___8 *);
	int (*runtime_idle)(struct device___8 *);
};

struct wakeup_source___6 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___8 *dev;
	bool active;
	bool autosleep_enabled;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___6 {
	struct dev_pm_ops___6 ops;
	int (*start)(struct device___8 *);
	void (*detach)(struct device___8 *, bool);
	int (*activate)(struct device___8 *);
	void (*sync)(struct device___8 *);
	void (*dismiss)(struct device___8 *);
};

struct bus_type___6 {
	const char *name;
	const char *dev_name;
	struct device___8 *dev_root;
	const struct attribute_group___6 **bus_groups;
	const struct attribute_group___6 **dev_groups;
	const struct attribute_group___6 **drv_groups;
	int (*match)(struct device___8 *, struct device_driver___6 *);
	int (*uevent)(struct device___8 *, struct kobj_uevent_env *);
	int (*probe)(struct device___8 *);
	void (*sync_state)(struct device___8 *);
	void (*remove)(struct device___8 *);
	void (*shutdown)(struct device___8 *);
	int (*online)(struct device___8 *);
	int (*offline)(struct device___8 *);
	int (*suspend)(struct device___8 *, pm_message_t);
	int (*resume)(struct device___8 *);
	int (*num_vf)(struct device___8 *);
	int (*dma_configure)(struct device___8 *);
	const struct dev_pm_ops___6 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___6 {
	const char *name;
	struct bus_type___6 *bus;
	struct module___7 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___8 *);
	void (*sync_state)(struct device___8 *);
	int (*remove)(struct device___8 *);
	void (*shutdown)(struct device___8 *);
	int (*suspend)(struct device___8 *, pm_message_t);
	int (*resume)(struct device___8 *);
	const struct attribute_group___6 **groups;
	const struct attribute_group___6 **dev_groups;
	const struct dev_pm_ops___6 *pm;
	void (*coredump)(struct device___8 *);
	struct driver_private *p;
};

struct device_type___6 {
	const char *name;
	const struct attribute_group___6 **groups;
	int (*uevent)(struct device___8 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___8 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___8 *);
	const struct dev_pm_ops___6 *pm;
};

struct class___6 {
	const char *name;
	struct module___7 *owner;
	const struct attribute_group___6 **class_groups;
	const struct attribute_group___6 **dev_groups;
	struct kobject___6 *dev_kobj;
	int (*dev_uevent)(struct device___8 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___8 *, umode_t *);
	void (*class_release)(struct class___6 *);
	void (*dev_release)(struct device___8 *);
	int (*shutdown_pre)(struct device___8 *);
	const struct kobj_ns_type_operations *ns_type;
	const void * (*namespace)(struct device___8 *);
	void (*get_ownership)(struct device___8 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___6 *pm;
	struct subsys_private *p;
};

struct fwnode_operations___6;

struct fwnode_handle___6 {
	struct fwnode_handle___6 *secondary;
	const struct fwnode_operations___6 *ops;
	struct device___8 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct device_node___3 {
	const char *name;
	phandle phandle;
	const char *full_name;
	struct fwnode_handle___6 fwnode;
	struct property *properties;
	struct property *deadprops;
	struct device_node___3 *parent;
	struct device_node___3 *child;
	struct device_node___3 *sibling;
	long unsigned int _flags;
	void *data;
};

struct timens_offsets {
	struct timespec64 monotonic;
	struct timespec64 boottime;
};

struct time_namespace {
	struct user_namespace *user_ns;
	struct ucounts *ucounts;
	struct ns_common ns;
	struct timens_offsets offsets;
	struct page___8 *vvar_page;
	bool frozen_offsets;
};

struct cgroup_namespace___5 {
	struct ns_common ns;
	struct user_namespace *user_ns;
	struct ucounts *ucounts;
	struct css_set___5 *root_cset;
};

struct pvclock_vcpu_time_info {
	u32 version;
	u32 pad0;
	u64 tsc_timestamp;
	u64 system_time;
	u32 tsc_to_system_mul;
	s8 tsc_shift;
	u8 flags;
	u8 pad[2];
};

struct pvclock_vsyscall_time_info {
	struct pvclock_vcpu_time_info pvti;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

enum vdso_clock_mode {
	VDSO_CLOCKMODE_NONE = 0,
	VDSO_CLOCKMODE_TSC = 1,
	VDSO_CLOCKMODE_PVCLOCK = 2,
	VDSO_CLOCKMODE_HVCLOCK = 3,
	VDSO_CLOCKMODE_MAX = 4,
	VDSO_CLOCKMODE_TIMENS = 2147483647,
};

struct arch_vdso_data {};

struct vdso_timestamp {
	u64 sec;
	u64 nsec;
};

struct vdso_data {
	u32 seq;
	s32 clock_mode;
	u64 cycle_last;
	u64 mask;
	u32 mult;
	u32 shift;
	union {
		struct vdso_timestamp basetime[12];
		struct timens_offset offset[12];
	};
	s32 tz_minuteswest;
	s32 tz_dsttime;
	u32 hrtimer_res;
	u32 __unused;
	struct arch_vdso_data arch_data;
};

struct fwnode_reference_args___6;

struct fwnode_endpoint___6;

struct fwnode_operations___6 {
	struct fwnode_handle___6 * (*get)(struct fwnode_handle___6 *);
	void (*put)(struct fwnode_handle___6 *);
	bool (*device_is_available)(const struct fwnode_handle___6 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___6 *, const struct device___8 *);
	bool (*property_present)(const struct fwnode_handle___6 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___6 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___6 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___6 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___6 *);
	struct fwnode_handle___6 * (*get_parent)(const struct fwnode_handle___6 *);
	struct fwnode_handle___6 * (*get_next_child_node)(const struct fwnode_handle___6 *, struct fwnode_handle___6 *);
	struct fwnode_handle___6 * (*get_named_child_node)(const struct fwnode_handle___6 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___6 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___6 *);
	struct fwnode_handle___6 * (*graph_get_next_endpoint)(const struct fwnode_handle___6 *, struct fwnode_handle___6 *);
	struct fwnode_handle___6 * (*graph_get_remote_endpoint)(const struct fwnode_handle___6 *);
	struct fwnode_handle___6 * (*graph_get_port_parent)(struct fwnode_handle___6 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___6 *, struct fwnode_endpoint___6 *);
	int (*add_links)(struct fwnode_handle___6 *);
};

struct fwnode_endpoint___6 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___6 *local_fwnode;
};

struct fwnode_reference_args___6 {
	struct fwnode_handle___6 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct irq_fwspec___3 {
	struct fwnode_handle___6 *fwnode;
	int param_count;
	u32 param[16];
};

struct irq_domain_ops___3 {
	int (*match)(struct irq_domain___3 *, struct device_node___3 *, enum irq_domain_bus_token);
	int (*select)(struct irq_domain___3 *, struct irq_fwspec___3 *, enum irq_domain_bus_token);
	int (*map)(struct irq_domain___3 *, unsigned int, irq_hw_number_t);
	void (*unmap)(struct irq_domain___3 *, unsigned int);
	int (*xlate)(struct irq_domain___3 *, struct device_node___3 *, const u32 *, unsigned int, long unsigned int *, unsigned int *);
	int (*alloc)(struct irq_domain___3 *, unsigned int, unsigned int, void *);
	void (*free)(struct irq_domain___3 *, unsigned int, unsigned int);
	int (*activate)(struct irq_domain___3 *, struct irq_data *, bool);
	void (*deactivate)(struct irq_domain___3 *, struct irq_data *);
	int (*translate)(struct irq_domain___3 *, struct irq_fwspec___3 *, long unsigned int *, unsigned int *);
};

struct ms_hyperv_tsc_page {
	volatile u32 tsc_sequence;
	u32 reserved1;
	volatile u64 tsc_scale;
	volatile s64 tsc_offset;
};

enum {
	TASKSTATS_CMD_UNSPEC = 0,
	TASKSTATS_CMD_GET = 1,
	TASKSTATS_CMD_NEW = 2,
	__TASKSTATS_CMD_MAX = 3,
};

enum ucount_type {
	UCOUNT_USER_NAMESPACES = 0,
	UCOUNT_PID_NAMESPACES = 1,
	UCOUNT_UTS_NAMESPACES = 2,
	UCOUNT_IPC_NAMESPACES = 3,
	UCOUNT_NET_NAMESPACES = 4,
	UCOUNT_MNT_NAMESPACES = 5,
	UCOUNT_CGROUP_NAMESPACES = 6,
	UCOUNT_TIME_NAMESPACES = 7,
	UCOUNT_INOTIFY_INSTANCES = 8,
	UCOUNT_INOTIFY_WATCHES = 9,
	UCOUNT_FANOTIFY_GROUPS = 10,
	UCOUNT_FANOTIFY_MARKS = 11,
	UCOUNT_RLIMIT_NPROC = 12,
	UCOUNT_RLIMIT_MSGQUEUE = 13,
	UCOUNT_RLIMIT_SIGPENDING = 14,
	UCOUNT_RLIMIT_MEMLOCK = 15,
	UCOUNT_COUNTS = 16,
};

enum {
	HI_SOFTIRQ = 0,
	TIMER_SOFTIRQ = 1,
	NET_TX_SOFTIRQ = 2,
	NET_RX_SOFTIRQ = 3,
	BLOCK_SOFTIRQ = 4,
	IRQ_POLL_SOFTIRQ = 5,
	TASKLET_SOFTIRQ = 6,
	SCHED_SOFTIRQ = 7,
	HRTIMER_SOFTIRQ = 8,
	RCU_SOFTIRQ = 9,
	NR_SOFTIRQS = 10,
};

enum cpu_usage_stat {
	CPUTIME_USER = 0,
	CPUTIME_NICE = 1,
	CPUTIME_SYSTEM = 2,
	CPUTIME_SOFTIRQ = 3,
	CPUTIME_IRQ = 4,
	CPUTIME_IDLE = 5,
	CPUTIME_IOWAIT = 6,
	CPUTIME_STEAL = 7,
	CPUTIME_GUEST = 8,
	CPUTIME_GUEST_NICE = 9,
	NR_STATS = 10,
};

struct kernel_param_ops___6 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___6 *);
	int (*get)(char *, const struct kernel_param___6 *);
	void (*free)(void *);
};

struct kparam_array___6;

struct kernel_param___6 {
	const char *name;
	struct module___7 *mod;
	const struct kernel_param_ops___6 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___6 *arr;
	};
};

struct kparam_array___6 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___6 *ops;
	void *elem;
};

struct module_attribute___6 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___6 *, struct module_kobject___6 *, char *);
	ssize_t (*store)(struct module_attribute___6 *, struct module_kobject___6 *, const char *, size_t);
	void (*setup)(struct module___7 *, const char *);
	int (*test)(struct module___7 *);
	void (*free)(struct module___7 *);
};

enum bpf_cgroup_storage_type {
	BPF_CGROUP_STORAGE_SHARED = 0,
	BPF_CGROUP_STORAGE_PERCPU = 1,
	__BPF_CGROUP_STORAGE_MAX = 2,
};

enum bpf_tramp_prog_type {
	BPF_TRAMP_FENTRY = 0,
	BPF_TRAMP_FEXIT = 1,
	BPF_TRAMP_MODIFY_RETURN = 2,
	BPF_TRAMP_MAX = 3,
	BPF_TRAMP_REPLACE = 4,
};

enum cgroup_bpf_attach_type {
	CGROUP_BPF_ATTACH_TYPE_INVALID = 0,
	CGROUP_INET_INGRESS = 0,
	CGROUP_INET_EGRESS = 1,
	CGROUP_INET_SOCK_CREATE = 2,
	CGROUP_SOCK_OPS = 3,
	CGROUP_DEVICE = 4,
	CGROUP_INET4_BIND = 5,
	CGROUP_INET6_BIND = 6,
	CGROUP_INET4_CONNECT = 7,
	CGROUP_INET6_CONNECT = 8,
	CGROUP_INET4_POST_BIND = 9,
	CGROUP_INET6_POST_BIND = 10,
	CGROUP_UDP4_SENDMSG = 11,
	CGROUP_UDP6_SENDMSG = 12,
	CGROUP_SYSCTL = 13,
	CGROUP_UDP4_RECVMSG = 14,
	CGROUP_UDP6_RECVMSG = 15,
	CGROUP_GETSOCKOPT = 16,
	CGROUP_SETSOCKOPT = 17,
	CGROUP_INET4_GETPEERNAME = 18,
	CGROUP_INET6_GETPEERNAME = 19,
	CGROUP_INET4_GETSOCKNAME = 20,
	CGROUP_INET6_GETSOCKNAME = 21,
	CGROUP_INET_SOCK_RELEASE = 22,
	MAX_CGROUP_BPF_ATTACH_TYPE = 23,
};

enum psi_task_count {
	NR_IOWAIT = 0,
	NR_MEMSTALL = 1,
	NR_RUNNING = 2,
	NR_ONCPU = 3,
	NR_MEMSTALL_RUNNING = 4,
	NR_PSI_TASK_COUNTS = 5,
};

enum psi_states {
	PSI_IO_SOME = 0,
	PSI_IO_FULL = 1,
	PSI_MEM_SOME = 2,
	PSI_MEM_FULL = 3,
	PSI_CPU_SOME = 4,
	PSI_CPU_FULL = 5,
	PSI_NONIDLE = 6,
	NR_PSI_STATES = 7,
};

enum psi_aggregators {
	PSI_AVGS = 0,
	PSI_POLL = 1,
	NR_PSI_AGGREGATORS = 2,
};

enum cgroup_subsys_id {
	cpuset_cgrp_id = 0,
	cpu_cgrp_id = 1,
	cpuacct_cgrp_id = 2,
	io_cgrp_id = 3,
	memory_cgrp_id = 4,
	devices_cgrp_id = 5,
	freezer_cgrp_id = 6,
	net_cls_cgrp_id = 7,
	perf_event_cgrp_id = 8,
	net_prio_cgrp_id = 9,
	hugetlb_cgrp_id = 10,
	pids_cgrp_id = 11,
	rdma_cgrp_id = 12,
	misc_cgrp_id = 13,
	CGROUP_SUBSYS_COUNT = 14,
};

struct cftype___5;

struct cgroup_subsys___5 {
	struct cgroup_subsys_state___5 * (*css_alloc)(struct cgroup_subsys_state___5 *);
	int (*css_online)(struct cgroup_subsys_state___5 *);
	void (*css_offline)(struct cgroup_subsys_state___5 *);
	void (*css_released)(struct cgroup_subsys_state___5 *);
	void (*css_free)(struct cgroup_subsys_state___5 *);
	void (*css_reset)(struct cgroup_subsys_state___5 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___5 *, int);
	int (*css_extra_stat_show)(struct seq_file___6 *, struct cgroup_subsys_state___5 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___9 *, struct css_set___5 *);
	void (*cancel_fork)(struct task_struct___9 *, struct css_set___5 *);
	void (*fork)(struct task_struct___9 *);
	void (*exit)(struct task_struct___9 *);
	void (*release)(struct task_struct___9 *);
	void (*bind)(struct cgroup_subsys_state___5 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___5 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___5 *dfl_cftypes;
	struct cftype___5 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___5 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___5 *updated_children;
	struct cgroup___5 *updated_next;
};

struct cgroup_root___5 {
	struct kernfs_root___6 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___5 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___5 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___5 *ss;
	struct list_head node;
	struct kernfs_ops___6 *kf_ops;
	int (*open)(struct kernfs_open_file___6 *);
	void (*release)(struct kernfs_open_file___6 *);
	u64 (*read_u64)(struct cgroup_subsys_state___5 *, struct cftype___5 *);
	s64 (*read_s64)(struct cgroup_subsys_state___5 *, struct cftype___5 *);
	int (*seq_show)(struct seq_file___6 *, void *);
	void * (*seq_start)(struct seq_file___6 *, loff_t *);
	void * (*seq_next)(struct seq_file___6 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___6 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___5 *, struct cftype___5 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___5 *, struct cftype___5 *, s64);
	ssize_t (*write)(struct kernfs_open_file___6 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___6 *, struct poll_table_struct *);
};

struct block_device_operations___5;

struct gendisk___5 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	short unsigned int events;
	short unsigned int event_flags;
	struct xarray part_tbl;
	struct block_device___5 *part0;
	const struct block_device_operations___5 *fops;
	struct request_queue___5 *queue;
	void *private_data;
	int flags;
	long unsigned int state;
	struct mutex open_mutex;
	unsigned int open_partitions;
	struct backing_dev_info___4 *bdi;
	struct kobject___6 *slave_dir;
	struct list_head slave_bdevs;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___6 integrity_kobj;
	struct cdrom_device_info *cdi;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	u64 diskseq;
};

struct bio_integrity_payload___5 {
	struct bio___5 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___6 *bip_vec;
	struct bio_vec___6 bip_inline_vecs[0];
};

struct blkcg___4;

struct blkg_policy_data___4;

struct blkcg_gq___3 {
	struct request_queue___5 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___4 *blkcg;
	struct blkcg_gq___3 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_iostat_set *iostat_cpu;
	struct blkg_iostat_set iostat;
	struct blkg_policy_data___4 *pd[6];
	spinlock_t async_bio_lock;
	struct bio_list___5 async_bios;
	struct work_struct async_bio_work;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
	struct callback_head callback_head;
};

typedef void integrity_prepare_fn___5(struct request___5 *);

typedef void integrity_complete_fn___5(struct request___5 *, unsigned int);

struct blk_integrity_profile___5 {
	integrity_processing_fn *generate_fn;
	integrity_processing_fn *verify_fn;
	integrity_prepare_fn___5 *prepare_fn;
	integrity_complete_fn___5 *complete_fn;
	const char *name;
};

struct block_device_operations___5 {
	blk_qc_t (*submit_bio)(struct bio___5 *);
	int (*open)(struct block_device___5 *, fmode_t);
	void (*release)(struct gendisk___5 *, fmode_t);
	int (*rw_page)(struct block_device___5 *, sector_t, struct page___8 *, unsigned int);
	int (*ioctl)(struct block_device___5 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___5 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___5 *, unsigned int);
	void (*unlock_native_capacity)(struct gendisk___5 *);
	int (*getgeo)(struct block_device___5 *, struct hd_geometry *);
	int (*set_read_only)(struct block_device___5 *, bool);
	void (*swap_slot_free_notify)(struct block_device___5 *, long unsigned int);
	int (*report_zones)(struct gendisk___5 *, sector_t, unsigned int, report_zones_cb, void *);
	char * (*devnode)(struct gendisk___5 *, umode_t *);
	struct module___7 *owner;
	const struct pr_ops *pr_ops;
	int (*alternative_gpt_sector)(struct gendisk___5 *, sector_t *);
};

typedef void rq_end_io_fn___5(struct request___5 *, blk_status_t);

struct request___5 {
	struct request_queue___5 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int tag;
	int internal_tag;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___5 *bio;
	struct bio___5 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct llist_node ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___6 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___5 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___5 *saved_end_io;
		} flush;
	};
	struct gendisk___5 *rq_disk;
	struct block_device___5 *part;
	u64 alloc_time_ns;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int stats_sectors;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	struct bio_crypt_ctx *crypt_ctx;
	struct blk_ksm_keyslot *crypt_keyslot;
	short unsigned int write_hint;
	short unsigned int ioprio;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___5 *end_io;
	void *end_io_data;
};

struct elevator_type___5;

struct elevator_mq_ops___5 {
	int (*init_sched)(struct request_queue___5 *, struct elevator_type___5 *);
	void (*exit_sched)(struct elevator_queue___5 *);
	int (*init_hctx)(struct blk_mq_hw_ctx *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx *, unsigned int);
	void (*depth_updated)(struct blk_mq_hw_ctx *);
	bool (*allow_merge)(struct request_queue___5 *, struct request___5 *, struct bio___5 *);
	bool (*bio_merge)(struct request_queue___5 *, struct bio___5 *, unsigned int);
	int (*request_merge)(struct request_queue___5 *, struct request___5 **, struct bio___5 *);
	void (*request_merged)(struct request_queue___5 *, struct request___5 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___5 *, struct request___5 *, struct request___5 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___5 *);
	void (*finish_request)(struct request___5 *);
	void (*insert_requests)(struct blk_mq_hw_ctx *, struct list_head *, bool);
	struct request___5 * (*dispatch_request)(struct blk_mq_hw_ctx *);
	bool (*has_work)(struct blk_mq_hw_ctx *);
	void (*completed_request)(struct request___5 *, u64);
	void (*requeue_request)(struct request___5 *);
	struct request___5 * (*former_request)(struct request_queue___5 *, struct request___5 *);
	struct request___5 * (*next_request)(struct request_queue___5 *, struct request___5 *);
	void (*init_icq)(struct io_cq___5 *);
	void (*exit_icq)(struct io_cq___5 *);
};

struct elv_fs_entry___5;

struct elevator_type___5 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___5 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___5 *elevator_attrs;
	const char *elevator_name;
	const char *elevator_alias;
	const unsigned int elevator_features;
	struct module___7 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
};

struct elevator_queue___5 {
	struct elevator_type___5 *type;
	void *elevator_data;
	struct kobject___6 kobj;
	struct mutex sysfs_lock;
	unsigned int registered;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hlist_head hash[64];
};

struct elv_fs_entry___5 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___5 *, char *);
	ssize_t (*store)(struct elevator_queue___5 *, const char *, size_t);
};

struct blkcg_policy_data___4;

struct blkcg___4 {
	struct cgroup_subsys_state___5 css;
	spinlock_t lock;
	refcount_t online_pin;
	struct xarray blkg_tree;
	struct blkcg_gq___3 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___4 *cpd[6];
	struct list_head all_blkcgs_node;
	char fc_app_id[129];
	struct list_head cgwb_list;
};

struct blkcg_policy_data___4 {
	struct blkcg___4 *blkcg;
	int plid;
};

struct blkg_policy_data___4 {
	struct blkcg_gq___3 *blkg;
	int plid;
};

struct mem_cgroup_reclaim_iter___4 {
	struct mem_cgroup___4 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___4 {
	struct lruvec___4 lruvec;
	struct lruvec_stats_percpu *lruvec_stats_percpu;
	struct lruvec_stats lruvec_stats;
	long unsigned int lru_zone_size[25];
	struct mem_cgroup_reclaim_iter___4 iter;
	struct shrinker_info *shrinker_info;
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	struct mem_cgroup___4 *memcg;
};

struct obj_cgroup___4 {
	struct percpu_ref refcnt;
	struct mem_cgroup___4 *memcg;
	atomic_t nr_charged_bytes;
	union {
		struct list_head list;
		struct callback_head rcu;
	};
};

struct linux_binprm___2;

struct vdso_exception_table_entry {
	int insn;
	int fixup;
};

struct qspinlock___2 {
	union {
		atomic_t val;
		struct {
			u8 locked;
			u8 pending;
		};
		struct {
			u16 locked_pending;
			u16 tail;
		};
	};
	int: 32;
};

typedef struct qspinlock___2 arch_spinlock_t___2;

struct raw_spinlock___2 {
	arch_spinlock_t___2 raw_lock;
};

typedef struct raw_spinlock___2 raw_spinlock_t___2;

struct spinlock___2 {
	union {
		struct raw_spinlock___2 rlock;
	};
	int: 32;
};

typedef struct spinlock___2 spinlock_t___2;

struct wait_queue_head___2 {
	spinlock_t___2 lock;
	struct list_head head;
};

typedef struct wait_queue_head___2 wait_queue_head_t___2;

struct swait_queue_head___2 {
	raw_spinlock_t___2 lock;
	struct list_head task_list;
};

struct completion___2 {
	unsigned int done;
	struct swait_queue_head___2 wait;
};

struct ctl_table___2;

typedef int proc_handler___2(struct ctl_table___2 *, int, void *, size_t *, loff_t *);

struct ctl_table_poll___2;

struct ctl_table___2 {
	const char *procname;
	void *data;
	int maxlen;
	umode_t mode;
	struct ctl_table___2 *child;
	proc_handler___2 *proc_handler;
	struct ctl_table_poll___2 *poll;
	void *extra1;
	void *extra2;
};

struct ctl_table_poll___2 {
	atomic_t event;
	wait_queue_head_t___2 wait;
};

struct ctl_table_header___2;

struct ctl_node___2 {
	struct rb_node node;
	struct ctl_table_header___2 *header;
};

struct ctl_table_root___2;

struct ctl_table_set___2;

struct ctl_dir___2;

struct ctl_table_header___2 {
	union {
		struct {
			struct ctl_table___2 *ctl_table;
			int used;
			int count;
			int nreg;
		};
		struct callback_head rcu;
	};
	struct completion___2 *unregistering;
	struct ctl_table___2 *ctl_table_arg;
	struct ctl_table_root___2 *root;
	struct ctl_table_set___2 *set;
	struct ctl_dir___2 *parent;
	struct ctl_node___2 *node;
	struct hlist_head inodes;
};

struct ctl_dir___2 {
	struct ctl_table_header___2 header;
	struct rb_root root;
};

struct ctl_table_set___2 {
	int (*is_seen)(struct ctl_table_set___2 *);
	struct ctl_dir___2 dir;
};

struct ctl_table_root___2 {
	struct ctl_table_set___2 default_set;
	struct ctl_table_set___2 * (*lookup)(struct ctl_table_root___2 *);
	void (*set_ownership)(struct ctl_table_header___2 *, struct ctl_table___2 *, kuid_t *, kgid_t *);
	int (*permissions)(struct ctl_table_header___2 *, struct ctl_table___2 *);
};

struct cpuinfo_x86 {
	__u8 x86;
	__u8 x86_vendor;
	__u8 x86_model;
	__u8 x86_stepping;
	int x86_tlbsize;
	__u32 vmx_capability[3];
	__u8 x86_virt_bits;
	__u8 x86_phys_bits;
	__u8 x86_coreid_bits;
	__u8 cu_id;
	__u32 extended_cpuid_level;
	int cpuid_level;
	union {
		__u32 x86_capability[21];
		long unsigned int x86_capability_alignment;
	};
	char x86_vendor_id[16];
	char x86_model_id[64];
	unsigned int x86_cache_size;
	int x86_cache_alignment;
	int x86_cache_max_rmid;
	int x86_cache_occ_scale;
	int x86_cache_mbm_width_offset;
	int x86_power;
	long unsigned int loops_per_jiffy;
	u16 x86_max_cores;
	u16 apicid;
	u16 initial_apicid;
	u16 x86_clflush_size;
	u16 booted_cores;
	u16 phys_proc_id;
	u16 logical_proc_id;
	u16 cpu_core_id;
	u16 cpu_die_id;
	u16 logical_die_id;
	u16 cpu_index;
	bool smt_active;
	u32 microcode;
	u8 x86_cache_bits;
	unsigned int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

enum syscall_work_bit {
	SYSCALL_WORK_BIT_SECCOMP = 0,
	SYSCALL_WORK_BIT_SYSCALL_TRACEPOINT = 1,
	SYSCALL_WORK_BIT_SYSCALL_TRACE = 2,
	SYSCALL_WORK_BIT_SYSCALL_EMU = 3,
	SYSCALL_WORK_BIT_SYSCALL_AUDIT = 4,
	SYSCALL_WORK_BIT_SYSCALL_USER_DISPATCH = 5,
	SYSCALL_WORK_BIT_SYSCALL_EXIT_TRAP = 6,
};

struct seccomp_data {
	int nr;
	__u32 arch;
	__u64 instruction_pointer;
	__u64 args[6];
};

struct trace_event_file___2;

struct trace_event_buffer___2 {
	struct trace_buffer *buffer;
	struct ring_buffer_event *event;
	struct trace_event_file___2 *trace_file;
	void *entry;
	unsigned int trace_ctx;
	struct pt_regs *regs;
};

struct trace_event_file___2 {
	struct list_head list;
	struct trace_event_call___4 *event_call;
	struct event_filter *filter;
	struct dentry___6 *dir;
	struct trace_array *tr;
	struct trace_subsystem_dir *system;
	struct list_head triggers;
	long unsigned int flags;
	atomic_t sm_ref;
	atomic_t tm_ref;
};

enum x86_pf_error_code {
	X86_PF_PROT = 1,
	X86_PF_WRITE = 2,
	X86_PF_USER = 4,
	X86_PF_RSVD = 8,
	X86_PF_INSTR = 16,
	X86_PF_PK = 32,
	X86_PF_SGX = 32768,
};

struct trace_event_raw_emulate_vsyscall {
	struct trace_entry ent;
	int nr;
	char __data[0];
};

struct trace_event_data_offsets_emulate_vsyscall {};

typedef void (*btf_trace_emulate_vsyscall)(void *, int);

enum {
	EMULATE = 0,
	XONLY = 1,
	NONE = 2,
};

enum perf_type_id {
	PERF_TYPE_HARDWARE = 0,
	PERF_TYPE_SOFTWARE = 1,
	PERF_TYPE_TRACEPOINT = 2,
	PERF_TYPE_HW_CACHE = 3,
	PERF_TYPE_RAW = 4,
	PERF_TYPE_BREAKPOINT = 5,
	PERF_TYPE_MAX = 6,
};

enum perf_hw_id {
	PERF_COUNT_HW_CPU_CYCLES = 0,
	PERF_COUNT_HW_INSTRUCTIONS = 1,
	PERF_COUNT_HW_CACHE_REFERENCES = 2,
	PERF_COUNT_HW_CACHE_MISSES = 3,
	PERF_COUNT_HW_BRANCH_INSTRUCTIONS = 4,
	PERF_COUNT_HW_BRANCH_MISSES = 5,
	PERF_COUNT_HW_BUS_CYCLES = 6,
	PERF_COUNT_HW_STALLED_CYCLES_FRONTEND = 7,
	PERF_COUNT_HW_STALLED_CYCLES_BACKEND = 8,
	PERF_COUNT_HW_REF_CPU_CYCLES = 9,
	PERF_COUNT_HW_MAX = 10,
};

enum perf_hw_cache_id {
	PERF_COUNT_HW_CACHE_L1D = 0,
	PERF_COUNT_HW_CACHE_L1I = 1,
	PERF_COUNT_HW_CACHE_LL = 2,
	PERF_COUNT_HW_CACHE_DTLB = 3,
	PERF_COUNT_HW_CACHE_ITLB = 4,
	PERF_COUNT_HW_CACHE_BPU = 5,
	PERF_COUNT_HW_CACHE_NODE = 6,
	PERF_COUNT_HW_CACHE_MAX = 7,
};

enum perf_hw_cache_op_id {
	PERF_COUNT_HW_CACHE_OP_READ = 0,
	PERF_COUNT_HW_CACHE_OP_WRITE = 1,
	PERF_COUNT_HW_CACHE_OP_PREFETCH = 2,
	PERF_COUNT_HW_CACHE_OP_MAX = 3,
};

enum perf_hw_cache_op_result_id {
	PERF_COUNT_HW_CACHE_RESULT_ACCESS = 0,
	PERF_COUNT_HW_CACHE_RESULT_MISS = 1,
	PERF_COUNT_HW_CACHE_RESULT_MAX = 2,
};

enum perf_event_sample_format {
	PERF_SAMPLE_IP = 1,
	PERF_SAMPLE_TID = 2,
	PERF_SAMPLE_TIME = 4,
	PERF_SAMPLE_ADDR = 8,
	PERF_SAMPLE_READ = 16,
	PERF_SAMPLE_CALLCHAIN = 32,
	PERF_SAMPLE_ID = 64,
	PERF_SAMPLE_CPU = 128,
	PERF_SAMPLE_PERIOD = 256,
	PERF_SAMPLE_STREAM_ID = 512,
	PERF_SAMPLE_RAW = 1024,
	PERF_SAMPLE_BRANCH_STACK = 2048,
	PERF_SAMPLE_REGS_USER = 4096,
	PERF_SAMPLE_STACK_USER = 8192,
	PERF_SAMPLE_WEIGHT = 16384,
	PERF_SAMPLE_DATA_SRC = 32768,
	PERF_SAMPLE_IDENTIFIER = 65536,
	PERF_SAMPLE_TRANSACTION = 131072,
	PERF_SAMPLE_REGS_INTR = 262144,
	PERF_SAMPLE_PHYS_ADDR = 524288,
	PERF_SAMPLE_AUX = 1048576,
	PERF_SAMPLE_CGROUP = 2097152,
	PERF_SAMPLE_DATA_PAGE_SIZE = 4194304,
	PERF_SAMPLE_CODE_PAGE_SIZE = 8388608,
	PERF_SAMPLE_WEIGHT_STRUCT = 16777216,
	PERF_SAMPLE_MAX = 33554432,
	__PERF_SAMPLE_CALLCHAIN_EARLY = 0,
};

enum perf_branch_sample_type {
	PERF_SAMPLE_BRANCH_USER = 1,
	PERF_SAMPLE_BRANCH_KERNEL = 2,
	PERF_SAMPLE_BRANCH_HV = 4,
	PERF_SAMPLE_BRANCH_ANY = 8,
	PERF_SAMPLE_BRANCH_ANY_CALL = 16,
	PERF_SAMPLE_BRANCH_ANY_RETURN = 32,
	PERF_SAMPLE_BRANCH_IND_CALL = 64,
	PERF_SAMPLE_BRANCH_ABORT_TX = 128,
	PERF_SAMPLE_BRANCH_IN_TX = 256,
	PERF_SAMPLE_BRANCH_NO_TX = 512,
	PERF_SAMPLE_BRANCH_COND = 1024,
	PERF_SAMPLE_BRANCH_CALL_STACK = 2048,
	PERF_SAMPLE_BRANCH_IND_JUMP = 4096,
	PERF_SAMPLE_BRANCH_CALL = 8192,
	PERF_SAMPLE_BRANCH_NO_FLAGS = 16384,
	PERF_SAMPLE_BRANCH_NO_CYCLES = 32768,
	PERF_SAMPLE_BRANCH_TYPE_SAVE = 65536,
	PERF_SAMPLE_BRANCH_HW_INDEX = 131072,
	PERF_SAMPLE_BRANCH_MAX = 262144,
};

struct perf_event_mmap_page {
	__u32 version;
	__u32 compat_version;
	__u32 lock;
	__u32 index;
	__s64 offset;
	__u64 time_enabled;
	__u64 time_running;
	union {
		__u64 capabilities;
		struct {
			__u64 cap_bit0: 1;
			__u64 cap_bit0_is_deprecated: 1;
			__u64 cap_user_rdpmc: 1;
			__u64 cap_user_time: 1;
			__u64 cap_user_time_zero: 1;
			__u64 cap_user_time_short: 1;
			__u64 cap_____res: 58;
		};
	};
	__u16 pmc_width;
	__u16 time_shift;
	__u32 time_mult;
	__u64 time_offset;
	__u64 time_zero;
	__u32 size;
	__u32 __reserved_1;
	__u64 time_cycles;
	__u64 time_mask;
	__u8 __reserved[928];
	__u64 data_head;
	__u64 data_tail;
	__u64 data_offset;
	__u64 data_size;
	__u64 aux_head;
	__u64 aux_tail;
	__u64 aux_offset;
	__u64 aux_size;
};

struct pv_info {
	u16 extra_user_64bit_cs;
	const char *name;
};

typedef bool (*smp_cond_func_t)(int, void *);

enum apic_delivery_modes {
	APIC_DELIVERY_MODE_FIXED = 0,
	APIC_DELIVERY_MODE_LOWESTPRIO = 1,
	APIC_DELIVERY_MODE_SMI = 2,
	APIC_DELIVERY_MODE_NMI = 4,
	APIC_DELIVERY_MODE_INIT = 5,
	APIC_DELIVERY_MODE_EXTINT = 7,
};

struct physid_mask {
	long unsigned int mask[512];
};

typedef struct physid_mask physid_mask_t;

struct x86_pmu_capability {
	int version;
	int num_counters_gp;
	int num_counters_fixed;
	int bit_width_gp;
	int bit_width_fixed;
	unsigned int events_mask;
	int events_mask_len;
};

struct debug_store {
	u64 bts_buffer_base;
	u64 bts_index;
	u64 bts_absolute_maximum;
	u64 bts_interrupt_threshold;
	u64 pebs_buffer_base;
	u64 pebs_index;
	u64 pebs_absolute_maximum;
	u64 pebs_interrupt_threshold;
	u64 pebs_event_reset[12];
};

enum stack_type {
	STACK_TYPE_UNKNOWN = 0,
	STACK_TYPE_TASK = 1,
	STACK_TYPE_IRQ = 2,
	STACK_TYPE_SOFTIRQ = 3,
	STACK_TYPE_ENTRY = 4,
	STACK_TYPE_EXCEPTION = 5,
	STACK_TYPE_EXCEPTION_LAST = 10,
};

struct stack_info {
	enum stack_type type;
	long unsigned int *begin;
	long unsigned int *end;
	long unsigned int *next_sp;
};

struct stack_frame {
	struct stack_frame *next_frame;
	long unsigned int return_address;
};

struct stack_frame_ia32 {
	u32 next_frame;
	u32 return_address;
};

struct perf_guest_switch_msr {
	unsigned int msr;
	u64 host;
	u64 guest;
};

struct perf_guest_info_callbacks {
	int (*is_in_guest)();
	int (*is_user_mode)();
	long unsigned int (*get_guest_ip)();
	void (*handle_intel_pt_intr)();
};

struct device_attribute {
	struct attribute attr;
	ssize_t (*show)(struct device___7 *, struct device_attribute *, char *);
	ssize_t (*store)(struct device___7 *, struct device_attribute *, const char *, size_t);
};

enum perf_event_x86_regs {
	PERF_REG_X86_AX = 0,
	PERF_REG_X86_BX = 1,
	PERF_REG_X86_CX = 2,
	PERF_REG_X86_DX = 3,
	PERF_REG_X86_SI = 4,
	PERF_REG_X86_DI = 5,
	PERF_REG_X86_BP = 6,
	PERF_REG_X86_SP = 7,
	PERF_REG_X86_IP = 8,
	PERF_REG_X86_FLAGS = 9,
	PERF_REG_X86_CS = 10,
	PERF_REG_X86_SS = 11,
	PERF_REG_X86_DS = 12,
	PERF_REG_X86_ES = 13,
	PERF_REG_X86_FS = 14,
	PERF_REG_X86_GS = 15,
	PERF_REG_X86_R8 = 16,
	PERF_REG_X86_R9 = 17,
	PERF_REG_X86_R10 = 18,
	PERF_REG_X86_R11 = 19,
	PERF_REG_X86_R12 = 20,
	PERF_REG_X86_R13 = 21,
	PERF_REG_X86_R14 = 22,
	PERF_REG_X86_R15 = 23,
	PERF_REG_X86_32_MAX = 16,
	PERF_REG_X86_64_MAX = 24,
	PERF_REG_X86_XMM0 = 32,
	PERF_REG_X86_XMM1 = 34,
	PERF_REG_X86_XMM2 = 36,
	PERF_REG_X86_XMM3 = 38,
	PERF_REG_X86_XMM4 = 40,
	PERF_REG_X86_XMM5 = 42,
	PERF_REG_X86_XMM6 = 44,
	PERF_REG_X86_XMM7 = 46,
	PERF_REG_X86_XMM8 = 48,
	PERF_REG_X86_XMM9 = 50,
	PERF_REG_X86_XMM10 = 52,
	PERF_REG_X86_XMM11 = 54,
	PERF_REG_X86_XMM12 = 56,
	PERF_REG_X86_XMM13 = 58,
	PERF_REG_X86_XMM14 = 60,
	PERF_REG_X86_XMM15 = 62,
	PERF_REG_X86_XMM_MAX = 64,
};

struct perf_callchain_entry_ctx {
	struct perf_callchain_entry *entry;
	u32 max_stack;
	u32 nr;
	short int contexts;
	bool contexts_maxed;
};

struct perf_pmu_events_attr {
	struct device_attribute attr;
	u64 id;
	const char *event_str;
};

struct perf_pmu_events_ht_attr {
	struct device_attribute attr;
	u64 id;
	const char *event_str_ht;
	const char *event_str_noht;
};

struct perf_pmu_events_hybrid_attr {
	struct device_attribute attr;
	u64 id;
	const char *event_str;
	u64 pmu_type;
};

struct apic {
	void (*eoi_write)(u32, u32);
	void (*native_eoi_write)(u32, u32);
	void (*write)(u32, u32);
	u32 (*read)(u32);
	void (*wait_icr_idle)();
	u32 (*safe_wait_icr_idle)();
	void (*send_IPI)(int, int);
	void (*send_IPI_mask)(const struct cpumask *, int);
	void (*send_IPI_mask_allbutself)(const struct cpumask *, int);
	void (*send_IPI_allbutself)(int);
	void (*send_IPI_all)(int);
	void (*send_IPI_self)(int);
	u32 disable_esr;
	enum apic_delivery_modes delivery_mode;
	bool dest_mode_logical;
	u32 (*calc_dest_apicid)(unsigned int);
	u64 (*icr_read)();
	void (*icr_write)(u32, u32);
	int (*probe)();
	int (*acpi_madt_oem_check)(char *, char *);
	int (*apic_id_valid)(u32);
	int (*apic_id_registered)();
	bool (*check_apicid_used)(physid_mask_t *, int);
	void (*init_apic_ldr)();
	void (*ioapic_phys_id_map)(physid_mask_t *, physid_mask_t *);
	void (*setup_apic_routing)();
	int (*cpu_present_to_apicid)(int);
	void (*apicid_to_cpu_present)(int, physid_mask_t *);
	int (*check_phys_apicid_present)(int);
	int (*phys_pkg_id)(int, int);
	u32 (*get_apic_id)(long unsigned int);
	u32 (*set_apic_id)(unsigned int);
	int (*wakeup_secondary_cpu)(int, long unsigned int);
	void (*inquire_remote_apic)(int);
	char *name;
};

enum {
	NMI_LOCAL = 0,
	NMI_UNKNOWN = 1,
	NMI_SERR = 2,
	NMI_IO_CHECK = 3,
	NMI_MAX = 4,
};

typedef int (*nmi_handler_t)(unsigned int, struct pt_regs *);

struct nmiaction {
	struct list_head list;
	nmi_handler_t handler;
	u64 max_duration;
	long unsigned int flags;
	const char *name;
};

struct gdt_page {
	struct desc_struct gdt[16];
};

struct cyc2ns_data {
	u32 cyc2ns_mul;
	u32 cyc2ns_shift;
	u64 cyc2ns_offset;
};

struct unwind_state {
	struct stack_info stack_info;
	long unsigned int stack_mask;
	struct task_struct___8 *task;
	int graph_idx;
	bool error;
	bool got_irq;
	long unsigned int *bp;
	long unsigned int *orig_sp;
	long unsigned int ip;
	long unsigned int *next_bp;
	struct pt_regs *regs;
};

enum extra_reg_type {
	EXTRA_REG_NONE = 4294967295,
	EXTRA_REG_RSP_0 = 0,
	EXTRA_REG_RSP_1 = 1,
	EXTRA_REG_LBR = 2,
	EXTRA_REG_LDLAT = 3,
	EXTRA_REG_FE = 4,
	EXTRA_REG_MAX = 5,
};

struct event_constraint {
	union {
		long unsigned int idxmsk[1];
		u64 idxmsk64;
	};
	u64 code;
	u64 cmask;
	int weight;
	int overlap;
	int flags;
	unsigned int size;
};

struct amd_nb {
	int nb_id;
	int refcnt;
	struct perf_event___4 *owners[64];
	struct event_constraint event_constraints[64];
};

struct er_account {
	raw_spinlock_t lock;
	u64 config;
	u64 reg;
	atomic_t ref;
};

struct intel_shared_regs {
	struct er_account regs[5];
	int refcnt;
	unsigned int core_id;
};

enum intel_excl_state_type {
	INTEL_EXCL_UNUSED = 0,
	INTEL_EXCL_SHARED = 1,
	INTEL_EXCL_EXCLUSIVE = 2,
};

struct intel_excl_states {
	enum intel_excl_state_type state[64];
	bool sched_started;
};

struct intel_excl_cntrs {
	raw_spinlock_t lock;
	struct intel_excl_states states[2];
	union {
		u16 has_exclusive[2];
		u32 exclusive_present;
	};
	int refcnt;
	unsigned int core_id;
};

enum {
	X86_PERF_KFREE_SHARED = 0,
	X86_PERF_KFREE_EXCL = 1,
	X86_PERF_KFREE_MAX = 2,
};

struct cpu_hw_events {
	struct perf_event___4 *events[64];
	long unsigned int active_mask[1];
	long unsigned int dirty[1];
	int enabled;
	int n_events;
	int n_added;
	int n_txn;
	int n_txn_pair;
	int n_txn_metric;
	int assign[64];
	u64 tags[64];
	struct perf_event___4 *event_list[64];
	struct event_constraint *event_constraint[64];
	int n_excl;
	unsigned int txn_flags;
	int is_fake;
	struct debug_store *ds;
	void *ds_pebs_vaddr;
	void *ds_bts_vaddr;
	u64 pebs_enabled;
	int n_pebs;
	int n_large_pebs;
	int n_pebs_via_pt;
	int pebs_output;
	u64 pebs_data_cfg;
	u64 active_pebs_data_cfg;
	int pebs_record_size;
	int lbr_users;
	int lbr_pebs_users;
	struct perf_branch_stack lbr_stack;
	struct perf_branch_entry lbr_entries[32];
	union {
		struct er_account *lbr_sel;
		struct er_account *lbr_ctl;
	};
	u64 br_sel;
	void *last_task_ctx;
	int last_log_id;
	int lbr_select;
	void *lbr_xsave;
	u64 intel_ctrl_guest_mask;
	u64 intel_ctrl_host_mask;
	struct perf_guest_switch_msr guest_switch_msrs[64];
	u64 intel_cp_status;
	struct intel_shared_regs *shared_regs;
	struct event_constraint *constraint_list;
	struct intel_excl_cntrs *excl_cntrs;
	int excl_thread_id;
	u64 tfa_shadow;
	int n_metric;
	struct amd_nb *amd_nb;
	u64 perf_ctr_virt_mask;
	int n_pair;
	void *kfree_on_online[2];
	struct pmu___4 *pmu;
};

struct extra_reg {
	unsigned int event;
	unsigned int msr;
	u64 config_mask;
	u64 valid_mask;
	int idx;
	bool extra_msr_access;
};

union perf_capabilities {
	struct {
		u64 lbr_format: 6;
		u64 pebs_trap: 1;
		u64 pebs_arch_reg: 1;
		u64 pebs_format: 4;
		u64 smm_freeze: 1;
		u64 full_width_write: 1;
		u64 pebs_baseline: 1;
		u64 perf_metrics: 1;
		u64 pebs_output_pt_available: 1;
		u64 anythread_deprecated: 1;
	};
	u64 capabilities;
};

struct x86_pmu_quirk {
	struct x86_pmu_quirk *next;
	void (*func)();
};

enum {
	x86_lbr_exclusive_lbr = 0,
	x86_lbr_exclusive_bts = 1,
	x86_lbr_exclusive_pt = 2,
	x86_lbr_exclusive_max = 3,
};

struct x86_hybrid_pmu {
	struct pmu___4 pmu;
	const char *name;
	u8 cpu_type;
	cpumask_t supported_cpus;
	union perf_capabilities intel_cap;
	u64 intel_ctrl;
	int max_pebs_events;
	int num_counters;
	int num_counters_fixed;
	struct event_constraint unconstrained;
	u64 hw_cache_event_ids[42];
	u64 hw_cache_extra_regs[42];
	struct event_constraint *event_constraints;
	struct event_constraint *pebs_constraints;
	struct extra_reg *extra_regs;
	unsigned int late_ack: 1;
	unsigned int mid_ack: 1;
	unsigned int enabled_ack: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

enum hybrid_pmu_type {
	hybrid_big = 64,
	hybrid_small = 32,
	hybrid_big_small = 96,
};

struct x86_pmu {
	const char *name;
	int version;
	int (*handle_irq)(struct pt_regs *);
	void (*disable_all)();
	void (*enable_all)(int);
	void (*enable)(struct perf_event___4 *);
	void (*disable)(struct perf_event___4 *);
	void (*add)(struct perf_event___4 *);
	void (*del)(struct perf_event___4 *);
	void (*read)(struct perf_event___4 *);
	int (*hw_config)(struct perf_event___4 *);
	int (*schedule_events)(struct cpu_hw_events *, int, int *);
	unsigned int eventsel;
	unsigned int perfctr;
	int (*addr_offset)(int, bool);
	int (*rdpmc_index)(int);
	u64 (*event_map)(int);
	int max_events;
	int num_counters;
	int num_counters_fixed;
	int cntval_bits;
	u64 cntval_mask;
	union {
		long unsigned int events_maskl;
		long unsigned int events_mask[1];
	};
	int events_mask_len;
	int apic;
	u64 max_period;
	struct event_constraint * (*get_event_constraints)(struct cpu_hw_events *, int, struct perf_event___4 *);
	void (*put_event_constraints)(struct cpu_hw_events *, struct perf_event___4 *);
	void (*start_scheduling)(struct cpu_hw_events *);
	void (*commit_scheduling)(struct cpu_hw_events *, int, int);
	void (*stop_scheduling)(struct cpu_hw_events *);
	struct event_constraint *event_constraints;
	struct x86_pmu_quirk *quirks;
	int perfctr_second_write;
	u64 (*limit_period)(struct perf_event___4 *, u64);
	unsigned int late_ack: 1;
	unsigned int mid_ack: 1;
	unsigned int enabled_ack: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int attr_rdpmc_broken;
	int attr_rdpmc;
	struct attribute **format_attrs;
	ssize_t (*events_sysfs_show)(char *, u64);
	const struct attribute_group___5 **attr_update;
	long unsigned int attr_freeze_on_smi;
	int (*cpu_prepare)(int);
	void (*cpu_starting)(int);
	void (*cpu_dying)(int);
	void (*cpu_dead)(int);
	void (*check_microcode)();
	void (*sched_task)(struct perf_event_context *, bool);
	u64 intel_ctrl;
	union perf_capabilities intel_cap;
	unsigned int bts: 1;
	unsigned int bts_active: 1;
	unsigned int pebs: 1;
	unsigned int pebs_active: 1;
	unsigned int pebs_broken: 1;
	unsigned int pebs_prec_dist: 1;
	unsigned int pebs_no_tlb: 1;
	unsigned int pebs_no_isolation: 1;
	unsigned int pebs_block: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int pebs_record_size;
	int pebs_buffer_size;
	int max_pebs_events;
	void (*drain_pebs)(struct pt_regs *, struct perf_sample_data *);
	struct event_constraint *pebs_constraints;
	void (*pebs_aliases)(struct perf_event___4 *);
	long unsigned int large_pebs_flags;
	u64 rtm_abort_event;
	unsigned int lbr_tos;
	unsigned int lbr_from;
	unsigned int lbr_to;
	unsigned int lbr_info;
	unsigned int lbr_nr;
	union {
		u64 lbr_sel_mask;
		u64 lbr_ctl_mask;
	};
	union {
		const int *lbr_sel_map;
		int *lbr_ctl_map;
	};
	bool lbr_double_abort;
	bool lbr_pt_coexist;
	unsigned int lbr_depth_mask: 8;
	unsigned int lbr_deep_c_reset: 1;
	unsigned int lbr_lip: 1;
	unsigned int lbr_cpl: 1;
	unsigned int lbr_filter: 1;
	unsigned int lbr_call_stack: 1;
	unsigned int lbr_mispred: 1;
	unsigned int lbr_timed_lbr: 1;
	unsigned int lbr_br_type: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	void (*lbr_reset)();
	void (*lbr_read)(struct cpu_hw_events *);
	void (*lbr_save)(void *);
	void (*lbr_restore)(void *);
	atomic_t lbr_exclusive[3];
	int num_topdown_events;
	u64 (*update_topdown_event)(struct perf_event___4 *);
	int (*set_topdown_event_period)(struct perf_event___4 *);
	void (*swap_task_ctx)(struct perf_event_context *, struct perf_event_context *);
	unsigned int amd_nb_constraints: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u64 perf_ctr_pair_en;
	struct extra_reg *extra_regs;
	unsigned int flags;
	struct perf_guest_switch_msr * (*guest_get_msrs)(int *);
	int (*check_period)(struct perf_event___4 *, u64);
	int (*aux_output_match)(struct perf_event___4 *);
	int (*filter_match)(struct perf_event___4 *);
	int num_hybrid_pmus;
	struct x86_hybrid_pmu *hybrid_pmu;
	u8 (*get_hybrid_cpu_type)();
};

struct sched_state {
	int weight;
	int event;
	int counter;
	int unassigned;
	int nr_gp;
	u64 used;
};

struct perf_sched {
	int max_weight;
	int max_events;
	int max_gp;
	int saved_states;
	struct event_constraint **constraints;
	struct sched_state state;
	struct sched_state saved[2];
};

typedef struct {
	pgdval_t pgd;
} pgd_t___2;

typedef struct {
	p4dval_t p4d;
} p4d_t___2;

typedef struct {
	pudval_t pud;
} pud_t___2;

typedef struct {
	pmdval_t pmd;
} pmd_t___2;

struct thread_struct___5;

struct pv_cpu_ops___4 {
	void (*io_delay)();
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	void (*write_cr4)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___5 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(long unsigned int);
	void (*invalidate_io_bitmap)();
	void (*update_io_bitmap)();
	void (*wbinvd)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int);
	void (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_msr_safe)(unsigned int, int *);
	int (*write_msr_safe)(unsigned int, unsigned int, unsigned int);
	u64 (*read_pmc)(int);
	void (*start_context_switch)(struct task_struct___9 *);
	void (*end_context_switch)(struct task_struct___9 *);
};

struct fpstate___2 {
	unsigned int size;
	unsigned int user_size;
	u64 xfeatures;
	u64 user_xfeatures;
	u64 xfd;
	unsigned int is_valloc;
	unsigned int is_guest;
	unsigned int is_confidential;
	unsigned int in_use;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	union fpregs_state regs;
};

struct fpu___2 {
	unsigned int last_cpu;
	long unsigned int avx512_timestamp;
	struct fpstate___2 *fpstate;
	struct fpstate___2 *__task_fpstate;
	struct fpu_state_perm perm;
	long: 64;
	long: 64;
	struct fpstate___2 __fpstate;
};

struct thread_struct___5 {
	struct desc_struct tls_array[3];
	long unsigned int sp;
	short unsigned int es;
	short unsigned int ds;
	short unsigned int fsindex;
	short unsigned int gsindex;
	long unsigned int fsbase;
	long unsigned int gsbase;
	struct perf_event *ptrace_bps[4];
	long unsigned int virtual_dr6;
	long unsigned int ptrace_dr7;
	long unsigned int cr2;
	long unsigned int trap_nr;
	long unsigned int error_code;
	struct io_bitmap *io_bitmap;
	long unsigned int iopl_emul;
	unsigned int iopl_warn;
	unsigned int sig_on_uaccess_err;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u32 pkru;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct fpu___2 fpu;
};

struct vm_area_struct___9;

struct pv_mmu_ops___4 {
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_one_user)(long unsigned int);
	void (*flush_tlb_multi)(const struct cpumask *, const struct flush_tlb_info___3 *);
	void (*tlb_remove_table)(struct mmu_gather *, void *);
	void (*exit_mmap)(struct mm_struct___4 *);
	struct paravirt_callee_save read_cr2;
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___4 *, struct mm_struct___4 *);
	void (*dup_mmap)(struct mm_struct___4 *, struct mm_struct___4 *);
	int (*pgd_alloc)(struct mm_struct___4 *);
	void (*pgd_free)(struct mm_struct___4 *, pgd_t___2 *);
	void (*alloc_pte)(struct mm_struct___4 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___4 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___4 *, long unsigned int);
	void (*alloc_p4d)(struct mm_struct___4 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*release_p4d)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pmd)(pmd_t___2 *, pmd_t___2);
	pte_t (*ptep_modify_prot_start)(struct vm_area_struct___9 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct vm_area_struct___9 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t___2 *, pud_t___2);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_p4d)(p4d_t___2 *, p4d_t___2);
	struct paravirt_callee_save p4d_val;
	struct paravirt_callee_save make_p4d;
	void (*set_pgd)(pgd_t___2 *, pgd_t___2);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

struct mm_struct___4 {
	struct {
		struct vm_area_struct___9 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___7 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int mmap_compat_base;
		long unsigned int mmap_compat_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t___2 *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[48];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___7 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___9 *owner;
		struct user_namespace *user_ns;
		struct file___7 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		bool tlb_flush_batched;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct vm_area_struct___9 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___9 *vm_next;
	struct vm_area_struct___9 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___4 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___6 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___7 *vm_file;
	struct file___7 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct paravirt_patch_template___4 {
	struct pv_cpu_ops___4 cpu;
	struct pv_irq_ops irq;
	struct pv_mmu_ops___4 mmu;
	struct pv_lock_ops lock;
};

struct kobject___7;

struct bin_attribute___7;

struct attribute_group___7 {
	const char *name;
	umode_t (*is_visible)(struct kobject___7 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___7 *, struct bin_attribute___7 *, int);
	struct attribute **attrs;
	struct bin_attribute___7 **bin_attrs;
};

struct address_space___8;

struct bin_attribute___7 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___8 * (*f_mapping)();
	ssize_t (*read)(struct file___7 *, struct kobject___7 *, struct bin_attribute___7 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___7 *, struct kobject___7 *, struct bin_attribute___7 *, char *, loff_t, size_t);
	int (*mmap)(struct file___7 *, struct kobject___7 *, struct bin_attribute___7 *, struct vm_area_struct___9 *);
};

struct perf_msr {
	u64 msr;
	struct attribute_group___7 *grp;
	bool (*test)(int, void *);
	bool no_check;
	u64 mask;
};

struct debug_store___2 {
	u64 bts_buffer_base;
	u64 bts_index;
	u64 bts_absolute_maximum;
	u64 bts_interrupt_threshold;
	u64 pebs_buffer_base;
	u64 pebs_index;
	u64 pebs_absolute_maximum;
	u64 pebs_interrupt_threshold;
	u64 pebs_event_reset[12];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct cpu_hw_events___2 {
	struct perf_event___4 *events[64];
	long unsigned int active_mask[1];
	long unsigned int dirty[1];
	int enabled;
	int n_events;
	int n_added;
	int n_txn;
	int n_txn_pair;
	int n_txn_metric;
	int assign[64];
	u64 tags[64];
	struct perf_event___4 *event_list[64];
	struct event_constraint *event_constraint[64];
	int n_excl;
	unsigned int txn_flags;
	int is_fake;
	struct debug_store___2 *ds;
	void *ds_pebs_vaddr;
	void *ds_bts_vaddr;
	u64 pebs_enabled;
	int n_pebs;
	int n_large_pebs;
	int n_pebs_via_pt;
	int pebs_output;
	u64 pebs_data_cfg;
	u64 active_pebs_data_cfg;
	int pebs_record_size;
	int lbr_users;
	int lbr_pebs_users;
	struct perf_branch_stack lbr_stack;
	struct perf_branch_entry lbr_entries[32];
	union {
		struct er_account *lbr_sel;
		struct er_account *lbr_ctl;
	};
	u64 br_sel;
	void *last_task_ctx;
	int last_log_id;
	int lbr_select;
	void *lbr_xsave;
	u64 intel_ctrl_guest_mask;
	u64 intel_ctrl_host_mask;
	struct perf_guest_switch_msr guest_switch_msrs[64];
	u64 intel_cp_status;
	struct intel_shared_regs *shared_regs;
	struct event_constraint *constraint_list;
	struct intel_excl_cntrs *excl_cntrs;
	int excl_thread_id;
	u64 tfa_shadow;
	int n_metric;
	struct amd_nb *amd_nb;
	u64 perf_ctr_virt_mask;
	int n_pair;
	void *kfree_on_online[2];
	struct pmu___4 *pmu;
};

struct x86_pmu___2 {
	const char *name;
	int version;
	int (*handle_irq)(struct pt_regs *);
	void (*disable_all)();
	void (*enable_all)(int);
	void (*enable)(struct perf_event___4 *);
	void (*disable)(struct perf_event___4 *);
	void (*add)(struct perf_event___4 *);
	void (*del)(struct perf_event___4 *);
	void (*read)(struct perf_event___4 *);
	int (*hw_config)(struct perf_event___4 *);
	int (*schedule_events)(struct cpu_hw_events___2 *, int, int *);
	unsigned int eventsel;
	unsigned int perfctr;
	int (*addr_offset)(int, bool);
	int (*rdpmc_index)(int);
	u64 (*event_map)(int);
	int max_events;
	int num_counters;
	int num_counters_fixed;
	int cntval_bits;
	u64 cntval_mask;
	union {
		long unsigned int events_maskl;
		long unsigned int events_mask[1];
	};
	int events_mask_len;
	int apic;
	u64 max_period;
	struct event_constraint * (*get_event_constraints)(struct cpu_hw_events___2 *, int, struct perf_event___4 *);
	void (*put_event_constraints)(struct cpu_hw_events___2 *, struct perf_event___4 *);
	void (*start_scheduling)(struct cpu_hw_events___2 *);
	void (*commit_scheduling)(struct cpu_hw_events___2 *, int, int);
	void (*stop_scheduling)(struct cpu_hw_events___2 *);
	struct event_constraint *event_constraints;
	struct x86_pmu_quirk *quirks;
	int perfctr_second_write;
	u64 (*limit_period)(struct perf_event___4 *, u64);
	unsigned int late_ack: 1;
	unsigned int mid_ack: 1;
	unsigned int enabled_ack: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int attr_rdpmc_broken;
	int attr_rdpmc;
	struct attribute **format_attrs;
	ssize_t (*events_sysfs_show)(char *, u64);
	const struct attribute_group___5 **attr_update;
	long unsigned int attr_freeze_on_smi;
	int (*cpu_prepare)(int);
	void (*cpu_starting)(int);
	void (*cpu_dying)(int);
	void (*cpu_dead)(int);
	void (*check_microcode)();
	void (*sched_task)(struct perf_event_context *, bool);
	u64 intel_ctrl;
	union perf_capabilities intel_cap;
	unsigned int bts: 1;
	unsigned int bts_active: 1;
	unsigned int pebs: 1;
	unsigned int pebs_active: 1;
	unsigned int pebs_broken: 1;
	unsigned int pebs_prec_dist: 1;
	unsigned int pebs_no_tlb: 1;
	unsigned int pebs_no_isolation: 1;
	unsigned int pebs_block: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int pebs_record_size;
	int pebs_buffer_size;
	int max_pebs_events;
	void (*drain_pebs)(struct pt_regs *, struct perf_sample_data *);
	struct event_constraint *pebs_constraints;
	void (*pebs_aliases)(struct perf_event___4 *);
	long unsigned int large_pebs_flags;
	u64 rtm_abort_event;
	unsigned int lbr_tos;
	unsigned int lbr_from;
	unsigned int lbr_to;
	unsigned int lbr_info;
	unsigned int lbr_nr;
	union {
		u64 lbr_sel_mask;
		u64 lbr_ctl_mask;
	};
	union {
		const int *lbr_sel_map;
		int *lbr_ctl_map;
	};
	bool lbr_double_abort;
	bool lbr_pt_coexist;
	unsigned int lbr_depth_mask: 8;
	unsigned int lbr_deep_c_reset: 1;
	unsigned int lbr_lip: 1;
	unsigned int lbr_cpl: 1;
	unsigned int lbr_filter: 1;
	unsigned int lbr_call_stack: 1;
	unsigned int lbr_mispred: 1;
	unsigned int lbr_timed_lbr: 1;
	unsigned int lbr_br_type: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	void (*lbr_reset)();
	void (*lbr_read)(struct cpu_hw_events___2 *);
	void (*lbr_save)(void *);
	void (*lbr_restore)(void *);
	atomic_t lbr_exclusive[3];
	int num_topdown_events;
	u64 (*update_topdown_event)(struct perf_event___4 *);
	int (*set_topdown_event_period)(struct perf_event___4 *);
	void (*swap_task_ctx)(struct perf_event_context *, struct perf_event_context *);
	unsigned int amd_nb_constraints: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u64 perf_ctr_pair_en;
	struct extra_reg *extra_regs;
	unsigned int flags;
	struct perf_guest_switch_msr * (*guest_get_msrs)(int *);
	int (*check_period)(struct perf_event___4 *, u64);
	int (*aux_output_match)(struct perf_event___4 *);
	int (*filter_match)(struct perf_event___4 *);
	int num_hybrid_pmus;
	struct x86_hybrid_pmu *hybrid_pmu;
	u8 (*get_hybrid_cpu_type)();
};

struct cpuinfo_x86___2 {
	__u8 x86;
	__u8 x86_vendor;
	__u8 x86_model;
	__u8 x86_stepping;
	int x86_tlbsize;
	__u32 vmx_capability[3];
	__u8 x86_virt_bits;
	__u8 x86_phys_bits;
	__u8 x86_coreid_bits;
	__u8 cu_id;
	__u32 extended_cpuid_level;
	int cpuid_level;
	union {
		__u32 x86_capability[21];
		long unsigned int x86_capability_alignment;
	};
	char x86_vendor_id[16];
	char x86_model_id[64];
	unsigned int x86_cache_size;
	int x86_cache_alignment;
	int x86_cache_max_rmid;
	int x86_cache_occ_scale;
	int x86_cache_mbm_width_offset;
	int x86_power;
	long unsigned int loops_per_jiffy;
	u16 x86_max_cores;
	u16 apicid;
	u16 initial_apicid;
	u16 x86_clflush_size;
	u16 booted_cores;
	u16 phys_proc_id;
	u16 logical_proc_id;
	u16 cpu_core_id;
	u16 cpu_die_id;
	u16 logical_die_id;
	u16 cpu_index;
	bool smt_active;
	u32 microcode;
	u8 x86_cache_bits;
	unsigned int initialized: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct aer_stats;

struct rcec_ea;

typedef int pci_power_t;

struct pcie_link_state;

typedef unsigned int pci_channel_state_t;

typedef short unsigned int pci_dev_flags_t;

struct pci_vpd {
	struct mutex lock;
	unsigned int len;
	u8 cap;
};

struct pci_sriov;

struct pci_bus;

struct pci_slot;

struct pci_driver;

struct pci_dev {
	struct list_head bus_list;
	struct pci_bus *bus;
	struct pci_bus *subordinate;
	void *sysdata;
	struct proc_dir_entry *procent;
	struct pci_slot *slot;
	unsigned int devfn;
	short unsigned int vendor;
	short unsigned int device;
	short unsigned int subsystem_vendor;
	short unsigned int subsystem_device;
	unsigned int class;
	u8 revision;
	u8 hdr_type;
	u16 aer_cap;
	struct aer_stats *aer_stats;
	struct rcec_ea *rcec_ea;
	struct pci_dev *rcec;
	u32 devcap;
	u8 pcie_cap;
	u8 msi_cap;
	u8 msix_cap;
	u8 pcie_mpss: 3;
	long: 61;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u8 rom_base_reg;
	u8 pin;
	u16 pcie_flags_reg;
	long unsigned int *dma_alias_mask;
	struct pci_driver *driver;
	u64 dma_mask;
	struct device_dma_parameters dma_parms;
	pci_power_t current_state;
	unsigned int imm_ready: 1;
	long: 39;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u8 pm_cap;
	unsigned int pme_support: 5;
	unsigned int pme_poll: 1;
	unsigned int d1_support: 1;
	unsigned int d2_support: 1;
	unsigned int no_d1d2: 1;
	unsigned int no_d3cold: 1;
	unsigned int bridge_d3: 1;
	unsigned int d3cold_allowed: 1;
	unsigned int mmio_always_on: 1;
	unsigned int wakeup_prepared: 1;
	unsigned int runtime_d3cold: 1;
	unsigned int skip_bus_pm: 1;
	unsigned int ignore_hotplug: 1;
	unsigned int hotplug_user_indicators: 1;
	unsigned int clear_retrain_link: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int d3hot_delay;
	unsigned int d3cold_delay;
	struct pcie_link_state *link_state;
	unsigned int ltr_path: 1;
	long: 15;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u16 l1ss;
	unsigned int pasid_no_tlp: 1;
	unsigned int eetlp_prefix_path: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	pci_channel_state_t error_state;
	struct device dev;
	int cfg_size;
	unsigned int irq;
	struct resource resource[17];
	bool match_driver;
	unsigned int transparent: 1;
	unsigned int io_window: 1;
	unsigned int pref_window: 1;
	unsigned int pref_64_window: 1;
	unsigned int multifunction: 1;
	unsigned int is_busmaster: 1;
	unsigned int no_msi: 1;
	unsigned int no_64bit_msi: 1;
	unsigned int block_cfg_access: 1;
	unsigned int broken_parity_status: 1;
	unsigned int irq_reroute_variant: 2;
	unsigned int msi_enabled: 1;
	unsigned int msix_enabled: 1;
	unsigned int ari_enabled: 1;
	unsigned int ats_enabled: 1;
	unsigned int pasid_enabled: 1;
	unsigned int pri_enabled: 1;
	unsigned int is_managed: 1;
	unsigned int needs_freset: 1;
	unsigned int state_saved: 1;
	unsigned int is_physfn: 1;
	unsigned int is_virtfn: 1;
	unsigned int is_hotplug_bridge: 1;
	unsigned int shpc_managed: 1;
	unsigned int is_thunderbolt: 1;
	unsigned int untrusted: 1;
	unsigned int external_facing: 1;
	unsigned int broken_intx_masking: 1;
	unsigned int io_window_1k: 1;
	unsigned int irq_managed: 1;
	unsigned int non_compliant_bars: 1;
	unsigned int is_probed: 1;
	unsigned int link_active_reporting: 1;
	unsigned int no_vf_scan: 1;
	unsigned int no_command_memory: 1;
	long: 47;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	pci_dev_flags_t dev_flags;
	atomic_t enable_cnt;
	u32 saved_config_space[16];
	struct hlist_head saved_cap_space;
	int rom_attr_enabled;
	struct bin_attribute *res_attr[17];
	struct bin_attribute *res_attr_wc[17];
	unsigned int broken_cmd_compl: 1;
	unsigned int ptm_root: 1;
	unsigned int ptm_enabled: 1;
	long: 7;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u8 ptm_granularity;
	const struct attribute_group **msi_irq_groups;
	struct pci_vpd vpd;
	u16 dpc_cap;
	unsigned int dpc_rp_extensions: 1;
	long: 23;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u8 dpc_rp_log_size;
	union {
		struct pci_sriov *sriov;
		struct pci_dev *physfn;
	};
	u16 ats_cap;
	u8 ats_stu;
	u16 pri_cap;
	u32 pri_reqs_alloc;
	unsigned int pasid_required: 1;
	long: 47;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u16 pasid_cap;
	u16 pasid_features;
	u16 acs_cap;
	phys_addr_t rom;
	size_t romlen;
	char *driver_override;
	long unsigned int priv_flags;
	u8 reset_methods[7];
};

struct device_attribute___2 {
	struct attribute attr;
	ssize_t (*show)(struct device *, struct device_attribute___2 *, char *);
	ssize_t (*store)(struct device *, struct device_attribute___2 *, const char *, size_t);
};

struct pci_device_id {
	__u32 vendor;
	__u32 device;
	__u32 subvendor;
	__u32 subdevice;
	__u32 class;
	__u32 class_mask;
	kernel_ulong_t driver_data;
	__u32 override_only;
};

struct hotplug_slot;

struct pci_slot {
	struct pci_bus *bus;
	struct list_head list;
	struct hotplug_slot *hotplug;
	unsigned char number;
	struct kobject kobj;
};

typedef short unsigned int pci_bus_flags_t;

struct pci_ops;

struct pci_bus {
	struct list_head node;
	struct pci_bus *parent;
	struct list_head children;
	struct list_head devices;
	struct pci_dev *self;
	struct list_head slots;
	struct resource *resource[4];
	struct list_head resources;
	struct resource busn_res;
	struct pci_ops *ops;
	void *sysdata;
	struct proc_dir_entry *procdir;
	unsigned char number;
	unsigned char primary;
	unsigned char max_bus_speed;
	unsigned char cur_bus_speed;
	char name[48];
	short unsigned int bridge_ctl;
	pci_bus_flags_t bus_flags;
	struct device *bridge;
	struct device dev;
	struct bin_attribute *legacy_io;
	struct bin_attribute *legacy_mem;
	unsigned int is_added: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

enum {
	PCI_STD_RESOURCES = 0,
	PCI_STD_RESOURCE_END = 5,
	PCI_ROM_RESOURCE = 6,
	PCI_IOV_RESOURCES = 7,
	PCI_IOV_RESOURCE_END = 12,
	PCI_BRIDGE_RESOURCES = 13,
	PCI_BRIDGE_RESOURCE_END = 16,
	PCI_NUM_RESOURCES = 17,
	DEVICE_COUNT_RESOURCE = 17,
};

typedef unsigned int pcie_reset_state_t;

struct pci_dynids {
	spinlock_t lock;
	struct list_head list;
};

struct pci_error_handlers;

struct pci_driver {
	struct list_head node;
	const char *name;
	const struct pci_device_id *id_table;
	int (*probe)(struct pci_dev *, const struct pci_device_id *);
	void (*remove)(struct pci_dev *);
	int (*suspend)(struct pci_dev *, pm_message_t);
	int (*resume)(struct pci_dev *);
	void (*shutdown)(struct pci_dev *);
	int (*sriov_configure)(struct pci_dev *, int);
	int (*sriov_set_msix_vec_count)(struct pci_dev *, int);
	u32 (*sriov_get_vf_total_msix)(struct pci_dev *);
	const struct pci_error_handlers *err_handler;
	const struct attribute_group **groups;
	const struct attribute_group **dev_groups;
	struct device_driver driver;
	struct pci_dynids dynids;
};

struct pci_ops {
	int (*add_bus)(struct pci_bus *);
	void (*remove_bus)(struct pci_bus *);
	void * (*map_bus)(struct pci_bus *, unsigned int, int);
	int (*read)(struct pci_bus *, unsigned int, int, int, u32 *);
	int (*write)(struct pci_bus *, unsigned int, int, int, u32);
};

typedef unsigned int pci_ers_result_t;

struct pci_error_handlers {
	pci_ers_result_t (*error_detected)(struct pci_dev *, pci_channel_state_t);
	pci_ers_result_t (*mmio_enabled)(struct pci_dev *);
	pci_ers_result_t (*slot_reset)(struct pci_dev *);
	void (*reset_prepare)(struct pci_dev *);
	void (*reset_done)(struct pci_dev *);
	void (*resume)(struct pci_dev *);
};

struct syscore_ops {
	struct list_head node;
	int (*suspend)();
	void (*resume)();
	void (*shutdown)();
};

union ibs_fetch_ctl {
	__u64 val;
	struct {
		__u64 fetch_maxcnt: 16;
		__u64 fetch_cnt: 16;
		__u64 fetch_lat: 16;
		__u64 fetch_en: 1;
		__u64 fetch_val: 1;
		__u64 fetch_comp: 1;
		__u64 ic_miss: 1;
		__u64 phy_addr_valid: 1;
		__u64 l1tlb_pgsz: 2;
		__u64 l1tlb_miss: 1;
		__u64 l2tlb_miss: 1;
		__u64 rand_en: 1;
		__u64 fetch_l2_miss: 1;
		__u64 reserved: 5;
	};
};

union ibs_op_ctl {
	__u64 val;
	struct {
		__u64 opmaxcnt: 16;
		__u64 reserved0: 1;
		__u64 op_en: 1;
		__u64 op_val: 1;
		__u64 cnt_ctl: 1;
		__u64 opmaxcnt_ext: 7;
		__u64 reserved1: 5;
		__u64 opcurcnt: 27;
		__u64 reserved2: 5;
	};
};

struct perf_ibs_data {
	u32 size;
	union {
		u32 data[0];
		u32 caps;
	};
	u64 regs[8];
};

enum ibs_states {
	IBS_ENABLED = 0,
	IBS_STARTED = 1,
	IBS_STOPPING = 2,
	IBS_STOPPED = 3,
	IBS_MAX_STATES = 4,
};

struct cpu_perf_ibs {
	struct perf_event *event;
	long unsigned int state[1];
};

struct perf_ibs {
	struct pmu pmu;
	unsigned int msr;
	u64 config_mask;
	u64 cnt_mask;
	u64 enable_mask;
	u64 valid_mask;
	u64 max_period;
	long unsigned int offset_mask[1];
	int offset_max;
	unsigned int fetch_count_reset_broken: 1;
	unsigned int fetch_ignore_if_zero_rip: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct cpu_perf_ibs *pcpu;
	struct attribute **format_attrs;
	struct attribute_group format_group;
	const struct attribute_group *attr_groups[2];
	u64 (*get_count)(u64);
};

struct amd_iommu;

struct perf_amd_iommu {
	struct list_head list;
	struct pmu___4 pmu;
	struct amd_iommu *iommu;
	char name[16];
	u8 max_banks;
	u8 max_counters;
	u64 cntr_assign_mask;
	raw_spinlock_t lock;
};

struct amd_iommu_event_desc {
	struct device_attribute attr;
	const char *event;
};

struct perf_msr___2 {
	u64 msr;
	struct attribute_group___5 *grp;
	bool (*test)(int, void *);
	bool no_check;
	u64 mask;
};

enum perf_msr_id {
	PERF_MSR_TSC = 0,
	PERF_MSR_APERF = 1,
	PERF_MSR_MPERF = 2,
	PERF_MSR_PPERF = 3,
	PERF_MSR_SMI = 4,
	PERF_MSR_PTSC = 5,
	PERF_MSR_IRPERF = 6,
	PERF_MSR_THERM = 7,
	PERF_MSR_EVENT_MAX = 8,
};

struct x86_cpu_desc {
	u8 x86_family;
	u8 x86_vendor;
	u8 x86_model;
	u8 x86_stepping;
	u32 x86_microcode_rev;
};

union cpuid10_eax {
	struct {
		unsigned int version_id: 8;
		unsigned int num_counters: 8;
		unsigned int bit_width: 8;
		unsigned int mask_length: 8;
	} split;
	unsigned int full;
};

union cpuid10_ebx {
	struct {
		unsigned int no_unhalted_core_cycles: 1;
		unsigned int no_instructions_retired: 1;
		unsigned int no_unhalted_reference_cycles: 1;
		unsigned int no_llc_reference: 1;
		unsigned int no_llc_misses: 1;
		unsigned int no_branch_instruction_retired: 1;
		unsigned int no_branch_misses_retired: 1;
	} split;
	unsigned int full;
};

union cpuid10_edx {
	struct {
		unsigned int num_counters_fixed: 5;
		unsigned int bit_width_fixed: 8;
		unsigned int reserved1: 2;
		unsigned int anythread_deprecated: 1;
		unsigned int reserved2: 16;
	} split;
	unsigned int full;
};

struct perf_pmu_format_hybrid_attr {
	struct device_attribute attr;
	u64 pmu_type;
};

enum {
	LBR_FORMAT_32 = 0,
	LBR_FORMAT_LIP = 1,
	LBR_FORMAT_EIP = 2,
	LBR_FORMAT_EIP_FLAGS = 3,
	LBR_FORMAT_EIP_FLAGS2 = 4,
	LBR_FORMAT_INFO = 5,
	LBR_FORMAT_TIME = 6,
	LBR_FORMAT_MAX_KNOWN = 6,
};

union x86_pmu_config {
	struct {
		u64 event: 8;
		u64 umask: 8;
		u64 usr;
		u64 os;
		u64 edge: 1;
		u64 pc;
		u64 interrupt: 1;
		u64 __reserved1: 1;
		u64 en;
		u64 inv;
		u64 cmask: 8;
		u64 event2: 4;
		u64 __reserved2: 4;
		u64 go;
		u64 ho;
	} bits;
	u64 value;
};

enum pageflags {
	PG_locked = 0,
	PG_referenced = 1,
	PG_uptodate = 2,
	PG_dirty = 3,
	PG_lru = 4,
	PG_active = 5,
	PG_workingset = 6,
	PG_waiters = 7,
	PG_error = 8,
	PG_slab = 9,
	PG_owner_priv_1 = 10,
	PG_arch_1 = 11,
	PG_reserved = 12,
	PG_private = 13,
	PG_private_2 = 14,
	PG_writeback = 15,
	PG_head = 16,
	PG_mappedtodisk = 17,
	PG_reclaim = 18,
	PG_swapbacked = 19,
	PG_unevictable = 20,
	PG_mlocked = 21,
	PG_uncached = 22,
	PG_hwpoison = 23,
	PG_young = 24,
	PG_idle = 25,
	PG_arch_2 = 26,
	__NR_PAGEFLAGS = 27,
	PG_checked = 10,
	PG_swapcache = 10,
	PG_fscache = 14,
	PG_pinned = 10,
	PG_savepinned = 3,
	PG_foreign = 10,
	PG_xen_remapped = 10,
	PG_slob_free = 13,
	PG_double_map = 6,
	PG_has_hwpoisoned = 17,
	PG_isolated = 18,
	PG_reported = 2,
};

struct bts_ctx {
	struct perf_output_handle___4 handle;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct debug_store___2 ds_back;
	int state;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

enum {
	BTS_STATE_STOPPED = 0,
	BTS_STATE_INACTIVE = 1,
	BTS_STATE_ACTIVE = 2,
};

struct bts_phys {
	struct page___7 *page;
	long unsigned int size;
	long unsigned int offset;
	long unsigned int displacement;
};

struct bts_buffer {
	size_t real_size;
	unsigned int nr_pages;
	unsigned int nr_bufs;
	unsigned int cur_buf;
	bool snapshot;
	local_t data_size;
	local_t head;
	long unsigned int end;
	void **data_pages;
	struct bts_phys buf[0];
};

struct lbr_entry {
	u64 from;
	u64 to;
	u64 info;
};

struct x86_hw_tss {
	u32 reserved1;
	u64 sp0;
	u64 sp1;
	u64 sp2;
	u64 reserved2;
	u64 ist[7];
	u32 reserved3;
	u32 reserved4;
	u16 reserved5;
	u16 io_bitmap_base;
} __attribute__((packed));

struct entry_stack {
	char stack[4096];
};

struct entry_stack_page {
	struct entry_stack stack;
};

struct x86_io_bitmap {
	u64 prev_sequence;
	unsigned int prev_max;
	long unsigned int bitmap[1025];
	long unsigned int mapall[1025];
};

struct tss_struct {
	struct x86_hw_tss x86_tss;
	struct x86_io_bitmap io_bitmap;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct debug_store_buffers {
	char bts_buffer[65536];
	char pebs_buffer[65536];
};

struct cea_exception_stacks {
	char DF_stack_guard[4096];
	char DF_stack[8192];
	char NMI_stack_guard[4096];
	char NMI_stack[8192];
	char DB_stack_guard[4096];
	char DB_stack[8192];
	char MCE_stack_guard[4096];
	char MCE_stack[8192];
	char VC_stack_guard[4096];
	char VC_stack[8192];
	char VC2_stack_guard[4096];
	char VC2_stack[8192];
	char IST_top_guard[4096];
};

struct cpu_entry_area {
	char gdt[4096];
	struct entry_stack_page entry_stack_page;
	struct tss_struct tss;
	struct cea_exception_stacks estacks;
	struct debug_store___2 cpu_debug_store;
	struct debug_store_buffers cpu_debug_buffers;
};

struct pebs_basic {
	u64 format_size;
	u64 ip;
	u64 applicable_counters;
	u64 tsc;
};

struct pebs_meminfo {
	u64 address;
	u64 aux;
	u64 latency;
	u64 tsx_tuning;
};

struct pebs_gprs {
	u64 flags;
	u64 ip;
	u64 ax;
	u64 cx;
	u64 dx;
	u64 bx;
	u64 sp;
	u64 bp;
	u64 si;
	u64 di;
	u64 r8;
	u64 r9;
	u64 r10;
	u64 r11;
	u64 r12;
	u64 r13;
	u64 r14;
	u64 r15;
};

struct pebs_xmm {
	u64 xmm[32];
};

struct x86_perf_regs {
	struct pt_regs regs;
	u64 *xmm_regs;
};

typedef unsigned int insn_attr_t;

typedef unsigned char insn_byte_t;

typedef int insn_value_t;

struct insn_field {
	union {
		insn_value_t value;
		insn_byte_t bytes[4];
	};
	unsigned char got;
	unsigned char nbytes;
};

struct insn {
	struct insn_field prefixes;
	struct insn_field rex_prefix;
	struct insn_field vex_prefix;
	struct insn_field opcode;
	struct insn_field modrm;
	struct insn_field sib;
	struct insn_field displacement;
	union {
		struct insn_field immediate;
		struct insn_field moffset1;
		struct insn_field immediate1;
	};
	union {
		struct insn_field moffset2;
		struct insn_field immediate2;
	};
	int emulate_prefix_size;
	insn_attr_t attr;
	unsigned char opnd_bytes;
	unsigned char addr_bytes;
	unsigned char length;
	unsigned char x86_64;
	const insn_byte_t *kaddr;
	const insn_byte_t *end_kaddr;
	const insn_byte_t *next_byte;
};

enum {
	PERF_TXN_ELISION = 1,
	PERF_TXN_TRANSACTION = 2,
	PERF_TXN_SYNC = 4,
	PERF_TXN_ASYNC = 8,
	PERF_TXN_RETRY = 16,
	PERF_TXN_CONFLICT = 32,
	PERF_TXN_CAPACITY_WRITE = 64,
	PERF_TXN_CAPACITY_READ = 128,
	PERF_TXN_MAX = 256,
	PERF_TXN_ABORT_MASK = 0,
	PERF_TXN_ABORT_SHIFT = 32,
};

struct perf_event_header {
	__u32 type;
	__u16 misc;
	__u16 size;
};

union intel_x86_pebs_dse {
	u64 val;
	struct {
		unsigned int ld_dse: 4;
		unsigned int ld_stlb_miss: 1;
		unsigned int ld_locked: 1;
		unsigned int ld_data_blk: 1;
		unsigned int ld_addr_blk: 1;
		unsigned int ld_reserved: 24;
	};
	struct {
		unsigned int st_l1d_hit: 1;
		unsigned int st_reserved1: 3;
		unsigned int st_stlb_miss: 1;
		unsigned int st_locked: 1;
		unsigned int st_reserved2: 26;
	};
	struct {
		unsigned int st_lat_dse: 4;
		unsigned int st_lat_stlb_miss: 1;
		unsigned int st_lat_locked: 1;
		unsigned int ld_reserved3: 26;
	};
};

struct pebs_record_core {
	u64 flags;
	u64 ip;
	u64 ax;
	u64 bx;
	u64 cx;
	u64 dx;
	u64 si;
	u64 di;
	u64 bp;
	u64 sp;
	u64 r8;
	u64 r9;
	u64 r10;
	u64 r11;
	u64 r12;
	u64 r13;
	u64 r14;
	u64 r15;
};

struct pebs_record_nhm {
	u64 flags;
	u64 ip;
	u64 ax;
	u64 bx;
	u64 cx;
	u64 dx;
	u64 si;
	u64 di;
	u64 bp;
	u64 sp;
	u64 r8;
	u64 r9;
	u64 r10;
	u64 r11;
	u64 r12;
	u64 r13;
	u64 r14;
	u64 r15;
	u64 status;
	u64 dla;
	u64 dse;
	u64 lat;
};

union hsw_tsx_tuning {
	struct {
		u32 cycles_last_block: 32;
		u32 hle_abort: 1;
		u32 rtm_abort: 1;
		u32 instruction_abort: 1;
		u32 non_instruction_abort: 1;
		u32 retry: 1;
		u32 data_conflict: 1;
		u32 capacity_writes: 1;
		u32 capacity_reads: 1;
		long: 63;
	};
	u64 value;
};

struct pebs_record_skl {
	u64 flags;
	u64 ip;
	u64 ax;
	u64 bx;
	u64 cx;
	u64 dx;
	u64 si;
	u64 di;
	u64 bp;
	u64 sp;
	u64 r8;
	u64 r9;
	u64 r10;
	u64 r11;
	u64 r12;
	u64 r13;
	u64 r14;
	u64 r15;
	u64 status;
	u64 dla;
	u64 dse;
	u64 lat;
	u64 real_ip;
	u64 tsx_tuning;
	u64 tsc;
};

struct bts_record {
	u64 from;
	u64 to;
	u64 flags;
};

enum {
	PERF_BR_UNKNOWN = 0,
	PERF_BR_COND = 1,
	PERF_BR_UNCOND = 2,
	PERF_BR_IND = 3,
	PERF_BR_CALL = 4,
	PERF_BR_IND_CALL = 5,
	PERF_BR_RET = 6,
	PERF_BR_SYSCALL = 7,
	PERF_BR_SYSRET = 8,
	PERF_BR_COND_CALL = 9,
	PERF_BR_COND_RET = 10,
	PERF_BR_MAX = 11,
};

enum xfeature {
	XFEATURE_FP = 0,
	XFEATURE_SSE = 1,
	XFEATURE_YMM = 2,
	XFEATURE_BNDREGS = 3,
	XFEATURE_BNDCSR = 4,
	XFEATURE_OPMASK = 5,
	XFEATURE_ZMM_Hi256 = 6,
	XFEATURE_Hi16_ZMM = 7,
	XFEATURE_PT_UNIMPLEMENTED_SO_FAR = 8,
	XFEATURE_PKRU = 9,
	XFEATURE_PASID = 10,
	XFEATURE_RSRVD_COMP_11 = 11,
	XFEATURE_RSRVD_COMP_12 = 12,
	XFEATURE_RSRVD_COMP_13 = 13,
	XFEATURE_RSRVD_COMP_14 = 14,
	XFEATURE_LBR = 15,
	XFEATURE_RSRVD_COMP_16 = 16,
	XFEATURE_XTILE_CFG = 17,
	XFEATURE_XTILE_DATA = 18,
	XFEATURE_MAX = 19,
};

struct arch_lbr_state {
	u64 lbr_ctl;
	u64 lbr_depth;
	u64 ler_from;
	u64 ler_to;
	u64 ler_info;
	struct lbr_entry entries[0];
};

union cpuid28_eax {
	struct {
		unsigned int lbr_depth_mask: 8;
		unsigned int reserved: 22;
		unsigned int lbr_deep_c_reset: 1;
		unsigned int lbr_lip: 1;
	} split;
	unsigned int full;
};

union cpuid28_ebx {
	struct {
		unsigned int lbr_cpl: 1;
		unsigned int lbr_filter: 1;
		unsigned int lbr_call_stack: 1;
	} split;
	unsigned int full;
};

union cpuid28_ecx {
	struct {
		unsigned int lbr_mispred: 1;
		unsigned int lbr_timed_lbr: 1;
		unsigned int lbr_br_type: 1;
	} split;
	unsigned int full;
};

struct x86_pmu_lbr {
	unsigned int nr;
	unsigned int from;
	unsigned int to;
	unsigned int info;
};

struct x86_perf_task_context_opt {
	int lbr_callstack_users;
	int lbr_stack_state;
	int log_id;
};

struct x86_perf_task_context {
	u64 lbr_sel;
	int tos;
	int valid_lbrs;
	struct x86_perf_task_context_opt opt;
	struct lbr_entry lbr[32];
};

struct x86_perf_task_context_arch_lbr {
	struct x86_perf_task_context_opt opt;
	struct lbr_entry entries[0];
};

struct x86_perf_task_context_arch_lbr_xsave {
	struct x86_perf_task_context_opt opt;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	union {
		struct xregs_state xsave;
		struct {
			struct fxregs_state i387;
			struct xstate_header header;
			struct arch_lbr_state lbr;
			long: 64;
			long: 64;
			long: 64;
		};
	};
};

enum {
	X86_BR_NONE = 0,
	X86_BR_USER = 1,
	X86_BR_KERNEL = 2,
	X86_BR_CALL = 4,
	X86_BR_RET = 8,
	X86_BR_SYSCALL = 16,
	X86_BR_SYSRET = 32,
	X86_BR_INT = 64,
	X86_BR_IRET = 128,
	X86_BR_JCC = 256,
	X86_BR_JMP = 512,
	X86_BR_IRQ = 1024,
	X86_BR_IND_CALL = 2048,
	X86_BR_ABORT = 4096,
	X86_BR_IN_TX = 8192,
	X86_BR_NO_TX = 16384,
	X86_BR_ZERO_CALL = 32768,
	X86_BR_CALL_STACK = 65536,
	X86_BR_IND_JMP = 131072,
	X86_BR_TYPE_SAVE = 262144,
};

enum {
	LBR_NONE = 0,
	LBR_VALID = 1,
};

enum {
	ARCH_LBR_BR_TYPE_JCC = 0,
	ARCH_LBR_BR_TYPE_NEAR_IND_JMP = 1,
	ARCH_LBR_BR_TYPE_NEAR_REL_JMP = 2,
	ARCH_LBR_BR_TYPE_NEAR_IND_CALL = 3,
	ARCH_LBR_BR_TYPE_NEAR_REL_CALL = 4,
	ARCH_LBR_BR_TYPE_NEAR_RET = 5,
	ARCH_LBR_BR_TYPE_KNOWN_MAX = 5,
	ARCH_LBR_BR_TYPE_MAP_MAX = 16,
};

enum P4_EVENTS {
	P4_EVENT_TC_DELIVER_MODE = 0,
	P4_EVENT_BPU_FETCH_REQUEST = 1,
	P4_EVENT_ITLB_REFERENCE = 2,
	P4_EVENT_MEMORY_CANCEL = 3,
	P4_EVENT_MEMORY_COMPLETE = 4,
	P4_EVENT_LOAD_PORT_REPLAY = 5,
	P4_EVENT_STORE_PORT_REPLAY = 6,
	P4_EVENT_MOB_LOAD_REPLAY = 7,
	P4_EVENT_PAGE_WALK_TYPE = 8,
	P4_EVENT_BSQ_CACHE_REFERENCE = 9,
	P4_EVENT_IOQ_ALLOCATION = 10,
	P4_EVENT_IOQ_ACTIVE_ENTRIES = 11,
	P4_EVENT_FSB_DATA_ACTIVITY = 12,
	P4_EVENT_BSQ_ALLOCATION = 13,
	P4_EVENT_BSQ_ACTIVE_ENTRIES = 14,
	P4_EVENT_SSE_INPUT_ASSIST = 15,
	P4_EVENT_PACKED_SP_UOP = 16,
	P4_EVENT_PACKED_DP_UOP = 17,
	P4_EVENT_SCALAR_SP_UOP = 18,
	P4_EVENT_SCALAR_DP_UOP = 19,
	P4_EVENT_64BIT_MMX_UOP = 20,
	P4_EVENT_128BIT_MMX_UOP = 21,
	P4_EVENT_X87_FP_UOP = 22,
	P4_EVENT_TC_MISC = 23,
	P4_EVENT_GLOBAL_POWER_EVENTS = 24,
	P4_EVENT_TC_MS_XFER = 25,
	P4_EVENT_UOP_QUEUE_WRITES = 26,
	P4_EVENT_RETIRED_MISPRED_BRANCH_TYPE = 27,
	P4_EVENT_RETIRED_BRANCH_TYPE = 28,
	P4_EVENT_RESOURCE_STALL = 29,
	P4_EVENT_WC_BUFFER = 30,
	P4_EVENT_B2B_CYCLES = 31,
	P4_EVENT_BNR = 32,
	P4_EVENT_SNOOP = 33,
	P4_EVENT_RESPONSE = 34,
	P4_EVENT_FRONT_END_EVENT = 35,
	P4_EVENT_EXECUTION_EVENT = 36,
	P4_EVENT_REPLAY_EVENT = 37,
	P4_EVENT_INSTR_RETIRED = 38,
	P4_EVENT_UOPS_RETIRED = 39,
	P4_EVENT_UOP_TYPE = 40,
	P4_EVENT_BRANCH_RETIRED = 41,
	P4_EVENT_MISPRED_BRANCH_RETIRED = 42,
	P4_EVENT_X87_ASSIST = 43,
	P4_EVENT_MACHINE_CLEAR = 44,
	P4_EVENT_INSTR_COMPLETED = 45,
};

enum P4_EVENT_OPCODES {
	P4_EVENT_TC_DELIVER_MODE_OPCODE = 257,
	P4_EVENT_BPU_FETCH_REQUEST_OPCODE = 768,
	P4_EVENT_ITLB_REFERENCE_OPCODE = 6147,
	P4_EVENT_MEMORY_CANCEL_OPCODE = 517,
	P4_EVENT_MEMORY_COMPLETE_OPCODE = 2050,
	P4_EVENT_LOAD_PORT_REPLAY_OPCODE = 1026,
	P4_EVENT_STORE_PORT_REPLAY_OPCODE = 1282,
	P4_EVENT_MOB_LOAD_REPLAY_OPCODE = 770,
	P4_EVENT_PAGE_WALK_TYPE_OPCODE = 260,
	P4_EVENT_BSQ_CACHE_REFERENCE_OPCODE = 3079,
	P4_EVENT_IOQ_ALLOCATION_OPCODE = 774,
	P4_EVENT_IOQ_ACTIVE_ENTRIES_OPCODE = 6662,
	P4_EVENT_FSB_DATA_ACTIVITY_OPCODE = 5894,
	P4_EVENT_BSQ_ALLOCATION_OPCODE = 1287,
	P4_EVENT_BSQ_ACTIVE_ENTRIES_OPCODE = 1543,
	P4_EVENT_SSE_INPUT_ASSIST_OPCODE = 13313,
	P4_EVENT_PACKED_SP_UOP_OPCODE = 2049,
	P4_EVENT_PACKED_DP_UOP_OPCODE = 3073,
	P4_EVENT_SCALAR_SP_UOP_OPCODE = 2561,
	P4_EVENT_SCALAR_DP_UOP_OPCODE = 3585,
	P4_EVENT_64BIT_MMX_UOP_OPCODE = 513,
	P4_EVENT_128BIT_MMX_UOP_OPCODE = 6657,
	P4_EVENT_X87_FP_UOP_OPCODE = 1025,
	P4_EVENT_TC_MISC_OPCODE = 1537,
	P4_EVENT_GLOBAL_POWER_EVENTS_OPCODE = 4870,
	P4_EVENT_TC_MS_XFER_OPCODE = 1280,
	P4_EVENT_UOP_QUEUE_WRITES_OPCODE = 2304,
	P4_EVENT_RETIRED_MISPRED_BRANCH_TYPE_OPCODE = 1282,
	P4_EVENT_RETIRED_BRANCH_TYPE_OPCODE = 1026,
	P4_EVENT_RESOURCE_STALL_OPCODE = 257,
	P4_EVENT_WC_BUFFER_OPCODE = 1285,
	P4_EVENT_B2B_CYCLES_OPCODE = 5635,
	P4_EVENT_BNR_OPCODE = 2051,
	P4_EVENT_SNOOP_OPCODE = 1539,
	P4_EVENT_RESPONSE_OPCODE = 1027,
	P4_EVENT_FRONT_END_EVENT_OPCODE = 2053,
	P4_EVENT_EXECUTION_EVENT_OPCODE = 3077,
	P4_EVENT_REPLAY_EVENT_OPCODE = 2309,
	P4_EVENT_INSTR_RETIRED_OPCODE = 516,
	P4_EVENT_UOPS_RETIRED_OPCODE = 260,
	P4_EVENT_UOP_TYPE_OPCODE = 514,
	P4_EVENT_BRANCH_RETIRED_OPCODE = 1541,
	P4_EVENT_MISPRED_BRANCH_RETIRED_OPCODE = 772,
	P4_EVENT_X87_ASSIST_OPCODE = 773,
	P4_EVENT_MACHINE_CLEAR_OPCODE = 517,
	P4_EVENT_INSTR_COMPLETED_OPCODE = 1796,
};

enum P4_ESCR_EMASKS {
	P4_EVENT_TC_DELIVER_MODE__DD = 512,
	P4_EVENT_TC_DELIVER_MODE__DB = 1024,
	P4_EVENT_TC_DELIVER_MODE__DI = 2048,
	P4_EVENT_TC_DELIVER_MODE__BD = 4096,
	P4_EVENT_TC_DELIVER_MODE__BB = 8192,
	P4_EVENT_TC_DELIVER_MODE__BI = 16384,
	P4_EVENT_TC_DELIVER_MODE__ID = 32768,
	P4_EVENT_BPU_FETCH_REQUEST__TCMISS = 512,
	P4_EVENT_ITLB_REFERENCE__HIT = 512,
	P4_EVENT_ITLB_REFERENCE__MISS = 1024,
	P4_EVENT_ITLB_REFERENCE__HIT_UK = 2048,
	P4_EVENT_MEMORY_CANCEL__ST_RB_FULL = 2048,
	P4_EVENT_MEMORY_CANCEL__64K_CONF = 4096,
	P4_EVENT_MEMORY_COMPLETE__LSC = 512,
	P4_EVENT_MEMORY_COMPLETE__SSC = 1024,
	P4_EVENT_LOAD_PORT_REPLAY__SPLIT_LD = 1024,
	P4_EVENT_STORE_PORT_REPLAY__SPLIT_ST = 1024,
	P4_EVENT_MOB_LOAD_REPLAY__NO_STA = 1024,
	P4_EVENT_MOB_LOAD_REPLAY__NO_STD = 4096,
	P4_EVENT_MOB_LOAD_REPLAY__PARTIAL_DATA = 8192,
	P4_EVENT_MOB_LOAD_REPLAY__UNALGN_ADDR = 16384,
	P4_EVENT_PAGE_WALK_TYPE__DTMISS = 512,
	P4_EVENT_PAGE_WALK_TYPE__ITMISS = 1024,
	P4_EVENT_BSQ_CACHE_REFERENCE__RD_2ndL_HITS = 512,
	P4_EVENT_BSQ_CACHE_REFERENCE__RD_2ndL_HITE = 1024,
	P4_EVENT_BSQ_CACHE_REFERENCE__RD_2ndL_HITM = 2048,
	P4_EVENT_BSQ_CACHE_REFERENCE__RD_3rdL_HITS = 4096,
	P4_EVENT_BSQ_CACHE_REFERENCE__RD_3rdL_HITE = 8192,
	P4_EVENT_BSQ_CACHE_REFERENCE__RD_3rdL_HITM = 16384,
	P4_EVENT_BSQ_CACHE_REFERENCE__RD_2ndL_MISS = 131072,
	P4_EVENT_BSQ_CACHE_REFERENCE__RD_3rdL_MISS = 262144,
	P4_EVENT_BSQ_CACHE_REFERENCE__WR_2ndL_MISS = 524288,
	P4_EVENT_IOQ_ALLOCATION__DEFAULT = 512,
	P4_EVENT_IOQ_ALLOCATION__ALL_READ = 16384,
	P4_EVENT_IOQ_ALLOCATION__ALL_WRITE = 32768,
	P4_EVENT_IOQ_ALLOCATION__MEM_UC = 65536,
	P4_EVENT_IOQ_ALLOCATION__MEM_WC = 131072,
	P4_EVENT_IOQ_ALLOCATION__MEM_WT = 262144,
	P4_EVENT_IOQ_ALLOCATION__MEM_WP = 524288,
	P4_EVENT_IOQ_ALLOCATION__MEM_WB = 1048576,
	P4_EVENT_IOQ_ALLOCATION__OWN = 4194304,
	P4_EVENT_IOQ_ALLOCATION__OTHER = 8388608,
	P4_EVENT_IOQ_ALLOCATION__PREFETCH = 16777216,
	P4_EVENT_IOQ_ACTIVE_ENTRIES__DEFAULT = 512,
	P4_EVENT_IOQ_ACTIVE_ENTRIES__ALL_READ = 16384,
	P4_EVENT_IOQ_ACTIVE_ENTRIES__ALL_WRITE = 32768,
	P4_EVENT_IOQ_ACTIVE_ENTRIES__MEM_UC = 65536,
	P4_EVENT_IOQ_ACTIVE_ENTRIES__MEM_WC = 131072,
	P4_EVENT_IOQ_ACTIVE_ENTRIES__MEM_WT = 262144,
	P4_EVENT_IOQ_ACTIVE_ENTRIES__MEM_WP = 524288,
	P4_EVENT_IOQ_ACTIVE_ENTRIES__MEM_WB = 1048576,
	P4_EVENT_IOQ_ACTIVE_ENTRIES__OWN = 4194304,
	P4_EVENT_IOQ_ACTIVE_ENTRIES__OTHER = 8388608,
	P4_EVENT_IOQ_ACTIVE_ENTRIES__PREFETCH = 16777216,
	P4_EVENT_FSB_DATA_ACTIVITY__DRDY_DRV = 512,
	P4_EVENT_FSB_DATA_ACTIVITY__DRDY_OWN = 1024,
	P4_EVENT_FSB_DATA_ACTIVITY__DRDY_OTHER = 2048,
	P4_EVENT_FSB_DATA_ACTIVITY__DBSY_DRV = 4096,
	P4_EVENT_FSB_DATA_ACTIVITY__DBSY_OWN = 8192,
	P4_EVENT_FSB_DATA_ACTIVITY__DBSY_OTHER = 16384,
	P4_EVENT_BSQ_ALLOCATION__REQ_TYPE0 = 512,
	P4_EVENT_BSQ_ALLOCATION__REQ_TYPE1 = 1024,
	P4_EVENT_BSQ_ALLOCATION__REQ_LEN0 = 2048,
	P4_EVENT_BSQ_ALLOCATION__REQ_LEN1 = 4096,
	P4_EVENT_BSQ_ALLOCATION__REQ_IO_TYPE = 16384,
	P4_EVENT_BSQ_ALLOCATION__REQ_LOCK_TYPE = 32768,
	P4_EVENT_BSQ_ALLOCATION__REQ_CACHE_TYPE = 65536,
	P4_EVENT_BSQ_ALLOCATION__REQ_SPLIT_TYPE = 131072,
	P4_EVENT_BSQ_ALLOCATION__REQ_DEM_TYPE = 262144,
	P4_EVENT_BSQ_ALLOCATION__REQ_ORD_TYPE = 524288,
	P4_EVENT_BSQ_ALLOCATION__MEM_TYPE0 = 1048576,
	P4_EVENT_BSQ_ALLOCATION__MEM_TYPE1 = 2097152,
	P4_EVENT_BSQ_ALLOCATION__MEM_TYPE2 = 4194304,
	P4_EVENT_BSQ_ACTIVE_ENTRIES__REQ_TYPE0 = 512,
	P4_EVENT_BSQ_ACTIVE_ENTRIES__REQ_TYPE1 = 1024,
	P4_EVENT_BSQ_ACTIVE_ENTRIES__REQ_LEN0 = 2048,
	P4_EVENT_BSQ_ACTIVE_ENTRIES__REQ_LEN1 = 4096,
	P4_EVENT_BSQ_ACTIVE_ENTRIES__REQ_IO_TYPE = 16384,
	P4_EVENT_BSQ_ACTIVE_ENTRIES__REQ_LOCK_TYPE = 32768,
	P4_EVENT_BSQ_ACTIVE_ENTRIES__REQ_CACHE_TYPE = 65536,
	P4_EVENT_BSQ_ACTIVE_ENTRIES__REQ_SPLIT_TYPE = 131072,
	P4_EVENT_BSQ_ACTIVE_ENTRIES__REQ_DEM_TYPE = 262144,
	P4_EVENT_BSQ_ACTIVE_ENTRIES__REQ_ORD_TYPE = 524288,
	P4_EVENT_BSQ_ACTIVE_ENTRIES__MEM_TYPE0 = 1048576,
	P4_EVENT_BSQ_ACTIVE_ENTRIES__MEM_TYPE1 = 2097152,
	P4_EVENT_BSQ_ACTIVE_ENTRIES__MEM_TYPE2 = 4194304,
	P4_EVENT_SSE_INPUT_ASSIST__ALL = 16777216,
	P4_EVENT_PACKED_SP_UOP__ALL = 16777216,
	P4_EVENT_PACKED_DP_UOP__ALL = 16777216,
	P4_EVENT_SCALAR_SP_UOP__ALL = 16777216,
	P4_EVENT_SCALAR_DP_UOP__ALL = 16777216,
	P4_EVENT_64BIT_MMX_UOP__ALL = 16777216,
	P4_EVENT_128BIT_MMX_UOP__ALL = 16777216,
	P4_EVENT_X87_FP_UOP__ALL = 16777216,
	P4_EVENT_TC_MISC__FLUSH = 8192,
	P4_EVENT_GLOBAL_POWER_EVENTS__RUNNING = 512,
	P4_EVENT_TC_MS_XFER__CISC = 512,
	P4_EVENT_UOP_QUEUE_WRITES__FROM_TC_BUILD = 512,
	P4_EVENT_UOP_QUEUE_WRITES__FROM_TC_DELIVER = 1024,
	P4_EVENT_UOP_QUEUE_WRITES__FROM_ROM = 2048,
	P4_EVENT_RETIRED_MISPRED_BRANCH_TYPE__CONDITIONAL = 1024,
	P4_EVENT_RETIRED_MISPRED_BRANCH_TYPE__CALL = 2048,
	P4_EVENT_RETIRED_MISPRED_BRANCH_TYPE__RETURN = 4096,
	P4_EVENT_RETIRED_MISPRED_BRANCH_TYPE__INDIRECT = 8192,
	P4_EVENT_RETIRED_BRANCH_TYPE__CONDITIONAL = 1024,
	P4_EVENT_RETIRED_BRANCH_TYPE__CALL = 2048,
	P4_EVENT_RETIRED_BRANCH_TYPE__RETURN = 4096,
	P4_EVENT_RETIRED_BRANCH_TYPE__INDIRECT = 8192,
	P4_EVENT_RESOURCE_STALL__SBFULL = 16384,
	P4_EVENT_WC_BUFFER__WCB_EVICTS = 512,
	P4_EVENT_WC_BUFFER__WCB_FULL_EVICTS = 1024,
	P4_EVENT_FRONT_END_EVENT__NBOGUS = 512,
	P4_EVENT_FRONT_END_EVENT__BOGUS = 1024,
	P4_EVENT_EXECUTION_EVENT__NBOGUS0 = 512,
	P4_EVENT_EXECUTION_EVENT__NBOGUS1 = 1024,
	P4_EVENT_EXECUTION_EVENT__NBOGUS2 = 2048,
	P4_EVENT_EXECUTION_EVENT__NBOGUS3 = 4096,
	P4_EVENT_EXECUTION_EVENT__BOGUS0 = 8192,
	P4_EVENT_EXECUTION_EVENT__BOGUS1 = 16384,
	P4_EVENT_EXECUTION_EVENT__BOGUS2 = 32768,
	P4_EVENT_EXECUTION_EVENT__BOGUS3 = 65536,
	P4_EVENT_REPLAY_EVENT__NBOGUS = 512,
	P4_EVENT_REPLAY_EVENT__BOGUS = 1024,
	P4_EVENT_INSTR_RETIRED__NBOGUSNTAG = 512,
	P4_EVENT_INSTR_RETIRED__NBOGUSTAG = 1024,
	P4_EVENT_INSTR_RETIRED__BOGUSNTAG = 2048,
	P4_EVENT_INSTR_RETIRED__BOGUSTAG = 4096,
	P4_EVENT_UOPS_RETIRED__NBOGUS = 512,
	P4_EVENT_UOPS_RETIRED__BOGUS = 1024,
	P4_EVENT_UOP_TYPE__TAGLOADS = 1024,
	P4_EVENT_UOP_TYPE__TAGSTORES = 2048,
	P4_EVENT_BRANCH_RETIRED__MMNP = 512,
	P4_EVENT_BRANCH_RETIRED__MMNM = 1024,
	P4_EVENT_BRANCH_RETIRED__MMTP = 2048,
	P4_EVENT_BRANCH_RETIRED__MMTM = 4096,
	P4_EVENT_MISPRED_BRANCH_RETIRED__NBOGUS = 512,
	P4_EVENT_X87_ASSIST__FPSU = 512,
	P4_EVENT_X87_ASSIST__FPSO = 1024,
	P4_EVENT_X87_ASSIST__POAO = 2048,
	P4_EVENT_X87_ASSIST__POAU = 4096,
	P4_EVENT_X87_ASSIST__PREA = 8192,
	P4_EVENT_MACHINE_CLEAR__CLEAR = 512,
	P4_EVENT_MACHINE_CLEAR__MOCLEAR = 1024,
	P4_EVENT_MACHINE_CLEAR__SMCLEAR = 2048,
	P4_EVENT_INSTR_COMPLETED__NBOGUS = 512,
	P4_EVENT_INSTR_COMPLETED__BOGUS = 1024,
};

enum P4_PEBS_METRIC {
	P4_PEBS_METRIC__none = 0,
	P4_PEBS_METRIC__1stl_cache_load_miss_retired = 1,
	P4_PEBS_METRIC__2ndl_cache_load_miss_retired = 2,
	P4_PEBS_METRIC__dtlb_load_miss_retired = 3,
	P4_PEBS_METRIC__dtlb_store_miss_retired = 4,
	P4_PEBS_METRIC__dtlb_all_miss_retired = 5,
	P4_PEBS_METRIC__tagged_mispred_branch = 6,
	P4_PEBS_METRIC__mob_load_replay_retired = 7,
	P4_PEBS_METRIC__split_load_retired = 8,
	P4_PEBS_METRIC__split_store_retired = 9,
	P4_PEBS_METRIC__max = 10,
};

struct p4_event_bind {
	unsigned int opcode;
	unsigned int escr_msr[2];
	unsigned int escr_emask;
	unsigned int shared;
	char cntr[6];
};

struct p4_pebs_bind {
	unsigned int metric_pebs;
	unsigned int metric_vert;
};

struct p4_event_alias {
	u64 original;
	u64 alternative;
};

enum cpuid_regs_idx {
	CPUID_EAX = 0,
	CPUID_EBX = 1,
	CPUID_ECX = 2,
	CPUID_EDX = 3,
};

struct dev_ext_attribute {
	struct device_attribute___2 attr;
	void *var;
};

enum pt_capabilities {
	PT_CAP_max_subleaf = 0,
	PT_CAP_cr3_filtering = 1,
	PT_CAP_psb_cyc = 2,
	PT_CAP_ip_filtering = 3,
	PT_CAP_mtc = 4,
	PT_CAP_ptwrite = 5,
	PT_CAP_power_event_trace = 6,
	PT_CAP_topa_output = 7,
	PT_CAP_topa_multiple_entries = 8,
	PT_CAP_single_range_output = 9,
	PT_CAP_output_subsys = 10,
	PT_CAP_payloads_lip = 11,
	PT_CAP_num_address_ranges = 12,
	PT_CAP_mtc_periods = 13,
	PT_CAP_cycle_thresholds = 14,
	PT_CAP_psb_periods = 15,
};

enum perf_addr_filter_action_t {
	PERF_ADDR_FILTER_ACTION_STOP = 0,
	PERF_ADDR_FILTER_ACTION_START = 1,
	PERF_ADDR_FILTER_ACTION_FILTER = 2,
};

struct perf_addr_filter {
	struct list_head entry;
	struct path___2 path;
	long unsigned int offset;
	long unsigned int size;
	enum perf_addr_filter_action_t action;
};

struct perf_pmu_events_attr___2 {
	struct device_attribute___2 attr;
	u64 id;
	const char *event_str;
};

struct topa_entry {
	u64 end: 1;
	u64 rsvd0: 1;
	u64 intr: 1;
	u64 rsvd1: 1;
	u64 stop: 1;
	u64 rsvd2: 1;
	u64 size: 4;
	u64 rsvd3: 2;
	u64 base: 36;
	u64 rsvd4: 16;
};

struct pt_pmu {
	struct pmu pmu;
	u32 caps[8];
	bool vmx;
	bool branch_en_always_on;
	long unsigned int max_nonturbo_ratio;
	unsigned int tsc_art_num;
	unsigned int tsc_art_den;
};

struct topa;

struct pt_buffer {
	struct list_head tables;
	struct topa *first;
	struct topa *last;
	struct topa *cur;
	unsigned int cur_idx;
	size_t output_off;
	long unsigned int nr_pages;
	local_t data_size;
	local64_t head;
	bool snapshot;
	bool single;
	long int stop_pos;
	long int intr_pos;
	struct topa_entry *stop_te;
	struct topa_entry *intr_te;
	void **data_pages;
};

struct topa {
	struct list_head list;
	u64 offset;
	size_t size;
	int last;
	unsigned int z_count;
};

struct pt_filter {
	long unsigned int msr_a;
	long unsigned int msr_b;
	long unsigned int config;
};

struct pt_filters {
	struct pt_filter filter[4];
	unsigned int nr_filters;
};

struct pt {
	struct perf_output_handle handle;
	struct pt_filters filters;
	int handle_nmi;
	int vmx_on;
	u64 output_base;
	u64 output_mask;
};

struct pt_cap_desc {
	const char *name;
	u32 leaf;
	u8 reg;
	u32 mask;
};

struct pt_address_range {
	long unsigned int msr_a;
	long unsigned int msr_b;
	unsigned int reg_off;
};

struct topa_page {
	struct topa_entry table[507];
	struct topa topa;
};

typedef void (*exitcall_t)();

struct x86_cpu_id {
	__u16 vendor;
	__u16 family;
	__u16 model;
	__u16 steppings;
	__u16 feature;
	kernel_ulong_t driver_data;
};

enum hrtimer_mode {
	HRTIMER_MODE_ABS = 0,
	HRTIMER_MODE_REL = 1,
	HRTIMER_MODE_PINNED = 2,
	HRTIMER_MODE_SOFT = 4,
	HRTIMER_MODE_HARD = 8,
	HRTIMER_MODE_ABS_PINNED = 2,
	HRTIMER_MODE_REL_PINNED = 3,
	HRTIMER_MODE_ABS_SOFT = 4,
	HRTIMER_MODE_REL_SOFT = 5,
	HRTIMER_MODE_ABS_PINNED_SOFT = 6,
	HRTIMER_MODE_REL_PINNED_SOFT = 7,
	HRTIMER_MODE_ABS_HARD = 8,
	HRTIMER_MODE_REL_HARD = 9,
	HRTIMER_MODE_ABS_PINNED_HARD = 10,
	HRTIMER_MODE_REL_PINNED_HARD = 11,
};

struct acpi_device;

struct pci_sysdata {
	int domain;
	int node;
	struct acpi_device *companion;
	void *iommu;
	void *fwnode;
	struct pci_dev *vmd_dev;
};

struct pci_extra_dev {
	struct pci_dev *dev[4];
};

struct intel_uncore_pmu;

struct intel_uncore_ops;

struct uncore_event_desc;

struct freerunning_counters;

struct intel_uncore_topology;

struct intel_uncore_type {
	const char *name;
	int num_counters;
	int num_boxes;
	int perf_ctr_bits;
	int fixed_ctr_bits;
	int num_freerunning_types;
	int type_id;
	unsigned int perf_ctr;
	unsigned int event_ctl;
	unsigned int event_mask;
	unsigned int event_mask_ext;
	unsigned int fixed_ctr;
	unsigned int fixed_ctl;
	unsigned int box_ctl;
	u64 *box_ctls;
	union {
		unsigned int msr_offset;
		unsigned int mmio_offset;
	};
	unsigned int mmio_map_size;
	unsigned int num_shared_regs: 8;
	unsigned int single_fixed: 1;
	unsigned int pair_ctr_ctl: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	union {
		unsigned int *msr_offsets;
		unsigned int *pci_offsets;
		unsigned int *mmio_offsets;
	};
	unsigned int *box_ids;
	struct event_constraint unconstrainted;
	struct event_constraint *constraints;
	struct intel_uncore_pmu *pmus;
	struct intel_uncore_ops *ops;
	struct uncore_event_desc *event_descs;
	struct freerunning_counters *freerunning;
	const struct attribute_group *attr_groups[4];
	const struct attribute_group **attr_update;
	struct pmu *pmu;
	struct intel_uncore_topology *topology;
	int (*get_topology)(struct intel_uncore_type *);
	int (*set_mapping)(struct intel_uncore_type *);
	void (*cleanup_mapping)(struct intel_uncore_type *);
};

struct intel_uncore_box;

struct intel_uncore_pmu {
	struct pmu pmu;
	char name[32];
	int pmu_idx;
	int func_id;
	bool registered;
	atomic_t activeboxes;
	struct intel_uncore_type *type;
	struct intel_uncore_box **boxes;
};

struct intel_uncore_ops {
	void (*init_box)(struct intel_uncore_box *);
	void (*exit_box)(struct intel_uncore_box *);
	void (*disable_box)(struct intel_uncore_box *);
	void (*enable_box)(struct intel_uncore_box *);
	void (*disable_event)(struct intel_uncore_box *, struct perf_event *);
	void (*enable_event)(struct intel_uncore_box *, struct perf_event *);
	u64 (*read_counter)(struct intel_uncore_box *, struct perf_event *);
	int (*hw_config)(struct intel_uncore_box *, struct perf_event *);
	struct event_constraint * (*get_constraint)(struct intel_uncore_box *, struct perf_event *);
	void (*put_constraint)(struct intel_uncore_box *, struct perf_event *);
};

struct uncore_event_desc {
	struct device_attribute___2 attr;
	const char *config;
};

struct freerunning_counters {
	unsigned int counter_base;
	unsigned int counter_offset;
	unsigned int box_offset;
	unsigned int num_counters;
	unsigned int bits;
	unsigned int *box_offsets;
};

struct intel_uncore_topology {
	u64 configuration;
	int segment;
};

struct intel_uncore_extra_reg {
	raw_spinlock_t lock;
	u64 config;
	u64 config1;
	u64 config2;
	atomic_t ref;
};

struct intel_uncore_box {
	int dieid;
	int n_active;
	int n_events;
	int cpu;
	long unsigned int flags;
	atomic_t refcnt;
	struct perf_event *events[10];
	struct perf_event *event_list[10];
	struct event_constraint *event_constraint[10];
	long unsigned int active_mask[1];
	u64 tags[10];
	struct pci_dev *pci_dev;
	struct intel_uncore_pmu *pmu;
	u64 hrtimer_duration;
	struct hrtimer hrtimer;
	struct list_head list;
	struct list_head active_list;
	void *io_addr;
	struct intel_uncore_extra_reg shared_regs[0];
};

struct pci2phy_map {
	struct list_head list;
	int segment;
	int pbus_to_dieid[256];
};

struct intel_uncore_init_fun {
	void (*cpu_init)();
	int (*pci_init)();
	void (*mmio_init)();
	bool use_discovery;
};

enum {
	EXTRA_REG_NHMEX_M_FILTER = 0,
	EXTRA_REG_NHMEX_M_DSP = 1,
	EXTRA_REG_NHMEX_M_ISS = 2,
	EXTRA_REG_NHMEX_M_MAP = 3,
	EXTRA_REG_NHMEX_M_MSC_THR = 4,
	EXTRA_REG_NHMEX_M_PGT = 5,
	EXTRA_REG_NHMEX_M_PLD = 6,
	EXTRA_REG_NHMEX_M_ZDP_CTL_FVC = 7,
};

enum {
	SNB_PCI_UNCORE_IMC = 0,
};

enum perf_snb_uncore_imc_freerunning_types {
	SNB_PCI_UNCORE_IMC_DATA_READS = 0,
	SNB_PCI_UNCORE_IMC_DATA_WRITES = 1,
	SNB_PCI_UNCORE_IMC_GT_REQUESTS = 2,
	SNB_PCI_UNCORE_IMC_IA_REQUESTS = 3,
	SNB_PCI_UNCORE_IMC_IO_REQUESTS = 4,
	SNB_PCI_UNCORE_IMC_FREERUNNING_TYPE_MAX = 5,
};

struct imc_uncore_pci_dev {
	__u32 pci_id;
	struct pci_driver *driver;
};

enum perf_tgl_uncore_imc_freerunning_types {
	TGL_MMIO_UNCORE_IMC_DATA_TOTAL = 0,
	TGL_MMIO_UNCORE_IMC_DATA_READ = 1,
	TGL_MMIO_UNCORE_IMC_DATA_WRITE = 2,
	TGL_MMIO_UNCORE_IMC_FREERUNNING_TYPE_MAX = 3,
};

enum uncore_access_type {
	UNCORE_ACCESS_MSR = 0,
	UNCORE_ACCESS_MMIO = 1,
	UNCORE_ACCESS_PCI = 2,
	UNCORE_ACCESS_MAX = 3,
};

enum {
	SNBEP_PCI_QPI_PORT0_FILTER = 0,
	SNBEP_PCI_QPI_PORT1_FILTER = 1,
	BDX_PCI_QPI_PORT2_FILTER = 2,
};

enum {
	SNBEP_PCI_UNCORE_HA = 0,
	SNBEP_PCI_UNCORE_IMC = 1,
	SNBEP_PCI_UNCORE_QPI = 2,
	SNBEP_PCI_UNCORE_R2PCIE = 3,
	SNBEP_PCI_UNCORE_R3QPI = 4,
};

enum {
	IVBEP_PCI_UNCORE_HA = 0,
	IVBEP_PCI_UNCORE_IMC = 1,
	IVBEP_PCI_UNCORE_IRP = 2,
	IVBEP_PCI_UNCORE_QPI = 3,
	IVBEP_PCI_UNCORE_R2PCIE = 4,
	IVBEP_PCI_UNCORE_R3QPI = 5,
};

enum {
	KNL_PCI_UNCORE_MC_UCLK = 0,
	KNL_PCI_UNCORE_MC_DCLK = 1,
	KNL_PCI_UNCORE_EDC_UCLK = 2,
	KNL_PCI_UNCORE_EDC_ECLK = 3,
	KNL_PCI_UNCORE_M2PCIE = 4,
	KNL_PCI_UNCORE_IRP = 5,
};

enum {
	HSWEP_PCI_UNCORE_HA = 0,
	HSWEP_PCI_UNCORE_IMC = 1,
	HSWEP_PCI_UNCORE_IRP = 2,
	HSWEP_PCI_UNCORE_QPI = 3,
	HSWEP_PCI_UNCORE_R2PCIE = 4,
	HSWEP_PCI_UNCORE_R3QPI = 5,
};

enum {
	BDX_PCI_UNCORE_HA = 0,
	BDX_PCI_UNCORE_IMC = 1,
	BDX_PCI_UNCORE_IRP = 2,
	BDX_PCI_UNCORE_QPI = 3,
	BDX_PCI_UNCORE_R2PCIE = 4,
	BDX_PCI_UNCORE_R3QPI = 5,
};

enum perf_uncore_iio_freerunning_type_id {
	SKX_IIO_MSR_IOCLK = 0,
	SKX_IIO_MSR_BW = 1,
	SKX_IIO_MSR_UTIL = 2,
	SKX_IIO_FREERUNNING_TYPE_MAX = 3,
};

enum {
	SKX_PCI_UNCORE_IMC = 0,
	SKX_PCI_UNCORE_M2M = 1,
	SKX_PCI_UNCORE_UPI = 2,
	SKX_PCI_UNCORE_M2PCIE = 3,
	SKX_PCI_UNCORE_M3UPI = 4,
};

enum {
	SNR_QAT_PMON_ID = 0,
	SNR_CBDMA_DMI_PMON_ID = 1,
	SNR_NIS_PMON_ID = 2,
	SNR_DLB_PMON_ID = 3,
	SNR_PCIE_GEN3_PMON_ID = 4,
};

enum perf_uncore_snr_iio_freerunning_type_id {
	SNR_IIO_MSR_IOCLK = 0,
	SNR_IIO_MSR_BW_IN = 1,
	SNR_IIO_FREERUNNING_TYPE_MAX = 2,
};

enum {
	SNR_PCI_UNCORE_M2M = 0,
	SNR_PCI_UNCORE_PCIE3 = 1,
};

enum perf_uncore_snr_imc_freerunning_type_id {
	SNR_IMC_DCLK = 0,
	SNR_IMC_DDR = 1,
	SNR_IMC_FREERUNNING_TYPE_MAX = 2,
};

enum {
	ICX_PCIE1_PMON_ID = 0,
	ICX_PCIE2_PMON_ID = 1,
	ICX_PCIE3_PMON_ID = 2,
	ICX_PCIE4_PMON_ID = 3,
	ICX_PCIE5_PMON_ID = 4,
	ICX_CBDMA_DMI_PMON_ID = 5,
};

enum perf_uncore_icx_iio_freerunning_type_id {
	ICX_IIO_MSR_IOCLK = 0,
	ICX_IIO_MSR_BW_IN = 1,
	ICX_IIO_FREERUNNING_TYPE_MAX = 2,
};

enum {
	ICX_PCI_UNCORE_M2M = 0,
	ICX_PCI_UNCORE_UPI = 1,
	ICX_PCI_UNCORE_M3UPI = 2,
};

enum perf_uncore_icx_imc_freerunning_type_id {
	ICX_IMC_DCLK = 0,
	ICX_IMC_DDR = 1,
	ICX_IMC_DDRT = 2,
	ICX_IMC_FREERUNNING_TYPE_MAX = 3,
};

enum perf_uncore_spr_iio_freerunning_type_id {
	SPR_IIO_MSR_IOCLK = 0,
	SPR_IIO_MSR_BW_IN = 1,
	SPR_IIO_MSR_BW_OUT = 2,
	SPR_IIO_FREERUNNING_TYPE_MAX = 3,
};

enum perf_uncore_spr_imc_freerunning_type_id {
	SPR_IMC_DCLK = 0,
	SPR_IMC_PQ_CYCLES = 1,
	SPR_IMC_FREERUNNING_TYPE_MAX = 2,
};

struct uncore_global_discovery {
	union {
		u64 table1;
		struct {
			u64 type: 8;
			u64 stride: 8;
			u64 max_units: 10;
			u64 __reserved_1: 36;
			u64 access_type: 2;
		};
	};
	u64 ctl;
	union {
		u64 table3;
		struct {
			u64 status_offset: 8;
			u64 num_status: 16;
			u64 __reserved_2: 40;
		};
	};
};

struct uncore_unit_discovery {
	union {
		u64 table1;
		struct {
			u64 num_regs: 8;
			u64 ctl_offset: 8;
			u64 bit_width: 8;
			u64 ctr_offset: 8;
			u64 status_offset: 8;
			u64 __reserved_1: 22;
			u64 access_type: 2;
		};
	};
	u64 ctl;
	union {
		u64 table3;
		struct {
			u64 box_type: 16;
			u64 box_id: 16;
			u64 __reserved_2: 32;
		};
	};
};

struct intel_uncore_discovery_type {
	struct rb_node node;
	enum uncore_access_type access_type;
	u64 box_ctrl;
	u64 *box_ctrl_die;
	u16 type;
	u8 num_counters;
	u8 counter_width;
	u8 ctl_offset;
	u8 ctr_offset;
	u16 num_boxes;
	unsigned int *ids;
	unsigned int *box_offset;
};

typedef s8 int8_t;

typedef u8 uint8_t;

typedef u64 uint64_t;

struct atomic_notifier_head {
	spinlock_t lock;
	struct notifier_block *head;
};

enum cpuhp_state___2 {
	CPUHP_INVALID___2 = 0,
	CPUHP_OFFLINE___2 = 0,
	CPUHP_CREATE_THREADS___2 = 1,
	CPUHP_PERF_PREPARE___2 = 2,
	CPUHP_PERF_X86_PREPARE___2 = 3,
	CPUHP_PERF_X86_AMD_UNCORE_PREP___2 = 4,
	CPUHP_PERF_POWER___2 = 5,
	CPUHP_PERF_SUPERH___2 = 6,
	CPUHP_X86_HPET_DEAD___2 = 7,
	CPUHP_X86_APB_DEAD___2 = 8,
	CPUHP_X86_MCE_DEAD___2 = 9,
	CPUHP_VIRT_NET_DEAD___2 = 10,
	CPUHP_SLUB_DEAD___2 = 11,
	CPUHP_DEBUG_OBJ_DEAD___2 = 12,
	CPUHP_MM_WRITEBACK_DEAD___2 = 13,
	CPUHP_MM_DEMOTION_DEAD___2 = 14,
	CPUHP_MM_VMSTAT_DEAD___2 = 15,
	CPUHP_SOFTIRQ_DEAD___2 = 16,
	CPUHP_NET_MVNETA_DEAD___2 = 17,
	CPUHP_CPUIDLE_DEAD___2 = 18,
	CPUHP_ARM64_FPSIMD_DEAD___2 = 19,
	CPUHP_ARM_OMAP_WAKE_DEAD___2 = 20,
	CPUHP_IRQ_POLL_DEAD___2 = 21,
	CPUHP_BLOCK_SOFTIRQ_DEAD___2 = 22,
	CPUHP_BIO_DEAD___2 = 23,
	CPUHP_ACPI_CPUDRV_DEAD___2 = 24,
	CPUHP_S390_PFAULT_DEAD___2 = 25,
	CPUHP_BLK_MQ_DEAD___2 = 26,
	CPUHP_FS_BUFF_DEAD___2 = 27,
	CPUHP_PRINTK_DEAD___2 = 28,
	CPUHP_MM_MEMCQ_DEAD___2 = 29,
	CPUHP_XFS_DEAD___2 = 30,
	CPUHP_PERCPU_CNT_DEAD___2 = 31,
	CPUHP_RADIX_DEAD___2 = 32,
	CPUHP_PAGE_ALLOC___2 = 33,
	CPUHP_NET_DEV_DEAD___2 = 34,
	CPUHP_PCI_XGENE_DEAD___2 = 35,
	CPUHP_IOMMU_IOVA_DEAD___2 = 36,
	CPUHP_LUSTRE_CFS_DEAD___2 = 37,
	CPUHP_AP_ARM_CACHE_B15_RAC_DEAD___2 = 38,
	CPUHP_PADATA_DEAD___2 = 39,
	CPUHP_WORKQUEUE_PREP___2 = 40,
	CPUHP_POWER_NUMA_PREPARE___2 = 41,
	CPUHP_HRTIMERS_PREPARE___2 = 42,
	CPUHP_PROFILE_PREPARE___2 = 43,
	CPUHP_X2APIC_PREPARE___2 = 44,
	CPUHP_SMPCFD_PREPARE___2 = 45,
	CPUHP_RELAY_PREPARE___2 = 46,
	CPUHP_SLAB_PREPARE___2 = 47,
	CPUHP_MD_RAID5_PREPARE___2 = 48,
	CPUHP_RCUTREE_PREP___2 = 49,
	CPUHP_CPUIDLE_COUPLED_PREPARE___2 = 50,
	CPUHP_POWERPC_PMAC_PREPARE___2 = 51,
	CPUHP_POWERPC_MMU_CTX_PREPARE___2 = 52,
	CPUHP_XEN_PREPARE___2 = 53,
	CPUHP_XEN_EVTCHN_PREPARE___2 = 54,
	CPUHP_ARM_SHMOBILE_SCU_PREPARE___2 = 55,
	CPUHP_SH_SH3X_PREPARE___2 = 56,
	CPUHP_NET_FLOW_PREPARE___2 = 57,
	CPUHP_TOPOLOGY_PREPARE___2 = 58,
	CPUHP_NET_IUCV_PREPARE___2 = 59,
	CPUHP_ARM_BL_PREPARE___2 = 60,
	CPUHP_TRACE_RB_PREPARE___2 = 61,
	CPUHP_MM_ZS_PREPARE___2 = 62,
	CPUHP_MM_ZSWP_MEM_PREPARE___2 = 63,
	CPUHP_MM_ZSWP_POOL_PREPARE___2 = 64,
	CPUHP_KVM_PPC_BOOK3S_PREPARE___2 = 65,
	CPUHP_ZCOMP_PREPARE___2 = 66,
	CPUHP_TIMERS_PREPARE___2 = 67,
	CPUHP_MIPS_SOC_PREPARE___2 = 68,
	CPUHP_BP_PREPARE_DYN___2 = 69,
	CPUHP_BP_PREPARE_DYN_END___2 = 89,
	CPUHP_BRINGUP_CPU___2 = 90,
	CPUHP_AP_IDLE_DEAD___2 = 91,
	CPUHP_AP_OFFLINE___2 = 92,
	CPUHP_AP_SCHED_STARTING___2 = 93,
	CPUHP_AP_RCUTREE_DYING___2 = 94,
	CPUHP_AP_CPU_PM_STARTING___2 = 95,
	CPUHP_AP_IRQ_GIC_STARTING___2 = 96,
	CPUHP_AP_IRQ_HIP04_STARTING___2 = 97,
	CPUHP_AP_IRQ_APPLE_AIC_STARTING___2 = 98,
	CPUHP_AP_IRQ_ARMADA_XP_STARTING___2 = 99,
	CPUHP_AP_IRQ_BCM2836_STARTING___2 = 100,
	CPUHP_AP_IRQ_MIPS_GIC_STARTING___2 = 101,
	CPUHP_AP_IRQ_RISCV_STARTING___2 = 102,
	CPUHP_AP_IRQ_SIFIVE_PLIC_STARTING___2 = 103,
	CPUHP_AP_ARM_MVEBU_COHERENCY___2 = 104,
	CPUHP_AP_MICROCODE_LOADER___2 = 105,
	CPUHP_AP_PERF_X86_AMD_UNCORE_STARTING___2 = 106,
	CPUHP_AP_PERF_X86_STARTING___2 = 107,
	CPUHP_AP_PERF_X86_AMD_IBS_STARTING___2 = 108,
	CPUHP_AP_PERF_X86_CQM_STARTING___2 = 109,
	CPUHP_AP_PERF_X86_CSTATE_STARTING___2 = 110,
	CPUHP_AP_PERF_XTENSA_STARTING___2 = 111,
	CPUHP_AP_MIPS_OP_LOONGSON3_STARTING___2 = 112,
	CPUHP_AP_ARM_SDEI_STARTING___2 = 113,
	CPUHP_AP_ARM_VFP_STARTING___2 = 114,
	CPUHP_AP_ARM64_DEBUG_MONITORS_STARTING___2 = 115,
	CPUHP_AP_PERF_ARM_HW_BREAKPOINT_STARTING___2 = 116,
	CPUHP_AP_PERF_ARM_ACPI_STARTING___2 = 117,
	CPUHP_AP_PERF_ARM_STARTING___2 = 118,
	CPUHP_AP_ARM_L2X0_STARTING___2 = 119,
	CPUHP_AP_EXYNOS4_MCT_TIMER_STARTING___2 = 120,
	CPUHP_AP_ARM_ARCH_TIMER_STARTING___2 = 121,
	CPUHP_AP_ARM_GLOBAL_TIMER_STARTING___2 = 122,
	CPUHP_AP_JCORE_TIMER_STARTING___2 = 123,
	CPUHP_AP_ARM_TWD_STARTING___2 = 124,
	CPUHP_AP_QCOM_TIMER_STARTING___2 = 125,
	CPUHP_AP_TEGRA_TIMER_STARTING___2 = 126,
	CPUHP_AP_ARMADA_TIMER_STARTING___2 = 127,
	CPUHP_AP_MARCO_TIMER_STARTING___2 = 128,
	CPUHP_AP_MIPS_GIC_TIMER_STARTING___2 = 129,
	CPUHP_AP_ARC_TIMER_STARTING___2 = 130,
	CPUHP_AP_RISCV_TIMER_STARTING___2 = 131,
	CPUHP_AP_CLINT_TIMER_STARTING___2 = 132,
	CPUHP_AP_CSKY_TIMER_STARTING___2 = 133,
	CPUHP_AP_TI_GP_TIMER_STARTING___2 = 134,
	CPUHP_AP_HYPERV_TIMER_STARTING___2 = 135,
	CPUHP_AP_KVM_STARTING___2 = 136,
	CPUHP_AP_KVM_ARM_VGIC_INIT_STARTING___2 = 137,
	CPUHP_AP_KVM_ARM_VGIC_STARTING___2 = 138,
	CPUHP_AP_KVM_ARM_TIMER_STARTING___2 = 139,
	CPUHP_AP_DUMMY_TIMER_STARTING___2 = 140,
	CPUHP_AP_ARM_XEN_STARTING___2 = 141,
	CPUHP_AP_ARM_CORESIGHT_STARTING___2 = 142,
	CPUHP_AP_ARM_CORESIGHT_CTI_STARTING___2 = 143,
	CPUHP_AP_ARM64_ISNDEP_STARTING___2 = 144,
	CPUHP_AP_SMPCFD_DYING___2 = 145,
	CPUHP_AP_X86_TBOOT_DYING___2 = 146,
	CPUHP_AP_ARM_CACHE_B15_RAC_DYING___2 = 147,
	CPUHP_AP_ONLINE___2 = 148,
	CPUHP_TEARDOWN_CPU___2 = 149,
	CPUHP_AP_ONLINE_IDLE___2 = 150,
	CPUHP_AP_SCHED_WAIT_EMPTY___2 = 151,
	CPUHP_AP_SMPBOOT_THREADS___2 = 152,
	CPUHP_AP_X86_VDSO_VMA_ONLINE___2 = 153,
	CPUHP_AP_IRQ_AFFINITY_ONLINE___2 = 154,
	CPUHP_AP_BLK_MQ_ONLINE___2 = 155,
	CPUHP_AP_ARM_MVEBU_SYNC_CLOCKS___2 = 156,
	CPUHP_AP_X86_INTEL_EPB_ONLINE___2 = 157,
	CPUHP_AP_PERF_ONLINE___2 = 158,
	CPUHP_AP_PERF_X86_ONLINE___2 = 159,
	CPUHP_AP_PERF_X86_UNCORE_ONLINE___2 = 160,
	CPUHP_AP_PERF_X86_AMD_UNCORE_ONLINE___2 = 161,
	CPUHP_AP_PERF_X86_AMD_POWER_ONLINE___2 = 162,
	CPUHP_AP_PERF_X86_RAPL_ONLINE___2 = 163,
	CPUHP_AP_PERF_X86_CQM_ONLINE___2 = 164,
	CPUHP_AP_PERF_X86_CSTATE_ONLINE___2 = 165,
	CPUHP_AP_PERF_X86_IDXD_ONLINE___2 = 166,
	CPUHP_AP_PERF_S390_CF_ONLINE___2 = 167,
	CPUHP_AP_PERF_S390_SF_ONLINE___2 = 168,
	CPUHP_AP_PERF_ARM_CCI_ONLINE___2 = 169,
	CPUHP_AP_PERF_ARM_CCN_ONLINE___2 = 170,
	CPUHP_AP_PERF_ARM_HISI_DDRC_ONLINE___2 = 171,
	CPUHP_AP_PERF_ARM_HISI_HHA_ONLINE___2 = 172,
	CPUHP_AP_PERF_ARM_HISI_L3_ONLINE___2 = 173,
	CPUHP_AP_PERF_ARM_HISI_PA_ONLINE___2 = 174,
	CPUHP_AP_PERF_ARM_HISI_SLLC_ONLINE___2 = 175,
	CPUHP_AP_PERF_ARM_L2X0_ONLINE___2 = 176,
	CPUHP_AP_PERF_ARM_QCOM_L2_ONLINE___2 = 177,
	CPUHP_AP_PERF_ARM_QCOM_L3_ONLINE___2 = 178,
	CPUHP_AP_PERF_ARM_APM_XGENE_ONLINE___2 = 179,
	CPUHP_AP_PERF_ARM_CAVIUM_TX2_UNCORE_ONLINE___2 = 180,
	CPUHP_AP_PERF_POWERPC_NEST_IMC_ONLINE___2 = 181,
	CPUHP_AP_PERF_POWERPC_CORE_IMC_ONLINE___2 = 182,
	CPUHP_AP_PERF_POWERPC_THREAD_IMC_ONLINE___2 = 183,
	CPUHP_AP_PERF_POWERPC_TRACE_IMC_ONLINE___2 = 184,
	CPUHP_AP_PERF_POWERPC_HV_24x7_ONLINE___2 = 185,
	CPUHP_AP_PERF_POWERPC_HV_GPCI_ONLINE___2 = 186,
	CPUHP_AP_PERF_CSKY_ONLINE___2 = 187,
	CPUHP_AP_WATCHDOG_ONLINE___2 = 188,
	CPUHP_AP_WORKQUEUE_ONLINE___2 = 189,
	CPUHP_AP_RCUTREE_ONLINE___2 = 190,
	CPUHP_AP_BASE_CACHEINFO_ONLINE___2 = 191,
	CPUHP_AP_ONLINE_DYN___2 = 192,
	CPUHP_AP_ONLINE_DYN_END___2 = 222,
	CPUHP_AP_MM_DEMOTION_ONLINE___2 = 223,
	CPUHP_AP_X86_HPET_ONLINE___2 = 224,
	CPUHP_AP_X86_KVM_CLK_ONLINE___2 = 225,
	CPUHP_AP_DTPM_CPU_ONLINE___2 = 226,
	CPUHP_AP_ACTIVE___2 = 227,
	CPUHP_ONLINE___2 = 228,
};

enum xen_domain_type {
	XEN_NATIVE = 0,
	XEN_PV_DOMAIN = 1,
	XEN_HVM_DOMAIN = 2,
};

typedef long unsigned int xen_pfn_t;

typedef long unsigned int xen_ulong_t;

struct arch_shared_info {
	long unsigned int max_pfn;
	xen_pfn_t pfn_to_mfn_frame_list_list;
	long unsigned int nmi_reason;
	long unsigned int p2m_cr3;
	long unsigned int p2m_vaddr;
	long unsigned int p2m_generation;
};

struct arch_vcpu_info {
	long unsigned int cr2;
	long unsigned int pad;
};

struct pvclock_wall_clock {
	u32 version;
	u32 sec;
	u32 nsec;
};

struct vcpu_info {
	uint8_t evtchn_upcall_pending;
	uint8_t evtchn_upcall_mask;
	xen_ulong_t evtchn_pending_sel;
	struct arch_vcpu_info arch;
	struct pvclock_vcpu_time_info time;
};

struct shared_info {
	struct vcpu_info vcpu_info[32];
	xen_ulong_t evtchn_pending[64];
	xen_ulong_t evtchn_mask[64];
	struct pvclock_wall_clock wc;
	uint32_t wc_sec_hi;
	struct arch_shared_info arch;
};

struct start_info {
	char magic[32];
	long unsigned int nr_pages;
	long unsigned int shared_info;
	uint32_t flags;
	xen_pfn_t store_mfn;
	uint32_t store_evtchn;
	union {
		struct {
			xen_pfn_t mfn;
			uint32_t evtchn;
		} domU;
		struct {
			uint32_t info_off;
			uint32_t info_size;
		} dom0;
	} console;
	long unsigned int pt_base;
	long unsigned int nr_pt_frames;
	long unsigned int mfn_list;
	long unsigned int mod_start;
	long unsigned int mod_len;
	int8_t cmd_line[1024];
	long unsigned int first_p2m_pfn;
	long unsigned int nr_p2m_frames;
};

struct sched_shutdown {
	unsigned int reason;
};

struct sched_pin_override {
	int32_t pcpu;
};

struct xen_extraversion {
	char extraversion[16];
};

struct vcpu_register_vcpu_info {
	uint64_t mfn;
	uint32_t offset;
	uint32_t rsvd;
};

struct xmaddr {
	phys_addr_t maddr;
};

typedef struct xmaddr xmaddr_t;

struct xpaddr {
	phys_addr_t paddr;
};

typedef struct xpaddr xpaddr_t;

typedef s16 int16_t;

typedef u16 uint16_t;

enum clocksource_ids {
	CSID_GENERIC = 0,
	CSID_ARM_ARCH_COUNTER = 1,
	CSID_MAX = 2,
};

struct clocksource {
	u64 (*read)(struct clocksource *);
	u64 mask;
	u32 mult;
	u32 shift;
	u64 max_idle_ns;
	u32 maxadj;
	u32 uncertainty_margin;
	u64 max_cycles;
	const char *name;
	struct list_head list;
	int rating;
	enum clocksource_ids id;
	enum vdso_clock_mode vdso_clock_mode;
	long unsigned int flags;
	int (*enable)(struct clocksource *);
	void (*disable)(struct clocksource *);
	void (*suspend)(struct clocksource *);
	void (*resume)(struct clocksource *);
	void (*mark_unstable)(struct clocksource *);
	void (*tick_stable)(struct clocksource *);
	struct list_head wd_list;
	u64 cs_last;
	u64 wd_last;
	struct module *owner;
};

struct x86_init_mpparse {
	void (*setup_ioapic_ids)();
	void (*find_smp_config)();
	void (*get_smp_config)(unsigned int);
};

struct x86_init_resources {
	void (*probe_roms)();
	void (*reserve_resources)();
	char * (*memory_setup)();
};

struct x86_init_irqs {
	void (*pre_vector_init)();
	void (*intr_init)();
	void (*intr_mode_select)();
	void (*intr_mode_init)();
	struct irq_domain___3 * (*create_pci_msi_domain)();
};

struct x86_init_oem {
	void (*arch_setup)();
	void (*banner)();
};

struct x86_init_paging {
	void (*pagetable_init)();
};

struct x86_init_timers {
	void (*setup_percpu_clockev)();
	void (*timer_init)();
	void (*wallclock_init)();
};

struct x86_init_iommu {
	int (*iommu_init)();
};

struct x86_init_pci {
	int (*arch_init)();
	int (*init)();
	void (*init_irq)();
	void (*fixup_irqs)();
};

struct x86_hyper_init {
	void (*init_platform)();
	void (*guest_late_init)();
	bool (*x2apic_available)();
	bool (*msi_ext_dest_id)();
	void (*init_mem_mapping)();
	void (*init_after_bootmem)();
};

struct x86_init_acpi {
	void (*set_root_pointer)(u64);
	u64 (*get_root_pointer)();
	void (*reduced_hw_early_init)();
};

struct x86_init_ops {
	struct x86_init_resources resources;
	struct x86_init_mpparse mpparse;
	struct x86_init_irqs irqs;
	struct x86_init_oem oem;
	struct x86_init_paging paging;
	struct x86_init_timers timers;
	struct x86_init_iommu iommu;
	struct x86_init_pci pci;
	struct x86_hyper_init hyper;
	struct x86_init_acpi acpi;
};

struct x86_cpuinit_ops {
	void (*setup_percpu_clockev)();
	void (*early_percpu_clock_init)();
	void (*fixup_cpu_id)(struct cpuinfo_x86 *, int);
};

enum clock_event_state {
	CLOCK_EVT_STATE_DETACHED = 0,
	CLOCK_EVT_STATE_SHUTDOWN = 1,
	CLOCK_EVT_STATE_PERIODIC = 2,
	CLOCK_EVT_STATE_ONESHOT = 3,
	CLOCK_EVT_STATE_ONESHOT_STOPPED = 4,
};

struct clock_event_device {
	void (*event_handler)(struct clock_event_device *);
	int (*set_next_event)(long unsigned int, struct clock_event_device *);
	int (*set_next_ktime)(ktime_t, struct clock_event_device *);
	ktime_t next_event;
	u64 max_delta_ns;
	u64 min_delta_ns;
	u32 mult;
	u32 shift;
	enum clock_event_state state_use_accessors;
	unsigned int features;
	long unsigned int retries;
	int (*set_state_periodic)(struct clock_event_device *);
	int (*set_state_oneshot)(struct clock_event_device *);
	int (*set_state_oneshot_stopped)(struct clock_event_device *);
	int (*set_state_shutdown)(struct clock_event_device *);
	int (*tick_resume)(struct clock_event_device *);
	void (*broadcast)(const struct cpumask *);
	void (*suspend)(struct clock_event_device *);
	void (*resume)(struct clock_event_device *);
	long unsigned int min_delta_ticks;
	long unsigned int max_delta_ticks;
	const char *name;
	int rating;
	int irq;
	int bound_on;
	const struct cpumask *cpumask;
	struct list_head list;
	struct module *owner;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct tk_read_base {
	struct clocksource *clock;
	u64 mask;
	u64 cycle_last;
	u32 mult;
	u32 shift;
	u64 xtime_nsec;
	ktime_t base;
	u64 base_real;
};

struct timekeeper {
	struct tk_read_base tkr_mono;
	struct tk_read_base tkr_raw;
	u64 xtime_sec;
	long unsigned int ktime_sec;
	struct timespec64 wall_to_monotonic;
	ktime_t offs_real;
	ktime_t offs_boot;
	ktime_t offs_tai;
	s32 tai_offset;
	unsigned int clock_was_set_seq;
	u8 cs_was_changed_seq;
	ktime_t next_leap_ktime;
	u64 raw_sec;
	struct timespec64 monotonic_to_boot;
	u64 cycle_interval;
	u64 xtime_interval;
	s64 xtime_remainder;
	u64 raw_interval;
	u64 ntp_tick;
	s64 ntp_error;
	u32 ntp_error_shift;
	u32 ntp_err_mult;
	u32 skip_second_overflow;
};

typedef unsigned char *__guest_handle_uchar;

typedef char *__guest_handle_char;

typedef void *__guest_handle_void;

typedef uint64_t *__guest_handle_uint64_t;

typedef uint32_t *__guest_handle_uint32_t;

struct vcpu_time_info {
	uint32_t version;
	uint32_t pad0;
	uint64_t tsc_timestamp;
	uint64_t system_time;
	uint32_t tsc_to_system_mul;
	int8_t tsc_shift;
	int8_t pad1[3];
};

struct xenpf_settime32 {
	uint32_t secs;
	uint32_t nsecs;
	uint64_t system_time;
};

struct xenpf_settime64 {
	uint64_t secs;
	uint32_t nsecs;
	uint32_t mbz;
	uint64_t system_time;
};

struct xenpf_add_memtype {
	xen_pfn_t mfn;
	uint64_t nr_mfns;
	uint32_t type;
	uint32_t handle;
	uint32_t reg;
};

struct xenpf_del_memtype {
	uint32_t handle;
	uint32_t reg;
};

struct xenpf_read_memtype {
	uint32_t reg;
	xen_pfn_t mfn;
	uint64_t nr_mfns;
	uint32_t type;
};

struct xenpf_microcode_update {
	__guest_handle_void data;
	uint32_t length;
};

struct xenpf_platform_quirk {
	uint32_t quirk_id;
};

struct xenpf_efi_time {
	uint16_t year;
	uint8_t month;
	uint8_t day;
	uint8_t hour;
	uint8_t min;
	uint8_t sec;
	uint32_t ns;
	int16_t tz;
	uint8_t daylight;
};

struct xenpf_efi_guid {
	uint32_t data1;
	uint16_t data2;
	uint16_t data3;
	uint8_t data4[8];
};

struct xenpf_efi_runtime_call {
	uint32_t function;
	uint32_t misc;
	xen_ulong_t status;
	union {
		struct {
			struct xenpf_efi_time time;
			uint32_t resolution;
			uint32_t accuracy;
		} get_time;
		struct xenpf_efi_time set_time;
		struct xenpf_efi_time get_wakeup_time;
		struct xenpf_efi_time set_wakeup_time;
		struct {
			__guest_handle_void name;
			xen_ulong_t size;
			__guest_handle_void data;
			struct xenpf_efi_guid vendor_guid;
		} get_variable;
		struct {
			__guest_handle_void name;
			xen_ulong_t size;
			__guest_handle_void data;
			struct xenpf_efi_guid vendor_guid;
		} set_variable;
		struct {
			xen_ulong_t size;
			__guest_handle_void name;
			struct xenpf_efi_guid vendor_guid;
		} get_next_variable_name;
		struct {
			uint32_t attr;
			uint64_t max_store_size;
			uint64_t remain_store_size;
			uint64_t max_size;
		} query_variable_info;
		struct {
			__guest_handle_void capsule_header_array;
			xen_ulong_t capsule_count;
			uint64_t max_capsule_size;
			uint32_t reset_type;
		} query_capsule_capabilities;
		struct {
			__guest_handle_void capsule_header_array;
			xen_ulong_t capsule_count;
			uint64_t sg_list;
		} update_capsule;
	} u;
};

union xenpf_efi_info {
	uint32_t version;
	struct {
		uint64_t addr;
		uint32_t nent;
	} cfg;
	struct {
		uint32_t revision;
		uint32_t bufsz;
		__guest_handle_void name;
	} vendor;
	struct {
		uint64_t addr;
		uint64_t size;
		uint64_t attr;
		uint32_t type;
	} mem;
};

struct xenpf_firmware_info {
	uint32_t type;
	uint32_t index;
	union {
		struct {
			uint8_t device;
			uint8_t version;
			uint16_t interface_support;
			uint16_t legacy_max_cylinder;
			uint8_t legacy_max_head;
			uint8_t legacy_sectors_per_track;
			__guest_handle_void edd_params;
		} disk_info;
		struct {
			uint8_t device;
			uint32_t mbr_signature;
		} disk_mbr_signature;
		struct {
			uint8_t capabilities;
			uint8_t edid_transfer_time;
			__guest_handle_uchar edid;
		} vbeddc_info;
		union xenpf_efi_info efi_info;
		uint8_t kbd_shift_flags;
	} u;
};

struct xenpf_enter_acpi_sleep {
	uint16_t val_a;
	uint16_t val_b;
	uint32_t sleep_state;
	uint32_t flags;
};

struct xenpf_change_freq {
	uint32_t flags;
	uint32_t cpu;
	uint64_t freq;
};

struct xenpf_getidletime {
	__guest_handle_uchar cpumap_bitmap;
	uint32_t cpumap_nr_cpus;
	__guest_handle_uint64_t idletime;
	uint64_t now;
};

struct xen_power_register {
	uint32_t space_id;
	uint32_t bit_width;
	uint32_t bit_offset;
	uint32_t access_size;
	uint64_t address;
};

struct xen_processor_csd {
	uint32_t domain;
	uint32_t coord_type;
	uint32_t num;
};

typedef struct xen_processor_csd *__guest_handle_xen_processor_csd;

struct xen_processor_cx {
	struct xen_power_register reg;
	uint8_t type;
	uint32_t latency;
	uint32_t power;
	uint32_t dpcnt;
	__guest_handle_xen_processor_csd dp;
};

typedef struct xen_processor_cx *__guest_handle_xen_processor_cx;

struct xen_processor_flags {
	uint32_t bm_control: 1;
	uint32_t bm_check: 1;
	uint32_t has_cst: 1;
	uint32_t power_setup_done: 1;
	uint32_t bm_rld_set: 1;
};

struct xen_processor_power {
	uint32_t count;
	struct xen_processor_flags flags;
	__guest_handle_xen_processor_cx states;
};

struct xen_pct_register {
	uint8_t descriptor;
	uint16_t length;
	uint8_t space_id;
	uint8_t bit_width;
	uint8_t bit_offset;
	uint8_t reserved;
	uint64_t address;
};

struct xen_processor_px {
	uint64_t core_frequency;
	uint64_t power;
	uint64_t transition_latency;
	uint64_t bus_master_latency;
	uint64_t control;
	uint64_t status;
};

typedef struct xen_processor_px *__guest_handle_xen_processor_px;

struct xen_psd_package {
	uint64_t num_entries;
	uint64_t revision;
	uint64_t domain;
	uint64_t coord_type;
	uint64_t num_processors;
};

struct xen_processor_performance {
	uint32_t flags;
	uint32_t platform_limit;
	struct xen_pct_register control_register;
	struct xen_pct_register status_register;
	uint32_t state_count;
	__guest_handle_xen_processor_px states;
	struct xen_psd_package domain_info;
	uint32_t shared_type;
};

struct xenpf_set_processor_pminfo {
	uint32_t id;
	uint32_t type;
	union {
		struct xen_processor_power power;
		struct xen_processor_performance perf;
		__guest_handle_uint32_t pdc;
	};
};

struct xenpf_pcpuinfo {
	uint32_t xen_cpuid;
	uint32_t max_present;
	uint32_t flags;
	uint32_t apic_id;
	uint32_t acpi_id;
};

struct xenpf_cpu_ol {
	uint32_t cpuid;
};

struct xenpf_cpu_hotadd {
	uint32_t apic_id;
	uint32_t acpi_id;
	uint32_t pxm;
};

struct xenpf_mem_hotadd {
	uint64_t spfn;
	uint64_t epfn;
	uint32_t pxm;
	uint32_t flags;
};

struct xenpf_core_parking {
	uint32_t type;
	uint32_t idle_nums;
};

struct xenpf_symdata {
	uint32_t namelen;
	uint32_t symnum;
	__guest_handle_char name;
	uint64_t address;
	char type;
};

struct xen_platform_op {
	uint32_t cmd;
	uint32_t interface_version;
	union {
		struct xenpf_settime32 settime32;
		struct xenpf_settime64 settime64;
		struct xenpf_add_memtype add_memtype;
		struct xenpf_del_memtype del_memtype;
		struct xenpf_read_memtype read_memtype;
		struct xenpf_microcode_update microcode;
		struct xenpf_platform_quirk platform_quirk;
		struct xenpf_efi_runtime_call efi_runtime_call;
		struct xenpf_firmware_info firmware_info;
		struct xenpf_enter_acpi_sleep enter_acpi_sleep;
		struct xenpf_change_freq change_freq;
		struct xenpf_getidletime getidletime;
		struct xenpf_set_processor_pminfo set_pminfo;
		struct xenpf_pcpuinfo pcpu_info;
		struct xenpf_cpu_ol cpu_ol;
		struct xenpf_cpu_hotadd cpu_add;
		struct xenpf_mem_hotadd mem_add;
		struct xenpf_core_parking core_parking;
		struct xenpf_symdata symdata;
		uint8_t pad[128];
	} u;
};

struct vcpu_set_singleshot_timer {
	uint64_t timeout_abs_ns;
	uint32_t flags;
};

typedef struct vcpu_time_info *__guest_handle_vcpu_time_info;

struct vcpu_register_time_memory_area {
	union {
		__guest_handle_vcpu_time_info h;
		struct pvclock_vcpu_time_info *v;
		uint64_t p;
	} addr;
};

struct xen_clock_event_device {
	struct clock_event_device evt;
	char name[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef int (*pte_fn_t)(pte_t *, long unsigned int, void *);

typedef uint16_t grant_status_t;

struct grant_frames {
	xen_pfn_t *pfn;
	unsigned int count;
	void *vaddr;
};

struct gnttab_vm_area {
	struct vm_struct___3 *area;
	pte_t **ptes;
	int idx;
};

enum acpi_irq_model_id {
	ACPI_IRQ_MODEL_PIC = 0,
	ACPI_IRQ_MODEL_IOAPIC = 1,
	ACPI_IRQ_MODEL_IOSAPIC = 2,
	ACPI_IRQ_MODEL_PLATFORM = 3,
	ACPI_IRQ_MODEL_GIC = 4,
	ACPI_IRQ_MODEL_COUNT = 5,
};

typedef uint16_t domid_t;

struct xen_add_to_physmap {
	domid_t domid;
	uint16_t size;
	unsigned int space;
	xen_ulong_t idx;
	xen_pfn_t gpfn;
};

struct machine_ops {
	void (*restart)(char *);
	void (*halt)();
	void (*power_off)();
	void (*shutdown)();
	void (*crash_shutdown)(struct pt_regs *);
	void (*emergency_restart)();
};

enum cgroup_bpf_attach_type___2 {
	CGROUP_BPF_ATTACH_TYPE_INVALID___2 = 4294967295,
	CGROUP_INET_INGRESS___2 = 0,
	CGROUP_INET_EGRESS___2 = 1,
	CGROUP_INET_SOCK_CREATE___2 = 2,
	CGROUP_SOCK_OPS___2 = 3,
	CGROUP_DEVICE___2 = 4,
	CGROUP_INET4_BIND___2 = 5,
	CGROUP_INET6_BIND___2 = 6,
	CGROUP_INET4_CONNECT___2 = 7,
	CGROUP_INET6_CONNECT___2 = 8,
	CGROUP_INET4_POST_BIND___2 = 9,
	CGROUP_INET6_POST_BIND___2 = 10,
	CGROUP_UDP4_SENDMSG___2 = 11,
	CGROUP_UDP6_SENDMSG___2 = 12,
	CGROUP_SYSCTL___2 = 13,
	CGROUP_UDP4_RECVMSG___2 = 14,
	CGROUP_UDP6_RECVMSG___2 = 15,
	CGROUP_GETSOCKOPT___2 = 16,
	CGROUP_SETSOCKOPT___2 = 17,
	CGROUP_INET4_GETPEERNAME___2 = 18,
	CGROUP_INET6_GETPEERNAME___2 = 19,
	CGROUP_INET4_GETSOCKNAME___2 = 20,
	CGROUP_INET6_GETSOCKNAME___2 = 21,
	CGROUP_INET_SOCK_RELEASE___2 = 22,
	MAX_CGROUP_BPF_ATTACH_TYPE___2 = 23,
};

enum x86_hypervisor_type {
	X86_HYPER_NATIVE = 0,
	X86_HYPER_VMWARE = 1,
	X86_HYPER_MS_HYPERV = 2,
	X86_HYPER_XEN_PV = 3,
	X86_HYPER_XEN_HVM = 4,
	X86_HYPER_KVM = 5,
	X86_HYPER_JAILHOUSE = 6,
	X86_HYPER_ACRN = 7,
};

struct hypervisor_x86 {
	const char *name;
	uint32_t (*detect)();
	enum x86_hypervisor_type type;
	struct x86_hyper_init init;
	struct x86_hyper_runtime runtime;
	bool ignore_nopv;
};

enum e820_type {
	E820_TYPE_RAM = 1,
	E820_TYPE_RESERVED = 2,
	E820_TYPE_ACPI = 3,
	E820_TYPE_NVS = 4,
	E820_TYPE_UNUSABLE = 5,
	E820_TYPE_PMEM = 7,
	E820_TYPE_PRAM = 12,
	E820_TYPE_SOFT_RESERVED = 4026531839,
	E820_TYPE_RESERVED_KERN = 128,
};

struct xen_hvm_pagetable_dying {
	domid_t domid;
	__u64 gpa;
};

enum hvmmem_type_t {
	HVMMEM_ram_rw = 0,
	HVMMEM_ram_ro = 1,
	HVMMEM_mmio_dm = 2,
};

struct xen_hvm_get_mem_type {
	domid_t domid;
	uint16_t mem_type;
	uint16_t pad[2];
	uint64_t pfn;
};

struct jump_entry___2 {
	s32 code;
	s32 target;
	long int key;
};

struct static_key___2 {
	atomic_t enabled;
	union {
		long unsigned int type;
		struct jump_entry___2 *entries;
		struct static_key_mod *next;
	};
};

struct static_key_true___2 {
	struct static_key___2 key;
	long: 64;
	long: 64;
};

struct static_key_false___2 {
	struct static_key___2 key;
	long: 64;
	long: 64;
};

struct _ddebug___2 {
	const char *modname;
	const char *function;
	const char *filename;
	const char *format;
	unsigned int lineno: 18;
	unsigned int flags: 8;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	union {
		struct static_key_true___2 dd_key_true;
		struct static_key_false___2 dd_key_false;
	} key;
};

struct e820_entry {
	u64 addr;
	u64 size;
	enum e820_type type;
} __attribute__((packed));

struct e820_table {
	__u32 nr_entries;
	struct e820_entry entries[3200];
} __attribute__((packed));

typedef xen_pfn_t *__guest_handle_xen_pfn_t;

typedef long unsigned int xen_callback_t;

struct mmu_update {
	uint64_t ptr;
	uint64_t val;
};

struct xen_memory_region {
	long unsigned int start_pfn;
	long unsigned int n_pfns;
};

struct callback_register {
	uint16_t type;
	uint16_t flags;
	xen_callback_t address;
};

struct xen_memory_reservation {
	__guest_handle_xen_pfn_t extent_start;
	xen_ulong_t nr_extents;
	unsigned int extent_order;
	unsigned int address_bits;
	domid_t domid;
};

struct xen_memory_map {
	unsigned int nr_entries;
	__guest_handle_void buffer;
};

struct x86_apic_ops {
	unsigned int (*io_apic_read)(unsigned int, unsigned int);
	void (*restore)();
};

struct physdev_apic {
	long unsigned int apic_physbase;
	uint32_t reg;
	uint32_t value;
};

struct xen_processor_flags___2 {
	uint32_t bm_control;
	uint32_t bm_check;
	uint32_t has_cst;
	uint32_t power_setup_done;
	uint32_t bm_rld_set;
};

struct xen_processor_power___2 {
	uint32_t count;
	struct xen_processor_flags___2 flags;
	__guest_handle_xen_processor_cx states;
};

struct xenpf_set_processor_pminfo___2 {
	uint32_t id;
	uint32_t type;
	union {
		struct xen_processor_power___2 power;
		struct xen_processor_performance perf;
		__guest_handle_uint32_t pdc;
	};
};

struct xen_platform_op___2 {
	uint32_t cmd;
	uint32_t interface_version;
	union {
		struct xenpf_settime32 settime32;
		struct xenpf_settime64 settime64;
		struct xenpf_add_memtype add_memtype;
		struct xenpf_del_memtype del_memtype;
		struct xenpf_read_memtype read_memtype;
		struct xenpf_microcode_update microcode;
		struct xenpf_platform_quirk platform_quirk;
		struct xenpf_efi_runtime_call efi_runtime_call;
		struct xenpf_firmware_info firmware_info;
		struct xenpf_enter_acpi_sleep enter_acpi_sleep;
		struct xenpf_change_freq change_freq;
		struct xenpf_getidletime getidletime;
		struct xenpf_set_processor_pminfo___2 set_pminfo;
		struct xenpf_pcpuinfo pcpu_info;
		struct xenpf_cpu_ol cpu_ol;
		struct xenpf_cpu_hotadd cpu_add;
		struct xenpf_mem_hotadd mem_add;
		struct xenpf_core_parking core_parking;
		struct xenpf_symdata symdata;
		uint8_t pad[128];
	} u;
};

typedef long unsigned int uintptr_t;

struct xen_pmu_amd_ctxt {
	uint32_t counters;
	uint32_t ctrls;
	uint64_t regs[0];
};

struct xen_pmu_cntr_pair {
	uint64_t counter;
	uint64_t control;
};

struct xen_pmu_intel_ctxt {
	uint32_t fixed_counters;
	uint32_t arch_counters;
	uint64_t global_ctrl;
	uint64_t global_ovf_ctrl;
	uint64_t global_status;
	uint64_t fixed_ctrl;
	uint64_t ds_area;
	uint64_t pebs_enable;
	uint64_t debugctl;
	uint64_t regs[0];
};

struct xen_pmu_regs {
	uint64_t ip;
	uint64_t sp;
	uint64_t flags;
	uint16_t cs;
	uint16_t ss;
	uint8_t cpl;
	uint8_t pad[3];
};

struct xen_pmu_arch {
	union {
		struct xen_pmu_regs regs;
		uint8_t pad[64];
	} r;
	uint64_t pmu_flags;
	union {
		uint32_t lapic_lvtpc;
		uint64_t pad;
	} l;
	union {
		struct xen_pmu_amd_ctxt amd;
		struct xen_pmu_intel_ctxt intel;
		uint8_t pad[128];
	} c;
};

struct xen_pmu_params {
	struct {
		uint32_t maj;
		uint32_t min;
	} version;
	uint64_t val;
	uint32_t vcpu;
	uint32_t pad;
};

struct xen_pmu_data {
	uint32_t vcpu_id;
	uint32_t pcpu_id;
	domid_t domain_id;
	uint8_t pad[6];
	struct xen_pmu_arch pmu;
};

struct xenpmu {
	struct xen_pmu_data *xenpmu_data;
	uint8_t flags;
};

enum pg_level {
	PG_LEVEL_NONE = 0,
	PG_LEVEL_4K = 1,
	PG_LEVEL_2M = 2,
	PG_LEVEL_1G = 3,
	PG_LEVEL_512G = 4,
	PG_LEVEL_NUM = 5,
};

typedef uint32_t grant_ref_t;

typedef uint32_t grant_handle_t;

struct gnttab_map_grant_ref {
	uint64_t host_addr;
	uint32_t flags;
	grant_ref_t ref;
	domid_t dom;
	int16_t status;
	grant_handle_t handle;
	uint64_t dev_bus_addr;
};

struct gnttab_unmap_grant_ref {
	uint64_t host_addr;
	uint64_t dev_bus_addr;
	grant_handle_t handle;
	int16_t status;
};

struct dentry___8;

struct super_block___8;

struct module___8;

struct file_system_type___8 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___8 * (*mount)(struct file_system_type___8 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___8 *);
	struct module___8 *owner;
	struct file_system_type___8 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___8;

struct kiocb___8;

struct iov_iter___7;

struct poll_table_struct___5;

struct inode___8;

struct file_lock___8;

struct seq_file___7;

struct file_operations___8 {
	struct module___8 *owner;
	loff_t (*llseek)(struct file___8 *, loff_t, int);
	ssize_t (*read)(struct file___8 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___8 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___8 *, struct iov_iter___7 *);
	ssize_t (*write_iter)(struct kiocb___8 *, struct iov_iter___7 *);
	int (*iopoll)(struct kiocb___8 *, bool);
	int (*iterate)(struct file___8 *, struct dir_context *);
	int (*iterate_shared)(struct file___8 *, struct dir_context *);
	__poll_t (*poll)(struct file___8 *, struct poll_table_struct___5 *);
	long int (*unlocked_ioctl)(struct file___8 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___8 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___8 *, struct vm_area_struct___3 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___8 *, struct file___8 *);
	int (*flush)(struct file___8 *, fl_owner_t);
	int (*release)(struct inode___8 *, struct file___8 *);
	int (*fsync)(struct file___8 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___8 *, int);
	int (*lock)(struct file___8 *, int, struct file_lock___8 *);
	ssize_t (*sendpage)(struct file___8 *, struct page___3 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___8 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___8 *, long unsigned int);
	int (*flock)(struct file___8 *, int, struct file_lock___8 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___8 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___8 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___8 *, long int, struct file_lock___8 **, void **);
	long int (*fallocate)(struct file___8 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___7 *, struct file___8 *);
	ssize_t (*copy_file_range)(struct file___8 *, loff_t, struct file___8 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___8 *, loff_t, struct file___8 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___8 *, loff_t, loff_t, int);
};

struct static_call_mod___5 {
	struct static_call_mod___5 *next;
	struct module___8 *mod;
	struct static_call_site *sites;
};

struct static_call_key___5 {
	void *func;
	union {
		long unsigned int type;
		struct static_call_mod___5 *mods;
		struct static_call_site *sites;
	};
};

struct vmacache___8 {
	u64 seqnum;
	struct vm_area_struct___3 *vmas[4];
};

struct page_frag___8 {
	struct page___3 *page;
	__u32 offset;
	__u32 size;
};

struct perf_event___5;

struct thread_struct___6 {
	struct desc_struct tls_array[3];
	long unsigned int sp;
	short unsigned int es;
	short unsigned int ds;
	short unsigned int fsindex;
	short unsigned int gsindex;
	long unsigned int fsbase;
	long unsigned int gsbase;
	struct perf_event___5 *ptrace_bps[4];
	long unsigned int virtual_dr6;
	long unsigned int ptrace_dr7;
	long unsigned int cr2;
	long unsigned int trap_nr;
	long unsigned int error_code;
	struct io_bitmap *io_bitmap;
	long unsigned int iopl_emul;
	unsigned int iopl_warn: 1;
	unsigned int sig_on_uaccess_err: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u32 pkru;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct fpu fpu;
};

struct mm_struct___10;

struct pid___7;

struct nsproxy___8;

struct signal_struct___9;

struct bio_list___6;

struct backing_dev_info___5;

struct io_context___7;

struct css_set___6;

struct perf_event_context___5;

struct mem_cgroup___5;

struct request_queue___6;

struct vm_struct___8;

struct task_struct___10 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___10 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___10 *mm;
	struct mm_struct___10 *active_mm;
	struct vmacache___8 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int restore_sigmask: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___10 *real_parent;
	struct task_struct___10 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___10 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___7 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	struct posix_cputimers_work posix_cputimers_work;
	const struct cred *ptracer_cred;
	const struct cred *real_cred;
	const struct cred *cred;
	struct key *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___8 *nsproxy;
	struct signal_struct___9 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___10 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___6 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___5 *backing_dev_info;
	struct io_context___7 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___6 *cgroups;
	struct list_head cg_list;
	u32 closid;
	u32 rmid;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___5 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	long: 64;
	long: 64;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___8 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___5 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___5 *active_memcg;
	struct request_queue___6 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___10 *oom_reaper_list;
	struct vm_struct___8 *stack_vm_area;
	refcount_t stack_refcount;
	int patch_state;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	void *mce_vaddr;
	__u64 mce_kflags;
	u64 mce_addr;
	__u64 mce_ripv: 1;
	__u64 mce_whole_page: 1;
	__u64 __mce_reserved: 62;
	long: 2;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct callback_head mce_kill_me;
	int mce_count;
	struct llist_head kretprobe_instances;
	struct callback_head l1d_flush_kill;
	long: 64;
	struct thread_struct___6 thread;
};

typedef struct page___3 *pgtable_t___8;

struct address_space___9;

struct dev_pagemap___8;

struct page___3 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___9 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___3 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___8 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___10 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___8 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

enum {
	DESC_TSS = 9,
	DESC_LDT = 2,
	DESCTYPE_S = 16,
};

struct pv_cpu_ops___5 {
	void (*io_delay)();
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	void (*write_cr4)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___6 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(long unsigned int);
	void (*invalidate_io_bitmap)();
	void (*update_io_bitmap)();
	void (*wbinvd)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int);
	void (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_msr_safe)(unsigned int, int *);
	int (*write_msr_safe)(unsigned int, unsigned int, unsigned int);
	u64 (*read_pmc)(int);
	void (*start_context_switch)(struct task_struct___10 *);
	void (*end_context_switch)(struct task_struct___10 *);
};

struct flush_tlb_info___4;

struct pv_mmu_ops___5 {
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_one_user)(long unsigned int);
	void (*flush_tlb_multi)(const struct cpumask *, const struct flush_tlb_info___4 *);
	void (*tlb_remove_table)(struct mmu_gather *, void *);
	void (*exit_mmap)(struct mm_struct___10 *);
	struct paravirt_callee_save read_cr2;
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___10 *, struct mm_struct___10 *);
	void (*dup_mmap)(struct mm_struct___10 *, struct mm_struct___10 *);
	int (*pgd_alloc)(struct mm_struct___10 *);
	void (*pgd_free)(struct mm_struct___10 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___10 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___10 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___10 *, long unsigned int);
	void (*alloc_p4d)(struct mm_struct___10 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*release_p4d)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	pte_t (*ptep_modify_prot_start)(struct vm_area_struct___3 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct vm_area_struct___3 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_p4d)(p4d_t *, p4d_t);
	struct paravirt_callee_save p4d_val;
	struct paravirt_callee_save make_p4d;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

struct flush_tlb_info___4 {
	struct mm_struct___10 *mm;
	long unsigned int start;
	long unsigned int end;
	u64 new_tlb_gen;
	unsigned int initiating_cpu;
	u8 stride_shift;
	u8 freed_tables;
};

struct core_state___8;

struct mm_struct___10 {
	struct {
		struct vm_area_struct___3 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___8 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int mmap_compat_base;
		long unsigned int mmap_compat_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[48];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___8 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___10 *owner;
		struct user_namespace *user_ns;
		struct file___8 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		bool tlb_flush_batched;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct vm_operations_struct___8;

struct vm_area_struct___3 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___3 *vm_next;
	struct vm_area_struct___3 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___10 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___8 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___8 *vm_file;
	struct file___8 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct paravirt_patch_template___5 {
	struct pv_cpu_ops___5 cpu;
	struct pv_irq_ops irq;
	struct pv_mmu_ops___5 mmu;
	struct pv_lock_ops lock;
};

enum paravirt_lazy_mode {
	PARAVIRT_LAZY_NONE = 0,
	PARAVIRT_LAZY_MMU = 1,
	PARAVIRT_LAZY_CPU = 2,
};

struct tracepoint___5 {
	const char *name;
	struct static_key key;
	struct static_call_key___5 *static_call_key;
	void *static_call_tramp;
	void *iterator;
	int (*regfunc)();
	void (*unregfunc)();
	struct tracepoint_func *funcs;
};

struct bpf_raw_event_map___5 {
	struct tracepoint___5 *tp;
	void *bpf_func;
	u32 num_args;
	u32 writable_size;
	long: 64;
};

struct seq_operations___7 {
	void * (*start)(struct seq_file___7 *, loff_t *);
	void (*stop)(struct seq_file___7 *, void *);
	void * (*next)(struct seq_file___7 *, void *, loff_t *);
	int (*show)(struct seq_file___7 *, void *);
};

struct hw_perf_event___5 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___10 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	union {
		struct {
			u64 last_period;
			local64_t period_left;
		};
		struct {
			u64 saved_metric;
			u64 saved_slots;
		};
	};
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___5)(struct perf_event___5 *, struct perf_sample_data *, struct pt_regs *);

struct pmu___5;

struct fasync_struct___8;

struct pid_namespace___7;

struct trace_event_call___5;

struct perf_cgroup___5;

struct perf_event___5 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___5 *group_leader;
	struct pmu___5 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___5 hw;
	struct perf_event_context___5 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___5 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___10 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct perf_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___8 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	long unsigned int pending_addr;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	struct perf_addr_filter_range *addr_filter_ranges;
	long unsigned int addr_filters_gen;
	struct perf_event___5 *aux_event;
	void (*destroy)(struct perf_event___5 *);
	struct callback_head callback_head;
	struct pid_namespace___7 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___5 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___5 orig_overflow_handler;
	struct bpf_prog *prog;
	u64 bpf_cookie;
	struct trace_event_call___5 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___5 *cgrp;
	void *security;
	struct list_head sb_list;
};

struct upid___7 {
	int nr;
	struct pid_namespace___7 *ns;
};

struct pid_namespace___7 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___10 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___7 *parent;
	struct fs_pin *bacct;
	struct user_namespace *user_ns;
	struct ucounts *ucounts;
	int reboot;
	struct ns_common ns;
};

struct pid___7 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___7 numbers[1];
};

struct plist_head {
	struct list_head node_list;
};

struct signal_struct___9 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___10 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___10 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper;
	unsigned int has_child_subreaper;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___7 *pids[4];
	struct pid___7 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___10 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct cgroup_namespace___6;

struct nsproxy___8 {
	atomic_t count;
	struct uts_namespace *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___7 *pid_ns_for_children;
	struct net *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___6 *cgroup_ns;
};

struct bio___6;

struct bio_list___6 {
	struct bio___6 *head;
	struct bio___6 *tail;
};

struct cgroup_subsys_state___6;

struct bdi_writeback___5 {
	struct backing_dev_info___5 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	atomic_t writeback_inodes;
	struct percpu_counter stat[4];
	long unsigned int congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	struct delayed_work bw_dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___6 *memcg_css;
	struct cgroup_subsys_state___6 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	struct list_head b_attached;
	struct list_head offline_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
};

struct backing_dev_info___5 {
	u64 id;
	struct rb_node rb_node;
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___5 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct mutex cgwb_release_mutex;
	struct rw_semaphore wb_switch_rwsem;
	wait_queue_head_t wb_waitq;
	struct device___3 *dev;
	char dev_name[64];
	struct device___3 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___8 *debug_dir;
};

struct io_cq___6;

struct io_context___7 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	struct xarray icq_tree;
	struct io_cq___6 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct cgroup___6;

struct css_set___6 {
	struct cgroup_subsys_state___6 *subsys[14];
	refcount_t refcount;
	struct css_set___6 *dom_cset;
	struct cgroup___6 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___6 *mg_src_cgrp;
	struct cgroup___6 *mg_dst_cgrp;
	struct css_set___6 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___5 {
	struct pmu___5 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	int rotate_necessary;
	refcount_t refcount;
	struct task_struct___10 *task;
	u64 time;
	u64 timestamp;
	u64 timeoffset;
	struct perf_event_context___5 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

struct cgroup_subsys___6;

struct cgroup_subsys_state___6 {
	struct cgroup___6 *cgroup;
	struct cgroup_subsys___6 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___6 *parent;
};

struct kernfs_node___7;

struct cgroup_file___6 {
	struct kernfs_node___7 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct obj_cgroup___5;

struct mem_cgroup_per_node___5;

struct mem_cgroup___5 {
	struct cgroup_subsys_state___6 css;
	struct mem_cgroup_id id;
	struct page_counter memory;
	union {
		struct page_counter swap;
		struct page_counter memsw;
	};
	struct page_counter kmem;
	struct page_counter tcpmem;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool oom_group;
	bool oom_lock;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___6 events_file;
	struct cgroup_file___6 events_local_file;
	struct cgroup_file___6 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	struct memcg_vmstats vmstats;
	atomic_long_t memory_events[8];
	atomic_long_t memory_events_local[8];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct obj_cgroup___5 *objcg;
	struct list_head objcg_list;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad2_;
	atomic_t moving_account;
	struct task_struct___10 *move_lock_task;
	struct memcg_vmstats_percpu *vmstats_percpu;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct memcg_cgwb_frn cgwb_frn[4];
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct deferred_split deferred_split_queue;
	struct mem_cgroup_per_node___5 *nodeinfo[0];
	long: 64;
};

struct kset___7;

struct kobj_type___7;

struct kobject___8 {
	const char *name;
	struct list_head entry;
	struct kobject___8 *parent;
	struct kset___7 *kset;
	struct kobj_type___7 *ktype;
	struct kernfs_node___7 *sd;
	struct kref kref;
	unsigned int state_initialized;
	unsigned int state_in_sysfs;
	unsigned int state_add_uevent_sent;
	unsigned int state_remove_uevent_sent;
	unsigned int uevent_suppress;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct blk_integrity_profile___6;

struct blk_integrity___6 {
	const struct blk_integrity_profile___6 *profile;
	unsigned char flags;
	unsigned char tuple_size;
	unsigned char interval_exp;
	unsigned char tag_size;
};

struct bio_set___6 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	struct bio_alloc_cache *cache;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	unsigned int back_pad;
	spinlock_t rescue_lock;
	struct bio_list___6 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	struct hlist_node cpuhp_dead;
};

struct request___6;

struct elevator_queue___6;

struct gendisk___6;

struct blkcg_gq___5;

struct request_queue___6 {
	struct request___6 *last_merge;
	struct elevator_queue___6 *elevator;
	struct percpu_ref q_usage_counter;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	const struct blk_mq_ops *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx **queue_hw_ctx;
	unsigned int nr_hw_queues;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	spinlock_t queue_lock;
	struct gendisk___6 *disk;
	struct kobject___8 kobj;
	struct kobject___8 *mq_kobj;
	struct blk_integrity___6 integrity;
	struct device___3 *dev;
	enum rpm_status rpm_status;
	long unsigned int nr_requests;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_keyslot_manager *ksm;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	atomic_t nr_active_requests_shared_sbitmap;
	struct sbitmap_queue sched_bitmap_tags;
	struct sbitmap_queue sched_breserved_tags;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___5 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int required_elevator_features;
	unsigned int nr_zones;
	long unsigned int *conv_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int max_open_zones;
	unsigned int max_active_zones;
	int node;
	struct mutex debugfs_mutex;
	struct blk_trace *blk_trace;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	struct mutex sysfs_dir_lock;
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	int mq_freeze_depth;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct mutex mq_freeze_lock;
	struct blk_mq_tag_set *tag_set;
	struct list_head tag_set_list;
	struct bio_set___6 bio_split;
	struct dentry___8 *debugfs_dir;
	struct dentry___8 *sched_debugfs_dir;
	struct dentry___8 *rqos_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	u64 write_hints[5];
};

struct vm_struct___8 {
	struct vm_struct___8 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___3 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct address_space_operations___8;

struct address_space___9 {
	struct inode___8 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___8 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct dev_pagemap_ops___8;

struct dev_pagemap___8 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___8 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vfsmount___8;

struct path___8 {
	struct vfsmount___8 *mnt;
	struct dentry___8 *dentry;
};

struct fown_struct___7 {
	rwlock_t lock;
	struct pid___7 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___8 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	long: 64;
	long: 64;
	struct path___8 f_path;
	struct inode___8 *f_inode;
	const struct file_operations___8 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___7 f_owner;
	const struct cred *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___9 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___8;

struct vm_operations_struct___8 {
	void (*open)(struct vm_area_struct___3 *);
	void (*close)(struct vm_area_struct___3 *);
	int (*may_split)(struct vm_area_struct___3 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___3 *);
	int (*mprotect)(struct vm_area_struct___3 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___8 *);
	vm_fault_t (*huge_fault)(struct vm_fault___8 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___8 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___3 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___8 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___8 *);
	int (*access)(struct vm_area_struct___3 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___3 *);
	int (*set_policy)(struct vm_area_struct___3 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___3 *, long unsigned int);
	struct page___3 * (*find_special_page)(struct vm_area_struct___3 *, long unsigned int);
};

struct core_thread___8 {
	struct task_struct___10 *task;
	struct core_thread___8 *next;
};

struct core_state___8 {
	atomic_t nr_threads;
	struct core_thread___8 dumper;
	struct completion startup;
};

struct vm_fault___8 {
	const struct {
		struct vm_area_struct___3 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___3 *cow_page;
	struct page___3 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___8 prealloc_pte;
};

struct pglist_data___5;

struct lruvec___5 {
	struct list_head lists[5];
	spinlock_t lru_lock;
	long unsigned int anon_cost;
	long unsigned int file_cost;
	atomic_long_t nonresident_age;
	long unsigned int refaults[2];
	long unsigned int flags;
	struct pglist_data___5 *pgdat;
};

struct zone___5 {
	long unsigned int _watermark[3];
	long unsigned int watermark_boost;
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[5];
	int node;
	struct pglist_data___5 *zone_pgdat;
	struct per_cpu_pages *per_cpu_pageset;
	struct per_cpu_zonestat *per_cpu_zonestats;
	int pageset_high;
	int pageset_batch;
	long unsigned int zone_start_pfn;
	atomic_long_t managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int present_early_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	seqlock_t span_seqlock;
	int initialized;
	int: 32;
	struct zone_padding _pad1_;
	struct free_area free_area[11];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	long unsigned int compact_init_migrate_pfn;
	long unsigned int compact_init_free_pfn;
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	short: 16;
	struct zone_padding _pad3_;
	atomic_long_t vm_stat[11];
	atomic_long_t vm_numa_event[6];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___5 {
	struct zone___5 *zone;
	int zone_idx;
};

struct zonelist___5 {
	struct zoneref___5 _zonerefs[5121];
};

struct pglist_data___5 {
	struct zone___5 node_zones[5];
	struct zonelist___5 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___10 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_highest_zoneidx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_highest_zoneidx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___10 *kcompactd;
	bool proactive_compact_trigger;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct deferred_split deferred_split_queue;
	struct lruvec___5 __lruvec;
	long unsigned int flags;
	long: 64;
	struct zone_padding _pad2_;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[39];
};

struct irq_domain___4;

struct x86_init_irqs___2 {
	void (*pre_vector_init)();
	void (*intr_init)();
	void (*intr_mode_select)();
	void (*intr_mode_init)();
	struct irq_domain___4 * (*create_pci_msi_domain)();
};

struct irq_domain_ops___4;

struct fwnode_handle___7;

struct irq_domain_chip_generic___2;

struct irq_data___2;

struct irq_domain___4 {
	struct list_head link;
	const char *name;
	const struct irq_domain_ops___4 *ops;
	void *host_data;
	unsigned int flags;
	unsigned int mapcount;
	struct fwnode_handle___7 *fwnode;
	enum irq_domain_bus_token bus_token;
	struct irq_domain_chip_generic___2 *gc;
	struct irq_domain___4 *parent;
	irq_hw_number_t hwirq_max;
	unsigned int revmap_size;
	struct xarray revmap_tree;
	struct mutex revmap_mutex;
	struct irq_data___2 *revmap[0];
};

struct x86_init_ops___2 {
	struct x86_init_resources resources;
	struct x86_init_mpparse mpparse;
	struct x86_init_irqs___2 irqs;
	struct x86_init_oem oem;
	struct x86_init_paging paging;
	struct x86_init_timers timers;
	struct x86_init_iommu iommu;
	struct x86_init_pci pci;
	struct x86_hyper_init hyper;
	struct x86_init_acpi acpi;
};

struct kernfs_root___7;

struct kernfs_elem_dir___7 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___7 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___7;

struct kernfs_root___7 {
	struct kernfs_node___7 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___7 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___7 {
	struct kernfs_node___7 *target_kn;
};

struct kernfs_ops___7;

struct kernfs_elem_attr___7 {
	const struct kernfs_ops___7 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___7 *notify_next;
};

struct kernfs_node___7 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___7 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___7 dir;
		struct kernfs_elem_symlink___7 symlink;
		struct kernfs_elem_attr___7 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___7;

struct kernfs_ops___7 {
	int (*open)(struct kernfs_open_file___7 *);
	void (*release)(struct kernfs_open_file___7 *);
	int (*seq_show)(struct seq_file___7 *, void *);
	void * (*seq_start)(struct seq_file___7 *, loff_t *);
	void * (*seq_next)(struct seq_file___7 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___7 *, void *);
	ssize_t (*read)(struct kernfs_open_file___7 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___7 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___7 *, struct poll_table_struct___5 *);
	int (*mmap)(struct kernfs_open_file___7 *, struct vm_area_struct___3 *);
};

struct kernfs_syscall_ops___7 {
	int (*show_options)(struct seq_file___7 *, struct kernfs_root___7 *);
	int (*mkdir)(struct kernfs_node___7 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___7 *);
	int (*rename)(struct kernfs_node___7 *, struct kernfs_node___7 *, const char *);
	int (*show_path)(struct seq_file___7 *, struct kernfs_node___7 *, struct kernfs_root___7 *);
};

struct seq_file___7 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___7 *op;
	int poll_event;
	const struct file___8 *file;
	void *private;
};

struct kernfs_open_file___7 {
	struct kernfs_node___7 *kn;
	struct file___8 *file;
	struct seq_file___7 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped;
	bool released;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___8 *vm_ops;
};

typedef void (*poll_queue_proc___5)(struct file___8 *, wait_queue_head_t *, struct poll_table_struct___5 *);

struct poll_table_struct___5 {
	poll_queue_proc___5 _qproc;
	__poll_t _key;
};

struct bin_attribute___8;

struct attribute_group___8 {
	const char *name;
	umode_t (*is_visible)(struct kobject___8 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___8 *, struct bin_attribute___8 *, int);
	struct attribute **attrs;
	struct bin_attribute___8 **bin_attrs;
};

struct bin_attribute___8 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___9 * (*f_mapping)();
	ssize_t (*read)(struct file___8 *, struct kobject___8 *, struct bin_attribute___8 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___8 *, struct kobject___8 *, struct bin_attribute___8 *, char *, loff_t, size_t);
	int (*mmap)(struct file___8 *, struct kobject___8 *, struct bin_attribute___8 *, struct vm_area_struct___3 *);
};

struct sysfs_ops___7 {
	ssize_t (*show)(struct kobject___8 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___8 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___7;

struct kset___7 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___8 kobj;
	const struct kset_uevent_ops___7 *uevent_ops;
};

struct kobj_type___7 {
	void (*release)(struct kobject___8 *);
	const struct sysfs_ops___7 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___8 **default_groups;
	const struct kobj_ns_type_operations * (*child_ns_type)(struct kobject___8 *);
	const void * (*namespace)(struct kobject___8 *);
	void (*get_ownership)(struct kobject___8 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___7 {
	int (* const filter)(struct kset___7 *, struct kobject___8 *);
	const char * (* const name)(struct kset___7 *, struct kobject___8 *);
	int (* const uevent)(struct kset___7 *, struct kobject___8 *, struct kobj_uevent_env *);
};

struct wakeup_source___7;

struct dev_pm_info___7 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___7 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___3 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___7;

struct bus_type___7;

struct device_driver___7;

struct dev_pm_domain___7;

struct device_node___4;

struct class___7;

struct device___3 {
	struct kobject___8 kobj;
	struct device___3 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___7 *type;
	struct bus_type___7 *bus;
	struct device_driver___7 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___7 power;
	struct dev_pm_domain___7 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___4 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___4 *of_node;
	struct fwnode_handle___7 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___7 *class;
	const struct attribute_group___8 **groups;
	void (*release)(struct device___3 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_ops___7 {
	int (*prepare)(struct device___3 *);
	void (*complete)(struct device___3 *);
	int (*suspend)(struct device___3 *);
	int (*resume)(struct device___3 *);
	int (*freeze)(struct device___3 *);
	int (*thaw)(struct device___3 *);
	int (*poweroff)(struct device___3 *);
	int (*restore)(struct device___3 *);
	int (*suspend_late)(struct device___3 *);
	int (*resume_early)(struct device___3 *);
	int (*freeze_late)(struct device___3 *);
	int (*thaw_early)(struct device___3 *);
	int (*poweroff_late)(struct device___3 *);
	int (*restore_early)(struct device___3 *);
	int (*suspend_noirq)(struct device___3 *);
	int (*resume_noirq)(struct device___3 *);
	int (*freeze_noirq)(struct device___3 *);
	int (*thaw_noirq)(struct device___3 *);
	int (*poweroff_noirq)(struct device___3 *);
	int (*restore_noirq)(struct device___3 *);
	int (*runtime_suspend)(struct device___3 *);
	int (*runtime_resume)(struct device___3 *);
	int (*runtime_idle)(struct device___3 *);
};

struct wakeup_source___7 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___3 *dev;
	bool active;
	bool autosleep_enabled;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

enum pm_qos_type {
	PM_QOS_UNITIALIZED = 0,
	PM_QOS_MAX = 1,
	PM_QOS_MIN = 2,
};

struct pm_qos_constraints {
	struct plist_head list;
	s32 target_value;
	s32 default_value;
	s32 no_constraint_value;
	enum pm_qos_type type;
	struct blocking_notifier_head *notifiers;
};

struct freq_constraints {
	struct pm_qos_constraints min_freq;
	struct blocking_notifier_head min_freq_notifiers;
	struct pm_qos_constraints max_freq;
	struct blocking_notifier_head max_freq_notifiers;
};

struct pm_qos_flags {
	struct list_head list;
	s32 effective_flags;
};

struct dev_pm_qos_request;

struct dev_pm_qos {
	struct pm_qos_constraints resume_latency;
	struct pm_qos_constraints latency_tolerance;
	struct freq_constraints freq;
	struct pm_qos_flags flags;
	struct dev_pm_qos_request *resume_latency_req;
	struct dev_pm_qos_request *latency_tolerance_req;
	struct dev_pm_qos_request *flags_req;
};

struct dev_pm_domain___7 {
	struct dev_pm_ops___7 ops;
	int (*start)(struct device___3 *);
	void (*detach)(struct device___3 *, bool);
	int (*activate)(struct device___3 *);
	void (*sync)(struct device___3 *);
	void (*dismiss)(struct device___3 *);
};

struct bus_type___7 {
	const char *name;
	const char *dev_name;
	struct device___3 *dev_root;
	const struct attribute_group___8 **bus_groups;
	const struct attribute_group___8 **dev_groups;
	const struct attribute_group___8 **drv_groups;
	int (*match)(struct device___3 *, struct device_driver___7 *);
	int (*uevent)(struct device___3 *, struct kobj_uevent_env *);
	int (*probe)(struct device___3 *);
	void (*sync_state)(struct device___3 *);
	void (*remove)(struct device___3 *);
	void (*shutdown)(struct device___3 *);
	int (*online)(struct device___3 *);
	int (*offline)(struct device___3 *);
	int (*suspend)(struct device___3 *, pm_message_t);
	int (*resume)(struct device___3 *);
	int (*num_vf)(struct device___3 *);
	int (*dma_configure)(struct device___3 *);
	const struct dev_pm_ops___7 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___7 {
	const char *name;
	struct bus_type___7 *bus;
	struct module___8 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___3 *);
	void (*sync_state)(struct device___3 *);
	int (*remove)(struct device___3 *);
	void (*shutdown)(struct device___3 *);
	int (*suspend)(struct device___3 *, pm_message_t);
	int (*resume)(struct device___3 *);
	const struct attribute_group___8 **groups;
	const struct attribute_group___8 **dev_groups;
	const struct dev_pm_ops___7 *pm;
	void (*coredump)(struct device___3 *);
	struct driver_private *p;
};

struct device_type___7 {
	const char *name;
	const struct attribute_group___8 **groups;
	int (*uevent)(struct device___3 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___3 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___3 *);
	const struct dev_pm_ops___7 *pm;
};

struct class___7 {
	const char *name;
	struct module___8 *owner;
	const struct attribute_group___8 **class_groups;
	const struct attribute_group___8 **dev_groups;
	struct kobject___8 *dev_kobj;
	int (*dev_uevent)(struct device___3 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___3 *, umode_t *);
	void (*class_release)(struct class___7 *);
	void (*dev_release)(struct device___3 *);
	int (*shutdown_pre)(struct device___3 *);
	const struct kobj_ns_type_operations *ns_type;
	const void * (*namespace)(struct device___3 *);
	void (*get_ownership)(struct device___3 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___7 *pm;
	struct subsys_private *p;
};

struct module_kobject___7 {
	struct kobject___8 kobj;
	struct module___8 *mod;
	struct kobject___8 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___7 {
	struct module___8 *mod;
	struct latch_tree_node node;
};

struct module_layout___7 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___7 mtn;
};

struct module_attribute___7;

struct kernel_param___7;

struct module___8 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___7 mkobj;
	struct module_attribute___7 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___8 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___7 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___7 core_layout;
	struct module_layout___7 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map___5 *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	int num_static_call_sites;
	struct static_call_site *static_call_sites;
	bool klp;
	bool klp_alive;
	struct klp_modinfo *klp_info;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fwnode_operations___7;

struct fwnode_handle___7 {
	struct fwnode_handle___7 *secondary;
	const struct fwnode_operations___7 *ops;
	struct device___3 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct device_node___4 {
	const char *name;
	phandle phandle;
	const char *full_name;
	struct fwnode_handle___7 fwnode;
	struct property *properties;
	struct property *deadprops;
	struct device_node___4 *parent;
	struct device_node___4 *child;
	struct device_node___4 *sibling;
	long unsigned int _flags;
	void *data;
};

struct irqaction___2 {
	irq_handler_t handler;
	void *dev_id;
	void *percpu_dev_id;
	struct irqaction___2 *next;
	irq_handler_t thread_fn;
	struct task_struct___10 *thread;
	struct irqaction___2 *secondary;
	unsigned int irq;
	unsigned int flags;
	long unsigned int thread_flags;
	long unsigned int thread_mask;
	const char *name;
	struct proc_dir_entry *dir;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct shrink_control___5 {
	gfp_t gfp_mask;
	int nid;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	struct mem_cgroup___5 *memcg;
};

struct shrinker___5 {
	long unsigned int (*count_objects)(struct shrinker___5 *, struct shrink_control___5 *);
	long unsigned int (*scan_objects)(struct shrinker___5 *, struct shrink_control___5 *);
	long int batch;
	int seeks;
	unsigned int flags;
	struct list_head list;
	int id;
	atomic_long_t *nr_deferred;
};

struct dev_pagemap_ops___8 {
	void (*page_free)(struct page___3 *);
	void (*kill)(struct dev_pagemap___8 *);
	void (*cleanup)(struct dev_pagemap___8 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___8 *);
};

struct dentry_operations___8;

struct dentry___8 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___8 *d_parent;
	struct qstr d_name;
	struct inode___8 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___8 *d_op;
	struct super_block___8 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___8;

struct cdev___4;

struct inode___8 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___8 *i_op;
	struct super_block___8 *i_sb;
	struct address_space___9 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___5 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	long: 64;
	long: 64;
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___8 *i_fop;
		void (*free_inode)(struct inode___8 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___9 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct cdev___4 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___8 {
	int (*d_revalidate)(struct dentry___8 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___8 *, unsigned int);
	int (*d_hash)(const struct dentry___8 *, struct qstr *);
	int (*d_compare)(const struct dentry___8 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___8 *);
	int (*d_init)(struct dentry___8 *);
	void (*d_release)(struct dentry___8 *);
	void (*d_prune)(struct dentry___8 *);
	void (*d_iput)(struct dentry___8 *, struct inode___8 *);
	char * (*d_dname)(struct dentry___8 *, char *, int);
	struct vfsmount___8 * (*d_automount)(struct path___8 *);
	int (*d_manage)(const struct path___8 *, bool);
	struct dentry___8 * (*d_real)(struct dentry___8 *, const struct inode___8 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___8;

struct mem_dqinfo___8 {
	struct quota_format_type___8 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___8;

struct quota_info___8 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___8 *files[3];
	struct mem_dqinfo___8 info[3];
	const struct quota_format_ops___8 *ops[3];
};

struct rcuwait___8 {
	struct task_struct___10 *task;
};

struct percpu_rw_semaphore___8 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___8 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___8 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___8 rw_sem[3];
};

struct super_operations___8;

struct dquot_operations___8;

struct quotactl_ops___8;

struct block_device___6;

struct super_block___8 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___8 *s_type;
	const struct super_operations___8 *s_op;
	const struct dquot_operations___8 *dq_op;
	const struct quotactl_ops___8 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___8 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___6 *s_bdev;
	struct backing_dev_info___5 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___8 s_dquot;
	struct sb_writers___8 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___8 *s_d_op;
	int cleancache_poolid;
	struct shrinker___5 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___8 {
	struct dentry___8 *mnt_root;
	struct super_block___8 *mnt_sb;
	int mnt_flags;
	struct user_namespace *mnt_userns;
};

struct psi_group___6 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___10 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___6;

struct cgroup_rstat_cpu___6;

struct cgroup___6 {
	struct cgroup_subsys_state___6 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___7 *kn;
	struct cgroup_file___6 procs_file;
	struct cgroup_file___6 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___6 *subsys[14];
	struct cgroup_root___6 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___6 *dom_cgrp;
	struct cgroup___6 *old_dom_cgrp;
	struct cgroup_rstat_cpu___6 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___6 psi;
	struct cgroup_bpf bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct io_cq___6 {
	struct request_queue___6 *q;
	struct io_context___7 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct wait_page_queue___4;

struct kiocb___8 {
	struct file___8 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___8 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___4 *ki_waitq;
	};
};

struct iattr___8 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___8 *ia_file;
};

struct dquot___8 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___8 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___8 {
	int qf_fmt_id;
	const struct quota_format_ops___8 *qf_ops;
	struct module___8 *qf_owner;
	struct quota_format_type___8 *qf_next;
};

struct quota_format_ops___8 {
	int (*check_quota_file)(struct super_block___8 *, int);
	int (*read_file_info)(struct super_block___8 *, int);
	int (*write_file_info)(struct super_block___8 *, int);
	int (*free_file_info)(struct super_block___8 *, int);
	int (*read_dqblk)(struct dquot___8 *);
	int (*commit_dqblk)(struct dquot___8 *);
	int (*release_dqblk)(struct dquot___8 *);
	int (*get_next_id)(struct super_block___8 *, struct kqid *);
};

struct dquot_operations___8 {
	int (*write_dquot)(struct dquot___8 *);
	struct dquot___8 * (*alloc_dquot)(struct super_block___8 *, int);
	void (*destroy_dquot)(struct dquot___8 *);
	int (*acquire_dquot)(struct dquot___8 *);
	int (*release_dquot)(struct dquot___8 *);
	int (*mark_dirty)(struct dquot___8 *);
	int (*write_info)(struct super_block___8 *, int);
	qsize_t * (*get_reserved_space)(struct inode___8 *);
	int (*get_projid)(struct inode___8 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___8 *, qsize_t *);
	int (*get_next_id)(struct super_block___8 *, struct kqid *);
};

struct quotactl_ops___8 {
	int (*quota_on)(struct super_block___8 *, int, int, const struct path___8 *);
	int (*quota_off)(struct super_block___8 *, int);
	int (*quota_enable)(struct super_block___8 *, unsigned int);
	int (*quota_disable)(struct super_block___8 *, unsigned int);
	int (*quota_sync)(struct super_block___8 *, int);
	int (*set_info)(struct super_block___8 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___8 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___8 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___8 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___8 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___8 *, unsigned int);
};

struct wait_page_queue___4 {
	struct page___3 *page;
	int bit_nr;
	wait_queue_entry_t wait;
};

struct writeback_control___5;

struct readahead_control___4;

struct address_space_operations___8 {
	int (*writepage)(struct page___3 *, struct writeback_control___5 *);
	int (*readpage)(struct file___8 *, struct page___3 *);
	int (*writepages)(struct address_space___9 *, struct writeback_control___5 *);
	int (*set_page_dirty)(struct page___3 *);
	int (*readpages)(struct file___8 *, struct address_space___9 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___4 *);
	int (*write_begin)(struct file___8 *, struct address_space___9 *, loff_t, unsigned int, unsigned int, struct page___3 **, void **);
	int (*write_end)(struct file___8 *, struct address_space___9 *, loff_t, unsigned int, unsigned int, struct page___3 *, void *);
	sector_t (*bmap)(struct address_space___9 *, sector_t);
	void (*invalidatepage)(struct page___3 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___3 *, gfp_t);
	void (*freepage)(struct page___3 *);
	ssize_t (*direct_IO)(struct kiocb___8 *, struct iov_iter___7 *);
	int (*migratepage)(struct address_space___9 *, struct page___3 *, struct page___3 *, enum migrate_mode);
	bool (*isolate_page)(struct page___3 *, isolate_mode_t);
	void (*putback_page)(struct page___3 *);
	int (*launder_page)(struct page___3 *);
	int (*is_partially_uptodate)(struct page___3 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___3 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___9 *, struct page___3 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___8 *, sector_t *);
	void (*swap_deactivate)(struct file___8 *);
};

struct writeback_control___5 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate;
	unsigned int for_background;
	unsigned int tagged_writepages;
	unsigned int for_reclaim;
	unsigned int range_cyclic;
	unsigned int for_sync;
	unsigned int no_cgroup_owner;
	unsigned int punt_to_cgroup;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bdi_writeback___5 *wb;
	struct inode___8 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
};

struct readahead_control___4 {
	struct file___8 *file;
	struct address_space___9 *mapping;
	struct file_ra_state *ra;
	long unsigned int _index;
	unsigned int _nr_pages;
	unsigned int _batch_count;
};

struct bio_vec___7;

struct iov_iter___7 {
	u8 iter_type;
	bool data_source;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___7 *bvec;
		struct xarray *xarray;
		struct pipe_inode_info *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			unsigned int head;
			unsigned int start_head;
		};
		loff_t xarray_start;
	};
};

struct cdev___4 {
	struct kobject___8 kobj;
	struct module___8 *owner;
	const struct file_operations___8 *ops;
	struct list_head list;
	dev_t dev;
	unsigned int count;
};

struct inode_operations___8 {
	struct dentry___8 * (*lookup)(struct inode___8 *, struct dentry___8 *, unsigned int);
	const char * (*get_link)(struct dentry___8 *, struct inode___8 *, struct delayed_call *);
	int (*permission)(struct user_namespace *, struct inode___8 *, int);
	struct posix_acl * (*get_acl)(struct inode___8 *, int, bool);
	int (*readlink)(struct dentry___8 *, char *, int);
	int (*create)(struct user_namespace *, struct inode___8 *, struct dentry___8 *, umode_t, bool);
	int (*link)(struct dentry___8 *, struct inode___8 *, struct dentry___8 *);
	int (*unlink)(struct inode___8 *, struct dentry___8 *);
	int (*symlink)(struct user_namespace *, struct inode___8 *, struct dentry___8 *, const char *);
	int (*mkdir)(struct user_namespace *, struct inode___8 *, struct dentry___8 *, umode_t);
	int (*rmdir)(struct inode___8 *, struct dentry___8 *);
	int (*mknod)(struct user_namespace *, struct inode___8 *, struct dentry___8 *, umode_t, dev_t);
	int (*rename)(struct user_namespace *, struct inode___8 *, struct dentry___8 *, struct inode___8 *, struct dentry___8 *, unsigned int);
	int (*setattr)(struct user_namespace *, struct dentry___8 *, struct iattr___8 *);
	int (*getattr)(struct user_namespace *, const struct path___8 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___8 *, char *, size_t);
	int (*fiemap)(struct inode___8 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___8 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___8 *, struct dentry___8 *, struct file___8 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace *, struct inode___8 *, struct dentry___8 *, umode_t);
	int (*set_acl)(struct user_namespace *, struct inode___8 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace *, struct dentry___8 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___8 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___8 {
	void (*fl_copy_lock)(struct file_lock___8 *, struct file_lock___8 *);
	void (*fl_release_private)(struct file_lock___8 *);
};

struct lock_manager_operations___8;

struct file_lock___8 {
	struct file_lock___8 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___8 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___8 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___8 *fl_ops;
	const struct lock_manager_operations___8 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___8 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___8 *);
	int (*lm_grant)(struct file_lock___8 *, int);
	bool (*lm_break)(struct file_lock___8 *);
	int (*lm_change)(struct file_lock___8 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___8 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___8 *);
};

struct fasync_struct___8 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___8 *fa_next;
	struct file___8 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___8 {
	struct inode___8 * (*alloc_inode)(struct super_block___8 *);
	void (*destroy_inode)(struct inode___8 *);
	void (*free_inode)(struct inode___8 *);
	void (*dirty_inode)(struct inode___8 *, int);
	int (*write_inode)(struct inode___8 *, struct writeback_control___5 *);
	int (*drop_inode)(struct inode___8 *);
	void (*evict_inode)(struct inode___8 *);
	void (*put_super)(struct super_block___8 *);
	int (*sync_fs)(struct super_block___8 *, int);
	int (*freeze_super)(struct super_block___8 *);
	int (*freeze_fs)(struct super_block___8 *);
	int (*thaw_super)(struct super_block___8 *);
	int (*unfreeze_fs)(struct super_block___8 *);
	int (*statfs)(struct dentry___8 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___8 *, int *, char *);
	void (*umount_begin)(struct super_block___8 *);
	int (*show_options)(struct seq_file___7 *, struct dentry___8 *);
	int (*show_devname)(struct seq_file___7 *, struct dentry___8 *);
	int (*show_path)(struct seq_file___7 *, struct dentry___8 *);
	int (*show_stats)(struct seq_file___7 *, struct dentry___8 *);
	ssize_t (*quota_read)(struct super_block___8 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___8 *, int, const char *, size_t, loff_t);
	struct dquot___8 ** (*get_dquots)(struct inode___8 *);
	long int (*nr_cached_objects)(struct super_block___8 *, struct shrink_control___5 *);
	long int (*free_cached_objects)(struct super_block___8 *, struct shrink_control___5 *);
	struct file___8 * (*real_loop)(struct file___8 *);
};

struct block_device___6 {
	sector_t bd_start_sect;
	struct disk_stats *bd_stats;
	long unsigned int bd_stamp;
	bool bd_read_only;
	dev_t bd_dev;
	int bd_openers;
	struct inode___8 *bd_inode;
	struct super_block___8 *bd_super;
	void *bd_claiming;
	struct device___3 bd_device;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct kobject___8 *bd_holder_dir;
	u8 bd_partno;
	spinlock_t bd_size_lock;
	struct gendisk___6 *bd_disk;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	struct super_block___8 *bd_fsfreeze_sb;
	struct partition_meta_info *bd_meta_info;
};

typedef void bio_end_io_t___6(struct bio___6 *);

struct bio_vec___7 {
	struct page___3 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___6;

struct bio___6 {
	struct bio___6 *bi_next;
	struct block_device___6 *bi_bdev;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	atomic_t __bi_remaining;
	struct bvec_iter bi_iter;
	bio_end_io_t___6 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___5 *bi_blkg;
	struct bio_issue bi_issue;
	u64 bi_iocost_cost;
	struct bio_crypt_ctx *bi_crypt_context;
	union {
		struct bio_integrity_payload___6 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___7 *bi_io_vec;
	struct bio_set___6 *bi_pool;
	struct bio_vec___7 bi_inline_vecs[0];
};

struct kernel_param_ops___7 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___7 *);
	int (*get)(char *, const struct kernel_param___7 *);
	void (*free)(void *);
};

struct kparam_array___7;

struct kernel_param___7 {
	const char *name;
	struct module___8 *mod;
	const struct kernel_param_ops___7 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___7 *arr;
	};
};

struct kparam_array___7 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___7 *ops;
	void *elem;
};

struct module_attribute___7 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___7 *, struct module_kobject___7 *, char *);
	ssize_t (*store)(struct module_attribute___7 *, struct module_kobject___7 *, const char *, size_t);
	void (*setup)(struct module___8 *, const char *);
	int (*test)(struct module___8 *);
	void (*free)(struct module___8 *);
};

struct trace_event_class___5;

struct trace_event_call___5 {
	struct list_head list;
	struct trace_event_class___5 *class;
	union {
		char *name;
		struct tracepoint___5 *tp;
	};
	struct trace_event event;
	char *print_fmt;
	struct event_filter *filter;
	union {
		void *module;
		atomic_t refcnt;
	};
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
	struct bpf_prog_array *prog_array;
	int (*perf_perm)(struct trace_event_call___5 *, struct perf_event___5 *);
};

struct cgroup_namespace___6 {
	struct ns_common ns;
	struct user_namespace *user_ns;
	struct ucounts *ucounts;
	struct css_set___6 *root_cset;
};

struct fwnode_reference_args___7;

struct fwnode_endpoint___7;

struct fwnode_operations___7 {
	struct fwnode_handle___7 * (*get)(struct fwnode_handle___7 *);
	void (*put)(struct fwnode_handle___7 *);
	bool (*device_is_available)(const struct fwnode_handle___7 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___7 *, const struct device___3 *);
	bool (*property_present)(const struct fwnode_handle___7 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___7 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___7 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___7 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___7 *);
	struct fwnode_handle___7 * (*get_parent)(const struct fwnode_handle___7 *);
	struct fwnode_handle___7 * (*get_next_child_node)(const struct fwnode_handle___7 *, struct fwnode_handle___7 *);
	struct fwnode_handle___7 * (*get_named_child_node)(const struct fwnode_handle___7 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___7 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___7 *);
	struct fwnode_handle___7 * (*graph_get_next_endpoint)(const struct fwnode_handle___7 *, struct fwnode_handle___7 *);
	struct fwnode_handle___7 * (*graph_get_remote_endpoint)(const struct fwnode_handle___7 *);
	struct fwnode_handle___7 * (*graph_get_port_parent)(struct fwnode_handle___7 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___7 *, struct fwnode_endpoint___7 *);
	int (*add_links)(struct fwnode_handle___7 *);
};

struct fwnode_endpoint___7 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___7 *local_fwnode;
};

struct fwnode_reference_args___7 {
	struct fwnode_handle___7 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

typedef long int xen_long_t;

struct trap_info {
	uint8_t vector;
	uint8_t flags;
	uint16_t cs;
	long unsigned int address;
};

struct mmuext_op {
	unsigned int cmd;
	union {
		xen_pfn_t mfn;
		long unsigned int linear_addr;
	} arg1;
	union {
		unsigned int nr_ents;
		void *vcpumask;
		xen_pfn_t src_mfn;
	} arg2;
};

struct multicall_entry {
	xen_ulong_t op;
	xen_long_t result;
	xen_ulong_t args[6];
};

struct dom0_vga_console_info {
	uint8_t video_type;
	union {
		struct {
			uint16_t font_height;
			uint16_t cursor_x;
			uint16_t cursor_y;
			uint16_t rows;
			uint16_t columns;
		} text_mode_3;
		struct {
			uint16_t width;
			uint16_t height;
			uint16_t bytes_per_line;
			uint16_t bits_per_pixel;
			uint32_t lfb_base;
			uint32_t lfb_size;
			uint8_t red_pos;
			uint8_t red_size;
			uint8_t green_pos;
			uint8_t green_size;
			uint8_t blue_pos;
			uint8_t blue_size;
			uint8_t rsvd_pos;
			uint8_t rsvd_size;
			uint32_t gbl_caps;
			uint16_t mode_attrs;
		} vesa_lfb;
	} u;
};

struct irq_desc___2;

typedef void (*irq_flow_handler_t___2)(struct irq_desc___2 *);

struct msi_desc___2;

struct irq_common_data___2 {
	unsigned int state_use_accessors;
	unsigned int node;
	void *handler_data;
	struct msi_desc___2 *msi_desc;
	cpumask_var_t affinity;
	cpumask_var_t effective_affinity;
};

struct irq_chip___2;

struct irq_data___2 {
	u32 mask;
	unsigned int irq;
	long unsigned int hwirq;
	struct irq_common_data___2 *common;
	struct irq_chip___2 *chip;
	struct irq_domain___4 *domain;
	struct irq_data___2 *parent_data;
	void *chip_data;
};

struct irq_desc___2 {
	struct irq_common_data___2 irq_common_data;
	struct irq_data___2 irq_data;
	unsigned int *kstat_irqs;
	irq_flow_handler_t___2 handle_irq;
	struct irqaction___2 *action;
	unsigned int status_use_accessors;
	unsigned int core_internal_state__do_not_mess_with_it;
	unsigned int depth;
	unsigned int wake_depth;
	unsigned int tot_count;
	unsigned int irq_count;
	long unsigned int last_unhandled;
	unsigned int irqs_unhandled;
	atomic_t threads_handled;
	int threads_handled_last;
	raw_spinlock_t lock;
	struct cpumask *percpu_enabled;
	const struct cpumask *percpu_affinity;
	const struct cpumask *affinity_hint;
	struct irq_affinity_notify *affinity_notify;
	cpumask_var_t pending_mask;
	long unsigned int threads_oneshot;
	atomic_t threads_active;
	wait_queue_head_t wait_for_threads;
	unsigned int nr_actions;
	unsigned int no_suspend_depth;
	unsigned int cond_suspend_depth;
	unsigned int force_resume_depth;
	struct proc_dir_entry *dir;
	struct callback_head rcu;
	struct kobject___8 kobj;
	struct mutex request_mutex;
	int parent_irq;
	struct module___8 *owner;
	const char *name;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct msi_desc___2 {
	struct list_head list;
	unsigned int irq;
	unsigned int nvec_used;
	struct device___3 *dev;
	struct msi_msg msg;
	struct irq_affinity_desc *affinity;
	const void *iommu_cookie;
	void (*write_msi_msg)(struct msi_desc___2 *, void *);
	void *write_msi_msg_data;
	union {
		struct {
			union {
				u32 msi_mask;
				u32 msix_ctrl;
			};
			struct {
				u8 is_msix: 1;
				u8 multiple: 3;
				u8 multi_cap: 3;
				u8 can_mask: 1;
				u8 is_64: 1;
				u8 is_virtual: 1;
				u16 entry_nr;
				unsigned int default_irq;
			} msi_attrib;
			union {
				u8 mask_pos;
				void *mask_base;
			};
		};
		struct platform_msi_desc platform;
		struct fsl_mc_msi_desc fsl_mc;
		struct ti_sci_inta_msi_desc inta;
	};
};

struct irq_chip___2 {
	struct device___3 *parent_device;
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___2 *);
	void (*irq_shutdown)(struct irq_data___2 *);
	void (*irq_enable)(struct irq_data___2 *);
	void (*irq_disable)(struct irq_data___2 *);
	void (*irq_ack)(struct irq_data___2 *);
	void (*irq_mask)(struct irq_data___2 *);
	void (*irq_mask_ack)(struct irq_data___2 *);
	void (*irq_unmask)(struct irq_data___2 *);
	void (*irq_eoi)(struct irq_data___2 *);
	int (*irq_set_affinity)(struct irq_data___2 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___2 *);
	int (*irq_set_type)(struct irq_data___2 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___2 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___2 *);
	void (*irq_bus_sync_unlock)(struct irq_data___2 *);
	void (*irq_cpu_online)(struct irq_data___2 *);
	void (*irq_cpu_offline)(struct irq_data___2 *);
	void (*irq_suspend)(struct irq_data___2 *);
	void (*irq_resume)(struct irq_data___2 *);
	void (*irq_pm_shutdown)(struct irq_data___2 *);
	void (*irq_calc_mask)(struct irq_data___2 *);
	void (*irq_print_chip)(struct irq_data___2 *, struct seq_file___7 *);
	int (*irq_request_resources)(struct irq_data___2 *);
	void (*irq_release_resources)(struct irq_data___2 *);
	void (*irq_compose_msi_msg)(struct irq_data___2 *, struct msi_msg *);
	void (*irq_write_msi_msg)(struct irq_data___2 *, struct msi_msg *);
	int (*irq_get_irqchip_state)(struct irq_data___2 *, enum irqchip_irq_state, bool *);
	int (*irq_set_irqchip_state)(struct irq_data___2 *, enum irqchip_irq_state, bool);
	int (*irq_set_vcpu_affinity)(struct irq_data___2 *, void *);
	void (*ipi_send_single)(struct irq_data___2 *, unsigned int);
	void (*ipi_send_mask)(struct irq_data___2 *, const struct cpumask *);
	int (*irq_nmi_setup)(struct irq_data___2 *);
	void (*irq_nmi_teardown)(struct irq_data___2 *);
	long unsigned int flags;
};

struct irq_chip_type___2 {
	struct irq_chip___2 chip;
	struct irq_chip_regs regs;
	irq_flow_handler_t___2 handler;
	u32 type;
	u32 mask_cache_priv;
	u32 *mask_cache;
};

struct irq_chip_generic___2 {
	raw_spinlock_t lock;
	void *reg_base;
	u32 (*reg_readl)(void *);
	void (*reg_writel)(u32, void *);
	void (*suspend)(struct irq_chip_generic___2 *);
	void (*resume)(struct irq_chip_generic___2 *);
	unsigned int irq_base;
	unsigned int irq_cnt;
	u32 mask_cache;
	u32 type_cache;
	u32 polarity_cache;
	u32 wake_enabled;
	u32 wake_active;
	unsigned int num_ct;
	void *private;
	long unsigned int installed;
	long unsigned int unused;
	struct irq_domain___4 *domain;
	struct list_head list;
	struct irq_chip_type___2 chip_types[0];
};

struct irq_domain_chip_generic___2 {
	unsigned int irqs_per_chip;
	unsigned int num_chips;
	unsigned int irq_flags_to_clear;
	unsigned int irq_flags_to_set;
	enum irq_gc_flags gc_flags;
	struct irq_chip_generic___2 *gc[0];
};

struct irq_fwspec___4 {
	struct fwnode_handle___7 *fwnode;
	int param_count;
	u32 param[16];
};

struct irq_domain_ops___4 {
	int (*match)(struct irq_domain___4 *, struct device_node___4 *, enum irq_domain_bus_token);
	int (*select)(struct irq_domain___4 *, struct irq_fwspec___4 *, enum irq_domain_bus_token);
	int (*map)(struct irq_domain___4 *, unsigned int, irq_hw_number_t);
	void (*unmap)(struct irq_domain___4 *, unsigned int);
	int (*xlate)(struct irq_domain___4 *, struct device_node___4 *, const u32 *, unsigned int, long unsigned int *, unsigned int *);
	int (*alloc)(struct irq_domain___4 *, unsigned int, unsigned int, void *);
	void (*free)(struct irq_domain___4 *, unsigned int, unsigned int);
	int (*activate)(struct irq_domain___4 *, struct irq_data___2 *, bool);
	void (*deactivate)(struct irq_domain___4 *, struct irq_data___2 *);
	int (*translate)(struct irq_domain___4 *, struct irq_fwspec___4 *, long unsigned int *, unsigned int *);
};

struct physdev_set_iopl {
	uint32_t iopl;
};

struct physdev_set_iobitmap {
	uint8_t *bitmap;
	uint32_t nr_ports;
};

typedef u32 acpi_status;

struct cftype___6;

struct cgroup_subsys___6 {
	struct cgroup_subsys_state___6 * (*css_alloc)(struct cgroup_subsys_state___6 *);
	int (*css_online)(struct cgroup_subsys_state___6 *);
	void (*css_offline)(struct cgroup_subsys_state___6 *);
	void (*css_released)(struct cgroup_subsys_state___6 *);
	void (*css_free)(struct cgroup_subsys_state___6 *);
	void (*css_reset)(struct cgroup_subsys_state___6 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___6 *, int);
	int (*css_extra_stat_show)(struct seq_file___7 *, struct cgroup_subsys_state___6 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___10 *, struct css_set___6 *);
	void (*cancel_fork)(struct task_struct___10 *, struct css_set___6 *);
	void (*fork)(struct task_struct___10 *);
	void (*exit)(struct task_struct___10 *);
	void (*release)(struct task_struct___10 *);
	void (*bind)(struct cgroup_subsys_state___6 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___6 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___6 *dfl_cftypes;
	struct cftype___6 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___6 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___6 *updated_children;
	struct cgroup___6 *updated_next;
};

struct cgroup_root___6 {
	struct kernfs_root___7 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___6 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___6 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___6 *ss;
	struct list_head node;
	struct kernfs_ops___7 *kf_ops;
	int (*open)(struct kernfs_open_file___7 *);
	void (*release)(struct kernfs_open_file___7 *);
	u64 (*read_u64)(struct cgroup_subsys_state___6 *, struct cftype___6 *);
	s64 (*read_s64)(struct cgroup_subsys_state___6 *, struct cftype___6 *);
	int (*seq_show)(struct seq_file___7 *, void *);
	void * (*seq_start)(struct seq_file___7 *, loff_t *);
	void * (*seq_next)(struct seq_file___7 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___7 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___6 *, struct cftype___6 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___6 *, struct cftype___6 *, s64);
	ssize_t (*write)(struct kernfs_open_file___7 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___7 *, struct poll_table_struct___5 *);
};

struct block_device_operations___6;

struct gendisk___6 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	short unsigned int events;
	short unsigned int event_flags;
	struct xarray part_tbl;
	struct block_device___6 *part0;
	const struct block_device_operations___6 *fops;
	struct request_queue___6 *queue;
	void *private_data;
	int flags;
	long unsigned int state;
	struct mutex open_mutex;
	unsigned int open_partitions;
	struct backing_dev_info___5 *bdi;
	struct kobject___8 *slave_dir;
	struct list_head slave_bdevs;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___8 integrity_kobj;
	struct cdrom_device_info *cdi;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	u64 diskseq;
};

struct bio_integrity_payload___6 {
	struct bio___6 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___7 *bip_vec;
	struct bio_vec___7 bip_inline_vecs[0];
};

struct blkcg___5;

struct blkg_policy_data___5;

struct blkcg_gq___5 {
	struct request_queue___6 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___5 *blkcg;
	struct blkcg_gq___5 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_iostat_set *iostat_cpu;
	struct blkg_iostat_set iostat;
	struct blkg_policy_data___5 *pd[6];
	spinlock_t async_bio_lock;
	struct bio_list___6 async_bios;
	struct work_struct async_bio_work;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
	struct callback_head callback_head;
};

typedef void integrity_prepare_fn___6(struct request___6 *);

typedef void integrity_complete_fn___6(struct request___6 *, unsigned int);

struct blk_integrity_profile___6 {
	integrity_processing_fn *generate_fn;
	integrity_processing_fn *verify_fn;
	integrity_prepare_fn___6 *prepare_fn;
	integrity_complete_fn___6 *complete_fn;
	const char *name;
};

struct block_device_operations___6 {
	blk_qc_t (*submit_bio)(struct bio___6 *);
	int (*open)(struct block_device___6 *, fmode_t);
	void (*release)(struct gendisk___6 *, fmode_t);
	int (*rw_page)(struct block_device___6 *, sector_t, struct page___3 *, unsigned int);
	int (*ioctl)(struct block_device___6 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___6 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___6 *, unsigned int);
	void (*unlock_native_capacity)(struct gendisk___6 *);
	int (*getgeo)(struct block_device___6 *, struct hd_geometry *);
	int (*set_read_only)(struct block_device___6 *, bool);
	void (*swap_slot_free_notify)(struct block_device___6 *, long unsigned int);
	int (*report_zones)(struct gendisk___6 *, sector_t, unsigned int, report_zones_cb, void *);
	char * (*devnode)(struct gendisk___6 *, umode_t *);
	struct module___8 *owner;
	const struct pr_ops *pr_ops;
	int (*alternative_gpt_sector)(struct gendisk___6 *, sector_t *);
};

typedef void rq_end_io_fn___6(struct request___6 *, blk_status_t);

struct request___6 {
	struct request_queue___6 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int tag;
	int internal_tag;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___6 *bio;
	struct bio___6 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct llist_node ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___7 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___6 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___6 *saved_end_io;
		} flush;
	};
	struct gendisk___6 *rq_disk;
	struct block_device___6 *part;
	u64 alloc_time_ns;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int stats_sectors;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	struct bio_crypt_ctx *crypt_ctx;
	struct blk_ksm_keyslot *crypt_keyslot;
	short unsigned int write_hint;
	short unsigned int ioprio;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___6 *end_io;
	void *end_io_data;
};

struct elevator_type___6;

struct elevator_mq_ops___6 {
	int (*init_sched)(struct request_queue___6 *, struct elevator_type___6 *);
	void (*exit_sched)(struct elevator_queue___6 *);
	int (*init_hctx)(struct blk_mq_hw_ctx *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx *, unsigned int);
	void (*depth_updated)(struct blk_mq_hw_ctx *);
	bool (*allow_merge)(struct request_queue___6 *, struct request___6 *, struct bio___6 *);
	bool (*bio_merge)(struct request_queue___6 *, struct bio___6 *, unsigned int);
	int (*request_merge)(struct request_queue___6 *, struct request___6 **, struct bio___6 *);
	void (*request_merged)(struct request_queue___6 *, struct request___6 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___6 *, struct request___6 *, struct request___6 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___6 *);
	void (*finish_request)(struct request___6 *);
	void (*insert_requests)(struct blk_mq_hw_ctx *, struct list_head *, bool);
	struct request___6 * (*dispatch_request)(struct blk_mq_hw_ctx *);
	bool (*has_work)(struct blk_mq_hw_ctx *);
	void (*completed_request)(struct request___6 *, u64);
	void (*requeue_request)(struct request___6 *);
	struct request___6 * (*former_request)(struct request_queue___6 *, struct request___6 *);
	struct request___6 * (*next_request)(struct request_queue___6 *, struct request___6 *);
	void (*init_icq)(struct io_cq___6 *);
	void (*exit_icq)(struct io_cq___6 *);
};

struct elv_fs_entry___6;

struct elevator_type___6 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___6 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___6 *elevator_attrs;
	const char *elevator_name;
	const char *elevator_alias;
	const unsigned int elevator_features;
	struct module___8 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
};

struct elevator_queue___6 {
	struct elevator_type___6 *type;
	void *elevator_data;
	struct kobject___8 kobj;
	struct mutex sysfs_lock;
	unsigned int registered;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hlist_head hash[64];
};

struct elv_fs_entry___6 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___6 *, char *);
	ssize_t (*store)(struct elevator_queue___6 *, const char *, size_t);
};

struct blkcg_policy_data___5;

struct blkcg___5 {
	struct cgroup_subsys_state___6 css;
	spinlock_t lock;
	refcount_t online_pin;
	struct xarray blkg_tree;
	struct blkcg_gq___5 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___5 *cpd[6];
	struct list_head all_blkcgs_node;
	char fc_app_id[129];
	struct list_head cgwb_list;
};

struct blkcg_policy_data___5 {
	struct blkcg___5 *blkcg;
	int plid;
};

struct blkg_policy_data___5 {
	struct blkcg_gq___5 *blkg;
	int plid;
};

struct mem_cgroup_reclaim_iter___5 {
	struct mem_cgroup___5 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___5 {
	struct lruvec___5 lruvec;
	struct lruvec_stats_percpu *lruvec_stats_percpu;
	struct lruvec_stats lruvec_stats;
	long unsigned int lru_zone_size[25];
	struct mem_cgroup_reclaim_iter___5 iter;
	struct shrinker_info *shrinker_info;
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	struct mem_cgroup___5 *memcg;
};

struct obj_cgroup___5 {
	struct percpu_ref refcnt;
	struct mem_cgroup___5 *memcg;
	atomic_t nr_charged_bytes;
	union {
		struct list_head list;
		struct callback_head rcu;
	};
};

struct perf_cpu_context___5;

struct perf_output_handle___5;

struct pmu___5 {
	struct list_head entry;
	struct module___8 *module;
	struct device___3 *dev;
	const struct attribute_group___8 **attr_groups;
	const struct attribute_group___8 **attr_update;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___5 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___5 *);
	void (*pmu_disable)(struct pmu___5 *);
	int (*event_init)(struct perf_event___5 *);
	void (*event_mapped)(struct perf_event___5 *, struct mm_struct___10 *);
	void (*event_unmapped)(struct perf_event___5 *, struct mm_struct___10 *);
	int (*add)(struct perf_event___5 *, int);
	void (*del)(struct perf_event___5 *, int);
	void (*start)(struct perf_event___5 *, int);
	void (*stop)(struct perf_event___5 *, int);
	void (*read)(struct perf_event___5 *);
	void (*start_txn)(struct pmu___5 *, unsigned int);
	int (*commit_txn)(struct pmu___5 *);
	void (*cancel_txn)(struct pmu___5 *);
	int (*event_idx)(struct perf_event___5 *);
	void (*sched_task)(struct perf_event_context___5 *, bool);
	struct kmem_cache *task_ctx_cache;
	void (*swap_task_ctx)(struct perf_event_context___5 *, struct perf_event_context___5 *);
	void * (*setup_aux)(struct perf_event___5 *, void **, int, bool);
	void (*free_aux)(void *);
	long int (*snapshot_aux)(struct perf_event___5 *, struct perf_output_handle___5 *, long unsigned int);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___5 *);
	int (*aux_output_match)(struct perf_event___5 *);
	int (*filter_match)(struct perf_event___5 *);
	int (*check_period)(struct perf_event___5 *, u64);
};

struct perf_cpu_context___5 {
	struct perf_event_context___5 ctx;
	struct perf_event_context___5 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___5 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
	int heap_size;
	struct perf_event___5 **heap;
	struct perf_event___5 *heap_default[2];
};

struct perf_output_handle___5 {
	struct perf_event___5 *event;
	struct perf_buffer *rb;
	long unsigned int wakeup;
	long unsigned int size;
	u64 aux_flags;
	union {
		void *addr;
		long unsigned int head;
	};
	int page;
};

struct perf_cgroup___5 {
	struct cgroup_subsys_state___6 css;
	struct perf_cgroup_info *info;
};

struct trace_event_fields___5 {
	const char *type;
	union {
		struct {
			const char *name;
			const int size;
			const int align;
			const int is_signed;
			const int filter_type;
		};
		int (*define_fields)(struct trace_event_call___5 *);
	};
};

struct trace_event_class___5 {
	const char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct trace_event_call___5 *, enum trace_reg, void *);
	struct trace_event_fields___5 *fields_array;
	struct list_head * (*get_fields)(struct trace_event_call___5 *);
	struct list_head fields;
	int (*raw_init)(struct trace_event_call___5 *);
};

struct gdt_page___2 {
	struct desc_struct gdt[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct tlb_state___2 {
	struct mm_struct___10 *loaded_mm;
	union {
		struct mm_struct___10 *last_user_mm;
		long unsigned int last_user_mm_spec;
	};
	u16 loaded_mm_asid;
	u16 next_asid;
	bool invalidate_other;
	short unsigned int user_pcid_flush_mask;
	long unsigned int cr4;
	struct tlb_context ctxs[6];
};

struct pm_qos_flags_request {
	struct list_head node;
	s32 flags;
};

enum freq_qos_req_type {
	FREQ_QOS_MIN = 1,
	FREQ_QOS_MAX = 2,
};

struct freq_qos_request {
	enum freq_qos_req_type type;
	struct plist_node pnode;
	struct freq_constraints *qos;
};

enum dev_pm_qos_req_type {
	DEV_PM_QOS_RESUME_LATENCY = 1,
	DEV_PM_QOS_LATENCY_TOLERANCE = 2,
	DEV_PM_QOS_MIN_FREQUENCY = 3,
	DEV_PM_QOS_MAX_FREQUENCY = 4,
	DEV_PM_QOS_FLAGS = 5,
};

struct dev_pm_qos_request {
	enum dev_pm_qos_req_type type;
	union {
		struct plist_node pnode;
		struct pm_qos_flags_request flr;
		struct freq_qos_request freq;
	} data;
	struct device___3 *dev;
};

struct multicall_space {
	struct multicall_entry *mc;
	void *args;
};

struct tls_descs {
	struct desc_struct desc[3];
};

struct trap_array_entry {
	void (*orig)();
	void (*xen)();
	bool ist_okay;
};

struct dentry___9;

struct super_block___9;

struct module___9;

struct file_system_type___9 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___9 * (*mount)(struct file_system_type___9 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___9 *);
	struct module___9 *owner;
	struct file_system_type___9 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___9;

struct kiocb___9;

struct iov_iter___8;

struct poll_table_struct___6;

struct vm_area_struct___10;

struct inode___9;

struct file_lock___9;

struct page___9;

struct seq_file___8;

struct file_operations___9 {
	struct module___9 *owner;
	loff_t (*llseek)(struct file___9 *, loff_t, int);
	ssize_t (*read)(struct file___9 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___9 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___9 *, struct iov_iter___8 *);
	ssize_t (*write_iter)(struct kiocb___9 *, struct iov_iter___8 *);
	int (*iopoll)(struct kiocb___9 *, bool);
	int (*iterate)(struct file___9 *, struct dir_context *);
	int (*iterate_shared)(struct file___9 *, struct dir_context *);
	__poll_t (*poll)(struct file___9 *, struct poll_table_struct___6 *);
	long int (*unlocked_ioctl)(struct file___9 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___9 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___9 *, struct vm_area_struct___10 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___9 *, struct file___9 *);
	int (*flush)(struct file___9 *, fl_owner_t);
	int (*release)(struct inode___9 *, struct file___9 *);
	int (*fsync)(struct file___9 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___9 *, int);
	int (*lock)(struct file___9 *, int, struct file_lock___9 *);
	ssize_t (*sendpage)(struct file___9 *, struct page___9 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___9 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___9 *, long unsigned int);
	int (*flock)(struct file___9 *, int, struct file_lock___9 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___9 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___9 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___9 *, long int, struct file_lock___9 **, void **);
	long int (*fallocate)(struct file___9 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___8 *, struct file___9 *);
	ssize_t (*copy_file_range)(struct file___9 *, loff_t, struct file___9 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___9 *, loff_t, struct file___9 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___9 *, loff_t, loff_t, int);
};

struct static_call_mod___6 {
	struct static_call_mod___6 *next;
	struct module___9 *mod;
	struct static_call_site *sites;
};

struct static_call_key___6 {
	void *func;
	union {
		long unsigned int type;
		struct static_call_mod___6 *mods;
		struct static_call_site *sites;
	};
};

struct vmacache___9 {
	u64 seqnum;
	struct vm_area_struct___10 *vmas[4];
};

struct page_frag___9 {
	struct page___9 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___11;

struct pid___8;

struct nsproxy___9;

struct signal_struct___10;

struct bio_list___7;

struct backing_dev_info___6;

struct io_context___8;

struct css_set___7;

struct mem_cgroup___6;

struct request_queue___7;

struct vm_struct___9;

struct task_struct___11 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___11 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___11 *mm;
	struct mm_struct___11 *active_mm;
	struct vmacache___9 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int restore_sigmask: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___11 *real_parent;
	struct task_struct___11 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___11 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___8 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	struct posix_cputimers_work posix_cputimers_work;
	const struct cred *ptracer_cred;
	const struct cred *real_cred;
	const struct cred *cred;
	struct key *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___9 *nsproxy;
	struct signal_struct___10 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___11 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___7 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___6 *backing_dev_info;
	struct io_context___8 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___7 *cgroups;
	struct list_head cg_list;
	u32 closid;
	u32 rmid;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	long: 64;
	long: 64;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___9 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___6 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___6 *active_memcg;
	struct request_queue___7 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___11 *oom_reaper_list;
	struct vm_struct___9 *stack_vm_area;
	refcount_t stack_refcount;
	int patch_state;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	void *mce_vaddr;
	__u64 mce_kflags;
	u64 mce_addr;
	__u64 mce_ripv: 1;
	__u64 mce_whole_page: 1;
	__u64 __mce_reserved: 62;
	long: 2;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct callback_head mce_kill_me;
	int mce_count;
	struct llist_head kretprobe_instances;
	struct callback_head l1d_flush_kill;
	long: 64;
	struct thread_struct___6 thread;
};

typedef struct page___9 *pgtable_t___9;

struct address_space___10;

struct dev_pagemap___9;

struct page___9 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___10 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___9 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___9 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___11 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___9 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct pv_cpu_ops___6 {
	void (*io_delay)();
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	void (*write_cr4)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___6 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(long unsigned int);
	void (*invalidate_io_bitmap)();
	void (*update_io_bitmap)();
	void (*wbinvd)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int);
	void (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_msr_safe)(unsigned int, int *);
	int (*write_msr_safe)(unsigned int, unsigned int, unsigned int);
	u64 (*read_pmc)(int);
	void (*start_context_switch)(struct task_struct___11 *);
	void (*end_context_switch)(struct task_struct___11 *);
};

struct flush_tlb_info___5;

struct mmu_gather___2;

struct pv_mmu_ops___6 {
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_one_user)(long unsigned int);
	void (*flush_tlb_multi)(const struct cpumask *, const struct flush_tlb_info___5 *);
	void (*tlb_remove_table)(struct mmu_gather___2 *, void *);
	void (*exit_mmap)(struct mm_struct___11 *);
	struct paravirt_callee_save read_cr2;
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___11 *, struct mm_struct___11 *);
	void (*dup_mmap)(struct mm_struct___11 *, struct mm_struct___11 *);
	int (*pgd_alloc)(struct mm_struct___11 *);
	void (*pgd_free)(struct mm_struct___11 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___11 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___11 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___11 *, long unsigned int);
	void (*alloc_p4d)(struct mm_struct___11 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*release_p4d)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	pte_t (*ptep_modify_prot_start)(struct vm_area_struct___10 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct vm_area_struct___10 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_p4d)(p4d_t *, p4d_t);
	struct paravirt_callee_save p4d_val;
	struct paravirt_callee_save make_p4d;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

struct flush_tlb_info___5 {
	struct mm_struct___11 *mm;
	long unsigned int start;
	long unsigned int end;
	u64 new_tlb_gen;
	unsigned int initiating_cpu;
	u8 stride_shift;
	u8 freed_tables;
};

struct mmu_gather_batch {
	struct mmu_gather_batch *next;
	unsigned int nr;
	unsigned int max;
	struct page___9 *pages[0];
};

struct mmu_table_batch;

struct mmu_gather___2 {
	struct mm_struct___11 *mm;
	struct mmu_table_batch *batch;
	long unsigned int start;
	long unsigned int end;
	unsigned int fullmm: 1;
	unsigned int need_flush_all: 1;
	unsigned int freed_tables: 1;
	unsigned int cleared_ptes: 1;
	unsigned int cleared_pmds: 1;
	unsigned int cleared_puds: 1;
	unsigned int cleared_p4ds: 1;
	unsigned int vma_exec: 1;
	unsigned int vma_huge: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int batch_count;
	struct mmu_gather_batch *active;
	struct mmu_gather_batch local;
	struct page___9 *__pages[8];
};

struct core_state___9;

struct mm_struct___11 {
	struct {
		struct vm_area_struct___10 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___9 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int mmap_compat_base;
		long unsigned int mmap_compat_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[48];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___9 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___11 *owner;
		struct user_namespace *user_ns;
		struct file___9 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		bool tlb_flush_batched;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int cpu_bitmap[0];
};

struct vm_operations_struct___9;

struct vm_area_struct___10 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___10 *vm_next;
	struct vm_area_struct___10 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___11 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___9 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___9 *vm_file;
	struct file___9 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct paravirt_patch_template___6 {
	struct pv_cpu_ops___6 cpu;
	struct pv_irq_ops irq;
	struct pv_mmu_ops___6 mmu;
	struct pv_lock_ops lock;
};

struct tracepoint___6 {
	const char *name;
	struct static_key key;
	struct static_call_key___6 *static_call_key;
	void *static_call_tramp;
	void *iterator;
	int (*regfunc)();
	void (*unregfunc)();
	struct tracepoint_func *funcs;
};

struct bpf_raw_event_map___6 {
	struct tracepoint___6 *tp;
	void *bpf_func;
	u32 num_args;
	u32 writable_size;
	long: 64;
};

struct seq_operations___8 {
	void * (*start)(struct seq_file___8 *, loff_t *);
	void (*stop)(struct seq_file___8 *, void *);
	void * (*next)(struct seq_file___8 *, void *, loff_t *);
	int (*show)(struct seq_file___8 *, void *);
};

struct pid_namespace___8;

struct upid___8 {
	int nr;
	struct pid_namespace___8 *ns;
};

struct pid_namespace___8 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___11 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___8 *parent;
	struct fs_pin *bacct;
	struct user_namespace *user_ns;
	struct ucounts *ucounts;
	int reboot;
	struct ns_common ns;
};

struct pid___8 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___8 numbers[1];
};

struct signal_struct___10 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___11 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___11 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper;
	unsigned int has_child_subreaper;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___8 *pids[4];
	struct pid___8 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___11 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct cgroup_namespace___7;

struct nsproxy___9 {
	atomic_t count;
	struct uts_namespace *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___8 *pid_ns_for_children;
	struct net *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___7 *cgroup_ns;
};

struct bio___7;

struct bio_list___7 {
	struct bio___7 *head;
	struct bio___7 *tail;
};

struct cgroup_subsys_state___7;

struct bdi_writeback___6 {
	struct backing_dev_info___6 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	atomic_t writeback_inodes;
	struct percpu_counter stat[4];
	long unsigned int congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	struct delayed_work bw_dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___7 *memcg_css;
	struct cgroup_subsys_state___7 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	struct list_head b_attached;
	struct list_head offline_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
};

struct device___9;

struct backing_dev_info___6 {
	u64 id;
	struct rb_node rb_node;
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___6 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct mutex cgwb_release_mutex;
	struct rw_semaphore wb_switch_rwsem;
	wait_queue_head_t wb_waitq;
	struct device___9 *dev;
	char dev_name[64];
	struct device___9 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___9 *debug_dir;
};

struct io_cq___7;

struct io_context___8 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	struct xarray icq_tree;
	struct io_cq___7 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct cgroup___7;

struct css_set___7 {
	struct cgroup_subsys_state___7 *subsys[14];
	refcount_t refcount;
	struct css_set___7 *dom_cset;
	struct cgroup___7 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___7 *mg_src_cgrp;
	struct cgroup___7 *mg_dst_cgrp;
	struct css_set___7 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct cgroup_subsys___7;

struct cgroup_subsys_state___7 {
	struct cgroup___7 *cgroup;
	struct cgroup_subsys___7 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___7 *parent;
};

struct kernfs_node___8;

struct cgroup_file___7 {
	struct kernfs_node___8 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct obj_cgroup___6;

struct mem_cgroup_per_node___6;

struct mem_cgroup___6 {
	struct cgroup_subsys_state___7 css;
	struct mem_cgroup_id id;
	struct page_counter memory;
	union {
		struct page_counter swap;
		struct page_counter memsw;
	};
	struct page_counter kmem;
	struct page_counter tcpmem;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool oom_group;
	bool oom_lock;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___7 events_file;
	struct cgroup_file___7 events_local_file;
	struct cgroup_file___7 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	struct memcg_vmstats vmstats;
	atomic_long_t memory_events[8];
	atomic_long_t memory_events_local[8];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct obj_cgroup___6 *objcg;
	struct list_head objcg_list;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad2_;
	atomic_t moving_account;
	struct task_struct___11 *move_lock_task;
	struct memcg_vmstats_percpu *vmstats_percpu;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct memcg_cgwb_frn cgwb_frn[4];
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct deferred_split deferred_split_queue;
	struct mem_cgroup_per_node___6 *nodeinfo[0];
	long: 64;
};

struct kset___8;

struct kobj_type___8;

struct kobject___9 {
	const char *name;
	struct list_head entry;
	struct kobject___9 *parent;
	struct kset___8 *kset;
	struct kobj_type___8 *ktype;
	struct kernfs_node___8 *sd;
	struct kref kref;
	unsigned int state_initialized;
	unsigned int state_in_sysfs;
	unsigned int state_add_uevent_sent;
	unsigned int state_remove_uevent_sent;
	unsigned int uevent_suppress;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct blk_integrity_profile___7;

struct blk_integrity___7 {
	const struct blk_integrity_profile___7 *profile;
	unsigned char flags;
	unsigned char tuple_size;
	unsigned char interval_exp;
	unsigned char tag_size;
};

struct bio_set___7 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	struct bio_alloc_cache *cache;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	unsigned int back_pad;
	spinlock_t rescue_lock;
	struct bio_list___7 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	struct hlist_node cpuhp_dead;
};

struct request___7;

struct elevator_queue___7;

struct gendisk___7;

struct blkcg_gq___6;

struct request_queue___7 {
	struct request___7 *last_merge;
	struct elevator_queue___7 *elevator;
	struct percpu_ref q_usage_counter;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	const struct blk_mq_ops *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx **queue_hw_ctx;
	unsigned int nr_hw_queues;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	spinlock_t queue_lock;
	struct gendisk___7 *disk;
	struct kobject___9 kobj;
	struct kobject___9 *mq_kobj;
	struct blk_integrity___7 integrity;
	struct device___9 *dev;
	enum rpm_status rpm_status;
	long unsigned int nr_requests;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_keyslot_manager *ksm;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	atomic_t nr_active_requests_shared_sbitmap;
	struct sbitmap_queue sched_bitmap_tags;
	struct sbitmap_queue sched_breserved_tags;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___6 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int required_elevator_features;
	unsigned int nr_zones;
	long unsigned int *conv_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int max_open_zones;
	unsigned int max_active_zones;
	int node;
	struct mutex debugfs_mutex;
	struct blk_trace *blk_trace;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	struct mutex sysfs_dir_lock;
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	int mq_freeze_depth;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct mutex mq_freeze_lock;
	struct blk_mq_tag_set *tag_set;
	struct list_head tag_set_list;
	struct bio_set___7 bio_split;
	struct dentry___9 *debugfs_dir;
	struct dentry___9 *sched_debugfs_dir;
	struct dentry___9 *rqos_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	u64 write_hints[5];
};

struct vm_struct___9 {
	struct vm_struct___9 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___9 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct address_space_operations___9;

struct address_space___10 {
	struct inode___9 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___9 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct dev_pagemap_ops___9;

struct dev_pagemap___9 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___9 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vfsmount___9;

struct path___9 {
	struct vfsmount___9 *mnt;
	struct dentry___9 *dentry;
};

struct fown_struct___8 {
	rwlock_t lock;
	struct pid___8 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___9 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	long: 64;
	long: 64;
	struct path___9 f_path;
	struct inode___9 *f_inode;
	const struct file_operations___9 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___8 f_owner;
	const struct cred *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___10 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___9;

struct vm_operations_struct___9 {
	void (*open)(struct vm_area_struct___10 *);
	void (*close)(struct vm_area_struct___10 *);
	int (*may_split)(struct vm_area_struct___10 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___10 *);
	int (*mprotect)(struct vm_area_struct___10 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___9 *);
	vm_fault_t (*huge_fault)(struct vm_fault___9 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___9 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___10 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___9 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___9 *);
	int (*access)(struct vm_area_struct___10 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___10 *);
	int (*set_policy)(struct vm_area_struct___10 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___10 *, long unsigned int);
	struct page___9 * (*find_special_page)(struct vm_area_struct___10 *, long unsigned int);
};

struct core_thread___9 {
	struct task_struct___11 *task;
	struct core_thread___9 *next;
};

struct core_state___9 {
	atomic_t nr_threads;
	struct core_thread___9 dumper;
	struct completion startup;
};

struct vm_fault___9 {
	const struct {
		struct vm_area_struct___10 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___9 *cow_page;
	struct page___9 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___9 prealloc_pte;
};

struct pglist_data___6;

struct lruvec___6 {
	struct list_head lists[5];
	spinlock_t lru_lock;
	long unsigned int anon_cost;
	long unsigned int file_cost;
	atomic_long_t nonresident_age;
	long unsigned int refaults[2];
	long unsigned int flags;
	struct pglist_data___6 *pgdat;
};

struct zone___6 {
	long unsigned int _watermark[3];
	long unsigned int watermark_boost;
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[5];
	int node;
	struct pglist_data___6 *zone_pgdat;
	struct per_cpu_pages *per_cpu_pageset;
	struct per_cpu_zonestat *per_cpu_zonestats;
	int pageset_high;
	int pageset_batch;
	long unsigned int zone_start_pfn;
	atomic_long_t managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int present_early_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	seqlock_t span_seqlock;
	int initialized;
	int: 32;
	struct zone_padding _pad1_;
	struct free_area free_area[11];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	long unsigned int compact_init_migrate_pfn;
	long unsigned int compact_init_free_pfn;
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	short: 16;
	struct zone_padding _pad3_;
	atomic_long_t vm_stat[11];
	atomic_long_t vm_numa_event[6];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___6 {
	struct zone___6 *zone;
	int zone_idx;
};

struct zonelist___6 {
	struct zoneref___6 _zonerefs[5121];
};

struct pglist_data___6 {
	struct zone___6 node_zones[5];
	struct zonelist___6 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___11 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_highest_zoneidx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_highest_zoneidx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___11 *kcompactd;
	bool proactive_compact_trigger;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct deferred_split deferred_split_queue;
	struct lruvec___6 __lruvec;
	long unsigned int flags;
	long: 64;
	struct zone_padding _pad2_;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[39];
};

struct dentry_operations___9;

struct dentry___9 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___9 *d_parent;
	struct qstr d_name;
	struct inode___9 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___9 *d_op;
	struct super_block___9 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___9;

struct cdev___5;

struct inode___9 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___9 *i_op;
	struct super_block___9 *i_sb;
	struct address_space___10 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___6 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	long: 64;
	long: 64;
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___9 *i_fop;
		void (*free_inode)(struct inode___9 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___10 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct cdev___5 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___9 {
	int (*d_revalidate)(struct dentry___9 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___9 *, unsigned int);
	int (*d_hash)(const struct dentry___9 *, struct qstr *);
	int (*d_compare)(const struct dentry___9 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___9 *);
	int (*d_init)(struct dentry___9 *);
	void (*d_release)(struct dentry___9 *);
	void (*d_prune)(struct dentry___9 *);
	void (*d_iput)(struct dentry___9 *, struct inode___9 *);
	char * (*d_dname)(struct dentry___9 *, char *, int);
	struct vfsmount___9 * (*d_automount)(struct path___9 *);
	int (*d_manage)(const struct path___9 *, bool);
	struct dentry___9 * (*d_real)(struct dentry___9 *, const struct inode___9 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___9;

struct mem_dqinfo___9 {
	struct quota_format_type___9 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___9;

struct quota_info___9 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___9 *files[3];
	struct mem_dqinfo___9 info[3];
	const struct quota_format_ops___9 *ops[3];
};

struct rcuwait___9 {
	struct task_struct___11 *task;
};

struct percpu_rw_semaphore___9 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___9 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___9 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___9 rw_sem[3];
};

struct shrink_control___6;

struct shrinker___6 {
	long unsigned int (*count_objects)(struct shrinker___6 *, struct shrink_control___6 *);
	long unsigned int (*scan_objects)(struct shrinker___6 *, struct shrink_control___6 *);
	long int batch;
	int seeks;
	unsigned int flags;
	struct list_head list;
	int id;
	atomic_long_t *nr_deferred;
};

struct super_operations___9;

struct dquot_operations___9;

struct quotactl_ops___9;

struct block_device___7;

struct super_block___9 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___9 *s_type;
	const struct super_operations___9 *s_op;
	const struct dquot_operations___9 *dq_op;
	const struct quotactl_ops___9 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___9 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___7 *s_bdev;
	struct backing_dev_info___6 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___9 s_dquot;
	struct sb_writers___9 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___9 *s_d_op;
	int cleancache_poolid;
	struct shrinker___6 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___9 {
	struct dentry___9 *mnt_root;
	struct super_block___9 *mnt_sb;
	int mnt_flags;
	struct user_namespace *mnt_userns;
};

struct shrink_control___6 {
	gfp_t gfp_mask;
	int nid;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	struct mem_cgroup___6 *memcg;
};

struct psi_group___7 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___11 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___7;

struct cgroup_rstat_cpu___7;

struct cgroup___7 {
	struct cgroup_subsys_state___7 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___8 *kn;
	struct cgroup_file___7 procs_file;
	struct cgroup_file___7 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___7 *subsys[14];
	struct cgroup_root___7 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___7 *dom_cgrp;
	struct cgroup___7 *old_dom_cgrp;
	struct cgroup_rstat_cpu___7 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___7 psi;
	struct cgroup_bpf bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct io_cq___7 {
	struct request_queue___7 *q;
	struct io_context___8 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct wait_page_queue___5;

struct kiocb___9 {
	struct file___9 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___9 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___5 *ki_waitq;
	};
};

struct iattr___9 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___9 *ia_file;
};

struct dquot___9 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___9 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___9 {
	int qf_fmt_id;
	const struct quota_format_ops___9 *qf_ops;
	struct module___9 *qf_owner;
	struct quota_format_type___9 *qf_next;
};

struct quota_format_ops___9 {
	int (*check_quota_file)(struct super_block___9 *, int);
	int (*read_file_info)(struct super_block___9 *, int);
	int (*write_file_info)(struct super_block___9 *, int);
	int (*free_file_info)(struct super_block___9 *, int);
	int (*read_dqblk)(struct dquot___9 *);
	int (*commit_dqblk)(struct dquot___9 *);
	int (*release_dqblk)(struct dquot___9 *);
	int (*get_next_id)(struct super_block___9 *, struct kqid *);
};

struct dquot_operations___9 {
	int (*write_dquot)(struct dquot___9 *);
	struct dquot___9 * (*alloc_dquot)(struct super_block___9 *, int);
	void (*destroy_dquot)(struct dquot___9 *);
	int (*acquire_dquot)(struct dquot___9 *);
	int (*release_dquot)(struct dquot___9 *);
	int (*mark_dirty)(struct dquot___9 *);
	int (*write_info)(struct super_block___9 *, int);
	qsize_t * (*get_reserved_space)(struct inode___9 *);
	int (*get_projid)(struct inode___9 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___9 *, qsize_t *);
	int (*get_next_id)(struct super_block___9 *, struct kqid *);
};

struct quotactl_ops___9 {
	int (*quota_on)(struct super_block___9 *, int, int, const struct path___9 *);
	int (*quota_off)(struct super_block___9 *, int);
	int (*quota_enable)(struct super_block___9 *, unsigned int);
	int (*quota_disable)(struct super_block___9 *, unsigned int);
	int (*quota_sync)(struct super_block___9 *, int);
	int (*set_info)(struct super_block___9 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___9 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___9 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___9 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___9 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___9 *, unsigned int);
};

struct module_kobject___8 {
	struct kobject___9 kobj;
	struct module___9 *mod;
	struct kobject___9 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___8 {
	struct module___9 *mod;
	struct latch_tree_node node;
};

struct module_layout___8 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___8 mtn;
};

struct module_attribute___8;

struct kernel_param___8;

struct module___9 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___8 mkobj;
	struct module_attribute___8 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___9 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___8 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___8 core_layout;
	struct module_layout___8 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map___6 *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___4 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	int num_static_call_sites;
	struct static_call_site *static_call_sites;
	bool klp;
	bool klp_alive;
	struct klp_modinfo *klp_info;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct wait_page_queue___5 {
	struct page___9 *page;
	int bit_nr;
	wait_queue_entry_t wait;
};

struct writeback_control___6;

struct readahead_control___5;

struct swap_info_struct___4;

struct address_space_operations___9 {
	int (*writepage)(struct page___9 *, struct writeback_control___6 *);
	int (*readpage)(struct file___9 *, struct page___9 *);
	int (*writepages)(struct address_space___10 *, struct writeback_control___6 *);
	int (*set_page_dirty)(struct page___9 *);
	int (*readpages)(struct file___9 *, struct address_space___10 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___5 *);
	int (*write_begin)(struct file___9 *, struct address_space___10 *, loff_t, unsigned int, unsigned int, struct page___9 **, void **);
	int (*write_end)(struct file___9 *, struct address_space___10 *, loff_t, unsigned int, unsigned int, struct page___9 *, void *);
	sector_t (*bmap)(struct address_space___10 *, sector_t);
	void (*invalidatepage)(struct page___9 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___9 *, gfp_t);
	void (*freepage)(struct page___9 *);
	ssize_t (*direct_IO)(struct kiocb___9 *, struct iov_iter___8 *);
	int (*migratepage)(struct address_space___10 *, struct page___9 *, struct page___9 *, enum migrate_mode);
	bool (*isolate_page)(struct page___9 *, isolate_mode_t);
	void (*putback_page)(struct page___9 *);
	int (*launder_page)(struct page___9 *);
	int (*is_partially_uptodate)(struct page___9 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___9 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___10 *, struct page___9 *);
	int (*swap_activate)(struct swap_info_struct___4 *, struct file___9 *, sector_t *);
	void (*swap_deactivate)(struct file___9 *);
};

struct writeback_control___6 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate;
	unsigned int for_background;
	unsigned int tagged_writepages;
	unsigned int for_reclaim;
	unsigned int range_cyclic;
	unsigned int for_sync;
	unsigned int no_cgroup_owner;
	unsigned int punt_to_cgroup;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bdi_writeback___6 *wb;
	struct inode___9 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
};

struct readahead_control___5 {
	struct file___9 *file;
	struct address_space___10 *mapping;
	struct file_ra_state *ra;
	long unsigned int _index;
	unsigned int _nr_pages;
	unsigned int _batch_count;
};

struct bio_vec___8;

struct iov_iter___8 {
	u8 iter_type;
	bool data_source;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___8 *bvec;
		struct xarray *xarray;
		struct pipe_inode_info *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			unsigned int head;
			unsigned int start_head;
		};
		loff_t xarray_start;
	};
};

struct swap_info_struct___4 {
	struct percpu_ref users;
	long unsigned int flags;
	short int prio;
	struct plist_node list;
	signed char type;
	unsigned int max;
	unsigned char *swap_map;
	struct swap_cluster_info *cluster_info;
	struct swap_cluster_list free_clusters;
	unsigned int lowest_bit;
	unsigned int highest_bit;
	unsigned int pages;
	unsigned int inuse_pages;
	unsigned int cluster_next;
	unsigned int cluster_nr;
	unsigned int *cluster_next_cpu;
	struct percpu_cluster *percpu_cluster;
	struct rb_root swap_extent_root;
	struct block_device___7 *bdev;
	struct file___9 *swap_file;
	unsigned int old_block_size;
	struct completion comp;
	long unsigned int *frontswap_map;
	atomic_t frontswap_pages;
	spinlock_t lock;
	spinlock_t cont_lock;
	struct work_struct discard_work;
	struct swap_cluster_list discard_clusters;
	struct plist_node avail_lists[0];
};

struct cdev___5 {
	struct kobject___9 kobj;
	struct module___9 *owner;
	const struct file_operations___9 *ops;
	struct list_head list;
	dev_t dev;
	unsigned int count;
};

struct inode_operations___9 {
	struct dentry___9 * (*lookup)(struct inode___9 *, struct dentry___9 *, unsigned int);
	const char * (*get_link)(struct dentry___9 *, struct inode___9 *, struct delayed_call *);
	int (*permission)(struct user_namespace *, struct inode___9 *, int);
	struct posix_acl * (*get_acl)(struct inode___9 *, int, bool);
	int (*readlink)(struct dentry___9 *, char *, int);
	int (*create)(struct user_namespace *, struct inode___9 *, struct dentry___9 *, umode_t, bool);
	int (*link)(struct dentry___9 *, struct inode___9 *, struct dentry___9 *);
	int (*unlink)(struct inode___9 *, struct dentry___9 *);
	int (*symlink)(struct user_namespace *, struct inode___9 *, struct dentry___9 *, const char *);
	int (*mkdir)(struct user_namespace *, struct inode___9 *, struct dentry___9 *, umode_t);
	int (*rmdir)(struct inode___9 *, struct dentry___9 *);
	int (*mknod)(struct user_namespace *, struct inode___9 *, struct dentry___9 *, umode_t, dev_t);
	int (*rename)(struct user_namespace *, struct inode___9 *, struct dentry___9 *, struct inode___9 *, struct dentry___9 *, unsigned int);
	int (*setattr)(struct user_namespace *, struct dentry___9 *, struct iattr___9 *);
	int (*getattr)(struct user_namespace *, const struct path___9 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___9 *, char *, size_t);
	int (*fiemap)(struct inode___9 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___9 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___9 *, struct dentry___9 *, struct file___9 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace *, struct inode___9 *, struct dentry___9 *, umode_t);
	int (*set_acl)(struct user_namespace *, struct inode___9 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace *, struct dentry___9 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___9 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___9 {
	void (*fl_copy_lock)(struct file_lock___9 *, struct file_lock___9 *);
	void (*fl_release_private)(struct file_lock___9 *);
};

struct fasync_struct___9;

struct lock_manager_operations___9;

struct file_lock___9 {
	struct file_lock___9 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___9 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___9 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___9 *fl_ops;
	const struct lock_manager_operations___9 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___9 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___9 *);
	int (*lm_grant)(struct file_lock___9 *, int);
	bool (*lm_break)(struct file_lock___9 *);
	int (*lm_change)(struct file_lock___9 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___9 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___9 *);
};

struct fasync_struct___9 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___9 *fa_next;
	struct file___9 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___9 {
	struct inode___9 * (*alloc_inode)(struct super_block___9 *);
	void (*destroy_inode)(struct inode___9 *);
	void (*free_inode)(struct inode___9 *);
	void (*dirty_inode)(struct inode___9 *, int);
	int (*write_inode)(struct inode___9 *, struct writeback_control___6 *);
	int (*drop_inode)(struct inode___9 *);
	void (*evict_inode)(struct inode___9 *);
	void (*put_super)(struct super_block___9 *);
	int (*sync_fs)(struct super_block___9 *, int);
	int (*freeze_super)(struct super_block___9 *);
	int (*freeze_fs)(struct super_block___9 *);
	int (*thaw_super)(struct super_block___9 *);
	int (*unfreeze_fs)(struct super_block___9 *);
	int (*statfs)(struct dentry___9 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___9 *, int *, char *);
	void (*umount_begin)(struct super_block___9 *);
	int (*show_options)(struct seq_file___8 *, struct dentry___9 *);
	int (*show_devname)(struct seq_file___8 *, struct dentry___9 *);
	int (*show_path)(struct seq_file___8 *, struct dentry___9 *);
	int (*show_stats)(struct seq_file___8 *, struct dentry___9 *);
	ssize_t (*quota_read)(struct super_block___9 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___9 *, int, const char *, size_t, loff_t);
	struct dquot___9 ** (*get_dquots)(struct inode___9 *);
	long int (*nr_cached_objects)(struct super_block___9 *, struct shrink_control___6 *);
	long int (*free_cached_objects)(struct super_block___9 *, struct shrink_control___6 *);
	struct file___9 * (*real_loop)(struct file___9 *);
};

struct wakeup_source___8;

struct dev_pm_info___8 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___8 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___9 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___8;

struct bus_type___8;

struct device_driver___8;

struct dev_pm_domain___8;

struct device_node___5;

struct fwnode_handle___8;

struct class___8;

struct attribute_group___9;

struct device___9 {
	struct kobject___9 kobj;
	struct device___9 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___8 *type;
	struct bus_type___8 *bus;
	struct device_driver___8 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___8 power;
	struct dev_pm_domain___8 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___5 *of_node;
	struct fwnode_handle___8 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___8 *class;
	const struct attribute_group___9 **groups;
	void (*release)(struct device___9 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct block_device___7 {
	sector_t bd_start_sect;
	struct disk_stats *bd_stats;
	long unsigned int bd_stamp;
	bool bd_read_only;
	dev_t bd_dev;
	int bd_openers;
	struct inode___9 *bd_inode;
	struct super_block___9 *bd_super;
	void *bd_claiming;
	struct device___9 bd_device;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct kobject___9 *bd_holder_dir;
	u8 bd_partno;
	spinlock_t bd_size_lock;
	struct gendisk___7 *bd_disk;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	struct super_block___9 *bd_fsfreeze_sb;
	struct partition_meta_info *bd_meta_info;
};

typedef void (*poll_queue_proc___6)(struct file___9 *, wait_queue_head_t *, struct poll_table_struct___6 *);

struct poll_table_struct___6 {
	poll_queue_proc___6 _qproc;
	__poll_t _key;
};

struct seq_file___8 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___8 *op;
	int poll_event;
	const struct file___9 *file;
	void *private;
};

typedef void bio_end_io_t___7(struct bio___7 *);

struct bio_vec___8 {
	struct page___9 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___7;

struct bio___7 {
	struct bio___7 *bi_next;
	struct block_device___7 *bi_bdev;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	atomic_t __bi_remaining;
	struct bvec_iter bi_iter;
	bio_end_io_t___7 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___6 *bi_blkg;
	struct bio_issue bi_issue;
	u64 bi_iocost_cost;
	struct bio_crypt_ctx *bi_crypt_context;
	union {
		struct bio_integrity_payload___7 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___8 *bi_io_vec;
	struct bio_set___7 *bi_pool;
	struct bio_vec___8 bi_inline_vecs[0];
};

struct dev_pagemap_ops___9 {
	void (*page_free)(struct page___9 *);
	void (*kill)(struct dev_pagemap___9 *);
	void (*cleanup)(struct dev_pagemap___9 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___9 *);
};

struct fwnode_operations___8;

struct fwnode_handle___8 {
	struct fwnode_handle___8 *secondary;
	const struct fwnode_operations___8 *ops;
	struct device___9 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct fwnode_reference_args___8;

struct fwnode_endpoint___8;

struct fwnode_operations___8 {
	struct fwnode_handle___8 * (*get)(struct fwnode_handle___8 *);
	void (*put)(struct fwnode_handle___8 *);
	bool (*device_is_available)(const struct fwnode_handle___8 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___8 *, const struct device___9 *);
	bool (*property_present)(const struct fwnode_handle___8 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___8 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___8 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___8 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___8 *);
	struct fwnode_handle___8 * (*get_parent)(const struct fwnode_handle___8 *);
	struct fwnode_handle___8 * (*get_next_child_node)(const struct fwnode_handle___8 *, struct fwnode_handle___8 *);
	struct fwnode_handle___8 * (*get_named_child_node)(const struct fwnode_handle___8 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___8 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___8 *);
	struct fwnode_handle___8 * (*graph_get_next_endpoint)(const struct fwnode_handle___8 *, struct fwnode_handle___8 *);
	struct fwnode_handle___8 * (*graph_get_remote_endpoint)(const struct fwnode_handle___8 *);
	struct fwnode_handle___8 * (*graph_get_port_parent)(struct fwnode_handle___8 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___8 *, struct fwnode_endpoint___8 *);
	int (*add_links)(struct fwnode_handle___8 *);
};

struct fwnode_endpoint___8 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___8 *local_fwnode;
};

struct fwnode_reference_args___8 {
	struct fwnode_handle___8 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct cgroup_namespace___7 {
	struct ns_common ns;
	struct user_namespace *user_ns;
	struct ucounts *ucounts;
	struct css_set___7 *root_cset;
};

struct kernfs_root___8;

struct kernfs_elem_dir___8 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___8 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___8;

struct kernfs_root___8 {
	struct kernfs_node___8 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___8 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___8 {
	struct kernfs_node___8 *target_kn;
};

struct kernfs_ops___8;

struct kernfs_elem_attr___8 {
	const struct kernfs_ops___8 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___8 *notify_next;
};

struct kernfs_node___8 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___8 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___8 dir;
		struct kernfs_elem_symlink___8 symlink;
		struct kernfs_elem_attr___8 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___8;

struct kernfs_ops___8 {
	int (*open)(struct kernfs_open_file___8 *);
	void (*release)(struct kernfs_open_file___8 *);
	int (*seq_show)(struct seq_file___8 *, void *);
	void * (*seq_start)(struct seq_file___8 *, loff_t *);
	void * (*seq_next)(struct seq_file___8 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___8 *, void *);
	ssize_t (*read)(struct kernfs_open_file___8 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___8 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___8 *, struct poll_table_struct___6 *);
	int (*mmap)(struct kernfs_open_file___8 *, struct vm_area_struct___10 *);
};

struct kernfs_syscall_ops___8 {
	int (*show_options)(struct seq_file___8 *, struct kernfs_root___8 *);
	int (*mkdir)(struct kernfs_node___8 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___8 *);
	int (*rename)(struct kernfs_node___8 *, struct kernfs_node___8 *, const char *);
	int (*show_path)(struct seq_file___8 *, struct kernfs_node___8 *, struct kernfs_root___8 *);
};

struct kernfs_open_file___8 {
	struct kernfs_node___8 *kn;
	struct file___9 *file;
	struct seq_file___8 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped;
	bool released;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___9 *vm_ops;
};

struct bin_attribute___9;

struct attribute_group___9 {
	const char *name;
	umode_t (*is_visible)(struct kobject___9 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___9 *, struct bin_attribute___9 *, int);
	struct attribute **attrs;
	struct bin_attribute___9 **bin_attrs;
};

struct bin_attribute___9 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___10 * (*f_mapping)();
	ssize_t (*read)(struct file___9 *, struct kobject___9 *, struct bin_attribute___9 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___9 *, struct kobject___9 *, struct bin_attribute___9 *, char *, loff_t, size_t);
	int (*mmap)(struct file___9 *, struct kobject___9 *, struct bin_attribute___9 *, struct vm_area_struct___10 *);
};

struct sysfs_ops___8 {
	ssize_t (*show)(struct kobject___9 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___9 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___8;

struct kset___8 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___9 kobj;
	const struct kset_uevent_ops___8 *uevent_ops;
};

struct kobj_type___8 {
	void (*release)(struct kobject___9 *);
	const struct sysfs_ops___8 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___9 **default_groups;
	const struct kobj_ns_type_operations * (*child_ns_type)(struct kobject___9 *);
	const void * (*namespace)(struct kobject___9 *);
	void (*get_ownership)(struct kobject___9 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___8 {
	int (* const filter)(struct kset___8 *, struct kobject___9 *);
	const char * (* const name)(struct kset___8 *, struct kobject___9 *);
	int (* const uevent)(struct kset___8 *, struct kobject___9 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___8 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___8 *);
	int (*get)(char *, const struct kernel_param___8 *);
	void (*free)(void *);
};

struct kparam_array___8;

struct kernel_param___8 {
	const char *name;
	struct module___9 *mod;
	const struct kernel_param_ops___8 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___8 *arr;
	};
};

struct kparam_array___8 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___8 *ops;
	void *elem;
};

struct module_attribute___8 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___8 *, struct module_kobject___8 *, char *);
	ssize_t (*store)(struct module_attribute___8 *, struct module_kobject___8 *, const char *, size_t);
	void (*setup)(struct module___9 *, const char *);
	int (*test)(struct module___9 *);
	void (*free)(struct module___9 *);
};

struct dev_pm_ops___8 {
	int (*prepare)(struct device___9 *);
	void (*complete)(struct device___9 *);
	int (*suspend)(struct device___9 *);
	int (*resume)(struct device___9 *);
	int (*freeze)(struct device___9 *);
	int (*thaw)(struct device___9 *);
	int (*poweroff)(struct device___9 *);
	int (*restore)(struct device___9 *);
	int (*suspend_late)(struct device___9 *);
	int (*resume_early)(struct device___9 *);
	int (*freeze_late)(struct device___9 *);
	int (*thaw_early)(struct device___9 *);
	int (*poweroff_late)(struct device___9 *);
	int (*restore_early)(struct device___9 *);
	int (*suspend_noirq)(struct device___9 *);
	int (*resume_noirq)(struct device___9 *);
	int (*freeze_noirq)(struct device___9 *);
	int (*thaw_noirq)(struct device___9 *);
	int (*poweroff_noirq)(struct device___9 *);
	int (*restore_noirq)(struct device___9 *);
	int (*runtime_suspend)(struct device___9 *);
	int (*runtime_resume)(struct device___9 *);
	int (*runtime_idle)(struct device___9 *);
};

struct wakeup_source___8 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___9 *dev;
	bool active;
	bool autosleep_enabled;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___8 {
	struct dev_pm_ops___8 ops;
	int (*start)(struct device___9 *);
	void (*detach)(struct device___9 *, bool);
	int (*activate)(struct device___9 *);
	void (*sync)(struct device___9 *);
	void (*dismiss)(struct device___9 *);
};

struct bus_type___8 {
	const char *name;
	const char *dev_name;
	struct device___9 *dev_root;
	const struct attribute_group___9 **bus_groups;
	const struct attribute_group___9 **dev_groups;
	const struct attribute_group___9 **drv_groups;
	int (*match)(struct device___9 *, struct device_driver___8 *);
	int (*uevent)(struct device___9 *, struct kobj_uevent_env *);
	int (*probe)(struct device___9 *);
	void (*sync_state)(struct device___9 *);
	void (*remove)(struct device___9 *);
	void (*shutdown)(struct device___9 *);
	int (*online)(struct device___9 *);
	int (*offline)(struct device___9 *);
	int (*suspend)(struct device___9 *, pm_message_t);
	int (*resume)(struct device___9 *);
	int (*num_vf)(struct device___9 *);
	int (*dma_configure)(struct device___9 *);
	const struct dev_pm_ops___8 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___8 {
	const char *name;
	struct bus_type___8 *bus;
	struct module___9 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___9 *);
	void (*sync_state)(struct device___9 *);
	int (*remove)(struct device___9 *);
	void (*shutdown)(struct device___9 *);
	int (*suspend)(struct device___9 *, pm_message_t);
	int (*resume)(struct device___9 *);
	const struct attribute_group___9 **groups;
	const struct attribute_group___9 **dev_groups;
	const struct dev_pm_ops___8 *pm;
	void (*coredump)(struct device___9 *);
	struct driver_private *p;
};

struct device_type___8 {
	const char *name;
	const struct attribute_group___9 **groups;
	int (*uevent)(struct device___9 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___9 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___9 *);
	const struct dev_pm_ops___8 *pm;
};

struct class___8 {
	const char *name;
	struct module___9 *owner;
	const struct attribute_group___9 **class_groups;
	const struct attribute_group___9 **dev_groups;
	struct kobject___9 *dev_kobj;
	int (*dev_uevent)(struct device___9 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___9 *, umode_t *);
	void (*class_release)(struct class___8 *);
	void (*dev_release)(struct device___9 *);
	int (*shutdown_pre)(struct device___9 *);
	const struct kobj_ns_type_operations *ns_type;
	const void * (*namespace)(struct device___9 *);
	void (*get_ownership)(struct device___9 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___8 *pm;
	struct subsys_private *p;
};

struct device_node___5 {
	const char *name;
	phandle phandle;
	const char *full_name;
	struct fwnode_handle___8 fwnode;
	struct property *properties;
	struct property *deadprops;
	struct device_node___5 *parent;
	struct device_node___5 *child;
	struct device_node___5 *sibling;
	long unsigned int _flags;
	void *data;
};

struct tlb_state___3 {
	struct mm_struct___11 *loaded_mm;
	union {
		struct mm_struct___11 *last_user_mm;
		long unsigned int last_user_mm_spec;
	};
	u16 loaded_mm_asid;
	u16 next_asid;
	bool invalidate_other;
	short unsigned int user_pcid_flush_mask;
	long unsigned int cr4;
	struct tlb_context ctxs[6];
};

struct cftype___7;

struct cgroup_subsys___7 {
	struct cgroup_subsys_state___7 * (*css_alloc)(struct cgroup_subsys_state___7 *);
	int (*css_online)(struct cgroup_subsys_state___7 *);
	void (*css_offline)(struct cgroup_subsys_state___7 *);
	void (*css_released)(struct cgroup_subsys_state___7 *);
	void (*css_free)(struct cgroup_subsys_state___7 *);
	void (*css_reset)(struct cgroup_subsys_state___7 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___7 *, int);
	int (*css_extra_stat_show)(struct seq_file___8 *, struct cgroup_subsys_state___7 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___11 *, struct css_set___7 *);
	void (*cancel_fork)(struct task_struct___11 *, struct css_set___7 *);
	void (*fork)(struct task_struct___11 *);
	void (*exit)(struct task_struct___11 *);
	void (*release)(struct task_struct___11 *);
	void (*bind)(struct cgroup_subsys_state___7 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___7 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___7 *dfl_cftypes;
	struct cftype___7 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___7 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___7 *updated_children;
	struct cgroup___7 *updated_next;
};

struct cgroup_root___7 {
	struct kernfs_root___8 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___7 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___7 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___7 *ss;
	struct list_head node;
	struct kernfs_ops___8 *kf_ops;
	int (*open)(struct kernfs_open_file___8 *);
	void (*release)(struct kernfs_open_file___8 *);
	u64 (*read_u64)(struct cgroup_subsys_state___7 *, struct cftype___7 *);
	s64 (*read_s64)(struct cgroup_subsys_state___7 *, struct cftype___7 *);
	int (*seq_show)(struct seq_file___8 *, void *);
	void * (*seq_start)(struct seq_file___8 *, loff_t *);
	void * (*seq_next)(struct seq_file___8 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___8 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___7 *, struct cftype___7 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___7 *, struct cftype___7 *, s64);
	ssize_t (*write)(struct kernfs_open_file___8 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___8 *, struct poll_table_struct___6 *);
};

struct block_device_operations___7;

struct gendisk___7 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	short unsigned int events;
	short unsigned int event_flags;
	struct xarray part_tbl;
	struct block_device___7 *part0;
	const struct block_device_operations___7 *fops;
	struct request_queue___7 *queue;
	void *private_data;
	int flags;
	long unsigned int state;
	struct mutex open_mutex;
	unsigned int open_partitions;
	struct backing_dev_info___6 *bdi;
	struct kobject___9 *slave_dir;
	struct list_head slave_bdevs;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___9 integrity_kobj;
	struct cdrom_device_info *cdi;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	u64 diskseq;
};

struct bio_integrity_payload___7 {
	struct bio___7 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___8 *bip_vec;
	struct bio_vec___8 bip_inline_vecs[0];
};

struct blkcg___6;

struct blkg_policy_data___6;

struct blkcg_gq___6 {
	struct request_queue___7 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___6 *blkcg;
	struct blkcg_gq___6 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_iostat_set *iostat_cpu;
	struct blkg_iostat_set iostat;
	struct blkg_policy_data___6 *pd[6];
	spinlock_t async_bio_lock;
	struct bio_list___7 async_bios;
	struct work_struct async_bio_work;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
	struct callback_head callback_head;
};

typedef void integrity_prepare_fn___7(struct request___7 *);

typedef void integrity_complete_fn___7(struct request___7 *, unsigned int);

struct blk_integrity_profile___7 {
	integrity_processing_fn *generate_fn;
	integrity_processing_fn *verify_fn;
	integrity_prepare_fn___7 *prepare_fn;
	integrity_complete_fn___7 *complete_fn;
	const char *name;
};

struct block_device_operations___7 {
	blk_qc_t (*submit_bio)(struct bio___7 *);
	int (*open)(struct block_device___7 *, fmode_t);
	void (*release)(struct gendisk___7 *, fmode_t);
	int (*rw_page)(struct block_device___7 *, sector_t, struct page___9 *, unsigned int);
	int (*ioctl)(struct block_device___7 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___7 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___7 *, unsigned int);
	void (*unlock_native_capacity)(struct gendisk___7 *);
	int (*getgeo)(struct block_device___7 *, struct hd_geometry *);
	int (*set_read_only)(struct block_device___7 *, bool);
	void (*swap_slot_free_notify)(struct block_device___7 *, long unsigned int);
	int (*report_zones)(struct gendisk___7 *, sector_t, unsigned int, report_zones_cb, void *);
	char * (*devnode)(struct gendisk___7 *, umode_t *);
	struct module___9 *owner;
	const struct pr_ops *pr_ops;
	int (*alternative_gpt_sector)(struct gendisk___7 *, sector_t *);
};

typedef void rq_end_io_fn___7(struct request___7 *, blk_status_t);

struct request___7 {
	struct request_queue___7 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int tag;
	int internal_tag;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___7 *bio;
	struct bio___7 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct llist_node ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___8 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___7 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___7 *saved_end_io;
		} flush;
	};
	struct gendisk___7 *rq_disk;
	struct block_device___7 *part;
	u64 alloc_time_ns;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int stats_sectors;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	struct bio_crypt_ctx *crypt_ctx;
	struct blk_ksm_keyslot *crypt_keyslot;
	short unsigned int write_hint;
	short unsigned int ioprio;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___7 *end_io;
	void *end_io_data;
};

struct elevator_type___7;

struct elevator_mq_ops___7 {
	int (*init_sched)(struct request_queue___7 *, struct elevator_type___7 *);
	void (*exit_sched)(struct elevator_queue___7 *);
	int (*init_hctx)(struct blk_mq_hw_ctx *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx *, unsigned int);
	void (*depth_updated)(struct blk_mq_hw_ctx *);
	bool (*allow_merge)(struct request_queue___7 *, struct request___7 *, struct bio___7 *);
	bool (*bio_merge)(struct request_queue___7 *, struct bio___7 *, unsigned int);
	int (*request_merge)(struct request_queue___7 *, struct request___7 **, struct bio___7 *);
	void (*request_merged)(struct request_queue___7 *, struct request___7 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___7 *, struct request___7 *, struct request___7 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___7 *);
	void (*finish_request)(struct request___7 *);
	void (*insert_requests)(struct blk_mq_hw_ctx *, struct list_head *, bool);
	struct request___7 * (*dispatch_request)(struct blk_mq_hw_ctx *);
	bool (*has_work)(struct blk_mq_hw_ctx *);
	void (*completed_request)(struct request___7 *, u64);
	void (*requeue_request)(struct request___7 *);
	struct request___7 * (*former_request)(struct request_queue___7 *, struct request___7 *);
	struct request___7 * (*next_request)(struct request_queue___7 *, struct request___7 *);
	void (*init_icq)(struct io_cq___7 *);
	void (*exit_icq)(struct io_cq___7 *);
};

struct elv_fs_entry___7;

struct elevator_type___7 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___7 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___7 *elevator_attrs;
	const char *elevator_name;
	const char *elevator_alias;
	const unsigned int elevator_features;
	struct module___9 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
};

struct elevator_queue___7 {
	struct elevator_type___7 *type;
	void *elevator_data;
	struct kobject___9 kobj;
	struct mutex sysfs_lock;
	unsigned int registered;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hlist_head hash[64];
};

struct elv_fs_entry___7 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___7 *, char *);
	ssize_t (*store)(struct elevator_queue___7 *, const char *, size_t);
};

struct blkcg_policy_data___6;

struct blkcg___6 {
	struct cgroup_subsys_state___7 css;
	spinlock_t lock;
	refcount_t online_pin;
	struct xarray blkg_tree;
	struct blkcg_gq___6 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___6 *cpd[6];
	struct list_head all_blkcgs_node;
	char fc_app_id[129];
	struct list_head cgwb_list;
};

struct blkcg_policy_data___6 {
	struct blkcg___6 *blkcg;
	int plid;
};

struct blkg_policy_data___6 {
	struct blkcg_gq___6 *blkg;
	int plid;
};

struct mem_cgroup_reclaim_iter___6 {
	struct mem_cgroup___6 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___6 {
	struct lruvec___6 lruvec;
	struct lruvec_stats_percpu *lruvec_stats_percpu;
	struct lruvec_stats lruvec_stats;
	long unsigned int lru_zone_size[25];
	struct mem_cgroup_reclaim_iter___6 iter;
	struct shrinker_info *shrinker_info;
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	struct mem_cgroup___6 *memcg;
};

struct obj_cgroup___6 {
	struct percpu_ref refcnt;
	struct mem_cgroup___6 *memcg;
	atomic_t nr_charged_bytes;
	union {
		struct list_head list;
		struct callback_head rcu;
	};
};

struct mmu_table_batch {
	struct callback_head rcu;
	unsigned int nr;
	void *tables[0];
};

struct xen_memory_exchange {
	struct xen_memory_reservation in;
	struct xen_memory_reservation out;
	xen_ulong_t nr_exchanged;
};

struct xen_machphys_mapping {
	xen_ulong_t v_start;
	xen_ulong_t v_end;
	xen_ulong_t max_mfn;
};

enum pt_level {
	PT_PGD = 0,
	PT_P4D = 1,
	PT_PUD = 2,
	PT_PMD = 3,
	PT_PTE = 4,
};

struct remap_data {
	xen_pfn_t *pfn;
	bool contiguous;
	bool no_translate;
	pgprot_t prot;
	struct mmu_update *mmu_update;
};

enum xen_mc_flush_reason {
	XEN_MC_FL_NONE = 0,
	XEN_MC_FL_BATCH = 1,
	XEN_MC_FL_ARGS = 2,
	XEN_MC_FL_CALLBACK = 3,
};

enum xen_mc_extend_args {
	XEN_MC_XE_OK = 0,
	XEN_MC_XE_BAD_OP = 1,
	XEN_MC_XE_NO_SPACE = 2,
};

typedef void (*xen_mc_callback_fn_t)(void *);

struct callback {
	void (*fn)(void *);
	void *data;
};

struct mc_buffer {
	unsigned int mcidx;
	unsigned int argidx;
	unsigned int cbidx;
	struct multicall_entry entries[32];
	unsigned char args[512];
	struct callback callbacks[32];
};

struct hvm_start_info {
	uint32_t magic;
	uint32_t version;
	uint32_t flags;
	uint32_t nr_modules;
	uint64_t modlist_paddr;
	uint64_t cmdline_paddr;
	uint64_t rsdp_paddr;
	uint64_t memmap_paddr;
	uint32_t memmap_entries;
	uint32_t reserved;
};

struct dentry___10;

struct super_block___10;

struct module___10;

struct file_system_type___10 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___10 * (*mount)(struct file_system_type___10 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___10 *);
	struct module___10 *owner;
	struct file_system_type___10 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___10;

struct kiocb___10;

struct poll_table_struct___7;

struct vm_area_struct___11;

struct inode___10;

struct file_lock___10;

struct page___10;

struct seq_file___9;

struct file_operations___10 {
	struct module___10 *owner;
	loff_t (*llseek)(struct file___10 *, loff_t, int);
	ssize_t (*read)(struct file___10 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___10 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___10 *, struct iov_iter___8 *);
	ssize_t (*write_iter)(struct kiocb___10 *, struct iov_iter___8 *);
	int (*iopoll)(struct kiocb___10 *, bool);
	int (*iterate)(struct file___10 *, struct dir_context *);
	int (*iterate_shared)(struct file___10 *, struct dir_context *);
	__poll_t (*poll)(struct file___10 *, struct poll_table_struct___7 *);
	long int (*unlocked_ioctl)(struct file___10 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___10 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___10 *, struct vm_area_struct___11 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___10 *, struct file___10 *);
	int (*flush)(struct file___10 *, fl_owner_t);
	int (*release)(struct inode___10 *, struct file___10 *);
	int (*fsync)(struct file___10 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___10 *, int);
	int (*lock)(struct file___10 *, int, struct file_lock___10 *);
	ssize_t (*sendpage)(struct file___10 *, struct page___10 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___10 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___10 *, long unsigned int);
	int (*flock)(struct file___10 *, int, struct file_lock___10 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___10 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___10 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___10 *, long int, struct file_lock___10 **, void **);
	long int (*fallocate)(struct file___10 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___9 *, struct file___10 *);
	ssize_t (*copy_file_range)(struct file___10 *, loff_t, struct file___10 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___10 *, loff_t, struct file___10 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___10 *, loff_t, loff_t, int);
};

struct static_call_mod___7 {
	struct static_call_mod___7 *next;
	struct module___10 *mod;
	struct static_call_site *sites;
};

struct static_call_key___7 {
	void *func;
	union {
		long unsigned int type;
		struct static_call_mod___7 *mods;
		struct static_call_site *sites;
	};
};

struct vmacache___10 {
	u64 seqnum;
	struct vm_area_struct___11 *vmas[4];
};

struct page_frag___10 {
	struct page___10 *page;
	__u32 offset;
	__u32 size;
};

struct perf_event___6;

struct thread_struct___7 {
	struct desc_struct tls_array[3];
	long unsigned int sp;
	short unsigned int es;
	short unsigned int ds;
	short unsigned int fsindex;
	short unsigned int gsindex;
	long unsigned int fsbase;
	long unsigned int gsbase;
	struct perf_event___6 *ptrace_bps[4];
	long unsigned int virtual_dr6;
	long unsigned int ptrace_dr7;
	long unsigned int cr2;
	long unsigned int trap_nr;
	long unsigned int error_code;
	struct io_bitmap *io_bitmap;
	long unsigned int iopl_emul;
	unsigned int iopl_warn: 1;
	unsigned int sig_on_uaccess_err: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u32 pkru;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct fpu fpu;
};

struct mm_struct___12;

struct pid___9;

struct nsproxy___10;

struct signal_struct___11;

struct css_set___8;

struct perf_event_context___6;

struct task_struct___12 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___12 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___12 *mm;
	struct mm_struct___12 *active_mm;
	struct vmacache___10 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int restore_sigmask: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___12 *real_parent;
	struct task_struct___12 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___12 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___9 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	struct posix_cputimers_work posix_cputimers_work;
	const struct cred *ptracer_cred;
	const struct cred *real_cred;
	const struct cred *cred;
	struct key *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___10 *nsproxy;
	struct signal_struct___11 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___12 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context___8 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___8 *cgroups;
	struct list_head cg_list;
	u32 closid;
	u32 rmid;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___6 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	struct pipe_inode_info *splice_pipe;
	struct page_frag___10 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup *active_memcg;
	struct request_queue *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___12 *oom_reaper_list;
	struct vm_struct___3 *stack_vm_area;
	refcount_t stack_refcount;
	int patch_state;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	void *mce_vaddr;
	__u64 mce_kflags;
	u64 mce_addr;
	__u64 mce_ripv: 1;
	__u64 mce_whole_page: 1;
	__u64 __mce_reserved: 62;
	long: 2;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct callback_head mce_kill_me;
	int mce_count;
	struct llist_head kretprobe_instances;
	struct callback_head l1d_flush_kill;
	long: 64;
	struct thread_struct___7 thread;
};

typedef struct page___10 *pgtable_t___10;

struct dev_pagemap___10;

struct page___10 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___8 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___10 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___10 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___12 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___10 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct pv_cpu_ops___7 {
	void (*io_delay)();
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	void (*write_cr4)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___7 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(long unsigned int);
	void (*invalidate_io_bitmap)();
	void (*update_io_bitmap)();
	void (*wbinvd)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int);
	void (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_msr_safe)(unsigned int, int *);
	int (*write_msr_safe)(unsigned int, unsigned int, unsigned int);
	u64 (*read_pmc)(int);
	void (*start_context_switch)(struct task_struct___12 *);
	void (*end_context_switch)(struct task_struct___12 *);
};

struct pv_mmu_ops___7 {
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_one_user)(long unsigned int);
	void (*flush_tlb_multi)(const struct cpumask *, const struct flush_tlb_info___3 *);
	void (*tlb_remove_table)(struct mmu_gather *, void *);
	void (*exit_mmap)(struct mm_struct___12 *);
	struct paravirt_callee_save read_cr2;
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___12 *, struct mm_struct___12 *);
	void (*dup_mmap)(struct mm_struct___12 *, struct mm_struct___12 *);
	int (*pgd_alloc)(struct mm_struct___12 *);
	void (*pgd_free)(struct mm_struct___12 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___12 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___12 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___12 *, long unsigned int);
	void (*alloc_p4d)(struct mm_struct___12 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*release_p4d)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	pte_t (*ptep_modify_prot_start)(struct vm_area_struct___11 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct vm_area_struct___11 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_p4d)(p4d_t *, p4d_t);
	struct paravirt_callee_save p4d_val;
	struct paravirt_callee_save make_p4d;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

struct core_state___10;

struct mm_struct___12 {
	struct {
		struct vm_area_struct___11 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___10 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int mmap_compat_base;
		long unsigned int mmap_compat_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[48];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___10 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___12 *owner;
		struct user_namespace *user_ns;
		struct file___10 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		bool tlb_flush_batched;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct vm_operations_struct___10;

struct vm_area_struct___11 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___11 *vm_next;
	struct vm_area_struct___11 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___12 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___10 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___10 *vm_file;
	struct file___10 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct paravirt_patch_template___7 {
	struct pv_cpu_ops___7 cpu;
	struct pv_irq_ops irq;
	struct pv_mmu_ops___7 mmu;
	struct pv_lock_ops lock;
};

struct tracepoint___7 {
	const char *name;
	struct static_key key;
	struct static_call_key___7 *static_call_key;
	void *static_call_tramp;
	void *iterator;
	int (*regfunc)();
	void (*unregfunc)();
	struct tracepoint_func *funcs;
};

struct bpf_raw_event_map___7 {
	struct tracepoint___7 *tp;
	void *bpf_func;
	u32 num_args;
	u32 writable_size;
	long: 64;
};

struct seq_operations___9 {
	void * (*start)(struct seq_file___9 *, loff_t *);
	void (*stop)(struct seq_file___9 *, void *);
	void * (*next)(struct seq_file___9 *, void *, loff_t *);
	int (*show)(struct seq_file___9 *, void *);
};

struct hw_perf_event___6 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___12 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	union {
		struct {
			u64 last_period;
			local64_t period_left;
		};
		struct {
			u64 saved_metric;
			u64 saved_slots;
		};
	};
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___6)(struct perf_event___6 *, struct perf_sample_data *, struct pt_regs *);

struct pmu___6;

struct fasync_struct___10;

struct pid_namespace___9;

struct trace_event_call___6;

struct perf_cgroup___6;

struct perf_event___6 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___6 *group_leader;
	struct pmu___6 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___6 hw;
	struct perf_event_context___6 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___6 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___12 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct perf_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___10 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	long unsigned int pending_addr;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	struct perf_addr_filter_range *addr_filter_ranges;
	long unsigned int addr_filters_gen;
	struct perf_event___6 *aux_event;
	void (*destroy)(struct perf_event___6 *);
	struct callback_head callback_head;
	struct pid_namespace___9 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___6 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___6 orig_overflow_handler;
	struct bpf_prog *prog;
	u64 bpf_cookie;
	struct trace_event_call___6 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___6 *cgrp;
	void *security;
	struct list_head sb_list;
};

struct upid___9 {
	int nr;
	struct pid_namespace___9 *ns;
};

struct pid_namespace___9 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___12 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___9 *parent;
	struct fs_pin *bacct;
	struct user_namespace *user_ns;
	struct ucounts *ucounts;
	int reboot;
	struct ns_common ns;
};

struct pid___9 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___9 numbers[1];
};

struct signal_struct___11 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___12 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___12 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper;
	unsigned int has_child_subreaper;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___9 *pids[4];
	struct pid___9 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___12 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct cgroup_namespace___8;

struct nsproxy___10 {
	atomic_t count;
	struct uts_namespace *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___9 *pid_ns_for_children;
	struct net *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___8 *cgroup_ns;
};

struct cgroup_subsys_state___8;

struct cgroup___8;

struct css_set___8 {
	struct cgroup_subsys_state___8 *subsys[14];
	refcount_t refcount;
	struct css_set___8 *dom_cset;
	struct cgroup___8 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___8 *mg_src_cgrp;
	struct cgroup___8 *mg_dst_cgrp;
	struct css_set___8 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___6 {
	struct pmu___6 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	int rotate_necessary;
	refcount_t refcount;
	struct task_struct___12 *task;
	u64 time;
	u64 timestamp;
	u64 timeoffset;
	struct perf_event_context___6 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

struct address_space_operations___10;

struct address_space___8 {
	struct inode___10 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___10 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct dev_pagemap_ops___10;

struct dev_pagemap___10 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___10 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vfsmount___10;

struct path___10 {
	struct vfsmount___10 *mnt;
	struct dentry___10 *dentry;
};

struct fown_struct___9 {
	rwlock_t lock;
	struct pid___9 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___10 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___10 f_path;
	struct inode___10 *f_inode;
	const struct file_operations___10 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___9 f_owner;
	const struct cred *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___8 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___10;

struct vm_operations_struct___10 {
	void (*open)(struct vm_area_struct___11 *);
	void (*close)(struct vm_area_struct___11 *);
	int (*may_split)(struct vm_area_struct___11 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___11 *);
	int (*mprotect)(struct vm_area_struct___11 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___10 *);
	vm_fault_t (*huge_fault)(struct vm_fault___10 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___10 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___11 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___10 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___10 *);
	int (*access)(struct vm_area_struct___11 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___11 *);
	int (*set_policy)(struct vm_area_struct___11 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___11 *, long unsigned int);
	struct page___10 * (*find_special_page)(struct vm_area_struct___11 *, long unsigned int);
};

struct core_thread___10 {
	struct task_struct___12 *task;
	struct core_thread___10 *next;
};

struct core_state___10 {
	atomic_t nr_threads;
	struct core_thread___10 dumper;
	struct completion startup;
};

struct vm_fault___10 {
	const struct {
		struct vm_area_struct___11 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___10 *cow_page;
	struct page___10 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___10 prealloc_pte;
};

struct dev_pagemap_ops___10 {
	void (*page_free)(struct page___10 *);
	void (*kill)(struct dev_pagemap___10 *);
	void (*cleanup)(struct dev_pagemap___10 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___10 *);
};

struct dentry_operations___10;

struct dentry___10 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___10 *d_parent;
	struct qstr d_name;
	struct inode___10 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___10 *d_op;
	struct super_block___10 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___10;

struct inode___10 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___10 *i_op;
	struct super_block___10 *i_sb;
	struct address_space___8 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___10 *i_fop;
		void (*free_inode)(struct inode___10 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___8 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct cdev___5 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___10 {
	int (*d_revalidate)(struct dentry___10 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___10 *, unsigned int);
	int (*d_hash)(const struct dentry___10 *, struct qstr *);
	int (*d_compare)(const struct dentry___10 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___10 *);
	int (*d_init)(struct dentry___10 *);
	void (*d_release)(struct dentry___10 *);
	void (*d_prune)(struct dentry___10 *);
	void (*d_iput)(struct dentry___10 *, struct inode___10 *);
	char * (*d_dname)(struct dentry___10 *, char *, int);
	struct vfsmount___10 * (*d_automount)(struct path___10 *);
	int (*d_manage)(const struct path___10 *, bool);
	struct dentry___10 * (*d_real)(struct dentry___10 *, const struct inode___10 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___10;

struct mem_dqinfo___10 {
	struct quota_format_type___10 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___10;

struct quota_info___10 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___10 *files[3];
	struct mem_dqinfo___10 info[3];
	const struct quota_format_ops___10 *ops[3];
};

struct rcuwait___10 {
	struct task_struct___12 *task;
};

struct percpu_rw_semaphore___10 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___10 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___10 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___10 rw_sem[3];
};

struct super_operations___10;

struct dquot_operations___10;

struct quotactl_ops___10;

struct super_block___10 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___10 *s_type;
	const struct super_operations___10 *s_op;
	const struct dquot_operations___10 *dq_op;
	const struct quotactl_ops___10 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___10 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device *s_bdev;
	struct backing_dev_info *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___10 s_dquot;
	struct sb_writers___10 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___10 *s_d_op;
	int cleancache_poolid;
	struct shrinker___6 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___10 {
	struct dentry___10 *mnt_root;
	struct super_block___10 *mnt_sb;
	int mnt_flags;
	struct user_namespace *mnt_userns;
};

struct cgroup_subsys___8;

struct cgroup_subsys_state___8 {
	struct cgroup___8 *cgroup;
	struct cgroup_subsys___8 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___8 *parent;
};

struct kernfs_node___9;

struct cgroup_file___8 {
	struct kernfs_node___9 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct psi_group___8 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___12 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___8;

struct cgroup_rstat_cpu___8;

struct cgroup___8 {
	struct cgroup_subsys_state___8 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___9 *kn;
	struct cgroup_file___8 procs_file;
	struct cgroup_file___8 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___8 *subsys[14];
	struct cgroup_root___8 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___8 *dom_cgrp;
	struct cgroup___8 *old_dom_cgrp;
	struct cgroup_rstat_cpu___8 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___8 psi;
	struct cgroup_bpf bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct kiocb___10 {
	struct file___10 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___10 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___5 *ki_waitq;
	};
};

struct iattr___10 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___10 *ia_file;
};

struct dquot___10 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___10 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___10 {
	int qf_fmt_id;
	const struct quota_format_ops___10 *qf_ops;
	struct module___10 *qf_owner;
	struct quota_format_type___10 *qf_next;
};

struct quota_format_ops___10 {
	int (*check_quota_file)(struct super_block___10 *, int);
	int (*read_file_info)(struct super_block___10 *, int);
	int (*write_file_info)(struct super_block___10 *, int);
	int (*free_file_info)(struct super_block___10 *, int);
	int (*read_dqblk)(struct dquot___10 *);
	int (*commit_dqblk)(struct dquot___10 *);
	int (*release_dqblk)(struct dquot___10 *);
	int (*get_next_id)(struct super_block___10 *, struct kqid *);
};

struct dquot_operations___10 {
	int (*write_dquot)(struct dquot___10 *);
	struct dquot___10 * (*alloc_dquot)(struct super_block___10 *, int);
	void (*destroy_dquot)(struct dquot___10 *);
	int (*acquire_dquot)(struct dquot___10 *);
	int (*release_dquot)(struct dquot___10 *);
	int (*mark_dirty)(struct dquot___10 *);
	int (*write_info)(struct super_block___10 *, int);
	qsize_t * (*get_reserved_space)(struct inode___10 *);
	int (*get_projid)(struct inode___10 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___10 *, qsize_t *);
	int (*get_next_id)(struct super_block___10 *, struct kqid *);
};

struct quotactl_ops___10 {
	int (*quota_on)(struct super_block___10 *, int, int, const struct path___10 *);
	int (*quota_off)(struct super_block___10 *, int);
	int (*quota_enable)(struct super_block___10 *, unsigned int);
	int (*quota_disable)(struct super_block___10 *, unsigned int);
	int (*quota_sync)(struct super_block___10 *, int);
	int (*set_info)(struct super_block___10 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___10 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___10 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___10 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___10 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___10 *, unsigned int);
};

struct kset___9;

struct kobj_type___9;

struct kobject___10 {
	const char *name;
	struct list_head entry;
	struct kobject___10 *parent;
	struct kset___9 *kset;
	struct kobj_type___9 *ktype;
	struct kernfs_node___9 *sd;
	struct kref kref;
	unsigned int state_initialized;
	unsigned int state_in_sysfs;
	unsigned int state_add_uevent_sent;
	unsigned int state_remove_uevent_sent;
	unsigned int uevent_suppress;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___9 {
	struct kobject___10 kobj;
	struct module___10 *mod;
	struct kobject___10 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___9 {
	struct module___10 *mod;
	struct latch_tree_node node;
};

struct module_layout___9 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___9 mtn;
};

struct module_attribute___9;

struct kernel_param___9;

struct module___10 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___9 mkobj;
	struct module_attribute___9 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___10 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___9 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___9 core_layout;
	struct module_layout___9 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map___7 *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___6 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	int num_static_call_sites;
	struct static_call_site *static_call_sites;
	bool klp;
	bool klp_alive;
	struct klp_modinfo *klp_info;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct address_space_operations___10 {
	int (*writepage)(struct page___10 *, struct writeback_control *);
	int (*readpage)(struct file___10 *, struct page___10 *);
	int (*writepages)(struct address_space___8 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___10 *);
	int (*readpages)(struct file___10 *, struct address_space___8 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control *);
	int (*write_begin)(struct file___10 *, struct address_space___8 *, loff_t, unsigned int, unsigned int, struct page___10 **, void **);
	int (*write_end)(struct file___10 *, struct address_space___8 *, loff_t, unsigned int, unsigned int, struct page___10 *, void *);
	sector_t (*bmap)(struct address_space___8 *, sector_t);
	void (*invalidatepage)(struct page___10 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___10 *, gfp_t);
	void (*freepage)(struct page___10 *);
	ssize_t (*direct_IO)(struct kiocb___10 *, struct iov_iter___8 *);
	int (*migratepage)(struct address_space___8 *, struct page___10 *, struct page___10 *, enum migrate_mode);
	bool (*isolate_page)(struct page___10 *, isolate_mode_t);
	void (*putback_page)(struct page___10 *);
	int (*launder_page)(struct page___10 *);
	int (*is_partially_uptodate)(struct page___10 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___10 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___8 *, struct page___10 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___10 *, sector_t *);
	void (*swap_deactivate)(struct file___10 *);
};

struct inode_operations___10 {
	struct dentry___10 * (*lookup)(struct inode___10 *, struct dentry___10 *, unsigned int);
	const char * (*get_link)(struct dentry___10 *, struct inode___10 *, struct delayed_call *);
	int (*permission)(struct user_namespace *, struct inode___10 *, int);
	struct posix_acl * (*get_acl)(struct inode___10 *, int, bool);
	int (*readlink)(struct dentry___10 *, char *, int);
	int (*create)(struct user_namespace *, struct inode___10 *, struct dentry___10 *, umode_t, bool);
	int (*link)(struct dentry___10 *, struct inode___10 *, struct dentry___10 *);
	int (*unlink)(struct inode___10 *, struct dentry___10 *);
	int (*symlink)(struct user_namespace *, struct inode___10 *, struct dentry___10 *, const char *);
	int (*mkdir)(struct user_namespace *, struct inode___10 *, struct dentry___10 *, umode_t);
	int (*rmdir)(struct inode___10 *, struct dentry___10 *);
	int (*mknod)(struct user_namespace *, struct inode___10 *, struct dentry___10 *, umode_t, dev_t);
	int (*rename)(struct user_namespace *, struct inode___10 *, struct dentry___10 *, struct inode___10 *, struct dentry___10 *, unsigned int);
	int (*setattr)(struct user_namespace *, struct dentry___10 *, struct iattr___10 *);
	int (*getattr)(struct user_namespace *, const struct path___10 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___10 *, char *, size_t);
	int (*fiemap)(struct inode___10 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___10 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___10 *, struct dentry___10 *, struct file___10 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace *, struct inode___10 *, struct dentry___10 *, umode_t);
	int (*set_acl)(struct user_namespace *, struct inode___10 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace *, struct dentry___10 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___10 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___10 {
	void (*fl_copy_lock)(struct file_lock___10 *, struct file_lock___10 *);
	void (*fl_release_private)(struct file_lock___10 *);
};

struct lock_manager_operations___10;

struct file_lock___10 {
	struct file_lock___10 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___10 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___10 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___10 *fl_ops;
	const struct lock_manager_operations___10 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___10 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___10 *);
	int (*lm_grant)(struct file_lock___10 *, int);
	bool (*lm_break)(struct file_lock___10 *);
	int (*lm_change)(struct file_lock___10 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___10 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___10 *);
};

struct fasync_struct___10 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___10 *fa_next;
	struct file___10 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___10 {
	struct inode___10 * (*alloc_inode)(struct super_block___10 *);
	void (*destroy_inode)(struct inode___10 *);
	void (*free_inode)(struct inode___10 *);
	void (*dirty_inode)(struct inode___10 *, int);
	int (*write_inode)(struct inode___10 *, struct writeback_control *);
	int (*drop_inode)(struct inode___10 *);
	void (*evict_inode)(struct inode___10 *);
	void (*put_super)(struct super_block___10 *);
	int (*sync_fs)(struct super_block___10 *, int);
	int (*freeze_super)(struct super_block___10 *);
	int (*freeze_fs)(struct super_block___10 *);
	int (*thaw_super)(struct super_block___10 *);
	int (*unfreeze_fs)(struct super_block___10 *);
	int (*statfs)(struct dentry___10 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___10 *, int *, char *);
	void (*umount_begin)(struct super_block___10 *);
	int (*show_options)(struct seq_file___9 *, struct dentry___10 *);
	int (*show_devname)(struct seq_file___9 *, struct dentry___10 *);
	int (*show_path)(struct seq_file___9 *, struct dentry___10 *);
	int (*show_stats)(struct seq_file___9 *, struct dentry___10 *);
	ssize_t (*quota_read)(struct super_block___10 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___10 *, int, const char *, size_t, loff_t);
	struct dquot___10 ** (*get_dquots)(struct inode___10 *);
	long int (*nr_cached_objects)(struct super_block___10 *, struct shrink_control___6 *);
	long int (*free_cached_objects)(struct super_block___10 *, struct shrink_control___6 *);
	struct file___10 * (*real_loop)(struct file___10 *);
};

typedef void (*poll_queue_proc___7)(struct file___10 *, wait_queue_head_t *, struct poll_table_struct___7 *);

struct poll_table_struct___7 {
	poll_queue_proc___7 _qproc;
	__poll_t _key;
};

struct seq_file___9 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___9 *op;
	int poll_event;
	const struct file___10 *file;
	void *private;
};

struct kernfs_root___9;

struct kernfs_elem_dir___9 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___9 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___9;

struct kernfs_root___9 {
	struct kernfs_node___9 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___9 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___9 {
	struct kernfs_node___9 *target_kn;
};

struct kernfs_ops___9;

struct kernfs_elem_attr___9 {
	const struct kernfs_ops___9 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___9 *notify_next;
};

struct kernfs_node___9 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___9 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___9 dir;
		struct kernfs_elem_symlink___9 symlink;
		struct kernfs_elem_attr___9 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___9;

struct kernfs_ops___9 {
	int (*open)(struct kernfs_open_file___9 *);
	void (*release)(struct kernfs_open_file___9 *);
	int (*seq_show)(struct seq_file___9 *, void *);
	void * (*seq_start)(struct seq_file___9 *, loff_t *);
	void * (*seq_next)(struct seq_file___9 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___9 *, void *);
	ssize_t (*read)(struct kernfs_open_file___9 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___9 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___9 *, struct poll_table_struct___7 *);
	int (*mmap)(struct kernfs_open_file___9 *, struct vm_area_struct___11 *);
};

struct kernfs_syscall_ops___9 {
	int (*show_options)(struct seq_file___9 *, struct kernfs_root___9 *);
	int (*mkdir)(struct kernfs_node___9 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___9 *);
	int (*rename)(struct kernfs_node___9 *, struct kernfs_node___9 *, const char *);
	int (*show_path)(struct seq_file___9 *, struct kernfs_node___9 *, struct kernfs_root___9 *);
};

struct kernfs_open_file___9 {
	struct kernfs_node___9 *kn;
	struct file___10 *file;
	struct seq_file___9 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped;
	bool released;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___10 *vm_ops;
};

struct bin_attribute___10;

struct attribute_group___10 {
	const char *name;
	umode_t (*is_visible)(struct kobject___10 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___10 *, struct bin_attribute___10 *, int);
	struct attribute **attrs;
	struct bin_attribute___10 **bin_attrs;
};

struct bin_attribute___10 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___8 * (*f_mapping)();
	ssize_t (*read)(struct file___10 *, struct kobject___10 *, struct bin_attribute___10 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___10 *, struct kobject___10 *, struct bin_attribute___10 *, char *, loff_t, size_t);
	int (*mmap)(struct file___10 *, struct kobject___10 *, struct bin_attribute___10 *, struct vm_area_struct___11 *);
};

struct sysfs_ops___9 {
	ssize_t (*show)(struct kobject___10 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___10 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___9;

struct kset___9 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___10 kobj;
	const struct kset_uevent_ops___9 *uevent_ops;
};

struct kobj_type___9 {
	void (*release)(struct kobject___10 *);
	const struct sysfs_ops___9 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___10 **default_groups;
	const struct kobj_ns_type_operations * (*child_ns_type)(struct kobject___10 *);
	const void * (*namespace)(struct kobject___10 *);
	void (*get_ownership)(struct kobject___10 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___9 {
	int (* const filter)(struct kset___9 *, struct kobject___10 *);
	const char * (* const name)(struct kset___9 *, struct kobject___10 *);
	int (* const uevent)(struct kset___9 *, struct kobject___10 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___9 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___9 *);
	int (*get)(char *, const struct kernel_param___9 *);
	void (*free)(void *);
};

struct kparam_array___9;

struct kernel_param___9 {
	const char *name;
	struct module___10 *mod;
	const struct kernel_param_ops___9 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___9 *arr;
	};
};

struct kparam_array___9 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___9 *ops;
	void *elem;
};

struct module_attribute___9 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___9 *, struct module_kobject___9 *, char *);
	ssize_t (*store)(struct module_attribute___9 *, struct module_kobject___9 *, const char *, size_t);
	void (*setup)(struct module___10 *, const char *);
	int (*test)(struct module___10 *);
	void (*free)(struct module___10 *);
};

struct trace_event_class___6;

struct trace_event_call___6 {
	struct list_head list;
	struct trace_event_class___6 *class;
	union {
		char *name;
		struct tracepoint___7 *tp;
	};
	struct trace_event event;
	char *print_fmt;
	struct event_filter *filter;
	union {
		void *module;
		atomic_t refcnt;
	};
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
	struct bpf_prog_array *prog_array;
	int (*perf_perm)(struct trace_event_call___6 *, struct perf_event___6 *);
};

struct cgroup_namespace___8 {
	struct ns_common ns;
	struct user_namespace *user_ns;
	struct ucounts *ucounts;
	struct css_set___8 *root_cset;
};

struct wakeup_source___9;

struct device___10;

struct dev_pm_info___9 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___9 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___10 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___9;

struct bus_type___9;

struct device_driver___9;

struct dev_pm_domain___9;

struct class___9;

struct device___10 {
	struct kobject___10 kobj;
	struct device___10 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___9 *type;
	struct bus_type___9 *bus;
	struct device_driver___9 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___9 power;
	struct dev_pm_domain___9 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node *of_node;
	struct fwnode_handle___5 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___9 *class;
	const struct attribute_group___10 **groups;
	void (*release)(struct device___10 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_ops___9 {
	int (*prepare)(struct device___10 *);
	void (*complete)(struct device___10 *);
	int (*suspend)(struct device___10 *);
	int (*resume)(struct device___10 *);
	int (*freeze)(struct device___10 *);
	int (*thaw)(struct device___10 *);
	int (*poweroff)(struct device___10 *);
	int (*restore)(struct device___10 *);
	int (*suspend_late)(struct device___10 *);
	int (*resume_early)(struct device___10 *);
	int (*freeze_late)(struct device___10 *);
	int (*thaw_early)(struct device___10 *);
	int (*poweroff_late)(struct device___10 *);
	int (*restore_early)(struct device___10 *);
	int (*suspend_noirq)(struct device___10 *);
	int (*resume_noirq)(struct device___10 *);
	int (*freeze_noirq)(struct device___10 *);
	int (*thaw_noirq)(struct device___10 *);
	int (*poweroff_noirq)(struct device___10 *);
	int (*restore_noirq)(struct device___10 *);
	int (*runtime_suspend)(struct device___10 *);
	int (*runtime_resume)(struct device___10 *);
	int (*runtime_idle)(struct device___10 *);
};

struct wakeup_source___9 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___10 *dev;
	bool active;
	bool autosleep_enabled;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___9 {
	struct dev_pm_ops___9 ops;
	int (*start)(struct device___10 *);
	void (*detach)(struct device___10 *, bool);
	int (*activate)(struct device___10 *);
	void (*sync)(struct device___10 *);
	void (*dismiss)(struct device___10 *);
};

struct bus_type___9 {
	const char *name;
	const char *dev_name;
	struct device___10 *dev_root;
	const struct attribute_group___10 **bus_groups;
	const struct attribute_group___10 **dev_groups;
	const struct attribute_group___10 **drv_groups;
	int (*match)(struct device___10 *, struct device_driver___9 *);
	int (*uevent)(struct device___10 *, struct kobj_uevent_env *);
	int (*probe)(struct device___10 *);
	void (*sync_state)(struct device___10 *);
	void (*remove)(struct device___10 *);
	void (*shutdown)(struct device___10 *);
	int (*online)(struct device___10 *);
	int (*offline)(struct device___10 *);
	int (*suspend)(struct device___10 *, pm_message_t);
	int (*resume)(struct device___10 *);
	int (*num_vf)(struct device___10 *);
	int (*dma_configure)(struct device___10 *);
	const struct dev_pm_ops___9 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___9 {
	const char *name;
	struct bus_type___9 *bus;
	struct module___10 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___10 *);
	void (*sync_state)(struct device___10 *);
	int (*remove)(struct device___10 *);
	void (*shutdown)(struct device___10 *);
	int (*suspend)(struct device___10 *, pm_message_t);
	int (*resume)(struct device___10 *);
	const struct attribute_group___10 **groups;
	const struct attribute_group___10 **dev_groups;
	const struct dev_pm_ops___9 *pm;
	void (*coredump)(struct device___10 *);
	struct driver_private *p;
};

struct device_type___9 {
	const char *name;
	const struct attribute_group___10 **groups;
	int (*uevent)(struct device___10 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___10 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___10 *);
	const struct dev_pm_ops___9 *pm;
};

struct class___9 {
	const char *name;
	struct module___10 *owner;
	const struct attribute_group___10 **class_groups;
	const struct attribute_group___10 **dev_groups;
	struct kobject___10 *dev_kobj;
	int (*dev_uevent)(struct device___10 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___10 *, umode_t *);
	void (*class_release)(struct class___9 *);
	void (*dev_release)(struct device___10 *);
	int (*shutdown_pre)(struct device___10 *);
	const struct kobj_ns_type_operations *ns_type;
	const void * (*namespace)(struct device___10 *);
	void (*get_ownership)(struct device___10 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___9 *pm;
	struct subsys_private *p;
};

struct perf_cpu_context___6;

struct perf_output_handle___6;

struct pmu___6 {
	struct list_head entry;
	struct module___10 *module;
	struct device___10 *dev;
	const struct attribute_group___10 **attr_groups;
	const struct attribute_group___10 **attr_update;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___6 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___6 *);
	void (*pmu_disable)(struct pmu___6 *);
	int (*event_init)(struct perf_event___6 *);
	void (*event_mapped)(struct perf_event___6 *, struct mm_struct___12 *);
	void (*event_unmapped)(struct perf_event___6 *, struct mm_struct___12 *);
	int (*add)(struct perf_event___6 *, int);
	void (*del)(struct perf_event___6 *, int);
	void (*start)(struct perf_event___6 *, int);
	void (*stop)(struct perf_event___6 *, int);
	void (*read)(struct perf_event___6 *);
	void (*start_txn)(struct pmu___6 *, unsigned int);
	int (*commit_txn)(struct pmu___6 *);
	void (*cancel_txn)(struct pmu___6 *);
	int (*event_idx)(struct perf_event___6 *);
	void (*sched_task)(struct perf_event_context___6 *, bool);
	struct kmem_cache *task_ctx_cache;
	void (*swap_task_ctx)(struct perf_event_context___6 *, struct perf_event_context___6 *);
	void * (*setup_aux)(struct perf_event___6 *, void **, int, bool);
	void (*free_aux)(void *);
	long int (*snapshot_aux)(struct perf_event___6 *, struct perf_output_handle___6 *, long unsigned int);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___6 *);
	int (*aux_output_match)(struct perf_event___6 *);
	int (*filter_match)(struct perf_event___6 *);
	int (*check_period)(struct perf_event___6 *, u64);
};

struct cftype___8;

struct cgroup_subsys___8 {
	struct cgroup_subsys_state___8 * (*css_alloc)(struct cgroup_subsys_state___8 *);
	int (*css_online)(struct cgroup_subsys_state___8 *);
	void (*css_offline)(struct cgroup_subsys_state___8 *);
	void (*css_released)(struct cgroup_subsys_state___8 *);
	void (*css_free)(struct cgroup_subsys_state___8 *);
	void (*css_reset)(struct cgroup_subsys_state___8 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___8 *, int);
	int (*css_extra_stat_show)(struct seq_file___9 *, struct cgroup_subsys_state___8 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___12 *, struct css_set___8 *);
	void (*cancel_fork)(struct task_struct___12 *, struct css_set___8 *);
	void (*fork)(struct task_struct___12 *);
	void (*exit)(struct task_struct___12 *);
	void (*release)(struct task_struct___12 *);
	void (*bind)(struct cgroup_subsys_state___8 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___8 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___8 *dfl_cftypes;
	struct cftype___8 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___8 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___8 *updated_children;
	struct cgroup___8 *updated_next;
};

struct cgroup_root___8 {
	struct kernfs_root___9 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___8 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___8 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___8 *ss;
	struct list_head node;
	struct kernfs_ops___9 *kf_ops;
	int (*open)(struct kernfs_open_file___9 *);
	void (*release)(struct kernfs_open_file___9 *);
	u64 (*read_u64)(struct cgroup_subsys_state___8 *, struct cftype___8 *);
	s64 (*read_s64)(struct cgroup_subsys_state___8 *, struct cftype___8 *);
	int (*seq_show)(struct seq_file___9 *, void *);
	void * (*seq_start)(struct seq_file___9 *, loff_t *);
	void * (*seq_next)(struct seq_file___9 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___9 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___8 *, struct cftype___8 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___8 *, struct cftype___8 *, s64);
	ssize_t (*write)(struct kernfs_open_file___9 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___9 *, struct poll_table_struct___7 *);
};

struct perf_cpu_context___6 {
	struct perf_event_context___6 ctx;
	struct perf_event_context___6 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___6 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
	int heap_size;
	struct perf_event___6 **heap;
	struct perf_event___6 *heap_default[2];
};

struct perf_output_handle___6 {
	struct perf_event___6 *event;
	struct perf_buffer *rb;
	long unsigned int wakeup;
	long unsigned int size;
	u64 aux_flags;
	union {
		void *addr;
		long unsigned int head;
	};
	int page;
};

struct perf_cgroup___6 {
	struct cgroup_subsys_state___8 css;
	struct perf_cgroup_info *info;
};

struct trace_event_fields___6 {
	const char *type;
	union {
		struct {
			const char *name;
			const int size;
			const int align;
			const int is_signed;
			const int filter_type;
		};
		int (*define_fields)(struct trace_event_call___6 *);
	};
};

struct trace_event_class___6 {
	const char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct trace_event_call___6 *, enum trace_reg, void *);
	struct trace_event_fields___6 *fields_array;
	struct list_head * (*get_fields)(struct trace_event_call___6 *);
	struct list_head fields;
	int (*raw_init)(struct trace_event_call___6 *);
};

struct trace_event_file___3;

struct trace_event_buffer___3 {
	struct trace_buffer *buffer;
	struct ring_buffer_event *event;
	struct trace_event_file___3 *trace_file;
	void *entry;
	unsigned int trace_ctx;
	struct pt_regs *regs;
};

struct trace_event_file___3 {
	struct list_head list;
	struct trace_event_call___6 *event_call;
	struct event_filter *filter;
	struct dentry___10 *dir;
	struct trace_array *tr;
	struct trace_subsystem_dir *system;
	struct list_head triggers;
	long unsigned int flags;
	atomic_t sm_ref;
	atomic_t tm_ref;
};

struct trace_event_raw_xen_mc__batch {
	struct trace_entry ent;
	enum paravirt_lazy_mode mode;
	char __data[0];
};

struct trace_event_raw_xen_mc_entry {
	struct trace_entry ent;
	unsigned int op;
	unsigned int nargs;
	long unsigned int args[6];
	char __data[0];
};

struct trace_event_raw_xen_mc_entry_alloc {
	struct trace_entry ent;
	size_t args;
	char __data[0];
};

struct trace_event_raw_xen_mc_callback {
	struct trace_entry ent;
	xen_mc_callback_fn_t fn;
	void *data;
	char __data[0];
};

struct trace_event_raw_xen_mc_flush_reason {
	struct trace_entry ent;
	enum xen_mc_flush_reason reason;
	char __data[0];
};

struct trace_event_raw_xen_mc_flush {
	struct trace_entry ent;
	unsigned int mcidx;
	unsigned int argidx;
	unsigned int cbidx;
	char __data[0];
};

struct trace_event_raw_xen_mc_extend_args {
	struct trace_entry ent;
	unsigned int op;
	size_t args;
	enum xen_mc_extend_args res;
	char __data[0];
};

struct trace_event_raw_xen_mmu__set_pte {
	struct trace_entry ent;
	pte_t *ptep;
	pteval_t pteval;
	char __data[0];
};

struct trace_event_raw_xen_mmu_set_pmd {
	struct trace_entry ent;
	pmd_t *pmdp;
	pmdval_t pmdval;
	char __data[0];
};

struct trace_event_raw_xen_mmu_set_pud {
	struct trace_entry ent;
	pud_t *pudp;
	pudval_t pudval;
	char __data[0];
};

struct trace_event_raw_xen_mmu_set_p4d {
	struct trace_entry ent;
	p4d_t *p4dp;
	p4d_t *user_p4dp;
	p4dval_t p4dval;
	char __data[0];
};

struct trace_event_raw_xen_mmu_ptep_modify_prot {
	struct trace_entry ent;
	struct mm_struct___12 *mm;
	long unsigned int addr;
	pte_t *ptep;
	pteval_t pteval;
	char __data[0];
};

struct trace_event_raw_xen_mmu_alloc_ptpage {
	struct trace_entry ent;
	struct mm_struct___12 *mm;
	long unsigned int pfn;
	unsigned int level;
	bool pinned;
	char __data[0];
};

struct trace_event_raw_xen_mmu_release_ptpage {
	struct trace_entry ent;
	long unsigned int pfn;
	unsigned int level;
	bool pinned;
	char __data[0];
};

struct trace_event_raw_xen_mmu_pgd {
	struct trace_entry ent;
	struct mm_struct___12 *mm;
	pgd_t *pgd;
	char __data[0];
};

struct trace_event_raw_xen_mmu_flush_tlb_one_user {
	struct trace_entry ent;
	long unsigned int addr;
	char __data[0];
};

struct trace_event_raw_xen_mmu_flush_tlb_multi {
	struct trace_entry ent;
	unsigned int ncpus;
	struct mm_struct___12 *mm;
	long unsigned int addr;
	long unsigned int end;
	char __data[0];
};

struct trace_event_raw_xen_mmu_write_cr3 {
	struct trace_entry ent;
	bool kernel;
	long unsigned int cr3;
	char __data[0];
};

struct trace_event_raw_xen_cpu_write_ldt_entry {
	struct trace_entry ent;
	struct desc_struct *dt;
	int entrynum;
	u64 desc;
	char __data[0];
};

struct trace_event_raw_xen_cpu_write_idt_entry {
	struct trace_entry ent;
	gate_desc *dt;
	int entrynum;
	char __data[0];
};

struct trace_event_raw_xen_cpu_load_idt {
	struct trace_entry ent;
	long unsigned int addr;
	char __data[0];
};

struct trace_event_raw_xen_cpu_write_gdt_entry {
	struct trace_entry ent;
	u64 desc;
	struct desc_struct *dt;
	int entrynum;
	int type;
	char __data[0];
};

struct trace_event_raw_xen_cpu_set_ldt {
	struct trace_entry ent;
	const void *addr;
	unsigned int entries;
	char __data[0];
};

struct trace_event_data_offsets_xen_mc__batch {};

struct trace_event_data_offsets_xen_mc_entry {};

struct trace_event_data_offsets_xen_mc_entry_alloc {};

struct trace_event_data_offsets_xen_mc_callback {};

struct trace_event_data_offsets_xen_mc_flush_reason {};

struct trace_event_data_offsets_xen_mc_flush {};

struct trace_event_data_offsets_xen_mc_extend_args {};

struct trace_event_data_offsets_xen_mmu__set_pte {};

struct trace_event_data_offsets_xen_mmu_set_pmd {};

struct trace_event_data_offsets_xen_mmu_set_pud {};

struct trace_event_data_offsets_xen_mmu_set_p4d {};

struct trace_event_data_offsets_xen_mmu_ptep_modify_prot {};

struct trace_event_data_offsets_xen_mmu_alloc_ptpage {};

struct trace_event_data_offsets_xen_mmu_release_ptpage {};

struct trace_event_data_offsets_xen_mmu_pgd {};

struct trace_event_data_offsets_xen_mmu_flush_tlb_one_user {};

struct trace_event_data_offsets_xen_mmu_flush_tlb_multi {};

struct trace_event_data_offsets_xen_mmu_write_cr3 {};

struct trace_event_data_offsets_xen_cpu_write_ldt_entry {};

struct trace_event_data_offsets_xen_cpu_write_idt_entry {};

struct trace_event_data_offsets_xen_cpu_load_idt {};

struct trace_event_data_offsets_xen_cpu_write_gdt_entry {};

struct trace_event_data_offsets_xen_cpu_set_ldt {};

typedef void (*btf_trace_xen_mc_batch)(void *, enum paravirt_lazy_mode);

typedef void (*btf_trace_xen_mc_issue)(void *, enum paravirt_lazy_mode);

typedef void (*btf_trace_xen_mc_entry)(void *, struct multicall_entry *, unsigned int);

typedef void (*btf_trace_xen_mc_entry_alloc)(void *, size_t);

typedef void (*btf_trace_xen_mc_callback)(void *, xen_mc_callback_fn_t, void *);

typedef void (*btf_trace_xen_mc_flush_reason)(void *, enum xen_mc_flush_reason);

typedef void (*btf_trace_xen_mc_flush)(void *, unsigned int, unsigned int, unsigned int);

typedef void (*btf_trace_xen_mc_extend_args)(void *, long unsigned int, size_t, enum xen_mc_extend_args);

typedef void (*btf_trace_xen_mmu_set_pte)(void *, pte_t *, pte_t);

typedef void (*btf_trace_xen_mmu_set_pmd)(void *, pmd_t *, pmd_t);

typedef void (*btf_trace_xen_mmu_set_pud)(void *, pud_t *, pud_t);

typedef void (*btf_trace_xen_mmu_set_p4d)(void *, p4d_t *, p4d_t *, p4d_t);

typedef void (*btf_trace_xen_mmu_ptep_modify_prot_start)(void *, struct mm_struct___12 *, long unsigned int, pte_t *, pte_t);

typedef void (*btf_trace_xen_mmu_ptep_modify_prot_commit)(void *, struct mm_struct___12 *, long unsigned int, pte_t *, pte_t);

typedef void (*btf_trace_xen_mmu_alloc_ptpage)(void *, struct mm_struct___12 *, long unsigned int, unsigned int, bool);

typedef void (*btf_trace_xen_mmu_release_ptpage)(void *, long unsigned int, unsigned int, bool);

typedef void (*btf_trace_xen_mmu_pgd_pin)(void *, struct mm_struct___12 *, pgd_t *);

typedef void (*btf_trace_xen_mmu_pgd_unpin)(void *, struct mm_struct___12 *, pgd_t *);

typedef void (*btf_trace_xen_mmu_flush_tlb_one_user)(void *, long unsigned int);

typedef void (*btf_trace_xen_mmu_flush_tlb_multi)(void *, const struct cpumask *, struct mm_struct___12 *, long unsigned int, long unsigned int);

typedef void (*btf_trace_xen_mmu_write_cr3)(void *, bool, long unsigned int);

typedef void (*btf_trace_xen_cpu_write_ldt_entry)(void *, struct desc_struct *, int, u64);

typedef void (*btf_trace_xen_cpu_write_idt_entry)(void *, gate_desc *, int, const gate_desc *);

typedef void (*btf_trace_xen_cpu_load_idt)(void *, const struct desc_ptr *);

typedef void (*btf_trace_xen_cpu_write_gdt_entry)(void *, struct desc_struct *, int, const void *, int);

typedef void (*btf_trace_xen_cpu_set_ldt)(void *, const void *, unsigned int);

enum ipi_vector {
	XEN_RESCHEDULE_VECTOR = 0,
	XEN_CALL_FUNCTION_VECTOR = 1,
	XEN_CALL_FUNCTION_SINGLE_VECTOR = 2,
	XEN_SPIN_UNLOCK_VECTOR = 3,
	XEN_IRQ_WORK_VECTOR = 4,
	XEN_NMI_VECTOR = 5,
	XEN_NR_IPIS = 6,
};

struct xen_common_irq {
	int irq;
	char *name;
};

struct smp_ops___2 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*crash_stop_other_cpus)();
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___10 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct cpu_user_regs {
	uint64_t r15;
	uint64_t r14;
	uint64_t r13;
	uint64_t r12;
	union {
		uint64_t rbp;
		uint64_t ebp;
		uint32_t _ebp;
	};
	union {
		uint64_t rbx;
		uint64_t ebx;
		uint32_t _ebx;
	};
	uint64_t r11;
	uint64_t r10;
	uint64_t r9;
	uint64_t r8;
	union {
		uint64_t rax;
		uint64_t eax;
		uint32_t _eax;
	};
	union {
		uint64_t rcx;
		uint64_t ecx;
		uint32_t _ecx;
	};
	union {
		uint64_t rdx;
		uint64_t edx;
		uint32_t _edx;
	};
	union {
		uint64_t rsi;
		uint64_t esi;
		uint32_t _esi;
	};
	union {
		uint64_t rdi;
		uint64_t edi;
		uint32_t _edi;
	};
	uint32_t error_code;
	uint32_t entry_vector;
	union {
		uint64_t rip;
		uint64_t eip;
		uint32_t _eip;
	};
	uint16_t cs;
	uint16_t _pad0[1];
	uint8_t saved_upcall_mask;
	uint8_t _pad1[3];
	union {
		uint64_t rflags;
		uint64_t eflags;
		uint32_t _eflags;
	};
	union {
		uint64_t rsp;
		uint64_t esp;
		uint32_t _esp;
	};
	uint16_t ss;
	uint16_t _pad2[3];
	uint16_t es;
	uint16_t _pad3[3];
	uint16_t ds;
	uint16_t _pad4[3];
	uint16_t fs;
	uint16_t _pad5[3];
	uint16_t gs;
	uint16_t _pad6[3];
};

struct vcpu_guest_context {
	struct {
		char x[512];
	} fpu_ctxt;
	long unsigned int flags;
	struct cpu_user_regs user_regs;
	struct trap_info trap_ctxt[256];
	long unsigned int ldt_base;
	long unsigned int ldt_ents;
	long unsigned int gdt_frames[16];
	long unsigned int gdt_ents;
	long unsigned int kernel_ss;
	long unsigned int kernel_sp;
	long unsigned int ctrlreg[8];
	long unsigned int debugreg[8];
	long unsigned int event_callback_eip;
	long unsigned int failsafe_callback_eip;
	long unsigned int syscall_callback_eip;
	long unsigned int vm_assist;
	uint64_t fs_base;
	uint64_t gs_base_kernel;
	uint64_t gs_base_user;
};

struct io_tlb_slot;

struct io_tlb_mem {
	phys_addr_t start;
	phys_addr_t end;
	long unsigned int nslabs;
	long unsigned int used;
	unsigned int index;
	spinlock_t lock;
	struct dentry___8 *debugfs;
	bool late_alloc;
	bool force_bounce;
	bool for_alloc;
	struct io_tlb_slot *slots;
};

struct sg_table {
	struct scatterlist *sgl;
	unsigned int nents;
	unsigned int orig_nents;
};

enum swiotlb_force {
	SWIOTLB_NORMAL = 0,
	SWIOTLB_FORCE = 1,
	SWIOTLB_NO_FORCE = 2,
};

struct io_tlb_slot {
	phys_addr_t orig_addr;
	size_t alloc_size;
	unsigned int list;
};

struct iommu_table_entry {
	initcall_t detect;
	initcall_t depend;
	void (*early_init)();
	void (*late_init)();
	int flags;
};

union efi_boot_services;

typedef union efi_boot_services efi_boot_services_t;

typedef struct {
	efi_table_hdr_t hdr;
	u32 fw_vendor;
	u32 fw_revision;
	u32 con_in_handle;
	u32 con_in;
	u32 con_out_handle;
	u32 con_out;
	u32 stderr_handle;
	u32 stderr;
	u32 runtime;
	u32 boottime;
	u32 nr_tables;
	u32 tables;
} efi_system_table_32_t;

union efi_simple_text_input_protocol;

typedef union efi_simple_text_input_protocol efi_simple_text_input_protocol_t;

union efi_simple_text_output_protocol;

typedef union efi_simple_text_output_protocol efi_simple_text_output_protocol_t;

typedef union {
	struct {
		efi_table_hdr_t hdr;
		long unsigned int fw_vendor;
		u32 fw_revision;
		long unsigned int con_in_handle;
		efi_simple_text_input_protocol_t *con_in;
		long unsigned int con_out_handle;
		efi_simple_text_output_protocol_t *con_out;
		long unsigned int stderr_handle;
		long unsigned int stderr;
		efi_runtime_services_t *runtime;
		efi_boot_services_t *boottime;
		long unsigned int nr_tables;
		long unsigned int tables;
	};
	efi_system_table_32_t mixed_mode;
} efi_system_table_t;

enum efi_secureboot_mode {
	efi_secureboot_mode_unset = 0,
	efi_secureboot_mode_unknown = 1,
	efi_secureboot_mode_disabled = 2,
	efi_secureboot_mode_enabled = 3,
};

struct vm_area_struct___12;

struct vmacache___11 {
	u64 seqnum;
	struct vm_area_struct___12 *vmas[4];
};

struct page___11;

struct page_frag___11 {
	struct page___11 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___13;

struct uprobe_task___2;

struct vm_struct___10;

struct task_struct___13 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___13 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___13 *mm;
	struct mm_struct___13 *active_mm;
	struct vmacache___11 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int restore_sigmask: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___13 *real_parent;
	struct task_struct___13 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___13 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___9 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	struct posix_cputimers_work posix_cputimers_work;
	const struct cred___2 *ptracer_cred;
	const struct cred___2 *real_cred;
	const struct cred___2 *cred;
	struct key *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy *nsproxy;
	struct signal_struct___3 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___13 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context___2 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set *cgroups;
	struct list_head cg_list;
	u32 closid;
	u32 rmid;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	struct pipe_inode_info *splice_pipe;
	struct page_frag___11 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup *active_memcg;
	struct request_queue *throttle_queue;
	struct uprobe_task___2 *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___13 *oom_reaper_list;
	struct vm_struct___10 *stack_vm_area;
	refcount_t stack_refcount;
	int patch_state;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	void *mce_vaddr;
	__u64 mce_kflags;
	u64 mce_addr;
	__u64 mce_ripv: 1;
	__u64 mce_whole_page: 1;
	__u64 __mce_reserved: 62;
	long: 2;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct callback_head mce_kill_me;
	int mce_count;
	struct llist_head kretprobe_instances;
	struct callback_head l1d_flush_kill;
	long: 64;
	struct thread_struct___7 thread;
};

typedef struct page___11 *pgtable_t___11;

struct page___11 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___8 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___11 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___11 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___13 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___10 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	long: 64;
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct pv_cpu_ops___8 {
	void (*io_delay)();
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	void (*write_cr4)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___7 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(long unsigned int);
	void (*invalidate_io_bitmap)();
	void (*update_io_bitmap)();
	void (*wbinvd)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int);
	void (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_msr_safe)(unsigned int, int *);
	int (*write_msr_safe)(unsigned int, unsigned int, unsigned int);
	u64 (*read_pmc)(int);
	void (*start_context_switch)(struct task_struct___13 *);
	void (*end_context_switch)(struct task_struct___13 *);
};

struct pv_mmu_ops___8 {
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_one_user)(long unsigned int);
	void (*flush_tlb_multi)(const struct cpumask *, const struct flush_tlb_info___3 *);
	void (*tlb_remove_table)(struct mmu_gather *, void *);
	void (*exit_mmap)(struct mm_struct___13 *);
	struct paravirt_callee_save read_cr2;
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___13 *, struct mm_struct___13 *);
	void (*dup_mmap)(struct mm_struct___13 *, struct mm_struct___13 *);
	int (*pgd_alloc)(struct mm_struct___13 *);
	void (*pgd_free)(struct mm_struct___13 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___13 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___13 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___13 *, long unsigned int);
	void (*alloc_p4d)(struct mm_struct___13 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*release_p4d)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	pte_t (*ptep_modify_prot_start)(struct vm_area_struct___12 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct vm_area_struct___12 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_p4d)(p4d_t *, p4d_t);
	struct paravirt_callee_save p4d_val;
	struct paravirt_callee_save make_p4d;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

struct core_state___11;

struct mm_struct___13 {
	struct {
		struct vm_area_struct___12 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___7 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int mmap_compat_base;
		long unsigned int mmap_compat_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[48];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___11 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___13 *owner;
		struct user_namespace *user_ns;
		struct file___7 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		bool tlb_flush_batched;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct vm_area_struct___12 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___12 *vm_next;
	struct vm_area_struct___12 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___13 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___6 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___7 *vm_file;
	struct file___7 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct paravirt_patch_template___8 {
	struct pv_cpu_ops___8 cpu;
	struct pv_irq_ops irq;
	struct pv_mmu_ops___8 mmu;
	struct pv_lock_ops lock;
};

struct uprobe_task___2 {
	enum uprobe_task_state state;
	union {
		struct {
			struct arch_uprobe_task autask;
			long unsigned int vaddr;
		};
		struct {
			struct callback_head dup_xol_work;
			long unsigned int dup_xol_addr;
		};
	};
	long: 64;
	struct uprobe *active_uprobe;
	long unsigned int xol_vaddr;
	struct return_instance *return_instances;
	unsigned int depth;
};

struct core_thread___11 {
	struct task_struct___13 *task;
	struct core_thread___11 *next;
};

struct core_state___11 {
	atomic_t nr_threads;
	struct core_thread___11 dumper;
	struct completion startup;
};

struct irq_domain___5;

struct x86_init_irqs___3 {
	void (*pre_vector_init)();
	void (*intr_init)();
	void (*intr_mode_select)();
	void (*intr_mode_init)();
	struct irq_domain___5 * (*create_pci_msi_domain)();
};

struct irq_domain_ops___5;

struct fwnode_handle___9;

struct irq_domain___5 {
	struct list_head link;
	const char *name;
	const struct irq_domain_ops___5 *ops;
	void *host_data;
	unsigned int flags;
	unsigned int mapcount;
	struct fwnode_handle___9 *fwnode;
	enum irq_domain_bus_token bus_token;
	struct irq_domain_chip_generic *gc;
	struct irq_domain___5 *parent;
	irq_hw_number_t hwirq_max;
	unsigned int revmap_size;
	struct xarray revmap_tree;
	struct mutex revmap_mutex;
	struct irq_data *revmap[0];
};

struct x86_init_ops___3 {
	struct x86_init_resources resources;
	struct x86_init_mpparse mpparse;
	struct x86_init_irqs___3 irqs;
	struct x86_init_oem oem;
	struct x86_init_paging paging;
	struct x86_init_timers timers;
	struct x86_init_iommu iommu;
	struct x86_init_pci pci;
	struct x86_hyper_init hyper;
	struct x86_init_acpi acpi;
};

struct kernfs_root___10;

struct kernfs_elem_dir___10 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___10 *root;
	long unsigned int rev;
};

struct kernfs_node___10;

struct kernfs_syscall_ops___10;

struct kernfs_root___10 {
	struct kernfs_node___10 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___10 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___10 {
	struct kernfs_node___10 *target_kn;
};

struct kernfs_ops___10;

struct kernfs_elem_attr___10 {
	const struct kernfs_ops___10 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___10 *notify_next;
};

struct kernfs_node___10 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___10 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___10 dir;
		struct kernfs_elem_symlink___10 symlink;
		struct kernfs_elem_attr___10 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___10;

struct kernfs_ops___10 {
	int (*open)(struct kernfs_open_file___10 *);
	void (*release)(struct kernfs_open_file___10 *);
	int (*seq_show)(struct seq_file *, void *);
	void * (*seq_start)(struct seq_file *, loff_t *);
	void * (*seq_next)(struct seq_file *, void *, loff_t *);
	void (*seq_stop)(struct seq_file *, void *);
	ssize_t (*read)(struct kernfs_open_file___10 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___10 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___10 *, struct poll_table_struct *);
	int (*mmap)(struct kernfs_open_file___10 *, struct vm_area_struct___12 *);
};

struct kernfs_syscall_ops___10 {
	int (*show_options)(struct seq_file *, struct kernfs_root___10 *);
	int (*mkdir)(struct kernfs_node___10 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___10 *);
	int (*rename)(struct kernfs_node___10 *, struct kernfs_node___10 *, const char *);
	int (*show_path)(struct seq_file *, struct kernfs_node___10 *, struct kernfs_root___10 *);
};

struct kernfs_open_file___10 {
	struct kernfs_node___10 *kn;
	struct file___7 *file;
	struct seq_file *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped;
	bool released;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___6 *vm_ops;
};

struct kobject___11;

struct bin_attribute___11;

struct attribute_group___11 {
	const char *name;
	umode_t (*is_visible)(struct kobject___11 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___11 *, struct bin_attribute___11 *, int);
	struct attribute **attrs;
	struct bin_attribute___11 **bin_attrs;
};

struct kset___10;

struct kobj_type___10;

struct kobject___11 {
	const char *name;
	struct list_head entry;
	struct kobject___11 *parent;
	struct kset___10 *kset;
	struct kobj_type___10 *ktype;
	struct kernfs_node___10 *sd;
	struct kref kref;
	unsigned int state_initialized;
	unsigned int state_in_sysfs;
	unsigned int state_add_uevent_sent;
	unsigned int state_remove_uevent_sent;
	unsigned int uevent_suppress;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bin_attribute___11 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___8 * (*f_mapping)();
	ssize_t (*read)(struct file___7 *, struct kobject___11 *, struct bin_attribute___11 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___7 *, struct kobject___11 *, struct bin_attribute___11 *, char *, loff_t, size_t);
	int (*mmap)(struct file___7 *, struct kobject___11 *, struct bin_attribute___11 *, struct vm_area_struct___12 *);
};

struct sysfs_ops___10 {
	ssize_t (*show)(struct kobject___11 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___11 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___10;

struct kset___10 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___11 kobj;
	const struct kset_uevent_ops___10 *uevent_ops;
};

struct kobj_type___10 {
	void (*release)(struct kobject___11 *);
	const struct sysfs_ops___10 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___11 **default_groups;
	const struct kobj_ns_type_operations * (*child_ns_type)(struct kobject___11 *);
	const void * (*namespace)(struct kobject___11 *);
	void (*get_ownership)(struct kobject___11 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___10 {
	int (* const filter)(struct kset___10 *, struct kobject___11 *);
	const char * (* const name)(struct kset___10 *, struct kobject___11 *);
	int (* const uevent)(struct kset___10 *, struct kobject___11 *, struct kobj_uevent_env *);
};

struct fwnode_operations___9;

struct device___11;

struct fwnode_handle___9 {
	struct fwnode_handle___9 *secondary;
	const struct fwnode_operations___9 *ops;
	struct device___11 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct fwnode_reference_args___9;

struct fwnode_endpoint___9;

struct fwnode_operations___9 {
	struct fwnode_handle___9 * (*get)(struct fwnode_handle___9 *);
	void (*put)(struct fwnode_handle___9 *);
	bool (*device_is_available)(const struct fwnode_handle___9 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___9 *, const struct device___11 *);
	bool (*property_present)(const struct fwnode_handle___9 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___9 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___9 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___9 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___9 *);
	struct fwnode_handle___9 * (*get_parent)(const struct fwnode_handle___9 *);
	struct fwnode_handle___9 * (*get_next_child_node)(const struct fwnode_handle___9 *, struct fwnode_handle___9 *);
	struct fwnode_handle___9 * (*get_named_child_node)(const struct fwnode_handle___9 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___9 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___9 *);
	struct fwnode_handle___9 * (*graph_get_next_endpoint)(const struct fwnode_handle___9 *, struct fwnode_handle___9 *);
	struct fwnode_handle___9 * (*graph_get_remote_endpoint)(const struct fwnode_handle___9 *);
	struct fwnode_handle___9 * (*graph_get_port_parent)(struct fwnode_handle___9 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___9 *, struct fwnode_endpoint___9 *);
	int (*add_links)(struct fwnode_handle___9 *);
};

struct wakeup_source___10;

struct dev_pm_info___10 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___10 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___11 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___10;

struct bus_type___10;

struct device_driver___10;

struct dev_pm_domain___10;

struct device_node___6;

struct class___10;

struct device___11 {
	struct kobject___11 kobj;
	struct device___11 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___10 *type;
	struct bus_type___10 *bus;
	struct device_driver___10 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___10 power;
	struct dev_pm_domain___10 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___5 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___6 *of_node;
	struct fwnode_handle___9 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___10 *class;
	const struct attribute_group___11 **groups;
	void (*release)(struct device___11 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fwnode_endpoint___9 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___9 *local_fwnode;
};

struct fwnode_reference_args___9 {
	struct fwnode_handle___9 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct device_node___6 {
	const char *name;
	phandle phandle;
	const char *full_name;
	struct fwnode_handle___9 fwnode;
	struct property *properties;
	struct property *deadprops;
	struct device_node___6 *parent;
	struct device_node___6 *child;
	struct device_node___6 *sibling;
	long unsigned int _flags;
	void *data;
};

struct irq_fwspec___5 {
	struct fwnode_handle___9 *fwnode;
	int param_count;
	u32 param[16];
};

struct irq_domain_ops___5 {
	int (*match)(struct irq_domain___5 *, struct device_node___6 *, enum irq_domain_bus_token);
	int (*select)(struct irq_domain___5 *, struct irq_fwspec___5 *, enum irq_domain_bus_token);
	int (*map)(struct irq_domain___5 *, unsigned int, irq_hw_number_t);
	void (*unmap)(struct irq_domain___5 *, unsigned int);
	int (*xlate)(struct irq_domain___5 *, struct device_node___6 *, const u32 *, unsigned int, long unsigned int *, unsigned int *);
	int (*alloc)(struct irq_domain___5 *, unsigned int, unsigned int, void *);
	void (*free)(struct irq_domain___5 *, unsigned int, unsigned int);
	int (*activate)(struct irq_domain___5 *, struct irq_data *, bool);
	void (*deactivate)(struct irq_domain___5 *, struct irq_data *);
	int (*translate)(struct irq_domain___5 *, struct irq_fwspec___5 *, long unsigned int *, unsigned int *);
};

struct vm_struct___10 {
	struct vm_struct___10 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___11 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct dev_pm_ops___10 {
	int (*prepare)(struct device___11 *);
	void (*complete)(struct device___11 *);
	int (*suspend)(struct device___11 *);
	int (*resume)(struct device___11 *);
	int (*freeze)(struct device___11 *);
	int (*thaw)(struct device___11 *);
	int (*poweroff)(struct device___11 *);
	int (*restore)(struct device___11 *);
	int (*suspend_late)(struct device___11 *);
	int (*resume_early)(struct device___11 *);
	int (*freeze_late)(struct device___11 *);
	int (*thaw_early)(struct device___11 *);
	int (*poweroff_late)(struct device___11 *);
	int (*restore_early)(struct device___11 *);
	int (*suspend_noirq)(struct device___11 *);
	int (*resume_noirq)(struct device___11 *);
	int (*freeze_noirq)(struct device___11 *);
	int (*thaw_noirq)(struct device___11 *);
	int (*poweroff_noirq)(struct device___11 *);
	int (*restore_noirq)(struct device___11 *);
	int (*runtime_suspend)(struct device___11 *);
	int (*runtime_resume)(struct device___11 *);
	int (*runtime_idle)(struct device___11 *);
};

struct wakeup_source___10 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___11 *dev;
	bool active;
	bool autosleep_enabled;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___10 {
	struct dev_pm_ops___10 ops;
	int (*start)(struct device___11 *);
	void (*detach)(struct device___11 *, bool);
	int (*activate)(struct device___11 *);
	void (*sync)(struct device___11 *);
	void (*dismiss)(struct device___11 *);
};

struct bus_type___10 {
	const char *name;
	const char *dev_name;
	struct device___11 *dev_root;
	const struct attribute_group___11 **bus_groups;
	const struct attribute_group___11 **dev_groups;
	const struct attribute_group___11 **drv_groups;
	int (*match)(struct device___11 *, struct device_driver___10 *);
	int (*uevent)(struct device___11 *, struct kobj_uevent_env *);
	int (*probe)(struct device___11 *);
	void (*sync_state)(struct device___11 *);
	void (*remove)(struct device___11 *);
	void (*shutdown)(struct device___11 *);
	int (*online)(struct device___11 *);
	int (*offline)(struct device___11 *);
	int (*suspend)(struct device___11 *, pm_message_t);
	int (*resume)(struct device___11 *);
	int (*num_vf)(struct device___11 *);
	int (*dma_configure)(struct device___11 *);
	const struct dev_pm_ops___10 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct module___11;

struct device_driver___10 {
	const char *name;
	struct bus_type___10 *bus;
	struct module___11 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___11 *);
	void (*sync_state)(struct device___11 *);
	int (*remove)(struct device___11 *);
	void (*shutdown)(struct device___11 *);
	int (*suspend)(struct device___11 *, pm_message_t);
	int (*resume)(struct device___11 *);
	const struct attribute_group___11 **groups;
	const struct attribute_group___11 **dev_groups;
	const struct dev_pm_ops___10 *pm;
	void (*coredump)(struct device___11 *);
	struct driver_private *p;
};

struct device_type___10 {
	const char *name;
	const struct attribute_group___11 **groups;
	int (*uevent)(struct device___11 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___11 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___11 *);
	const struct dev_pm_ops___10 *pm;
};

struct class___10 {
	const char *name;
	struct module___11 *owner;
	const struct attribute_group___11 **class_groups;
	const struct attribute_group___11 **dev_groups;
	struct kobject___11 *dev_kobj;
	int (*dev_uevent)(struct device___11 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___11 *, umode_t *);
	void (*class_release)(struct class___10 *);
	void (*dev_release)(struct device___11 *);
	int (*shutdown_pre)(struct device___11 *);
	const struct kobj_ns_type_operations *ns_type;
	const void * (*namespace)(struct device___11 *);
	void (*get_ownership)(struct device___11 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___10 *pm;
	struct subsys_private *p;
};

struct module_kobject___10 {
	struct kobject___11 kobj;
	struct module___11 *mod;
	struct kobject___11 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___10 {
	struct module___11 *mod;
	struct latch_tree_node node;
};

struct module_layout___10 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___10 mtn;
};

struct module_attribute___10;

struct kernel_param___10;

struct module___11 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___10 mkobj;
	struct module_attribute___10 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___11 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___10 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___10 core_layout;
	struct module_layout___10 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map___7 *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___4 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	int num_static_call_sites;
	struct static_call_site *static_call_sites;
	bool klp;
	bool klp_alive;
	struct klp_modinfo *klp_info;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kernel_param_ops___10 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___10 *);
	int (*get)(char *, const struct kernel_param___10 *);
	void (*free)(void *);
};

struct kparam_array___10;

struct kernel_param___10 {
	const char *name;
	struct module___11 *mod;
	const struct kernel_param_ops___10 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___10 *arr;
	};
};

struct kparam_array___10 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___10 *ops;
	void *elem;
};

struct module_attribute___10 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___10 *, struct module_kobject___10 *, char *);
	ssize_t (*store)(struct module_attribute___10 *, struct module_kobject___10 *, const char *, size_t);
	void (*setup)(struct module___11 *, const char *);
	int (*test)(struct module___11 *);
	void (*free)(struct module___11 *);
};

struct hvm_modlist_entry {
	uint64_t paddr;
	uint64_t size;
	uint64_t cmdline_paddr;
	uint64_t reserved;
};

struct hvm_memmap_table_entry {
	uint64_t addr;
	uint64_t size;
	uint32_t type;
	uint32_t reserved;
};

enum {
	WORK_STRUCT_PENDING_BIT = 0,
	WORK_STRUCT_INACTIVE_BIT = 1,
	WORK_STRUCT_PWQ_BIT = 2,
	WORK_STRUCT_LINKED_BIT = 3,
	WORK_STRUCT_COLOR_SHIFT = 4,
	WORK_STRUCT_COLOR_BITS = 4,
	WORK_STRUCT_PENDING = 1,
	WORK_STRUCT_INACTIVE = 2,
	WORK_STRUCT_PWQ = 4,
	WORK_STRUCT_LINKED = 8,
	WORK_STRUCT_STATIC = 0,
	WORK_NR_COLORS = 16,
	WORK_CPU_UNBOUND = 8192,
	WORK_STRUCT_FLAG_BITS = 8,
	WORK_OFFQ_FLAG_BASE = 4,
	__WORK_OFFQ_CANCELING = 4,
	WORK_OFFQ_CANCELING = 16,
	WORK_OFFQ_FLAG_BITS = 1,
	WORK_OFFQ_POOL_SHIFT = 5,
	WORK_OFFQ_LEFT = 59,
	WORK_OFFQ_POOL_BITS = 31,
	WORK_OFFQ_POOL_NONE = 2147483647,
	WORK_STRUCT_FLAG_MASK = 255,
	WORK_STRUCT_WQ_DATA_MASK = 4294967040,
	WORK_STRUCT_NO_POOL = 4294967264,
	WORK_BUSY_PENDING = 1,
	WORK_BUSY_RUNNING = 2,
	WORKER_DESC_LEN = 24,
};

enum {
	MEMREMAP_WB = 1,
	MEMREMAP_WT = 2,
	MEMREMAP_WC = 4,
	MEMREMAP_ENC = 8,
	MEMREMAP_DEC = 16,
};

enum hv_isolation_type {
	HV_ISOLATION_TYPE_NONE = 0,
	HV_ISOLATION_TYPE_VBS = 1,
	HV_ISOLATION_TYPE_SNP = 2,
};

union hv_x64_msr_hypercall_contents {
	u64 as_uint64;
	struct {
		u64 enable: 1;
		u64 reserved: 11;
		u64 guest_physical_address: 52;
	};
};

union hv_vp_assist_msr_contents {
	u64 as_uint64;
	struct {
		u64 enable: 1;
		u64 reserved: 11;
		u64 pfn: 52;
	};
};

struct hv_reenlightenment_control {
	__u64 vector: 8;
	__u64 reserved1: 8;
	__u64 enabled: 1;
	__u64 reserved2: 15;
	__u64 target_vp: 32;
};

struct hv_tsc_emulation_control {
	__u64 enabled: 1;
	__u64 reserved: 63;
};

struct hv_tsc_emulation_status {
	__u64 inprogress: 1;
	__u64 reserved: 63;
};

struct hv_nested_enlightenments_control {
	struct {
		__u32 directhypercall: 1;
		__u32 reserved: 31;
	} features;
	struct {
		__u32 reserved;
	} hypercallControls;
};

struct hv_vp_assist_page {
	__u32 apic_assist;
	__u32 reserved1;
	__u64 vtl_control[3];
	struct hv_nested_enlightenments_control nested_control;
	__u8 enlighten_vmentry;
	__u8 reserved2[7];
	__u64 current_nested_vmcs;
};

struct hv_get_partition_id {
	u64 partition_id;
};

struct ms_hyperv_info {
	u32 features;
	u32 priv_high;
	u32 misc_features;
	u32 hints;
	u32 nested_features;
	u32 max_vp_index;
	u32 max_lp_index;
	u32 isolation_config_a;
	u32 isolation_config_b;
};

struct dentry___11;

struct super_block___11;

struct module___12;

struct file_system_type___11 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___11 * (*mount)(struct file_system_type___11 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___11 *);
	struct module___12 *owner;
	struct file_system_type___11 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___11;

struct kiocb___11;

struct iov_iter___9;

struct poll_table_struct___8;

struct vm_area_struct___13;

struct inode___11;

struct file_lock___11;

struct page___12;

struct seq_file___10;

struct file_operations___11 {
	struct module___12 *owner;
	loff_t (*llseek)(struct file___11 *, loff_t, int);
	ssize_t (*read)(struct file___11 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___11 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___11 *, struct iov_iter___9 *);
	ssize_t (*write_iter)(struct kiocb___11 *, struct iov_iter___9 *);
	int (*iopoll)(struct kiocb___11 *, bool);
	int (*iterate)(struct file___11 *, struct dir_context *);
	int (*iterate_shared)(struct file___11 *, struct dir_context *);
	__poll_t (*poll)(struct file___11 *, struct poll_table_struct___8 *);
	long int (*unlocked_ioctl)(struct file___11 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___11 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___11 *, struct vm_area_struct___13 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___11 *, struct file___11 *);
	int (*flush)(struct file___11 *, fl_owner_t);
	int (*release)(struct inode___11 *, struct file___11 *);
	int (*fsync)(struct file___11 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___11 *, int);
	int (*lock)(struct file___11 *, int, struct file_lock___11 *);
	ssize_t (*sendpage)(struct file___11 *, struct page___12 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___11 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___11 *, long unsigned int);
	int (*flock)(struct file___11 *, int, struct file_lock___11 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___11 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___11 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___11 *, long int, struct file_lock___11 **, void **);
	long int (*fallocate)(struct file___11 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___10 *, struct file___11 *);
	ssize_t (*copy_file_range)(struct file___11 *, loff_t, struct file___11 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___11 *, loff_t, struct file___11 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___11 *, loff_t, loff_t, int);
};

struct static_call_mod___8 {
	struct static_call_mod___8 *next;
	struct module___12 *mod;
	struct static_call_site *sites;
};

struct static_call_key___8 {
	void *func;
	union {
		long unsigned int type;
		struct static_call_mod___8 *mods;
		struct static_call_site *sites;
	};
};

struct vmacache___12 {
	u64 seqnum;
	struct vm_area_struct___13 *vmas[4];
};

struct page_frag___12 {
	struct page___12 *page;
	__u32 offset;
	__u32 size;
};

struct perf_event___7;

struct thread_struct___8 {
	struct desc_struct tls_array[3];
	long unsigned int sp;
	short unsigned int es;
	short unsigned int ds;
	short unsigned int fsindex;
	short unsigned int gsindex;
	long unsigned int fsbase;
	long unsigned int gsbase;
	struct perf_event___7 *ptrace_bps[4];
	long unsigned int virtual_dr6;
	long unsigned int ptrace_dr7;
	long unsigned int cr2;
	long unsigned int trap_nr;
	long unsigned int error_code;
	struct io_bitmap *io_bitmap;
	long unsigned int iopl_emul;
	unsigned int iopl_warn: 1;
	unsigned int sig_on_uaccess_err: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u32 pkru;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct fpu fpu;
};

struct mm_struct___14;

struct pid___10;

struct nsproxy___11;

struct signal_struct___12;

struct bio_list___8;

struct backing_dev_info___7;

struct io_context___9;

struct css_set___9;

struct perf_event_context___7;

struct mem_cgroup___7;

struct request_queue___8;

struct vm_struct___11;

struct task_struct___14 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___14 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___14 *mm;
	struct mm_struct___14 *active_mm;
	struct vmacache___12 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int restore_sigmask: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___14 *real_parent;
	struct task_struct___14 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___14 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___10 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	struct posix_cputimers_work posix_cputimers_work;
	const struct cred *ptracer_cred;
	const struct cred *real_cred;
	const struct cred *cred;
	struct key *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___11 *nsproxy;
	struct signal_struct___12 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___14 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___8 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___7 *backing_dev_info;
	struct io_context___9 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___9 *cgroups;
	struct list_head cg_list;
	u32 closid;
	u32 rmid;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___7 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	long: 64;
	long: 64;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___12 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___7 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___7 *active_memcg;
	struct request_queue___8 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___14 *oom_reaper_list;
	struct vm_struct___11 *stack_vm_area;
	refcount_t stack_refcount;
	int patch_state;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	void *mce_vaddr;
	__u64 mce_kflags;
	u64 mce_addr;
	__u64 mce_ripv: 1;
	__u64 mce_whole_page: 1;
	__u64 __mce_reserved: 62;
	long: 2;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct callback_head mce_kill_me;
	int mce_count;
	struct llist_head kretprobe_instances;
	struct callback_head l1d_flush_kill;
	long: 64;
	struct thread_struct___8 thread;
};

typedef struct page___12 *pgtable_t___12;

struct address_space___11;

struct dev_pagemap___11;

struct page___12 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___11 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___12 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___12 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___14 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___11 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct pv_cpu_ops___9 {
	void (*io_delay)();
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	void (*write_cr4)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___8 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(long unsigned int);
	void (*invalidate_io_bitmap)();
	void (*update_io_bitmap)();
	void (*wbinvd)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int);
	void (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_msr_safe)(unsigned int, int *);
	int (*write_msr_safe)(unsigned int, unsigned int, unsigned int);
	u64 (*read_pmc)(int);
	void (*start_context_switch)(struct task_struct___14 *);
	void (*end_context_switch)(struct task_struct___14 *);
};

struct flush_tlb_info___6;

struct pv_mmu_ops___9 {
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_one_user)(long unsigned int);
	void (*flush_tlb_multi)(const struct cpumask *, const struct flush_tlb_info___6 *);
	void (*tlb_remove_table)(struct mmu_gather *, void *);
	void (*exit_mmap)(struct mm_struct___14 *);
	struct paravirt_callee_save read_cr2;
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___14 *, struct mm_struct___14 *);
	void (*dup_mmap)(struct mm_struct___14 *, struct mm_struct___14 *);
	int (*pgd_alloc)(struct mm_struct___14 *);
	void (*pgd_free)(struct mm_struct___14 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___14 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___14 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___14 *, long unsigned int);
	void (*alloc_p4d)(struct mm_struct___14 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*release_p4d)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	pte_t (*ptep_modify_prot_start)(struct vm_area_struct___13 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct vm_area_struct___13 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_p4d)(p4d_t *, p4d_t);
	struct paravirt_callee_save p4d_val;
	struct paravirt_callee_save make_p4d;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

struct flush_tlb_info___6 {
	struct mm_struct___14 *mm;
	long unsigned int start;
	long unsigned int end;
	u64 new_tlb_gen;
	unsigned int initiating_cpu;
	u8 stride_shift;
	u8 freed_tables;
};

struct mmu_gather_batch___2 {
	struct mmu_gather_batch___2 *next;
	unsigned int nr;
	unsigned int max;
	struct page___12 *pages[0];
};

struct mmu_gather {
	struct mm_struct___14 *mm;
	struct mmu_table_batch *batch;
	long unsigned int start;
	long unsigned int end;
	unsigned int fullmm: 1;
	unsigned int need_flush_all: 1;
	unsigned int freed_tables: 1;
	unsigned int cleared_ptes: 1;
	unsigned int cleared_pmds: 1;
	unsigned int cleared_puds: 1;
	unsigned int cleared_p4ds: 1;
	unsigned int vma_exec: 1;
	unsigned int vma_huge: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int batch_count;
	struct mmu_gather_batch___2 *active;
	struct mmu_gather_batch___2 local;
	struct page___12 *__pages[8];
};

struct core_state___12;

struct mm_struct___14 {
	struct {
		struct vm_area_struct___13 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___11 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int mmap_compat_base;
		long unsigned int mmap_compat_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[48];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___12 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___14 *owner;
		struct user_namespace *user_ns;
		struct file___11 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		bool tlb_flush_batched;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct vm_operations_struct___11;

struct vm_area_struct___13 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___13 *vm_next;
	struct vm_area_struct___13 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___14 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___11 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___11 *vm_file;
	struct file___11 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct paravirt_patch_template___9 {
	struct pv_cpu_ops___9 cpu;
	struct pv_irq_ops irq;
	struct pv_mmu_ops___9 mmu;
	struct pv_lock_ops lock;
};

struct tracepoint___8 {
	const char *name;
	struct static_key key;
	struct static_call_key___8 *static_call_key;
	void *static_call_tramp;
	void *iterator;
	int (*regfunc)();
	void (*unregfunc)();
	struct tracepoint_func *funcs;
};

struct bpf_raw_event_map___8 {
	struct tracepoint___8 *tp;
	void *bpf_func;
	u32 num_args;
	u32 writable_size;
	long: 64;
};

struct seq_operations___10 {
	void * (*start)(struct seq_file___10 *, loff_t *);
	void (*stop)(struct seq_file___10 *, void *);
	void * (*next)(struct seq_file___10 *, void *, loff_t *);
	int (*show)(struct seq_file___10 *, void *);
};

struct hw_perf_event___7 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___14 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	union {
		struct {
			u64 last_period;
			local64_t period_left;
		};
		struct {
			u64 saved_metric;
			u64 saved_slots;
		};
	};
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___7)(struct perf_event___7 *, struct perf_sample_data *, struct pt_regs *);

struct pmu___7;

struct fasync_struct___11;

struct pid_namespace___10;

struct trace_event_call___7;

struct perf_cgroup___7;

struct perf_event___7 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___7 *group_leader;
	struct pmu___7 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___7 hw;
	struct perf_event_context___7 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___7 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___14 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct perf_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___11 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	long unsigned int pending_addr;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	struct perf_addr_filter_range *addr_filter_ranges;
	long unsigned int addr_filters_gen;
	struct perf_event___7 *aux_event;
	void (*destroy)(struct perf_event___7 *);
	struct callback_head callback_head;
	struct pid_namespace___10 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___7 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___7 orig_overflow_handler;
	struct bpf_prog *prog;
	u64 bpf_cookie;
	struct trace_event_call___7 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___7 *cgrp;
	void *security;
	struct list_head sb_list;
};

struct address_space_operations___11;

struct address_space___11 {
	struct inode___11 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___11 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct dev_pagemap_ops___11;

struct dev_pagemap___11 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___11 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vfsmount___11;

struct path___11 {
	struct vfsmount___11 *mnt;
	struct dentry___11 *dentry;
};

struct fown_struct___10 {
	rwlock_t lock;
	struct pid___10 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___11 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	long: 64;
	long: 64;
	struct path___11 f_path;
	struct inode___11 *f_inode;
	const struct file_operations___11 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___10 f_owner;
	const struct cred *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___11 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___11;

struct vm_operations_struct___11 {
	void (*open)(struct vm_area_struct___13 *);
	void (*close)(struct vm_area_struct___13 *);
	int (*may_split)(struct vm_area_struct___13 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___13 *);
	int (*mprotect)(struct vm_area_struct___13 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___11 *);
	vm_fault_t (*huge_fault)(struct vm_fault___11 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___11 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___13 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___11 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___11 *);
	int (*access)(struct vm_area_struct___13 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___13 *);
	int (*set_policy)(struct vm_area_struct___13 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___13 *, long unsigned int);
	struct page___12 * (*find_special_page)(struct vm_area_struct___13 *, long unsigned int);
};

struct core_thread___12 {
	struct task_struct___14 *task;
	struct core_thread___12 *next;
};

struct core_state___12 {
	atomic_t nr_threads;
	struct core_thread___12 dumper;
	struct completion startup;
};

struct vm_fault___11 {
	const struct {
		struct vm_area_struct___13 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___12 *cow_page;
	struct page___12 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___12 prealloc_pte;
};

struct pglist_data___7;

struct lruvec___7 {
	struct list_head lists[5];
	spinlock_t lru_lock;
	long unsigned int anon_cost;
	long unsigned int file_cost;
	atomic_long_t nonresident_age;
	long unsigned int refaults[2];
	long unsigned int flags;
	struct pglist_data___7 *pgdat;
};

struct zone___7 {
	long unsigned int _watermark[3];
	long unsigned int watermark_boost;
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[5];
	int node;
	struct pglist_data___7 *zone_pgdat;
	struct per_cpu_pages *per_cpu_pageset;
	struct per_cpu_zonestat *per_cpu_zonestats;
	int pageset_high;
	int pageset_batch;
	long unsigned int zone_start_pfn;
	atomic_long_t managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int present_early_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	seqlock_t span_seqlock;
	int initialized;
	int: 32;
	struct zone_padding _pad1_;
	struct free_area free_area[11];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	long unsigned int compact_init_migrate_pfn;
	long unsigned int compact_init_free_pfn;
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	short: 16;
	struct zone_padding _pad3_;
	atomic_long_t vm_stat[11];
	atomic_long_t vm_numa_event[6];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___7 {
	struct zone___7 *zone;
	int zone_idx;
};

struct zonelist___7 {
	struct zoneref___7 _zonerefs[5121];
};

struct pglist_data___7 {
	struct zone___7 node_zones[5];
	struct zonelist___7 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___14 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_highest_zoneidx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_highest_zoneidx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___14 *kcompactd;
	bool proactive_compact_trigger;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct deferred_split deferred_split_queue;
	struct lruvec___7 __lruvec;
	long unsigned int flags;
	long: 64;
	struct zone_padding _pad2_;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[39];
};

struct irq_domain_ops___6;

struct fwnode_handle___10;

struct irq_domain___6 {
	struct list_head link;
	const char *name;
	const struct irq_domain_ops___6 *ops;
	void *host_data;
	unsigned int flags;
	unsigned int mapcount;
	struct fwnode_handle___10 *fwnode;
	enum irq_domain_bus_token bus_token;
	struct irq_domain_chip_generic *gc;
	struct irq_domain___6 *parent;
	irq_hw_number_t hwirq_max;
	unsigned int revmap_size;
	struct xarray revmap_tree;
	struct mutex revmap_mutex;
	struct irq_data *revmap[0];
};

struct shrink_control___7 {
	gfp_t gfp_mask;
	int nid;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	struct mem_cgroup___7 *memcg;
};

struct cgroup___9;

struct cgroup_subsys___9;

struct cgroup_subsys_state___9 {
	struct cgroup___9 *cgroup;
	struct cgroup_subsys___9 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___9 *parent;
};

struct kernfs_node___11;

struct cgroup_file___9 {
	struct kernfs_node___11 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct obj_cgroup___7;

struct mem_cgroup_per_node___7;

struct mem_cgroup___7 {
	struct cgroup_subsys_state___9 css;
	struct mem_cgroup_id id;
	struct page_counter memory;
	union {
		struct page_counter swap;
		struct page_counter memsw;
	};
	struct page_counter kmem;
	struct page_counter tcpmem;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool oom_group;
	bool oom_lock;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___9 events_file;
	struct cgroup_file___9 events_local_file;
	struct cgroup_file___9 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	struct memcg_vmstats vmstats;
	atomic_long_t memory_events[8];
	atomic_long_t memory_events_local[8];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct obj_cgroup___7 *objcg;
	struct list_head objcg_list;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad2_;
	atomic_t moving_account;
	struct task_struct___14 *move_lock_task;
	struct memcg_vmstats_percpu *vmstats_percpu;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct memcg_cgwb_frn cgwb_frn[4];
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct deferred_split deferred_split_queue;
	struct mem_cgroup_per_node___7 *nodeinfo[0];
	long: 64;
};

struct shrinker___7 {
	long unsigned int (*count_objects)(struct shrinker___7 *, struct shrink_control___7 *);
	long unsigned int (*scan_objects)(struct shrinker___7 *, struct shrink_control___7 *);
	long int batch;
	int seeks;
	unsigned int flags;
	struct list_head list;
	int id;
	atomic_long_t *nr_deferred;
};

struct dev_pagemap_ops___11 {
	void (*page_free)(struct page___12 *);
	void (*kill)(struct dev_pagemap___11 *);
	void (*cleanup)(struct dev_pagemap___11 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___11 *);
};

struct upid___10 {
	int nr;
	struct pid_namespace___10 *ns;
};

struct pid_namespace___10 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___14 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___10 *parent;
	struct fs_pin *bacct;
	struct user_namespace *user_ns;
	struct ucounts *ucounts;
	int reboot;
	struct ns_common ns;
};

struct pid___10 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___10 numbers[1];
};

struct signal_struct___12 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___14 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___14 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper;
	unsigned int has_child_subreaper;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___10 *pids[4];
	struct pid___10 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___14 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct cgroup_namespace___9;

struct nsproxy___11 {
	atomic_t count;
	struct uts_namespace *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___10 *pid_ns_for_children;
	struct net *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___9 *cgroup_ns;
};

struct bio___8;

struct bio_list___8 {
	struct bio___8 *head;
	struct bio___8 *tail;
};

struct bdi_writeback___7 {
	struct backing_dev_info___7 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	atomic_t writeback_inodes;
	struct percpu_counter stat[4];
	long unsigned int congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	struct delayed_work bw_dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___9 *memcg_css;
	struct cgroup_subsys_state___9 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	struct list_head b_attached;
	struct list_head offline_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
};

struct device___12;

struct backing_dev_info___7 {
	u64 id;
	struct rb_node rb_node;
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___7 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct mutex cgwb_release_mutex;
	struct rw_semaphore wb_switch_rwsem;
	wait_queue_head_t wb_waitq;
	struct device___12 *dev;
	char dev_name[64];
	struct device___12 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___11 *debug_dir;
};

struct io_cq___8;

struct io_context___9 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	struct xarray icq_tree;
	struct io_cq___8 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct css_set___9 {
	struct cgroup_subsys_state___9 *subsys[14];
	refcount_t refcount;
	struct css_set___9 *dom_cset;
	struct cgroup___9 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___9 *mg_src_cgrp;
	struct cgroup___9 *mg_dst_cgrp;
	struct css_set___9 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___7 {
	struct pmu___7 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	int rotate_necessary;
	refcount_t refcount;
	struct task_struct___14 *task;
	u64 time;
	u64 timestamp;
	u64 timeoffset;
	struct perf_event_context___7 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

struct kset___11;

struct kobj_type___11;

struct kobject___12 {
	const char *name;
	struct list_head entry;
	struct kobject___12 *parent;
	struct kset___11 *kset;
	struct kobj_type___11 *ktype;
	struct kernfs_node___11 *sd;
	struct kref kref;
	unsigned int state_initialized;
	unsigned int state_in_sysfs;
	unsigned int state_add_uevent_sent;
	unsigned int state_remove_uevent_sent;
	unsigned int uevent_suppress;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct blk_integrity_profile___8;

struct blk_integrity___8 {
	const struct blk_integrity_profile___8 *profile;
	unsigned char flags;
	unsigned char tuple_size;
	unsigned char interval_exp;
	unsigned char tag_size;
};

struct bio_set___8 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	struct bio_alloc_cache *cache;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	unsigned int back_pad;
	spinlock_t rescue_lock;
	struct bio_list___8 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	struct hlist_node cpuhp_dead;
};

struct request___8;

struct elevator_queue___8;

struct gendisk___8;

struct blkcg_gq___7;

struct request_queue___8 {
	struct request___8 *last_merge;
	struct elevator_queue___8 *elevator;
	struct percpu_ref q_usage_counter;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	const struct blk_mq_ops *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx **queue_hw_ctx;
	unsigned int nr_hw_queues;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	spinlock_t queue_lock;
	struct gendisk___8 *disk;
	struct kobject___12 kobj;
	struct kobject___12 *mq_kobj;
	struct blk_integrity___8 integrity;
	struct device___12 *dev;
	enum rpm_status rpm_status;
	long unsigned int nr_requests;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_keyslot_manager *ksm;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	atomic_t nr_active_requests_shared_sbitmap;
	struct sbitmap_queue sched_bitmap_tags;
	struct sbitmap_queue sched_breserved_tags;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___7 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int required_elevator_features;
	unsigned int nr_zones;
	long unsigned int *conv_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int max_open_zones;
	unsigned int max_active_zones;
	int node;
	struct mutex debugfs_mutex;
	struct blk_trace *blk_trace;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	struct mutex sysfs_dir_lock;
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	int mq_freeze_depth;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct mutex mq_freeze_lock;
	struct blk_mq_tag_set *tag_set;
	struct list_head tag_set_list;
	struct bio_set___8 bio_split;
	struct dentry___11 *debugfs_dir;
	struct dentry___11 *sched_debugfs_dir;
	struct dentry___11 *rqos_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	u64 write_hints[5];
};

struct vm_struct___11 {
	struct vm_struct___11 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___12 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct dentry_operations___11;

struct dentry___11 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___11 *d_parent;
	struct qstr d_name;
	struct inode___11 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___11 *d_op;
	struct super_block___11 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___11;

struct inode___11 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___11 *i_op;
	struct super_block___11 *i_sb;
	struct address_space___11 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___7 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	long: 64;
	long: 64;
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___11 *i_fop;
		void (*free_inode)(struct inode___11 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___11 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct cdev___5 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___11 {
	int (*d_revalidate)(struct dentry___11 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___11 *, unsigned int);
	int (*d_hash)(const struct dentry___11 *, struct qstr *);
	int (*d_compare)(const struct dentry___11 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___11 *);
	int (*d_init)(struct dentry___11 *);
	void (*d_release)(struct dentry___11 *);
	void (*d_prune)(struct dentry___11 *);
	void (*d_iput)(struct dentry___11 *, struct inode___11 *);
	char * (*d_dname)(struct dentry___11 *, char *, int);
	struct vfsmount___11 * (*d_automount)(struct path___11 *);
	int (*d_manage)(const struct path___11 *, bool);
	struct dentry___11 * (*d_real)(struct dentry___11 *, const struct inode___11 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___11;

struct mem_dqinfo___11 {
	struct quota_format_type___11 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___11;

struct quota_info___11 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___11 *files[3];
	struct mem_dqinfo___11 info[3];
	const struct quota_format_ops___11 *ops[3];
};

struct rcuwait___11 {
	struct task_struct___14 *task;
};

struct percpu_rw_semaphore___11 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___11 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___11 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___11 rw_sem[3];
};

struct super_operations___11;

struct dquot_operations___11;

struct quotactl_ops___11;

struct block_device___8;

struct super_block___11 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___11 *s_type;
	const struct super_operations___11 *s_op;
	const struct dquot_operations___11 *dq_op;
	const struct quotactl_ops___11 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___11 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___8 *s_bdev;
	struct backing_dev_info___7 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___11 s_dquot;
	struct sb_writers___11 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___11 *s_d_op;
	int cleancache_poolid;
	struct shrinker___7 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___11 {
	struct dentry___11 *mnt_root;
	struct super_block___11 *mnt_sb;
	int mnt_flags;
	struct user_namespace *mnt_userns;
};

struct psi_group___9 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___14 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___9;

struct cgroup_rstat_cpu___9;

struct cgroup___9 {
	struct cgroup_subsys_state___9 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___11 *kn;
	struct cgroup_file___9 procs_file;
	struct cgroup_file___9 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___9 *subsys[14];
	struct cgroup_root___9 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___9 *dom_cgrp;
	struct cgroup___9 *old_dom_cgrp;
	struct cgroup_rstat_cpu___9 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___9 psi;
	struct cgroup_bpf bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct io_cq___8 {
	struct request_queue___8 *q;
	struct io_context___9 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct wait_page_queue___6;

struct kiocb___11 {
	struct file___11 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___11 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___6 *ki_waitq;
	};
};

struct iattr___11 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___11 *ia_file;
};

struct dquot___11 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___11 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___11 {
	int qf_fmt_id;
	const struct quota_format_ops___11 *qf_ops;
	struct module___12 *qf_owner;
	struct quota_format_type___11 *qf_next;
};

struct quota_format_ops___11 {
	int (*check_quota_file)(struct super_block___11 *, int);
	int (*read_file_info)(struct super_block___11 *, int);
	int (*write_file_info)(struct super_block___11 *, int);
	int (*free_file_info)(struct super_block___11 *, int);
	int (*read_dqblk)(struct dquot___11 *);
	int (*commit_dqblk)(struct dquot___11 *);
	int (*release_dqblk)(struct dquot___11 *);
	int (*get_next_id)(struct super_block___11 *, struct kqid *);
};

struct dquot_operations___11 {
	int (*write_dquot)(struct dquot___11 *);
	struct dquot___11 * (*alloc_dquot)(struct super_block___11 *, int);
	void (*destroy_dquot)(struct dquot___11 *);
	int (*acquire_dquot)(struct dquot___11 *);
	int (*release_dquot)(struct dquot___11 *);
	int (*mark_dirty)(struct dquot___11 *);
	int (*write_info)(struct super_block___11 *, int);
	qsize_t * (*get_reserved_space)(struct inode___11 *);
	int (*get_projid)(struct inode___11 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___11 *, qsize_t *);
	int (*get_next_id)(struct super_block___11 *, struct kqid *);
};

struct quotactl_ops___11 {
	int (*quota_on)(struct super_block___11 *, int, int, const struct path___11 *);
	int (*quota_off)(struct super_block___11 *, int);
	int (*quota_enable)(struct super_block___11 *, unsigned int);
	int (*quota_disable)(struct super_block___11 *, unsigned int);
	int (*quota_sync)(struct super_block___11 *, int);
	int (*set_info)(struct super_block___11 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___11 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___11 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___11 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___11 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___11 *, unsigned int);
};

struct module_kobject___11 {
	struct kobject___12 kobj;
	struct module___12 *mod;
	struct kobject___12 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___11 {
	struct module___12 *mod;
	struct latch_tree_node node;
};

struct module_layout___11 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___11 mtn;
};

struct module_attribute___11;

struct kernel_param___11;

struct module___12 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___11 mkobj;
	struct module_attribute___11 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___12 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___11 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___11 core_layout;
	struct module_layout___11 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map___8 *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___7 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	int num_static_call_sites;
	struct static_call_site *static_call_sites;
	bool klp;
	bool klp_alive;
	struct klp_modinfo *klp_info;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct wait_page_queue___6 {
	struct page___12 *page;
	int bit_nr;
	wait_queue_entry_t wait;
};

struct writeback_control___7;

struct readahead_control___6;

struct swap_info_struct___5;

struct address_space_operations___11 {
	int (*writepage)(struct page___12 *, struct writeback_control___7 *);
	int (*readpage)(struct file___11 *, struct page___12 *);
	int (*writepages)(struct address_space___11 *, struct writeback_control___7 *);
	int (*set_page_dirty)(struct page___12 *);
	int (*readpages)(struct file___11 *, struct address_space___11 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___6 *);
	int (*write_begin)(struct file___11 *, struct address_space___11 *, loff_t, unsigned int, unsigned int, struct page___12 **, void **);
	int (*write_end)(struct file___11 *, struct address_space___11 *, loff_t, unsigned int, unsigned int, struct page___12 *, void *);
	sector_t (*bmap)(struct address_space___11 *, sector_t);
	void (*invalidatepage)(struct page___12 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___12 *, gfp_t);
	void (*freepage)(struct page___12 *);
	ssize_t (*direct_IO)(struct kiocb___11 *, struct iov_iter___9 *);
	int (*migratepage)(struct address_space___11 *, struct page___12 *, struct page___12 *, enum migrate_mode);
	bool (*isolate_page)(struct page___12 *, isolate_mode_t);
	void (*putback_page)(struct page___12 *);
	int (*launder_page)(struct page___12 *);
	int (*is_partially_uptodate)(struct page___12 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___12 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___11 *, struct page___12 *);
	int (*swap_activate)(struct swap_info_struct___5 *, struct file___11 *, sector_t *);
	void (*swap_deactivate)(struct file___11 *);
};

struct writeback_control___7 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate;
	unsigned int for_background;
	unsigned int tagged_writepages;
	unsigned int for_reclaim;
	unsigned int range_cyclic;
	unsigned int for_sync;
	unsigned int no_cgroup_owner;
	unsigned int punt_to_cgroup;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bdi_writeback___7 *wb;
	struct inode___11 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
};

struct readahead_control___6 {
	struct file___11 *file;
	struct address_space___11 *mapping;
	struct file_ra_state *ra;
	long unsigned int _index;
	unsigned int _nr_pages;
	unsigned int _batch_count;
};

struct bio_vec___9;

struct iov_iter___9 {
	u8 iter_type;
	bool data_source;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___9 *bvec;
		struct xarray *xarray;
		struct pipe_inode_info *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			unsigned int head;
			unsigned int start_head;
		};
		loff_t xarray_start;
	};
};

struct swap_info_struct___5 {
	struct percpu_ref users;
	long unsigned int flags;
	short int prio;
	struct plist_node list;
	signed char type;
	unsigned int max;
	unsigned char *swap_map;
	struct swap_cluster_info *cluster_info;
	struct swap_cluster_list free_clusters;
	unsigned int lowest_bit;
	unsigned int highest_bit;
	unsigned int pages;
	unsigned int inuse_pages;
	unsigned int cluster_next;
	unsigned int cluster_nr;
	unsigned int *cluster_next_cpu;
	struct percpu_cluster *percpu_cluster;
	struct rb_root swap_extent_root;
	struct block_device___8 *bdev;
	struct file___11 *swap_file;
	unsigned int old_block_size;
	struct completion comp;
	long unsigned int *frontswap_map;
	atomic_t frontswap_pages;
	spinlock_t lock;
	spinlock_t cont_lock;
	struct work_struct discard_work;
	struct swap_cluster_list discard_clusters;
	struct plist_node avail_lists[0];
};

struct inode_operations___11 {
	struct dentry___11 * (*lookup)(struct inode___11 *, struct dentry___11 *, unsigned int);
	const char * (*get_link)(struct dentry___11 *, struct inode___11 *, struct delayed_call *);
	int (*permission)(struct user_namespace *, struct inode___11 *, int);
	struct posix_acl * (*get_acl)(struct inode___11 *, int, bool);
	int (*readlink)(struct dentry___11 *, char *, int);
	int (*create)(struct user_namespace *, struct inode___11 *, struct dentry___11 *, umode_t, bool);
	int (*link)(struct dentry___11 *, struct inode___11 *, struct dentry___11 *);
	int (*unlink)(struct inode___11 *, struct dentry___11 *);
	int (*symlink)(struct user_namespace *, struct inode___11 *, struct dentry___11 *, const char *);
	int (*mkdir)(struct user_namespace *, struct inode___11 *, struct dentry___11 *, umode_t);
	int (*rmdir)(struct inode___11 *, struct dentry___11 *);
	int (*mknod)(struct user_namespace *, struct inode___11 *, struct dentry___11 *, umode_t, dev_t);
	int (*rename)(struct user_namespace *, struct inode___11 *, struct dentry___11 *, struct inode___11 *, struct dentry___11 *, unsigned int);
	int (*setattr)(struct user_namespace *, struct dentry___11 *, struct iattr___11 *);
	int (*getattr)(struct user_namespace *, const struct path___11 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___11 *, char *, size_t);
	int (*fiemap)(struct inode___11 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___11 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___11 *, struct dentry___11 *, struct file___11 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace *, struct inode___11 *, struct dentry___11 *, umode_t);
	int (*set_acl)(struct user_namespace *, struct inode___11 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace *, struct dentry___11 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___11 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___11 {
	void (*fl_copy_lock)(struct file_lock___11 *, struct file_lock___11 *);
	void (*fl_release_private)(struct file_lock___11 *);
};

struct lock_manager_operations___11;

struct file_lock___11 {
	struct file_lock___11 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___11 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___11 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___11 *fl_ops;
	const struct lock_manager_operations___11 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___11 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___11 *);
	int (*lm_grant)(struct file_lock___11 *, int);
	bool (*lm_break)(struct file_lock___11 *);
	int (*lm_change)(struct file_lock___11 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___11 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___11 *);
};

struct fasync_struct___11 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___11 *fa_next;
	struct file___11 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___11 {
	struct inode___11 * (*alloc_inode)(struct super_block___11 *);
	void (*destroy_inode)(struct inode___11 *);
	void (*free_inode)(struct inode___11 *);
	void (*dirty_inode)(struct inode___11 *, int);
	int (*write_inode)(struct inode___11 *, struct writeback_control___7 *);
	int (*drop_inode)(struct inode___11 *);
	void (*evict_inode)(struct inode___11 *);
	void (*put_super)(struct super_block___11 *);
	int (*sync_fs)(struct super_block___11 *, int);
	int (*freeze_super)(struct super_block___11 *);
	int (*freeze_fs)(struct super_block___11 *);
	int (*thaw_super)(struct super_block___11 *);
	int (*unfreeze_fs)(struct super_block___11 *);
	int (*statfs)(struct dentry___11 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___11 *, int *, char *);
	void (*umount_begin)(struct super_block___11 *);
	int (*show_options)(struct seq_file___10 *, struct dentry___11 *);
	int (*show_devname)(struct seq_file___10 *, struct dentry___11 *);
	int (*show_path)(struct seq_file___10 *, struct dentry___11 *);
	int (*show_stats)(struct seq_file___10 *, struct dentry___11 *);
	ssize_t (*quota_read)(struct super_block___11 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___11 *, int, const char *, size_t, loff_t);
	struct dquot___11 ** (*get_dquots)(struct inode___11 *);
	long int (*nr_cached_objects)(struct super_block___11 *, struct shrink_control___7 *);
	long int (*free_cached_objects)(struct super_block___11 *, struct shrink_control___7 *);
	struct file___11 * (*real_loop)(struct file___11 *);
};

struct wakeup_source___11;

struct dev_pm_info___11 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___11 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___12 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___11;

struct bus_type___11;

struct device_driver___11;

struct dev_pm_domain___11;

struct device_node___7;

struct class___11;

struct attribute_group___12;

struct device___12 {
	struct kobject___12 kobj;
	struct device___12 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___11 *type;
	struct bus_type___11 *bus;
	struct device_driver___11 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___11 power;
	struct dev_pm_domain___11 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___6 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___7 *of_node;
	struct fwnode_handle___10 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___11 *class;
	const struct attribute_group___12 **groups;
	void (*release)(struct device___12 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct block_device___8 {
	sector_t bd_start_sect;
	struct disk_stats *bd_stats;
	long unsigned int bd_stamp;
	bool bd_read_only;
	dev_t bd_dev;
	int bd_openers;
	struct inode___11 *bd_inode;
	struct super_block___11 *bd_super;
	void *bd_claiming;
	struct device___12 bd_device;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct kobject___12 *bd_holder_dir;
	u8 bd_partno;
	spinlock_t bd_size_lock;
	struct gendisk___8 *bd_disk;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	struct super_block___11 *bd_fsfreeze_sb;
	struct partition_meta_info *bd_meta_info;
};

typedef void (*poll_queue_proc___8)(struct file___11 *, wait_queue_head_t *, struct poll_table_struct___8 *);

struct poll_table_struct___8 {
	poll_queue_proc___8 _qproc;
	__poll_t _key;
};

struct seq_file___10 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___10 *op;
	int poll_event;
	const struct file___11 *file;
	void *private;
};

typedef void bio_end_io_t___8(struct bio___8 *);

struct bio_vec___9 {
	struct page___12 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___8;

struct bio___8 {
	struct bio___8 *bi_next;
	struct block_device___8 *bi_bdev;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	atomic_t __bi_remaining;
	struct bvec_iter bi_iter;
	bio_end_io_t___8 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___7 *bi_blkg;
	struct bio_issue bi_issue;
	u64 bi_iocost_cost;
	struct bio_crypt_ctx *bi_crypt_context;
	union {
		struct bio_integrity_payload___8 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___9 *bi_io_vec;
	struct bio_set___8 *bi_pool;
	struct bio_vec___9 bi_inline_vecs[0];
};

struct fwnode_operations___10;

struct fwnode_handle___10 {
	struct fwnode_handle___10 *secondary;
	const struct fwnode_operations___10 *ops;
	struct device___12 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct fwnode_reference_args___10;

struct fwnode_endpoint___10;

struct fwnode_operations___10 {
	struct fwnode_handle___10 * (*get)(struct fwnode_handle___10 *);
	void (*put)(struct fwnode_handle___10 *);
	bool (*device_is_available)(const struct fwnode_handle___10 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___10 *, const struct device___12 *);
	bool (*property_present)(const struct fwnode_handle___10 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___10 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___10 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___10 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___10 *);
	struct fwnode_handle___10 * (*get_parent)(const struct fwnode_handle___10 *);
	struct fwnode_handle___10 * (*get_next_child_node)(const struct fwnode_handle___10 *, struct fwnode_handle___10 *);
	struct fwnode_handle___10 * (*get_named_child_node)(const struct fwnode_handle___10 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___10 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___10 *);
	struct fwnode_handle___10 * (*graph_get_next_endpoint)(const struct fwnode_handle___10 *, struct fwnode_handle___10 *);
	struct fwnode_handle___10 * (*graph_get_remote_endpoint)(const struct fwnode_handle___10 *);
	struct fwnode_handle___10 * (*graph_get_port_parent)(struct fwnode_handle___10 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___10 *, struct fwnode_endpoint___10 *);
	int (*add_links)(struct fwnode_handle___10 *);
};

struct fwnode_endpoint___10 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___10 *local_fwnode;
};

struct fwnode_reference_args___10 {
	struct fwnode_handle___10 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct kernfs_root___11;

struct kernfs_elem_dir___11 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___11 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___11;

struct kernfs_root___11 {
	struct kernfs_node___11 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___11 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___11 {
	struct kernfs_node___11 *target_kn;
};

struct kernfs_ops___11;

struct kernfs_elem_attr___11 {
	const struct kernfs_ops___11 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___11 *notify_next;
};

struct kernfs_node___11 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___11 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___11 dir;
		struct kernfs_elem_symlink___11 symlink;
		struct kernfs_elem_attr___11 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___11;

struct kernfs_ops___11 {
	int (*open)(struct kernfs_open_file___11 *);
	void (*release)(struct kernfs_open_file___11 *);
	int (*seq_show)(struct seq_file___10 *, void *);
	void * (*seq_start)(struct seq_file___10 *, loff_t *);
	void * (*seq_next)(struct seq_file___10 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___10 *, void *);
	ssize_t (*read)(struct kernfs_open_file___11 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___11 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___11 *, struct poll_table_struct___8 *);
	int (*mmap)(struct kernfs_open_file___11 *, struct vm_area_struct___13 *);
};

struct kernfs_syscall_ops___11 {
	int (*show_options)(struct seq_file___10 *, struct kernfs_root___11 *);
	int (*mkdir)(struct kernfs_node___11 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___11 *);
	int (*rename)(struct kernfs_node___11 *, struct kernfs_node___11 *, const char *);
	int (*show_path)(struct seq_file___10 *, struct kernfs_node___11 *, struct kernfs_root___11 *);
};

struct kernfs_open_file___11 {
	struct kernfs_node___11 *kn;
	struct file___11 *file;
	struct seq_file___10 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped;
	bool released;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___11 *vm_ops;
};

struct bin_attribute___12;

struct attribute_group___12 {
	const char *name;
	umode_t (*is_visible)(struct kobject___12 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___12 *, struct bin_attribute___12 *, int);
	struct attribute **attrs;
	struct bin_attribute___12 **bin_attrs;
};

struct bin_attribute___12 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___11 * (*f_mapping)();
	ssize_t (*read)(struct file___11 *, struct kobject___12 *, struct bin_attribute___12 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___11 *, struct kobject___12 *, struct bin_attribute___12 *, char *, loff_t, size_t);
	int (*mmap)(struct file___11 *, struct kobject___12 *, struct bin_attribute___12 *, struct vm_area_struct___13 *);
};

struct sysfs_ops___11 {
	ssize_t (*show)(struct kobject___12 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___12 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___11;

struct kset___11 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___12 kobj;
	const struct kset_uevent_ops___11 *uevent_ops;
};

struct kobj_type___11 {
	void (*release)(struct kobject___12 *);
	const struct sysfs_ops___11 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___12 **default_groups;
	const struct kobj_ns_type_operations * (*child_ns_type)(struct kobject___12 *);
	const void * (*namespace)(struct kobject___12 *);
	void (*get_ownership)(struct kobject___12 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___11 {
	int (* const filter)(struct kset___11 *, struct kobject___12 *);
	const char * (* const name)(struct kset___11 *, struct kobject___12 *);
	int (* const uevent)(struct kset___11 *, struct kobject___12 *, struct kobj_uevent_env *);
};

struct dev_pm_ops___11 {
	int (*prepare)(struct device___12 *);
	void (*complete)(struct device___12 *);
	int (*suspend)(struct device___12 *);
	int (*resume)(struct device___12 *);
	int (*freeze)(struct device___12 *);
	int (*thaw)(struct device___12 *);
	int (*poweroff)(struct device___12 *);
	int (*restore)(struct device___12 *);
	int (*suspend_late)(struct device___12 *);
	int (*resume_early)(struct device___12 *);
	int (*freeze_late)(struct device___12 *);
	int (*thaw_early)(struct device___12 *);
	int (*poweroff_late)(struct device___12 *);
	int (*restore_early)(struct device___12 *);
	int (*suspend_noirq)(struct device___12 *);
	int (*resume_noirq)(struct device___12 *);
	int (*freeze_noirq)(struct device___12 *);
	int (*thaw_noirq)(struct device___12 *);
	int (*poweroff_noirq)(struct device___12 *);
	int (*restore_noirq)(struct device___12 *);
	int (*runtime_suspend)(struct device___12 *);
	int (*runtime_resume)(struct device___12 *);
	int (*runtime_idle)(struct device___12 *);
};

struct wakeup_source___11 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___12 *dev;
	bool active;
	bool autosleep_enabled;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___11 {
	struct dev_pm_ops___11 ops;
	int (*start)(struct device___12 *);
	void (*detach)(struct device___12 *, bool);
	int (*activate)(struct device___12 *);
	void (*sync)(struct device___12 *);
	void (*dismiss)(struct device___12 *);
};

struct bus_type___11 {
	const char *name;
	const char *dev_name;
	struct device___12 *dev_root;
	const struct attribute_group___12 **bus_groups;
	const struct attribute_group___12 **dev_groups;
	const struct attribute_group___12 **drv_groups;
	int (*match)(struct device___12 *, struct device_driver___11 *);
	int (*uevent)(struct device___12 *, struct kobj_uevent_env *);
	int (*probe)(struct device___12 *);
	void (*sync_state)(struct device___12 *);
	void (*remove)(struct device___12 *);
	void (*shutdown)(struct device___12 *);
	int (*online)(struct device___12 *);
	int (*offline)(struct device___12 *);
	int (*suspend)(struct device___12 *, pm_message_t);
	int (*resume)(struct device___12 *);
	int (*num_vf)(struct device___12 *);
	int (*dma_configure)(struct device___12 *);
	const struct dev_pm_ops___11 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___11 {
	const char *name;
	struct bus_type___11 *bus;
	struct module___12 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___12 *);
	void (*sync_state)(struct device___12 *);
	int (*remove)(struct device___12 *);
	void (*shutdown)(struct device___12 *);
	int (*suspend)(struct device___12 *, pm_message_t);
	int (*resume)(struct device___12 *);
	const struct attribute_group___12 **groups;
	const struct attribute_group___12 **dev_groups;
	const struct dev_pm_ops___11 *pm;
	void (*coredump)(struct device___12 *);
	struct driver_private *p;
};

struct device_type___11 {
	const char *name;
	const struct attribute_group___12 **groups;
	int (*uevent)(struct device___12 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___12 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___12 *);
	const struct dev_pm_ops___11 *pm;
};

struct class___11 {
	const char *name;
	struct module___12 *owner;
	const struct attribute_group___12 **class_groups;
	const struct attribute_group___12 **dev_groups;
	struct kobject___12 *dev_kobj;
	int (*dev_uevent)(struct device___12 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___12 *, umode_t *);
	void (*class_release)(struct class___11 *);
	void (*dev_release)(struct device___12 *);
	int (*shutdown_pre)(struct device___12 *);
	const struct kobj_ns_type_operations *ns_type;
	const void * (*namespace)(struct device___12 *);
	void (*get_ownership)(struct device___12 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___11 *pm;
	struct subsys_private *p;
};

struct device_node___7 {
	const char *name;
	phandle phandle;
	const char *full_name;
	struct fwnode_handle___10 fwnode;
	struct property *properties;
	struct property *deadprops;
	struct device_node___7 *parent;
	struct device_node___7 *child;
	struct device_node___7 *sibling;
	long unsigned int _flags;
	void *data;
};

enum HV_GENERIC_SET_FORMAT {
	HV_GENERIC_SET_SPARSE_4K = 0,
	HV_GENERIC_SET_ALL = 1,
};

struct hv_vpset {
	u64 format;
	u64 valid_bank_mask;
	u64 bank_contents[0];
};

struct hv_tlb_flush {
	u64 address_space;
	u64 flags;
	u64 processor_mask;
	u64 gva_list[0];
};

struct hv_tlb_flush_ex {
	u64 address_space;
	u64 flags;
	struct hv_vpset hv_vp_set;
	u64 gva_list[0];
};

struct irq_fwspec___6 {
	struct fwnode_handle___10 *fwnode;
	int param_count;
	u32 param[16];
};

struct irq_domain_ops___6 {
	int (*match)(struct irq_domain___6 *, struct device_node___7 *, enum irq_domain_bus_token);
	int (*select)(struct irq_domain___6 *, struct irq_fwspec___6 *, enum irq_domain_bus_token);
	int (*map)(struct irq_domain___6 *, unsigned int, irq_hw_number_t);
	void (*unmap)(struct irq_domain___6 *, unsigned int);
	int (*xlate)(struct irq_domain___6 *, struct device_node___7 *, const u32 *, unsigned int, long unsigned int *, unsigned int *);
	int (*alloc)(struct irq_domain___6 *, unsigned int, unsigned int, void *);
	void (*free)(struct irq_domain___6 *, unsigned int, unsigned int);
	int (*activate)(struct irq_domain___6 *, struct irq_data *, bool);
	void (*deactivate)(struct irq_domain___6 *, struct irq_data *);
	int (*translate)(struct irq_domain___6 *, struct irq_fwspec___6 *, long unsigned int *, unsigned int *);
};

struct cgroup_namespace___9 {
	struct ns_common ns;
	struct user_namespace *user_ns;
	struct ucounts *ucounts;
	struct css_set___9 *root_cset;
};

struct kernel_param_ops___11 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___11 *);
	int (*get)(char *, const struct kernel_param___11 *);
	void (*free)(void *);
};

struct kparam_array___11;

struct kernel_param___11 {
	const char *name;
	struct module___12 *mod;
	const struct kernel_param_ops___11 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___11 *arr;
	};
};

struct kparam_array___11 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___11 *ops;
	void *elem;
};

struct module_attribute___11 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___11 *, struct module_kobject___11 *, char *);
	ssize_t (*store)(struct module_attribute___11 *, struct module_kobject___11 *, const char *, size_t);
	void (*setup)(struct module___12 *, const char *);
	int (*test)(struct module___12 *);
	void (*free)(struct module___12 *);
};

struct trace_event_class___7;

struct trace_event_call___7 {
	struct list_head list;
	struct trace_event_class___7 *class;
	union {
		char *name;
		struct tracepoint___8 *tp;
	};
	struct trace_event event;
	char *print_fmt;
	struct event_filter *filter;
	union {
		void *module;
		atomic_t refcnt;
	};
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
	struct bpf_prog_array *prog_array;
	int (*perf_perm)(struct trace_event_call___7 *, struct perf_event___7 *);
};

struct cftype___9;

struct cgroup_subsys___9 {
	struct cgroup_subsys_state___9 * (*css_alloc)(struct cgroup_subsys_state___9 *);
	int (*css_online)(struct cgroup_subsys_state___9 *);
	void (*css_offline)(struct cgroup_subsys_state___9 *);
	void (*css_released)(struct cgroup_subsys_state___9 *);
	void (*css_free)(struct cgroup_subsys_state___9 *);
	void (*css_reset)(struct cgroup_subsys_state___9 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___9 *, int);
	int (*css_extra_stat_show)(struct seq_file___10 *, struct cgroup_subsys_state___9 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___14 *, struct css_set___9 *);
	void (*cancel_fork)(struct task_struct___14 *, struct css_set___9 *);
	void (*fork)(struct task_struct___14 *);
	void (*exit)(struct task_struct___14 *);
	void (*release)(struct task_struct___14 *);
	void (*bind)(struct cgroup_subsys_state___9 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___9 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___9 *dfl_cftypes;
	struct cftype___9 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___9 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___9 *updated_children;
	struct cgroup___9 *updated_next;
};

struct cgroup_root___9 {
	struct kernfs_root___11 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___9 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___9 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___9 *ss;
	struct list_head node;
	struct kernfs_ops___11 *kf_ops;
	int (*open)(struct kernfs_open_file___11 *);
	void (*release)(struct kernfs_open_file___11 *);
	u64 (*read_u64)(struct cgroup_subsys_state___9 *, struct cftype___9 *);
	s64 (*read_s64)(struct cgroup_subsys_state___9 *, struct cftype___9 *);
	int (*seq_show)(struct seq_file___10 *, void *);
	void * (*seq_start)(struct seq_file___10 *, loff_t *);
	void * (*seq_next)(struct seq_file___10 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___10 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___9 *, struct cftype___9 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___9 *, struct cftype___9 *, s64);
	ssize_t (*write)(struct kernfs_open_file___11 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___11 *, struct poll_table_struct___8 *);
};

struct block_device_operations___8;

struct gendisk___8 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	short unsigned int events;
	short unsigned int event_flags;
	struct xarray part_tbl;
	struct block_device___8 *part0;
	const struct block_device_operations___8 *fops;
	struct request_queue___8 *queue;
	void *private_data;
	int flags;
	long unsigned int state;
	struct mutex open_mutex;
	unsigned int open_partitions;
	struct backing_dev_info___7 *bdi;
	struct kobject___12 *slave_dir;
	struct list_head slave_bdevs;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___12 integrity_kobj;
	struct cdrom_device_info *cdi;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	u64 diskseq;
};

struct bio_integrity_payload___8 {
	struct bio___8 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___9 *bip_vec;
	struct bio_vec___9 bip_inline_vecs[0];
};

struct blkcg___7;

struct blkg_policy_data___7;

struct blkcg_gq___7 {
	struct request_queue___8 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___7 *blkcg;
	struct blkcg_gq___7 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_iostat_set *iostat_cpu;
	struct blkg_iostat_set iostat;
	struct blkg_policy_data___7 *pd[6];
	spinlock_t async_bio_lock;
	struct bio_list___8 async_bios;
	struct work_struct async_bio_work;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
	struct callback_head callback_head;
};

typedef void integrity_prepare_fn___8(struct request___8 *);

typedef void integrity_complete_fn___8(struct request___8 *, unsigned int);

struct blk_integrity_profile___8 {
	integrity_processing_fn *generate_fn;
	integrity_processing_fn *verify_fn;
	integrity_prepare_fn___8 *prepare_fn;
	integrity_complete_fn___8 *complete_fn;
	const char *name;
};

struct block_device_operations___8 {
	blk_qc_t (*submit_bio)(struct bio___8 *);
	int (*open)(struct block_device___8 *, fmode_t);
	void (*release)(struct gendisk___8 *, fmode_t);
	int (*rw_page)(struct block_device___8 *, sector_t, struct page___12 *, unsigned int);
	int (*ioctl)(struct block_device___8 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___8 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___8 *, unsigned int);
	void (*unlock_native_capacity)(struct gendisk___8 *);
	int (*getgeo)(struct block_device___8 *, struct hd_geometry *);
	int (*set_read_only)(struct block_device___8 *, bool);
	void (*swap_slot_free_notify)(struct block_device___8 *, long unsigned int);
	int (*report_zones)(struct gendisk___8 *, sector_t, unsigned int, report_zones_cb, void *);
	char * (*devnode)(struct gendisk___8 *, umode_t *);
	struct module___12 *owner;
	const struct pr_ops *pr_ops;
	int (*alternative_gpt_sector)(struct gendisk___8 *, sector_t *);
};

typedef void rq_end_io_fn___8(struct request___8 *, blk_status_t);

struct request___8 {
	struct request_queue___8 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int tag;
	int internal_tag;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___8 *bio;
	struct bio___8 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct llist_node ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___9 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___8 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___8 *saved_end_io;
		} flush;
	};
	struct gendisk___8 *rq_disk;
	struct block_device___8 *part;
	u64 alloc_time_ns;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int stats_sectors;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	struct bio_crypt_ctx *crypt_ctx;
	struct blk_ksm_keyslot *crypt_keyslot;
	short unsigned int write_hint;
	short unsigned int ioprio;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___8 *end_io;
	void *end_io_data;
};

struct elevator_type___8;

struct elevator_mq_ops___8 {
	int (*init_sched)(struct request_queue___8 *, struct elevator_type___8 *);
	void (*exit_sched)(struct elevator_queue___8 *);
	int (*init_hctx)(struct blk_mq_hw_ctx *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx *, unsigned int);
	void (*depth_updated)(struct blk_mq_hw_ctx *);
	bool (*allow_merge)(struct request_queue___8 *, struct request___8 *, struct bio___8 *);
	bool (*bio_merge)(struct request_queue___8 *, struct bio___8 *, unsigned int);
	int (*request_merge)(struct request_queue___8 *, struct request___8 **, struct bio___8 *);
	void (*request_merged)(struct request_queue___8 *, struct request___8 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___8 *, struct request___8 *, struct request___8 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___8 *);
	void (*finish_request)(struct request___8 *);
	void (*insert_requests)(struct blk_mq_hw_ctx *, struct list_head *, bool);
	struct request___8 * (*dispatch_request)(struct blk_mq_hw_ctx *);
	bool (*has_work)(struct blk_mq_hw_ctx *);
	void (*completed_request)(struct request___8 *, u64);
	void (*requeue_request)(struct request___8 *);
	struct request___8 * (*former_request)(struct request_queue___8 *, struct request___8 *);
	struct request___8 * (*next_request)(struct request_queue___8 *, struct request___8 *);
	void (*init_icq)(struct io_cq___8 *);
	void (*exit_icq)(struct io_cq___8 *);
};

struct elv_fs_entry___8;

struct elevator_type___8 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___8 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___8 *elevator_attrs;
	const char *elevator_name;
	const char *elevator_alias;
	const unsigned int elevator_features;
	struct module___12 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
};

struct elevator_queue___8 {
	struct elevator_type___8 *type;
	void *elevator_data;
	struct kobject___12 kobj;
	struct mutex sysfs_lock;
	unsigned int registered;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hlist_head hash[64];
};

struct elv_fs_entry___8 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___8 *, char *);
	ssize_t (*store)(struct elevator_queue___8 *, const char *, size_t);
};

struct blkcg_policy_data___7;

struct blkcg___7 {
	struct cgroup_subsys_state___9 css;
	spinlock_t lock;
	refcount_t online_pin;
	struct xarray blkg_tree;
	struct blkcg_gq___7 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___7 *cpd[6];
	struct list_head all_blkcgs_node;
	char fc_app_id[129];
	struct list_head cgwb_list;
};

struct blkcg_policy_data___7 {
	struct blkcg___7 *blkcg;
	int plid;
};

struct blkg_policy_data___7 {
	struct blkcg_gq___7 *blkg;
	int plid;
};

struct mem_cgroup_reclaim_iter___7 {
	struct mem_cgroup___7 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___7 {
	struct lruvec___7 lruvec;
	struct lruvec_stats_percpu *lruvec_stats_percpu;
	struct lruvec_stats lruvec_stats;
	long unsigned int lru_zone_size[25];
	struct mem_cgroup_reclaim_iter___7 iter;
	struct shrinker_info *shrinker_info;
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	struct mem_cgroup___7 *memcg;
};

struct obj_cgroup___7 {
	struct percpu_ref refcnt;
	struct mem_cgroup___7 *memcg;
	atomic_t nr_charged_bytes;
	union {
		struct list_head list;
		struct callback_head rcu;
	};
};

struct perf_cpu_context___7;

struct perf_output_handle___7;

struct pmu___7 {
	struct list_head entry;
	struct module___12 *module;
	struct device___12 *dev;
	const struct attribute_group___12 **attr_groups;
	const struct attribute_group___12 **attr_update;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___7 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___7 *);
	void (*pmu_disable)(struct pmu___7 *);
	int (*event_init)(struct perf_event___7 *);
	void (*event_mapped)(struct perf_event___7 *, struct mm_struct___14 *);
	void (*event_unmapped)(struct perf_event___7 *, struct mm_struct___14 *);
	int (*add)(struct perf_event___7 *, int);
	void (*del)(struct perf_event___7 *, int);
	void (*start)(struct perf_event___7 *, int);
	void (*stop)(struct perf_event___7 *, int);
	void (*read)(struct perf_event___7 *);
	void (*start_txn)(struct pmu___7 *, unsigned int);
	int (*commit_txn)(struct pmu___7 *);
	void (*cancel_txn)(struct pmu___7 *);
	int (*event_idx)(struct perf_event___7 *);
	void (*sched_task)(struct perf_event_context___7 *, bool);
	struct kmem_cache *task_ctx_cache;
	void (*swap_task_ctx)(struct perf_event_context___7 *, struct perf_event_context___7 *);
	void * (*setup_aux)(struct perf_event___7 *, void **, int, bool);
	void (*free_aux)(void *);
	long int (*snapshot_aux)(struct perf_event___7 *, struct perf_output_handle___7 *, long unsigned int);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___7 *);
	int (*aux_output_match)(struct perf_event___7 *);
	int (*filter_match)(struct perf_event___7 *);
	int (*check_period)(struct perf_event___7 *, u64);
};

struct perf_cpu_context___7 {
	struct perf_event_context___7 ctx;
	struct perf_event_context___7 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___7 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
	int heap_size;
	struct perf_event___7 **heap;
	struct perf_event___7 *heap_default[2];
};

struct perf_output_handle___7 {
	struct perf_event___7 *event;
	struct perf_buffer *rb;
	long unsigned int wakeup;
	long unsigned int size;
	u64 aux_flags;
	union {
		void *addr;
		long unsigned int head;
	};
	int page;
};

struct perf_cgroup___7 {
	struct cgroup_subsys_state___9 css;
	struct perf_cgroup_info *info;
};

struct trace_event_fields___7 {
	const char *type;
	union {
		struct {
			const char *name;
			const int size;
			const int align;
			const int is_signed;
			const int filter_type;
		};
		int (*define_fields)(struct trace_event_call___7 *);
	};
};

struct trace_event_class___7 {
	const char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct trace_event_call___7 *, enum trace_reg, void *);
	struct trace_event_fields___7 *fields_array;
	struct list_head * (*get_fields)(struct trace_event_call___7 *);
	struct list_head fields;
	int (*raw_init)(struct trace_event_call___7 *);
};

struct trace_event_file___4;

struct trace_event_buffer___4 {
	struct trace_buffer *buffer;
	struct ring_buffer_event *event;
	struct trace_event_file___4 *trace_file;
	void *entry;
	unsigned int trace_ctx;
	struct pt_regs *regs;
};

struct trace_event_file___4 {
	struct list_head list;
	struct trace_event_call___7 *event_call;
	struct event_filter *filter;
	struct dentry___11 *dir;
	struct trace_array *tr;
	struct trace_subsystem_dir *system;
	struct list_head triggers;
	long unsigned int flags;
	atomic_t sm_ref;
	atomic_t tm_ref;
};

struct trace_event_raw_hyperv_mmu_flush_tlb_multi {
	struct trace_entry ent;
	unsigned int ncpus;
	struct mm_struct___14 *mm;
	long unsigned int addr;
	long unsigned int end;
	char __data[0];
};

struct trace_event_raw_hyperv_nested_flush_guest_mapping {
	struct trace_entry ent;
	u64 as;
	int ret;
	char __data[0];
};

struct trace_event_raw_hyperv_nested_flush_guest_mapping_range {
	struct trace_entry ent;
	u64 as;
	int ret;
	char __data[0];
};

struct trace_event_raw_hyperv_send_ipi_mask {
	struct trace_entry ent;
	unsigned int ncpus;
	int vector;
	char __data[0];
};

struct trace_event_raw_hyperv_send_ipi_one {
	struct trace_entry ent;
	int cpu;
	int vector;
	char __data[0];
};

struct trace_event_data_offsets_hyperv_mmu_flush_tlb_multi {};

struct trace_event_data_offsets_hyperv_nested_flush_guest_mapping {};

struct trace_event_data_offsets_hyperv_nested_flush_guest_mapping_range {};

struct trace_event_data_offsets_hyperv_send_ipi_mask {};

struct trace_event_data_offsets_hyperv_send_ipi_one {};

typedef void (*btf_trace_hyperv_mmu_flush_tlb_multi)(void *, const struct cpumask *, const struct flush_tlb_info___6 *);

typedef void (*btf_trace_hyperv_nested_flush_guest_mapping)(void *, u64, int);

typedef void (*btf_trace_hyperv_nested_flush_guest_mapping_range)(void *, u64, int);

typedef void (*btf_trace_hyperv_send_ipi_mask)(void *, const struct cpumask *, int);

typedef void (*btf_trace_hyperv_send_ipi_one)(void *, int, int);

struct hv_guest_mapping_flush {
	u64 address_space;
	u64 flags;
};

union hv_gpa_page_range {
	u64 address_space;
	struct {
		u64 additional_pages: 11;
		u64 largepage: 1;
		u64 basepfn: 52;
	} page;
	struct {
		u64 reserved: 12;
		u64 page_size: 1;
		u64 reserved1: 8;
		u64 base_large_pfn: 43;
	};
};

struct hv_guest_mapping_flush_list {
	u64 address_space;
	u64 flags;
	union hv_gpa_page_range gpa_list[510];
};

typedef int (*hyperv_fill_flush_list_func)(struct hv_guest_mapping_flush_list *, void *);

struct irq_domain_ops___7;

struct fwnode_handle___11;

struct irq_domain_chip_generic___3;

struct irq_data___3;

struct irq_domain___7 {
	struct list_head link;
	const char *name;
	const struct irq_domain_ops___7 *ops;
	void *host_data;
	unsigned int flags;
	unsigned int mapcount;
	struct fwnode_handle___11 *fwnode;
	enum irq_domain_bus_token bus_token;
	struct irq_domain_chip_generic___3 *gc;
	struct irq_domain___7 *parent;
	irq_hw_number_t hwirq_max;
	unsigned int revmap_size;
	struct xarray revmap_tree;
	struct mutex revmap_mutex;
	struct irq_data___3 *revmap[0];
};

struct wakeup_source___12;

struct device___13;

struct dev_pm_info___12 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___12 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___13 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___12;

struct bus_type___12;

struct device_driver___12;

struct dev_pm_domain___12;

struct device_node___8;

struct class___12;

struct device___13 {
	struct kobject kobj;
	struct device___13 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___12 *type;
	struct bus_type___12 *bus;
	struct device_driver___12 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___12 power;
	struct dev_pm_domain___12 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___7 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___8 *of_node;
	struct fwnode_handle___11 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___12 *class;
	const struct attribute_group **groups;
	void (*release)(struct device___13 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct pci_bus___2;

struct pci_slot___2;

struct pci_driver___2;

struct pci_dev___2 {
	struct list_head bus_list;
	struct pci_bus___2 *bus;
	struct pci_bus___2 *subordinate;
	void *sysdata;
	struct proc_dir_entry *procent;
	struct pci_slot___2 *slot;
	unsigned int devfn;
	short unsigned int vendor;
	short unsigned int device;
	short unsigned int subsystem_vendor;
	short unsigned int subsystem_device;
	unsigned int class;
	u8 revision;
	u8 hdr_type;
	u16 aer_cap;
	struct aer_stats *aer_stats;
	struct rcec_ea *rcec_ea;
	struct pci_dev___2 *rcec;
	u32 devcap;
	u8 pcie_cap;
	u8 msi_cap;
	u8 msix_cap;
	u8 pcie_mpss: 3;
	long: 61;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u8 rom_base_reg;
	u8 pin;
	u16 pcie_flags_reg;
	long unsigned int *dma_alias_mask;
	struct pci_driver___2 *driver;
	u64 dma_mask;
	struct device_dma_parameters dma_parms;
	pci_power_t current_state;
	unsigned int imm_ready: 1;
	long: 39;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u8 pm_cap;
	unsigned int pme_support: 5;
	unsigned int pme_poll: 1;
	unsigned int d1_support: 1;
	unsigned int d2_support: 1;
	unsigned int no_d1d2: 1;
	unsigned int no_d3cold: 1;
	unsigned int bridge_d3: 1;
	unsigned int d3cold_allowed: 1;
	unsigned int mmio_always_on: 1;
	unsigned int wakeup_prepared: 1;
	unsigned int runtime_d3cold: 1;
	unsigned int skip_bus_pm: 1;
	unsigned int ignore_hotplug: 1;
	unsigned int hotplug_user_indicators: 1;
	unsigned int clear_retrain_link: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int d3hot_delay;
	unsigned int d3cold_delay;
	struct pcie_link_state *link_state;
	unsigned int ltr_path: 1;
	long: 15;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u16 l1ss;
	unsigned int pasid_no_tlp: 1;
	unsigned int eetlp_prefix_path: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	pci_channel_state_t error_state;
	struct device___13 dev;
	int cfg_size;
	unsigned int irq;
	struct resource resource[17];
	bool match_driver;
	unsigned int transparent: 1;
	unsigned int io_window: 1;
	unsigned int pref_window: 1;
	unsigned int pref_64_window: 1;
	unsigned int multifunction: 1;
	unsigned int is_busmaster: 1;
	unsigned int no_msi: 1;
	unsigned int no_64bit_msi: 1;
	unsigned int block_cfg_access: 1;
	unsigned int broken_parity_status: 1;
	unsigned int irq_reroute_variant: 2;
	unsigned int msi_enabled: 1;
	unsigned int msix_enabled: 1;
	unsigned int ari_enabled: 1;
	unsigned int ats_enabled: 1;
	unsigned int pasid_enabled: 1;
	unsigned int pri_enabled: 1;
	unsigned int is_managed: 1;
	unsigned int needs_freset: 1;
	unsigned int state_saved: 1;
	unsigned int is_physfn: 1;
	unsigned int is_virtfn: 1;
	unsigned int is_hotplug_bridge: 1;
	unsigned int shpc_managed: 1;
	unsigned int is_thunderbolt: 1;
	unsigned int untrusted: 1;
	unsigned int external_facing: 1;
	unsigned int broken_intx_masking: 1;
	unsigned int io_window_1k: 1;
	unsigned int irq_managed: 1;
	unsigned int non_compliant_bars: 1;
	unsigned int is_probed: 1;
	unsigned int link_active_reporting: 1;
	unsigned int no_vf_scan: 1;
	unsigned int no_command_memory: 1;
	long: 47;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	pci_dev_flags_t dev_flags;
	atomic_t enable_cnt;
	u32 saved_config_space[16];
	struct hlist_head saved_cap_space;
	int rom_attr_enabled;
	struct bin_attribute *res_attr[17];
	struct bin_attribute *res_attr_wc[17];
	unsigned int broken_cmd_compl: 1;
	unsigned int ptm_root: 1;
	unsigned int ptm_enabled: 1;
	long: 7;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u8 ptm_granularity;
	const struct attribute_group **msi_irq_groups;
	struct pci_vpd vpd;
	u16 dpc_cap;
	unsigned int dpc_rp_extensions: 1;
	long: 23;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u8 dpc_rp_log_size;
	union {
		struct pci_sriov *sriov;
		struct pci_dev___2 *physfn;
	};
	u16 ats_cap;
	u8 ats_stu;
	u16 pri_cap;
	u32 pri_reqs_alloc;
	unsigned int pasid_required: 1;
	long: 47;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u16 pasid_cap;
	u16 pasid_features;
	u16 acs_cap;
	phys_addr_t rom;
	size_t romlen;
	char *driver_override;
	long unsigned int priv_flags;
	u8 reset_methods[7];
};

struct dev_pm_ops___12 {
	int (*prepare)(struct device___13 *);
	void (*complete)(struct device___13 *);
	int (*suspend)(struct device___13 *);
	int (*resume)(struct device___13 *);
	int (*freeze)(struct device___13 *);
	int (*thaw)(struct device___13 *);
	int (*poweroff)(struct device___13 *);
	int (*restore)(struct device___13 *);
	int (*suspend_late)(struct device___13 *);
	int (*resume_early)(struct device___13 *);
	int (*freeze_late)(struct device___13 *);
	int (*thaw_early)(struct device___13 *);
	int (*poweroff_late)(struct device___13 *);
	int (*restore_early)(struct device___13 *);
	int (*suspend_noirq)(struct device___13 *);
	int (*resume_noirq)(struct device___13 *);
	int (*freeze_noirq)(struct device___13 *);
	int (*thaw_noirq)(struct device___13 *);
	int (*poweroff_noirq)(struct device___13 *);
	int (*restore_noirq)(struct device___13 *);
	int (*runtime_suspend)(struct device___13 *);
	int (*runtime_resume)(struct device___13 *);
	int (*runtime_idle)(struct device___13 *);
};

struct wakeup_source___12 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___13 *dev;
	bool active: 1;
	bool autosleep_enabled: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___12 {
	struct dev_pm_ops___12 ops;
	int (*start)(struct device___13 *);
	void (*detach)(struct device___13 *, bool);
	int (*activate)(struct device___13 *);
	void (*sync)(struct device___13 *);
	void (*dismiss)(struct device___13 *);
};

struct bus_type___12 {
	const char *name;
	const char *dev_name;
	struct device___13 *dev_root;
	const struct attribute_group **bus_groups;
	const struct attribute_group **dev_groups;
	const struct attribute_group **drv_groups;
	int (*match)(struct device___13 *, struct device_driver___12 *);
	int (*uevent)(struct device___13 *, struct kobj_uevent_env *);
	int (*probe)(struct device___13 *);
	void (*sync_state)(struct device___13 *);
	void (*remove)(struct device___13 *);
	void (*shutdown)(struct device___13 *);
	int (*online)(struct device___13 *);
	int (*offline)(struct device___13 *);
	int (*suspend)(struct device___13 *, pm_message_t);
	int (*resume)(struct device___13 *);
	int (*num_vf)(struct device___13 *);
	int (*dma_configure)(struct device___13 *);
	const struct dev_pm_ops___12 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___12 {
	const char *name;
	struct bus_type___12 *bus;
	struct module *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___13 *);
	void (*sync_state)(struct device___13 *);
	int (*remove)(struct device___13 *);
	void (*shutdown)(struct device___13 *);
	int (*suspend)(struct device___13 *, pm_message_t);
	int (*resume)(struct device___13 *);
	const struct attribute_group **groups;
	const struct attribute_group **dev_groups;
	const struct dev_pm_ops___12 *pm;
	void (*coredump)(struct device___13 *);
	struct driver_private *p;
};

struct device_type___12 {
	const char *name;
	const struct attribute_group **groups;
	int (*uevent)(struct device___13 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___13 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___13 *);
	const struct dev_pm_ops___12 *pm;
};

struct class___12 {
	const char *name;
	struct module *owner;
	const struct attribute_group **class_groups;
	const struct attribute_group **dev_groups;
	struct kobject *dev_kobj;
	int (*dev_uevent)(struct device___13 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___13 *, umode_t *);
	void (*class_release)(struct class___12 *);
	void (*dev_release)(struct device___13 *);
	int (*shutdown_pre)(struct device___13 *);
	const struct kobj_ns_type_operations *ns_type;
	const void * (*namespace)(struct device___13 *);
	void (*get_ownership)(struct device___13 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___12 *pm;
	struct subsys_private *p;
};

struct fwnode_operations___11;

struct fwnode_handle___11 {
	struct fwnode_handle___11 *secondary;
	const struct fwnode_operations___11 *ops;
	struct device___13 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct device_node___8 {
	const char *name;
	phandle phandle;
	const char *full_name;
	struct fwnode_handle___11 fwnode;
	struct property *properties;
	struct property *deadprops;
	struct device_node___8 *parent;
	struct device_node___8 *child;
	struct device_node___8 *sibling;
	long unsigned int _flags;
	void *data;
};

struct irqaction___3 {
	irq_handler_t handler;
	void *dev_id;
	void *percpu_dev_id;
	struct irqaction___3 *next;
	irq_handler_t thread_fn;
	struct task_struct___3 *thread;
	struct irqaction___3 *secondary;
	unsigned int irq;
	unsigned int flags;
	long unsigned int thread_flags;
	long unsigned int thread_mask;
	const char *name;
	struct proc_dir_entry *dir;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fwnode_reference_args___11;

struct fwnode_endpoint___11;

struct fwnode_operations___11 {
	struct fwnode_handle___11 * (*get)(struct fwnode_handle___11 *);
	void (*put)(struct fwnode_handle___11 *);
	bool (*device_is_available)(const struct fwnode_handle___11 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___11 *, const struct device___13 *);
	bool (*property_present)(const struct fwnode_handle___11 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___11 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___11 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___11 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___11 *);
	struct fwnode_handle___11 * (*get_parent)(const struct fwnode_handle___11 *);
	struct fwnode_handle___11 * (*get_next_child_node)(const struct fwnode_handle___11 *, struct fwnode_handle___11 *);
	struct fwnode_handle___11 * (*get_named_child_node)(const struct fwnode_handle___11 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___11 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___11 *);
	struct fwnode_handle___11 * (*graph_get_next_endpoint)(const struct fwnode_handle___11 *, struct fwnode_handle___11 *);
	struct fwnode_handle___11 * (*graph_get_remote_endpoint)(const struct fwnode_handle___11 *);
	struct fwnode_handle___11 * (*graph_get_port_parent)(struct fwnode_handle___11 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___11 *, struct fwnode_endpoint___11 *);
	int (*add_links)(struct fwnode_handle___11 *);
};

struct fwnode_endpoint___11 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___11 *local_fwnode;
};

struct fwnode_reference_args___11 {
	struct fwnode_handle___11 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct pci_slot___2 {
	struct pci_bus___2 *bus;
	struct list_head list;
	struct hotplug_slot *hotplug;
	unsigned char number;
	struct kobject kobj;
};

struct pci_ops___2;

struct pci_bus___2 {
	struct list_head node;
	struct pci_bus___2 *parent;
	struct list_head children;
	struct list_head devices;
	struct pci_dev___2 *self;
	struct list_head slots;
	struct resource *resource[4];
	struct list_head resources;
	struct resource busn_res;
	struct pci_ops___2 *ops;
	void *sysdata;
	struct proc_dir_entry *procdir;
	unsigned char number;
	unsigned char primary;
	unsigned char max_bus_speed;
	unsigned char cur_bus_speed;
	char name[48];
	short unsigned int bridge_ctl;
	pci_bus_flags_t bus_flags;
	struct device___13 *bridge;
	struct device___13 dev;
	struct bin_attribute *legacy_io;
	struct bin_attribute *legacy_mem;
	unsigned int is_added: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct pci_error_handlers___2;

struct pci_driver___2 {
	struct list_head node;
	const char *name;
	const struct pci_device_id *id_table;
	int (*probe)(struct pci_dev___2 *, const struct pci_device_id *);
	void (*remove)(struct pci_dev___2 *);
	int (*suspend)(struct pci_dev___2 *, pm_message_t);
	int (*resume)(struct pci_dev___2 *);
	void (*shutdown)(struct pci_dev___2 *);
	int (*sriov_configure)(struct pci_dev___2 *, int);
	int (*sriov_set_msix_vec_count)(struct pci_dev___2 *, int);
	u32 (*sriov_get_vf_total_msix)(struct pci_dev___2 *);
	const struct pci_error_handlers___2 *err_handler;
	const struct attribute_group **groups;
	const struct attribute_group **dev_groups;
	struct device_driver___12 driver;
	struct pci_dynids dynids;
};

struct pci_ops___2 {
	int (*add_bus)(struct pci_bus___2 *);
	void (*remove_bus)(struct pci_bus___2 *);
	void * (*map_bus)(struct pci_bus___2 *, unsigned int, int);
	int (*read)(struct pci_bus___2 *, unsigned int, int, int, u32 *);
	int (*write)(struct pci_bus___2 *, unsigned int, int, int, u32);
};

struct pci_error_handlers___2 {
	pci_ers_result_t (*error_detected)(struct pci_dev___2 *, pci_channel_state_t);
	pci_ers_result_t (*mmio_enabled)(struct pci_dev___2 *);
	pci_ers_result_t (*slot_reset)(struct pci_dev___2 *);
	void (*reset_prepare)(struct pci_dev___2 *);
	void (*reset_done)(struct pci_dev___2 *);
	void (*resume)(struct pci_dev___2 *);
};

struct pci_sysdata___2 {
	int domain;
	int node;
	struct acpi_device *companion;
	void *iommu;
	void *fwnode;
	struct pci_dev___2 *vmd_dev;
};

struct irq_desc___3;

typedef void (*irq_flow_handler_t___3)(struct irq_desc___3 *);

struct msi_desc___3;

struct irq_common_data___3 {
	unsigned int state_use_accessors;
	unsigned int node;
	void *handler_data;
	struct msi_desc___3 *msi_desc;
	cpumask_var_t affinity;
	cpumask_var_t effective_affinity;
};

struct irq_chip___3;

struct irq_data___3 {
	u32 mask;
	unsigned int irq;
	long unsigned int hwirq;
	struct irq_common_data___3 *common;
	struct irq_chip___3 *chip;
	struct irq_domain___7 *domain;
	struct irq_data___3 *parent_data;
	void *chip_data;
};

struct irq_desc___3 {
	struct irq_common_data___3 irq_common_data;
	struct irq_data___3 irq_data;
	unsigned int *kstat_irqs;
	irq_flow_handler_t___3 handle_irq;
	struct irqaction___3 *action;
	unsigned int status_use_accessors;
	unsigned int core_internal_state__do_not_mess_with_it;
	unsigned int depth;
	unsigned int wake_depth;
	unsigned int tot_count;
	unsigned int irq_count;
	long unsigned int last_unhandled;
	unsigned int irqs_unhandled;
	atomic_t threads_handled;
	int threads_handled_last;
	raw_spinlock_t lock;
	struct cpumask *percpu_enabled;
	const struct cpumask *percpu_affinity;
	const struct cpumask *affinity_hint;
	struct irq_affinity_notify *affinity_notify;
	cpumask_var_t pending_mask;
	long unsigned int threads_oneshot;
	atomic_t threads_active;
	wait_queue_head_t wait_for_threads;
	unsigned int nr_actions;
	unsigned int no_suspend_depth;
	unsigned int cond_suspend_depth;
	unsigned int force_resume_depth;
	struct proc_dir_entry *dir;
	struct callback_head rcu;
	struct kobject kobj;
	struct mutex request_mutex;
	int parent_irq;
	struct module *owner;
	const char *name;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct msi_desc___3 {
	struct list_head list;
	unsigned int irq;
	unsigned int nvec_used;
	struct device___13 *dev;
	struct msi_msg msg;
	struct irq_affinity_desc *affinity;
	const void *iommu_cookie;
	void (*write_msi_msg)(struct msi_desc___3 *, void *);
	void *write_msi_msg_data;
	union {
		struct {
			union {
				u32 msi_mask;
				u32 msix_ctrl;
			};
			struct {
				u8 is_msix: 1;
				u8 multiple: 3;
				u8 multi_cap: 3;
				u8 can_mask: 1;
				u8 is_64: 1;
				u8 is_virtual: 1;
				u16 entry_nr;
				unsigned int default_irq;
			} msi_attrib;
			union {
				u8 mask_pos;
				void *mask_base;
			};
		};
		struct platform_msi_desc platform;
		struct fsl_mc_msi_desc fsl_mc;
		struct ti_sci_inta_msi_desc inta;
	};
};

struct irq_chip___3 {
	struct device___13 *parent_device;
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___3 *);
	void (*irq_shutdown)(struct irq_data___3 *);
	void (*irq_enable)(struct irq_data___3 *);
	void (*irq_disable)(struct irq_data___3 *);
	void (*irq_ack)(struct irq_data___3 *);
	void (*irq_mask)(struct irq_data___3 *);
	void (*irq_mask_ack)(struct irq_data___3 *);
	void (*irq_unmask)(struct irq_data___3 *);
	void (*irq_eoi)(struct irq_data___3 *);
	int (*irq_set_affinity)(struct irq_data___3 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___3 *);
	int (*irq_set_type)(struct irq_data___3 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___3 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___3 *);
	void (*irq_bus_sync_unlock)(struct irq_data___3 *);
	void (*irq_cpu_online)(struct irq_data___3 *);
	void (*irq_cpu_offline)(struct irq_data___3 *);
	void (*irq_suspend)(struct irq_data___3 *);
	void (*irq_resume)(struct irq_data___3 *);
	void (*irq_pm_shutdown)(struct irq_data___3 *);
	void (*irq_calc_mask)(struct irq_data___3 *);
	void (*irq_print_chip)(struct irq_data___3 *, struct seq_file *);
	int (*irq_request_resources)(struct irq_data___3 *);
	void (*irq_release_resources)(struct irq_data___3 *);
	void (*irq_compose_msi_msg)(struct irq_data___3 *, struct msi_msg *);
	void (*irq_write_msi_msg)(struct irq_data___3 *, struct msi_msg *);
	int (*irq_get_irqchip_state)(struct irq_data___3 *, enum irqchip_irq_state, bool *);
	int (*irq_set_irqchip_state)(struct irq_data___3 *, enum irqchip_irq_state, bool);
	int (*irq_set_vcpu_affinity)(struct irq_data___3 *, void *);
	void (*ipi_send_single)(struct irq_data___3 *, unsigned int);
	void (*ipi_send_mask)(struct irq_data___3 *, const struct cpumask *);
	int (*irq_nmi_setup)(struct irq_data___3 *);
	void (*irq_nmi_teardown)(struct irq_data___3 *);
	long unsigned int flags;
};

enum {
	IRQCHIP_SET_TYPE_MASKED = 1,
	IRQCHIP_EOI_IF_HANDLED = 2,
	IRQCHIP_MASK_ON_SUSPEND = 4,
	IRQCHIP_ONOFFLINE_ENABLED = 8,
	IRQCHIP_SKIP_SET_WAKE = 16,
	IRQCHIP_ONESHOT_SAFE = 32,
	IRQCHIP_EOI_THREADED = 64,
	IRQCHIP_SUPPORTS_LEVEL_MSI = 128,
	IRQCHIP_SUPPORTS_NMI = 256,
	IRQCHIP_ENABLE_WAKEUP_ON_SUSPEND = 512,
	IRQCHIP_AFFINITY_PRE_STARTUP = 1024,
};

enum irq_alloc_type {
	X86_IRQ_ALLOC_TYPE_IOAPIC = 1,
	X86_IRQ_ALLOC_TYPE_HPET = 2,
	X86_IRQ_ALLOC_TYPE_PCI_MSI = 3,
	X86_IRQ_ALLOC_TYPE_PCI_MSIX = 4,
	X86_IRQ_ALLOC_TYPE_DMAR = 5,
	X86_IRQ_ALLOC_TYPE_AMDVI = 6,
	X86_IRQ_ALLOC_TYPE_UV = 7,
};

struct ioapic_alloc_info {
	int pin;
	int node;
	u32 is_level: 1;
	u32 active_low: 1;
	u32 valid: 1;
	long: 31;
	long: 64;
};

struct uv_alloc_info {
	int limit;
	int blade;
	long unsigned int offset;
	char *name;
};

struct irq_alloc_info {
	enum irq_alloc_type type;
	u32 flags;
	u32 devid;
	irq_hw_number_t hwirq;
	const struct cpumask *mask;
	struct msi_desc___3 *desc;
	void *data;
	union {
		struct ioapic_alloc_info ioapic;
		struct uv_alloc_info uv;
	};
};

struct irq_cfg {
	unsigned int dest_apicid;
	unsigned int vector;
};

struct irq_chip_type___3 {
	struct irq_chip___3 chip;
	struct irq_chip_regs regs;
	irq_flow_handler_t___3 handler;
	u32 type;
	u32 mask_cache_priv;
	u32 *mask_cache;
};

struct irq_chip_generic___3 {
	raw_spinlock_t lock;
	void *reg_base;
	u32 (*reg_readl)(void *);
	void (*reg_writel)(u32, void *);
	void (*suspend)(struct irq_chip_generic___3 *);
	void (*resume)(struct irq_chip_generic___3 *);
	unsigned int irq_base;
	unsigned int irq_cnt;
	u32 mask_cache;
	u32 type_cache;
	u32 polarity_cache;
	u32 wake_enabled;
	u32 wake_active;
	unsigned int num_ct;
	void *private;
	long unsigned int installed;
	long unsigned int unused;
	struct irq_domain___7 *domain;
	struct list_head list;
	struct irq_chip_type___3 chip_types[0];
};

struct irq_domain_chip_generic___3 {
	unsigned int irqs_per_chip;
	unsigned int num_chips;
	unsigned int irq_flags_to_clear;
	unsigned int irq_flags_to_set;
	enum irq_gc_flags gc_flags;
	struct irq_chip_generic___3 *gc[0];
};

struct irq_fwspec___7 {
	struct fwnode_handle___11 *fwnode;
	int param_count;
	u32 param[16];
};

struct irq_domain_ops___7 {
	int (*match)(struct irq_domain___7 *, struct device_node___8 *, enum irq_domain_bus_token);
	int (*select)(struct irq_domain___7 *, struct irq_fwspec___7 *, enum irq_domain_bus_token);
	int (*map)(struct irq_domain___7 *, unsigned int, irq_hw_number_t);
	void (*unmap)(struct irq_domain___7 *, unsigned int);
	int (*xlate)(struct irq_domain___7 *, struct device_node___8 *, const u32 *, unsigned int, long unsigned int *, unsigned int *);
	int (*alloc)(struct irq_domain___7 *, unsigned int, unsigned int, void *);
	void (*free)(struct irq_domain___7 *, unsigned int, unsigned int);
	int (*activate)(struct irq_domain___7 *, struct irq_data___3 *, bool);
	void (*deactivate)(struct irq_domain___7 *, struct irq_data___3 *);
	int (*translate)(struct irq_domain___7 *, struct irq_fwspec___7 *, long unsigned int *, unsigned int *);
};

enum {
	IRQCHIP_FWNODE_REAL = 0,
	IRQCHIP_FWNODE_NAMED = 1,
	IRQCHIP_FWNODE_NAMED_ID = 2,
};

typedef struct irq_alloc_info msi_alloc_info_t;

struct msi_domain_info;

struct msi_domain_ops {
	irq_hw_number_t (*get_hwirq)(struct msi_domain_info *, msi_alloc_info_t *);
	int (*msi_init)(struct irq_domain___7 *, struct msi_domain_info *, unsigned int, irq_hw_number_t, msi_alloc_info_t *);
	void (*msi_free)(struct irq_domain___7 *, struct msi_domain_info *, unsigned int);
	int (*msi_check)(struct irq_domain___7 *, struct msi_domain_info *, struct device___13 *);
	int (*msi_prepare)(struct irq_domain___7 *, struct device___13 *, int, msi_alloc_info_t *);
	void (*msi_finish)(msi_alloc_info_t *, int);
	void (*set_desc)(msi_alloc_info_t *, struct msi_desc___3 *);
	int (*handle_error)(struct irq_domain___7 *, struct msi_desc___3 *, int);
	int (*domain_alloc_irqs)(struct irq_domain___7 *, struct device___13 *, int);
	void (*domain_free_irqs)(struct irq_domain___7 *, struct device___13 *);
};

struct msi_domain_info {
	u32 flags;
	struct msi_domain_ops *ops;
	struct irq_chip___3 *chip;
	void *chip_data;
	irq_flow_handler_t___3 handler;
	void *handler_data;
	const char *handler_name;
	void *data;
};

enum {
	MSI_FLAG_USE_DEF_DOM_OPS = 1,
	MSI_FLAG_USE_DEF_CHIP_OPS = 2,
	MSI_FLAG_MULTI_PCI_MSI = 4,
	MSI_FLAG_PCI_MSIX = 8,
	MSI_FLAG_ACTIVATE_EARLY = 16,
	MSI_FLAG_MUST_REACTIVATE = 32,
	MSI_FLAG_LEVEL_CAPABLE = 64,
};

enum hv_interrupt_type {
	HV_X64_INTERRUPT_TYPE_FIXED = 0,
	HV_X64_INTERRUPT_TYPE_LOWESTPRIORITY = 1,
	HV_X64_INTERRUPT_TYPE_SMI = 2,
	HV_X64_INTERRUPT_TYPE_REMOTEREAD = 3,
	HV_X64_INTERRUPT_TYPE_NMI = 4,
	HV_X64_INTERRUPT_TYPE_INIT = 5,
	HV_X64_INTERRUPT_TYPE_SIPI = 6,
	HV_X64_INTERRUPT_TYPE_EXTINT = 7,
	HV_X64_INTERRUPT_TYPE_LOCALINT0 = 8,
	HV_X64_INTERRUPT_TYPE_LOCALINT1 = 9,
	HV_X64_INTERRUPT_TYPE_MAXIMUM = 10,
};

union hv_msi_address_register {
	u32 as_uint32;
	struct {
		u32 reserved1: 2;
		u32 destination_mode: 1;
		u32 redirection_hint: 1;
		u32 reserved2: 8;
		u32 destination_id: 8;
		u32 msi_base: 12;
	};
};

union hv_msi_data_register {
	u32 as_uint32;
	struct {
		u32 vector: 8;
		u32 delivery_mode: 3;
		u32 reserved1: 3;
		u32 level_assert: 1;
		u32 trigger_mode: 1;
		u32 reserved2: 16;
	};
};

union hv_msi_entry {
	u64 as_uint64;
	struct {
		union hv_msi_address_register address;
		union hv_msi_data_register data;
	};
};

union hv_ioapic_rte {
	u64 as_uint64;
	struct {
		u32 vector: 8;
		u32 delivery_mode: 3;
		u32 destination_mode: 1;
		u32 delivery_status: 1;
		u32 interrupt_polarity: 1;
		u32 remote_irr: 1;
		u32 trigger_mode: 1;
		u32 interrupt_mask: 1;
		u32 reserved1: 15;
		u32 reserved2: 24;
		u32 destination_id: 8;
		long: 56;
	};
	struct {
		u32 low_uint32;
		u32 high_uint32;
	};
};

struct hv_interrupt_entry {
	u32 source;
	u32 reserved1;
	union {
		union hv_msi_entry msi_entry;
		union hv_ioapic_rte ioapic_rte;
	};
};

struct hv_device_interrupt_target {
	u32 vector;
	u32 flags;
	union {
		u64 vp_mask;
		struct hv_vpset vp_set;
	};
};

enum hv_device_type {
	HV_DEVICE_TYPE_LOGICAL = 0,
	HV_DEVICE_TYPE_PCI = 1,
	HV_DEVICE_TYPE_IOAPIC = 2,
	HV_DEVICE_TYPE_ACPI = 3,
};

typedef u16 hv_pci_rid;

typedef u16 hv_pci_segment;

union hv_pci_bdf {
	u16 as_uint16;
	struct {
		u8 function: 3;
		u8 device: 5;
		u8 bus;
	};
};

union hv_pci_bus_range {
	u16 as_uint16;
	struct {
		u8 subordinate_bus;
		u8 secondary_bus;
	};
};

union hv_device_id {
	u64 as_uint64;
	struct {
		u64 reserved0: 62;
		u64 device_type: 2;
	};
	struct {
		u64 id: 62;
		u64 device_type: 2;
	} logical;
	struct {
		union {
			hv_pci_rid rid;
			union hv_pci_bdf bdf;
		};
		hv_pci_segment segment;
		union hv_pci_bus_range shadow_bus_range;
		u16 phantom_function_bits: 2;
		u16 source_shadow: 1;
		u16 rsvdz0: 11;
		u16 device_type: 2;
		long: 62;
	} pci;
	struct {
		u8 ioapic_id;
		u8 rsvdz0;
		u16 rsvdz1;
		u16 rsvdz2;
		u16 rsvdz3: 14;
		u16 device_type: 2;
		long: 62;
	} ioapic;
	struct {
		u32 input_mapping_base;
		u32 input_mapping_count: 30;
		u32 device_type: 2;
		long: 62;
	} acpi;
};

enum hv_interrupt_trigger_mode {
	HV_INTERRUPT_TRIGGER_MODE_EDGE = 0,
	HV_INTERRUPT_TRIGGER_MODE_LEVEL = 1,
};

struct hv_device_interrupt_descriptor {
	u32 interrupt_type;
	u32 trigger_mode;
	u32 vector_count;
	u32 reserved;
	struct hv_device_interrupt_target target;
};

struct hv_input_map_device_interrupt {
	u64 partition_id;
	u64 device_id;
	u64 flags;
	struct hv_interrupt_entry logical_interrupt_entry;
	struct hv_device_interrupt_descriptor interrupt_descriptor;
};

struct hv_output_map_device_interrupt {
	struct hv_interrupt_entry interrupt_entry;
};

struct hv_input_unmap_device_interrupt {
	u64 partition_id;
	u64 device_id;
	struct hv_interrupt_entry interrupt_entry;
};

struct rid_data {
	struct pci_dev___2 *bridge;
	u32 rid;
};

struct hv_send_ipi {
	u32 vector;
	u32 reserved;
	u64 cpu_mask;
};

struct hv_send_ipi_ex {
	u32 vector;
	u32 reserved;
	struct hv_vpset vp_set;
};

struct hv_deposit_memory {
	u64 partition_id;
	u64 gpa_page_list[0];
};

struct hv_proximity_domain_flags {
	u32 proximity_preferred: 1;
	u32 reserved: 30;
	u32 proximity_info_valid: 1;
};

union hv_proximity_domain_info {
	struct {
		u32 domain_id;
		struct hv_proximity_domain_flags flags;
	};
	u64 as_uint64;
};

struct hv_lp_startup_status {
	u64 hv_status;
	u64 substatus1;
	u64 substatus2;
	u64 substatus3;
	u64 substatus4;
	u64 substatus5;
	u64 substatus6;
};

struct hv_add_logical_processor_in {
	u32 lp_index;
	u32 apic_id;
	union hv_proximity_domain_info proximity_domain_info;
	u64 flags;
};

struct hv_add_logical_processor_out {
	struct hv_lp_startup_status startup_status;
};

enum HV_SUBNODE_TYPE {
	HvSubnodeAny = 0,
	HvSubnodeSocket = 1,
	HvSubnodeAmdNode = 2,
	HvSubnodeL3 = 3,
	HvSubnodeCount = 4,
	HvSubnodeInvalid = 4294967295,
};

struct hv_create_vp {
	u64 partition_id;
	u32 vp_index;
	u8 padding[3];
	u8 subnode_type;
	u64 subnode_id;
	union hv_proximity_domain_info proximity_domain_info;
	u64 flags;
};

struct real_mode_header {
	u32 text_start;
	u32 ro_end;
	u32 trampoline_start;
	u32 trampoline_header;
	u32 sev_es_trampoline_start;
	u32 trampoline_pgd;
	u32 wakeup_start;
	u32 wakeup_header;
	u32 machine_real_restart_asm;
	u32 machine_real_restart_seg;
};

struct trampoline_header {
	u64 start;
	u64 efer;
	u32 cr4;
	u32 flags;
};

enum show_regs_mode {
	SHOW_REGS_SHORT = 0,
	SHOW_REGS_USER = 1,
	SHOW_REGS_ALL = 2,
};

struct resctrl_pqr_state {
	u32 cur_rmid;
	u32 cur_closid;
	u32 default_rmid;
	u32 default_closid;
};

enum which_selector {
	FS = 0,
	GS = 1,
};

struct sigcontext_64 {
	__u64 r8;
	__u64 r9;
	__u64 r10;
	__u64 r11;
	__u64 r12;
	__u64 r13;
	__u64 r14;
	__u64 r15;
	__u64 di;
	__u64 si;
	__u64 bp;
	__u64 bx;
	__u64 dx;
	__u64 ax;
	__u64 cx;
	__u64 sp;
	__u64 ip;
	__u64 flags;
	__u16 cs;
	__u16 gs;
	__u16 fs;
	__u16 ss;
	__u64 err;
	__u64 trapno;
	__u64 oldmask;
	__u64 cr2;
	__u64 fpstate;
	__u64 reserved1[8];
};

struct sigaltstack {
	void *ss_sp;
	int ss_flags;
	size_t ss_size;
};

typedef struct sigaltstack stack_t;

struct siginfo {
	union {
		struct {
			int si_signo;
			int si_errno;
			int si_code;
			union __sifields _sifields;
		};
		int _si_pad[32];
	};
};

typedef struct siginfo siginfo_t;

struct ksignal {
	struct k_sigaction ka;
	kernel_siginfo_t info;
	int sig;
};

struct __large_struct {
	long unsigned int buf[100];
};

typedef u32 compat_size_t;

typedef s32 compat_clock_t;

typedef s32 compat_pid_t;

typedef s32 compat_timer_t;

typedef s32 compat_int_t;

typedef u32 compat_ulong_t;

typedef u32 __compat_uid32_t;

typedef s64 compat_s64;

typedef u32 compat_sigset_word;

struct compat_sigaltstack {
	compat_uptr_t ss_sp;
	int ss_flags;
	compat_size_t ss_size;
};

typedef struct compat_sigaltstack compat_stack_t;

typedef struct {
	compat_sigset_word sig[2];
} compat_sigset_t;

union compat_sigval {
	compat_int_t sival_int;
	compat_uptr_t sival_ptr;
};

typedef union compat_sigval compat_sigval_t;

struct compat_siginfo {
	int si_signo;
	int si_errno;
	int si_code;
	union {
		int _pad[29];
		struct {
			compat_pid_t _pid;
			__compat_uid32_t _uid;
		} _kill;
		struct {
			compat_timer_t _tid;
			int _overrun;
			compat_sigval_t _sigval;
		} _timer;
		struct {
			compat_pid_t _pid;
			__compat_uid32_t _uid;
			compat_sigval_t _sigval;
		} _rt;
		struct {
			compat_pid_t _pid;
			__compat_uid32_t _uid;
			int _status;
			compat_clock_t _utime;
			compat_clock_t _stime;
		} _sigchld;
		struct {
			compat_pid_t _pid;
			__compat_uid32_t _uid;
			int _status;
			compat_s64 _utime;
			compat_s64 _stime;
		} __attribute__((packed)) _sigchld_x32;
		struct {
			compat_uptr_t _addr;
			union {
				int _trapno;
				short int _addr_lsb;
				struct {
					char _dummy_bnd[4];
					compat_uptr_t _lower;
					compat_uptr_t _upper;
				} _addr_bnd;
				struct {
					char _dummy_pkey[4];
					u32 _pkey;
				} _addr_pkey;
				struct {
					compat_ulong_t _data;
					u32 _type;
				} _perf;
			};
		} _sigfault;
		struct {
			compat_long_t _band;
			int _fd;
		} _sigpoll;
		struct {
			compat_uptr_t _call_addr;
			int _syscall;
			unsigned int _arch;
		} _sigsys;
	} _sifields;
} __attribute__((packed));

typedef struct compat_siginfo compat_siginfo_t;

struct ucontext {
	long unsigned int uc_flags;
	struct ucontext *uc_link;
	stack_t uc_stack;
	struct sigcontext_64 uc_mcontext;
	sigset_t uc_sigmask;
};

struct kernel_vm86_regs {
	struct pt_regs pt;
	short unsigned int es;
	short unsigned int __esh;
	short unsigned int ds;
	short unsigned int __dsh;
	short unsigned int fs;
	short unsigned int __fsh;
	short unsigned int gs;
	short unsigned int __gsh;
};

struct rt_sigframe {
	char *pretcode;
	struct ucontext uc;
	struct siginfo info;
};

struct ucontext_x32 {
	unsigned int uc_flags;
	unsigned int uc_link;
	compat_stack_t uc_stack;
	unsigned int uc__pad0;
	struct sigcontext_64 uc_mcontext;
	compat_sigset_t uc_sigmask;
};

struct rt_sigframe_x32 {
	u64 pretcode;
	struct ucontext_x32 uc;
	compat_siginfo_t info;
};

enum bug_trap_type {
	BUG_TRAP_TYPE_NONE = 0,
	BUG_TRAP_TYPE_WARN = 1,
	BUG_TRAP_TYPE_BUG = 2,
};

enum insn_mode {
	INSN_MODE_32 = 0,
	INSN_MODE_64 = 1,
	INSN_MODE_KERN = 2,
	INSN_NUM_MODES = 3,
};

typedef u8 kprobe_opcode_t;

struct kprobe;

struct arch_specific_insn {
	kprobe_opcode_t *insn;
	unsigned int boostable: 1;
	long: 7;
	long: 64;
	unsigned char size;
	union {
		unsigned char opcode;
		struct {
			unsigned char type;
		} jcc;
		struct {
			unsigned char type;
			unsigned char asize;
		} loop;
		struct {
			unsigned char reg;
		} indirect;
	};
	s32 rel32;
	void (*emulate_op)(struct kprobe *, struct pt_regs *);
	int tp_len;
};

typedef int (*kprobe_pre_handler_t)(struct kprobe *, struct pt_regs *);

typedef void (*kprobe_post_handler_t)(struct kprobe *, struct pt_regs *, long unsigned int);

struct kprobe {
	struct hlist_node hlist;
	struct list_head list;
	long unsigned int nmissed;
	kprobe_opcode_t *addr;
	const char *symbol_name;
	unsigned int offset;
	kprobe_pre_handler_t pre_handler;
	kprobe_post_handler_t post_handler;
	kprobe_opcode_t opcode;
	struct arch_specific_insn ainsn;
	u32 flags;
};

enum die_val {
	DIE_OOPS = 1,
	DIE_INT3 = 2,
	DIE_DEBUG = 3,
	DIE_PANIC = 4,
	DIE_NMI = 5,
	DIE_DIE = 6,
	DIE_KERNELDEBUG = 7,
	DIE_TRAP = 8,
	DIE_GPF = 9,
	DIE_CALL = 10,
	DIE_PAGE_FAULT = 11,
	DIE_NMIUNKNOWN = 12,
};

enum kernel_gp_hint {
	GP_NO_HINT = 0,
	GP_NON_CANONICAL = 1,
	GP_CANONICAL = 2,
};

struct bad_iret_stack {
	void *error_entry_ret;
	struct pt_regs regs;
};

struct dentry___12;

struct super_block___12;

struct module___13;

struct file_system_type___12 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___12 * (*mount)(struct file_system_type___12 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___12 *);
	struct module___13 *owner;
	struct file_system_type___12 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___12;

struct kiocb___12;

struct iov_iter___10;

struct poll_table_struct___9;

struct vm_area_struct___14;

struct inode___12;

struct file_lock___12;

struct page___13;

struct seq_file___11;

struct file_operations___12 {
	struct module___13 *owner;
	loff_t (*llseek)(struct file___12 *, loff_t, int);
	ssize_t (*read)(struct file___12 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___12 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___12 *, struct iov_iter___10 *);
	ssize_t (*write_iter)(struct kiocb___12 *, struct iov_iter___10 *);
	int (*iopoll)(struct kiocb___12 *, bool);
	int (*iterate)(struct file___12 *, struct dir_context *);
	int (*iterate_shared)(struct file___12 *, struct dir_context *);
	__poll_t (*poll)(struct file___12 *, struct poll_table_struct___9 *);
	long int (*unlocked_ioctl)(struct file___12 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___12 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___12 *, struct vm_area_struct___14 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___12 *, struct file___12 *);
	int (*flush)(struct file___12 *, fl_owner_t);
	int (*release)(struct inode___12 *, struct file___12 *);
	int (*fsync)(struct file___12 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___12 *, int);
	int (*lock)(struct file___12 *, int, struct file_lock___12 *);
	ssize_t (*sendpage)(struct file___12 *, struct page___13 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___12 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___12 *, long unsigned int);
	int (*flock)(struct file___12 *, int, struct file_lock___12 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___12 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___12 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___12 *, long int, struct file_lock___12 **, void **);
	long int (*fallocate)(struct file___12 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___11 *, struct file___12 *);
	ssize_t (*copy_file_range)(struct file___12 *, loff_t, struct file___12 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___12 *, loff_t, struct file___12 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___12 *, loff_t, loff_t, int);
};

struct static_call_mod___9 {
	struct static_call_mod___9 *next;
	struct module___13 *mod;
	struct static_call_site *sites;
};

struct static_call_key___9 {
	void *func;
	union {
		long unsigned int type;
		struct static_call_mod___9 *mods;
		struct static_call_site *sites;
	};
};

struct vmacache___13 {
	u64 seqnum;
	struct vm_area_struct___14 *vmas[4];
};

struct page_frag___13 {
	struct page___13 *page;
	__u32 offset;
	__u32 size;
};

struct perf_event___8;

struct thread_struct___9 {
	struct desc_struct tls_array[3];
	long unsigned int sp;
	short unsigned int es;
	short unsigned int ds;
	short unsigned int fsindex;
	short unsigned int gsindex;
	long unsigned int fsbase;
	long unsigned int gsbase;
	struct perf_event___8 *ptrace_bps[4];
	long unsigned int virtual_dr6;
	long unsigned int ptrace_dr7;
	long unsigned int cr2;
	long unsigned int trap_nr;
	long unsigned int error_code;
	struct io_bitmap *io_bitmap;
	long unsigned int iopl_emul;
	unsigned int iopl_warn: 1;
	unsigned int sig_on_uaccess_err: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u32 pkru;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct fpu fpu;
};

struct mm_struct___15;

struct pid___11;

struct nsproxy___12;

struct signal_struct___13;

struct bio_list___9;

struct backing_dev_info___8;

struct io_context___10;

struct css_set___10;

struct perf_event_context___8;

struct mem_cgroup___8;

struct request_queue___9;

struct vm_struct___12;

struct task_struct___15 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___15 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___15 *mm;
	struct mm_struct___15 *active_mm;
	struct vmacache___13 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int restore_sigmask: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___15 *real_parent;
	struct task_struct___15 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___15 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___11 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	struct posix_cputimers_work posix_cputimers_work;
	const struct cred *ptracer_cred;
	const struct cred *real_cred;
	const struct cred *cred;
	struct key *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___12 *nsproxy;
	struct signal_struct___13 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___15 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___9 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___8 *backing_dev_info;
	struct io_context___10 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___10 *cgroups;
	struct list_head cg_list;
	u32 closid;
	u32 rmid;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___8 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	struct pipe_inode_info *splice_pipe;
	struct page_frag___13 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___8 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___8 *active_memcg;
	struct request_queue___9 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___15 *oom_reaper_list;
	struct vm_struct___12 *stack_vm_area;
	refcount_t stack_refcount;
	int patch_state;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	void *mce_vaddr;
	__u64 mce_kflags;
	u64 mce_addr;
	__u64 mce_ripv: 1;
	__u64 mce_whole_page: 1;
	__u64 __mce_reserved: 62;
	long: 2;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct callback_head mce_kill_me;
	int mce_count;
	struct llist_head kretprobe_instances;
	struct callback_head l1d_flush_kill;
	long: 64;
	struct thread_struct___9 thread;
};

typedef struct page___13 *pgtable_t___13;

struct address_space___12;

struct dev_pagemap___12;

struct page___13 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___12 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___13 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___13 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___15 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___12 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct pv_cpu_ops___10 {
	void (*io_delay)();
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	void (*write_cr4)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___9 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(long unsigned int);
	void (*invalidate_io_bitmap)();
	void (*update_io_bitmap)();
	void (*wbinvd)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int);
	void (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_msr_safe)(unsigned int, int *);
	int (*write_msr_safe)(unsigned int, unsigned int, unsigned int);
	u64 (*read_pmc)(int);
	void (*start_context_switch)(struct task_struct___15 *);
	void (*end_context_switch)(struct task_struct___15 *);
};

struct pv_mmu_ops___10 {
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_one_user)(long unsigned int);
	void (*flush_tlb_multi)(const struct cpumask *, const struct flush_tlb_info___3 *);
	void (*tlb_remove_table)(struct mmu_gather *, void *);
	void (*exit_mmap)(struct mm_struct___15 *);
	struct paravirt_callee_save read_cr2;
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___15 *, struct mm_struct___15 *);
	void (*dup_mmap)(struct mm_struct___15 *, struct mm_struct___15 *);
	int (*pgd_alloc)(struct mm_struct___15 *);
	void (*pgd_free)(struct mm_struct___15 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___15 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___15 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___15 *, long unsigned int);
	void (*alloc_p4d)(struct mm_struct___15 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*release_p4d)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	pte_t (*ptep_modify_prot_start)(struct vm_area_struct___14 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct vm_area_struct___14 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_p4d)(p4d_t *, p4d_t);
	struct paravirt_callee_save p4d_val;
	struct paravirt_callee_save make_p4d;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

struct core_state___13;

struct mm_struct___15 {
	struct {
		struct vm_area_struct___14 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___12 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int mmap_compat_base;
		long unsigned int mmap_compat_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[48];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___13 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___15 *owner;
		struct user_namespace *user_ns;
		struct file___12 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		bool tlb_flush_batched;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct vm_operations_struct___12;

struct vm_area_struct___14 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___14 *vm_next;
	struct vm_area_struct___14 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___15 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___12 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___12 *vm_file;
	struct file___12 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct paravirt_patch_template___10 {
	struct pv_cpu_ops___10 cpu;
	struct pv_irq_ops irq;
	struct pv_mmu_ops___10 mmu;
	struct pv_lock_ops lock;
};

struct tracepoint___9 {
	const char *name;
	struct static_key key;
	struct static_call_key___9 *static_call_key;
	void *static_call_tramp;
	void *iterator;
	int (*regfunc)();
	void (*unregfunc)();
	struct tracepoint_func *funcs;
};

struct bpf_raw_event_map___9 {
	struct tracepoint___9 *tp;
	void *bpf_func;
	u32 num_args;
	u32 writable_size;
	long: 64;
};

struct seq_operations___11 {
	void * (*start)(struct seq_file___11 *, loff_t *);
	void (*stop)(struct seq_file___11 *, void *);
	void * (*next)(struct seq_file___11 *, void *, loff_t *);
	int (*show)(struct seq_file___11 *, void *);
};

struct hw_perf_event___8 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___15 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	union {
		struct {
			u64 last_period;
			local64_t period_left;
		};
		struct {
			u64 saved_metric;
			u64 saved_slots;
		};
	};
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___8)(struct perf_event___8 *, struct perf_sample_data *, struct pt_regs *);

struct pmu___8;

struct fasync_struct___12;

struct pid_namespace___11;

struct trace_event_call___8;

struct perf_cgroup___8;

struct perf_event___8 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___8 *group_leader;
	struct pmu___8 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___8 hw;
	struct perf_event_context___8 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___8 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___15 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct perf_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___12 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	long unsigned int pending_addr;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	struct perf_addr_filter_range *addr_filter_ranges;
	long unsigned int addr_filters_gen;
	struct perf_event___8 *aux_event;
	void (*destroy)(struct perf_event___8 *);
	struct callback_head callback_head;
	struct pid_namespace___11 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___8 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___8 orig_overflow_handler;
	struct bpf_prog *prog;
	u64 bpf_cookie;
	struct trace_event_call___8 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___8 *cgrp;
	void *security;
	struct list_head sb_list;
};

struct upid___11 {
	int nr;
	struct pid_namespace___11 *ns;
};

struct pid_namespace___11 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___15 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___11 *parent;
	struct fs_pin *bacct;
	struct user_namespace *user_ns;
	struct ucounts *ucounts;
	int reboot;
	struct ns_common ns;
};

struct pid___11 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___11 numbers[1];
};

struct signal_struct___13 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___15 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___15 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper;
	unsigned int has_child_subreaper;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___11 *pids[4];
	struct pid___11 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___15 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct cgroup_namespace___10;

struct nsproxy___12 {
	atomic_t count;
	struct uts_namespace *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___11 *pid_ns_for_children;
	struct net *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___10 *cgroup_ns;
};

struct bio___9;

struct bio_list___9 {
	struct bio___9 *head;
	struct bio___9 *tail;
};

struct cgroup_subsys_state___10;

struct bdi_writeback___8 {
	struct backing_dev_info___8 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	atomic_t writeback_inodes;
	struct percpu_counter stat[4];
	long unsigned int congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	struct delayed_work bw_dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___10 *memcg_css;
	struct cgroup_subsys_state___10 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	struct list_head b_attached;
	struct list_head offline_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
};

struct device___14;

struct backing_dev_info___8 {
	u64 id;
	struct rb_node rb_node;
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___8 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct mutex cgwb_release_mutex;
	struct rw_semaphore wb_switch_rwsem;
	wait_queue_head_t wb_waitq;
	struct device___14 *dev;
	char dev_name[64];
	struct device___14 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___12 *debug_dir;
};

struct io_cq___9;

struct io_context___10 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	struct xarray icq_tree;
	struct io_cq___9 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct cgroup___10;

struct css_set___10 {
	struct cgroup_subsys_state___10 *subsys[14];
	refcount_t refcount;
	struct css_set___10 *dom_cset;
	struct cgroup___10 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___10 *mg_src_cgrp;
	struct cgroup___10 *mg_dst_cgrp;
	struct css_set___10 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___8 {
	struct pmu___8 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	int rotate_necessary;
	refcount_t refcount;
	struct task_struct___15 *task;
	u64 time;
	u64 timestamp;
	u64 timeoffset;
	struct perf_event_context___8 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

struct cgroup_subsys___10;

struct cgroup_subsys_state___10 {
	struct cgroup___10 *cgroup;
	struct cgroup_subsys___10 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___10 *parent;
};

struct kernfs_node___12;

struct cgroup_file___10 {
	struct kernfs_node___12 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct obj_cgroup___8;

struct mem_cgroup_per_node___8;

struct mem_cgroup___8 {
	struct cgroup_subsys_state___10 css;
	struct mem_cgroup_id id;
	struct page_counter memory;
	union {
		struct page_counter swap;
		struct page_counter memsw;
	};
	struct page_counter kmem;
	struct page_counter tcpmem;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool oom_group;
	bool oom_lock;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___10 events_file;
	struct cgroup_file___10 events_local_file;
	struct cgroup_file___10 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	struct memcg_vmstats vmstats;
	atomic_long_t memory_events[8];
	atomic_long_t memory_events_local[8];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct obj_cgroup___8 *objcg;
	struct list_head objcg_list;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad2_;
	atomic_t moving_account;
	struct task_struct___15 *move_lock_task;
	struct memcg_vmstats_percpu *vmstats_percpu;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct memcg_cgwb_frn cgwb_frn[4];
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct deferred_split deferred_split_queue;
	struct mem_cgroup_per_node___8 *nodeinfo[0];
	long: 64;
};

struct kset___12;

struct kobj_type___12;

struct kobject___13 {
	const char *name;
	struct list_head entry;
	struct kobject___13 *parent;
	struct kset___12 *kset;
	struct kobj_type___12 *ktype;
	struct kernfs_node___12 *sd;
	struct kref kref;
	unsigned int state_initialized;
	unsigned int state_in_sysfs;
	unsigned int state_add_uevent_sent;
	unsigned int state_remove_uevent_sent;
	unsigned int uevent_suppress;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct blk_integrity_profile___9;

struct blk_integrity___9 {
	const struct blk_integrity_profile___9 *profile;
	unsigned char flags;
	unsigned char tuple_size;
	unsigned char interval_exp;
	unsigned char tag_size;
};

struct bio_set___9 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	struct bio_alloc_cache *cache;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	unsigned int back_pad;
	spinlock_t rescue_lock;
	struct bio_list___9 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	struct hlist_node cpuhp_dead;
};

struct request___9;

struct elevator_queue___9;

struct gendisk___9;

struct blkcg_gq___8;

struct request_queue___9 {
	struct request___9 *last_merge;
	struct elevator_queue___9 *elevator;
	struct percpu_ref q_usage_counter;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	const struct blk_mq_ops *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx **queue_hw_ctx;
	unsigned int nr_hw_queues;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	spinlock_t queue_lock;
	struct gendisk___9 *disk;
	struct kobject___13 kobj;
	struct kobject___13 *mq_kobj;
	struct blk_integrity___9 integrity;
	struct device___14 *dev;
	enum rpm_status rpm_status;
	long unsigned int nr_requests;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_keyslot_manager *ksm;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	atomic_t nr_active_requests_shared_sbitmap;
	struct sbitmap_queue sched_bitmap_tags;
	struct sbitmap_queue sched_breserved_tags;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___8 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int required_elevator_features;
	unsigned int nr_zones;
	long unsigned int *conv_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int max_open_zones;
	unsigned int max_active_zones;
	int node;
	struct mutex debugfs_mutex;
	struct blk_trace *blk_trace;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	struct mutex sysfs_dir_lock;
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	int mq_freeze_depth;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct mutex mq_freeze_lock;
	struct blk_mq_tag_set *tag_set;
	struct list_head tag_set_list;
	struct bio_set___9 bio_split;
	struct dentry___12 *debugfs_dir;
	struct dentry___12 *sched_debugfs_dir;
	struct dentry___12 *rqos_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	u64 write_hints[5];
};

struct vm_struct___12 {
	struct vm_struct___12 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___13 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct address_space_operations___12;

struct address_space___12 {
	struct inode___12 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___12 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct dev_pagemap_ops___12;

struct dev_pagemap___12 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___12 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vfsmount___12;

struct path___12 {
	struct vfsmount___12 *mnt;
	struct dentry___12 *dentry;
};

struct fown_struct___11 {
	rwlock_t lock;
	struct pid___11 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___12 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___12 f_path;
	struct inode___12 *f_inode;
	const struct file_operations___12 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___11 f_owner;
	const struct cred *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___12 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___12;

struct vm_operations_struct___12 {
	void (*open)(struct vm_area_struct___14 *);
	void (*close)(struct vm_area_struct___14 *);
	int (*may_split)(struct vm_area_struct___14 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___14 *);
	int (*mprotect)(struct vm_area_struct___14 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___12 *);
	vm_fault_t (*huge_fault)(struct vm_fault___12 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___12 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___14 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___12 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___12 *);
	int (*access)(struct vm_area_struct___14 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___14 *);
	int (*set_policy)(struct vm_area_struct___14 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___14 *, long unsigned int);
	struct page___13 * (*find_special_page)(struct vm_area_struct___14 *, long unsigned int);
};

struct core_thread___13 {
	struct task_struct___15 *task;
	struct core_thread___13 *next;
};

struct core_state___13 {
	atomic_t nr_threads;
	struct core_thread___13 dumper;
	struct completion startup;
};

struct vm_fault___12 {
	const struct {
		struct vm_area_struct___14 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___13 *cow_page;
	struct page___13 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___13 prealloc_pte;
};

struct pglist_data___8;

struct lruvec___8 {
	struct list_head lists[5];
	spinlock_t lru_lock;
	long unsigned int anon_cost;
	long unsigned int file_cost;
	atomic_long_t nonresident_age;
	long unsigned int refaults[2];
	long unsigned int flags;
	struct pglist_data___8 *pgdat;
};

struct zone___8 {
	long unsigned int _watermark[3];
	long unsigned int watermark_boost;
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[5];
	int node;
	struct pglist_data___8 *zone_pgdat;
	struct per_cpu_pages *per_cpu_pageset;
	struct per_cpu_zonestat *per_cpu_zonestats;
	int pageset_high;
	int pageset_batch;
	long unsigned int zone_start_pfn;
	atomic_long_t managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int present_early_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	seqlock_t span_seqlock;
	int initialized;
	int: 32;
	struct zone_padding _pad1_;
	struct free_area free_area[11];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	long unsigned int compact_init_migrate_pfn;
	long unsigned int compact_init_free_pfn;
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	short: 16;
	struct zone_padding _pad3_;
	atomic_long_t vm_stat[11];
	atomic_long_t vm_numa_event[6];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___8 {
	struct zone___8 *zone;
	int zone_idx;
};

struct zonelist___8 {
	struct zoneref___8 _zonerefs[5121];
};

struct pglist_data___8 {
	struct zone___8 node_zones[5];
	struct zonelist___8 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___15 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_highest_zoneidx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_highest_zoneidx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___15 *kcompactd;
	bool proactive_compact_trigger;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct deferred_split deferred_split_queue;
	struct lruvec___8 __lruvec;
	long unsigned int flags;
	long: 64;
	struct zone_padding _pad2_;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[39];
};

struct kernfs_root___12;

struct kernfs_elem_dir___12 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___12 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___12;

struct kernfs_root___12 {
	struct kernfs_node___12 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___12 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___12 {
	struct kernfs_node___12 *target_kn;
};

struct kernfs_ops___12;

struct kernfs_elem_attr___12 {
	const struct kernfs_ops___12 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___12 *notify_next;
};

struct kernfs_node___12 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___12 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___12 dir;
		struct kernfs_elem_symlink___12 symlink;
		struct kernfs_elem_attr___12 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___12;

struct kernfs_ops___12 {
	int (*open)(struct kernfs_open_file___12 *);
	void (*release)(struct kernfs_open_file___12 *);
	int (*seq_show)(struct seq_file___11 *, void *);
	void * (*seq_start)(struct seq_file___11 *, loff_t *);
	void * (*seq_next)(struct seq_file___11 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___11 *, void *);
	ssize_t (*read)(struct kernfs_open_file___12 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___12 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___12 *, struct poll_table_struct___9 *);
	int (*mmap)(struct kernfs_open_file___12 *, struct vm_area_struct___14 *);
};

struct kernfs_syscall_ops___12 {
	int (*show_options)(struct seq_file___11 *, struct kernfs_root___12 *);
	int (*mkdir)(struct kernfs_node___12 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___12 *);
	int (*rename)(struct kernfs_node___12 *, struct kernfs_node___12 *, const char *);
	int (*show_path)(struct seq_file___11 *, struct kernfs_node___12 *, struct kernfs_root___12 *);
};

struct seq_file___11 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___11 *op;
	int poll_event;
	const struct file___12 *file;
	void *private;
};

struct kernfs_open_file___12 {
	struct kernfs_node___12 *kn;
	struct file___12 *file;
	struct seq_file___11 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped;
	bool released;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___12 *vm_ops;
};

typedef void (*poll_queue_proc___9)(struct file___12 *, wait_queue_head_t *, struct poll_table_struct___9 *);

struct poll_table_struct___9 {
	poll_queue_proc___9 _qproc;
	__poll_t _key;
};

struct bin_attribute___13;

struct attribute_group___13 {
	const char *name;
	umode_t (*is_visible)(struct kobject___13 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___13 *, struct bin_attribute___13 *, int);
	struct attribute **attrs;
	struct bin_attribute___13 **bin_attrs;
};

struct bin_attribute___13 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___12 * (*f_mapping)();
	ssize_t (*read)(struct file___12 *, struct kobject___13 *, struct bin_attribute___13 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___12 *, struct kobject___13 *, struct bin_attribute___13 *, char *, loff_t, size_t);
	int (*mmap)(struct file___12 *, struct kobject___13 *, struct bin_attribute___13 *, struct vm_area_struct___14 *);
};

struct sysfs_ops___12 {
	ssize_t (*show)(struct kobject___13 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___13 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___12;

struct kset___12 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___13 kobj;
	const struct kset_uevent_ops___12 *uevent_ops;
};

struct kobj_type___12 {
	void (*release)(struct kobject___13 *);
	const struct sysfs_ops___12 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___13 **default_groups;
	const struct kobj_ns_type_operations * (*child_ns_type)(struct kobject___13 *);
	const void * (*namespace)(struct kobject___13 *);
	void (*get_ownership)(struct kobject___13 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___12 {
	int (* const filter)(struct kset___12 *, struct kobject___13 *);
	const char * (* const name)(struct kset___12 *, struct kobject___13 *);
	int (* const uevent)(struct kset___12 *, struct kobject___13 *, struct kobj_uevent_env *);
};

struct wakeup_source___13;

struct dev_pm_info___13 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___13 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___14 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___13;

struct bus_type___13;

struct device_driver___13;

struct dev_pm_domain___13;

struct device_node___9;

struct fwnode_handle___12;

struct class___13;

struct device___14 {
	struct kobject___13 kobj;
	struct device___14 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___13 *type;
	struct bus_type___13 *bus;
	struct device_driver___13 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___13 power;
	struct dev_pm_domain___13 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___9 *of_node;
	struct fwnode_handle___12 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___13 *class;
	const struct attribute_group___13 **groups;
	void (*release)(struct device___14 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_ops___13 {
	int (*prepare)(struct device___14 *);
	void (*complete)(struct device___14 *);
	int (*suspend)(struct device___14 *);
	int (*resume)(struct device___14 *);
	int (*freeze)(struct device___14 *);
	int (*thaw)(struct device___14 *);
	int (*poweroff)(struct device___14 *);
	int (*restore)(struct device___14 *);
	int (*suspend_late)(struct device___14 *);
	int (*resume_early)(struct device___14 *);
	int (*freeze_late)(struct device___14 *);
	int (*thaw_early)(struct device___14 *);
	int (*poweroff_late)(struct device___14 *);
	int (*restore_early)(struct device___14 *);
	int (*suspend_noirq)(struct device___14 *);
	int (*resume_noirq)(struct device___14 *);
	int (*freeze_noirq)(struct device___14 *);
	int (*thaw_noirq)(struct device___14 *);
	int (*poweroff_noirq)(struct device___14 *);
	int (*restore_noirq)(struct device___14 *);
	int (*runtime_suspend)(struct device___14 *);
	int (*runtime_resume)(struct device___14 *);
	int (*runtime_idle)(struct device___14 *);
};

struct wakeup_source___13 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___14 *dev;
	bool active;
	bool autosleep_enabled;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___13 {
	struct dev_pm_ops___13 ops;
	int (*start)(struct device___14 *);
	void (*detach)(struct device___14 *, bool);
	int (*activate)(struct device___14 *);
	void (*sync)(struct device___14 *);
	void (*dismiss)(struct device___14 *);
};

struct bus_type___13 {
	const char *name;
	const char *dev_name;
	struct device___14 *dev_root;
	const struct attribute_group___13 **bus_groups;
	const struct attribute_group___13 **dev_groups;
	const struct attribute_group___13 **drv_groups;
	int (*match)(struct device___14 *, struct device_driver___13 *);
	int (*uevent)(struct device___14 *, struct kobj_uevent_env *);
	int (*probe)(struct device___14 *);
	void (*sync_state)(struct device___14 *);
	void (*remove)(struct device___14 *);
	void (*shutdown)(struct device___14 *);
	int (*online)(struct device___14 *);
	int (*offline)(struct device___14 *);
	int (*suspend)(struct device___14 *, pm_message_t);
	int (*resume)(struct device___14 *);
	int (*num_vf)(struct device___14 *);
	int (*dma_configure)(struct device___14 *);
	const struct dev_pm_ops___13 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___13 {
	const char *name;
	struct bus_type___13 *bus;
	struct module___13 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___14 *);
	void (*sync_state)(struct device___14 *);
	int (*remove)(struct device___14 *);
	void (*shutdown)(struct device___14 *);
	int (*suspend)(struct device___14 *, pm_message_t);
	int (*resume)(struct device___14 *);
	const struct attribute_group___13 **groups;
	const struct attribute_group___13 **dev_groups;
	const struct dev_pm_ops___13 *pm;
	void (*coredump)(struct device___14 *);
	struct driver_private *p;
};

struct device_type___13 {
	const char *name;
	const struct attribute_group___13 **groups;
	int (*uevent)(struct device___14 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___14 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___14 *);
	const struct dev_pm_ops___13 *pm;
};

struct class___13 {
	const char *name;
	struct module___13 *owner;
	const struct attribute_group___13 **class_groups;
	const struct attribute_group___13 **dev_groups;
	struct kobject___13 *dev_kobj;
	int (*dev_uevent)(struct device___14 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___14 *, umode_t *);
	void (*class_release)(struct class___13 *);
	void (*dev_release)(struct device___14 *);
	int (*shutdown_pre)(struct device___14 *);
	const struct kobj_ns_type_operations *ns_type;
	const void * (*namespace)(struct device___14 *);
	void (*get_ownership)(struct device___14 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___13 *pm;
	struct subsys_private *p;
};

struct module_kobject___12 {
	struct kobject___13 kobj;
	struct module___13 *mod;
	struct kobject___13 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___12 {
	struct module___13 *mod;
	struct latch_tree_node node;
};

struct module_layout___12 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___12 mtn;
};

struct module_attribute___12;

struct kernel_param___12;

struct module___13 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___12 mkobj;
	struct module_attribute___12 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___13 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___12 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___12 core_layout;
	struct module_layout___12 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map___9 *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___8 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	int num_static_call_sites;
	struct static_call_site *static_call_sites;
	bool klp;
	bool klp_alive;
	struct klp_modinfo *klp_info;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fwnode_operations___12;

struct fwnode_handle___12 {
	struct fwnode_handle___12 *secondary;
	const struct fwnode_operations___12 *ops;
	struct device___14 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct device_node___9 {
	const char *name;
	phandle phandle;
	const char *full_name;
	struct fwnode_handle___12 fwnode;
	struct property *properties;
	struct property *deadprops;
	struct device_node___9 *parent;
	struct device_node___9 *child;
	struct device_node___9 *sibling;
	long unsigned int _flags;
	void *data;
};

struct irqaction___4 {
	irq_handler_t handler;
	void *dev_id;
	void *percpu_dev_id;
	struct irqaction___4 *next;
	irq_handler_t thread_fn;
	struct task_struct___15 *thread;
	struct irqaction___4 *secondary;
	unsigned int irq;
	unsigned int flags;
	long unsigned int thread_flags;
	long unsigned int thread_mask;
	const char *name;
	struct proc_dir_entry *dir;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fwnode_reference_args___12;

struct fwnode_endpoint___12;

struct fwnode_operations___12 {
	struct fwnode_handle___12 * (*get)(struct fwnode_handle___12 *);
	void (*put)(struct fwnode_handle___12 *);
	bool (*device_is_available)(const struct fwnode_handle___12 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___12 *, const struct device___14 *);
	bool (*property_present)(const struct fwnode_handle___12 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___12 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___12 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___12 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___12 *);
	struct fwnode_handle___12 * (*get_parent)(const struct fwnode_handle___12 *);
	struct fwnode_handle___12 * (*get_next_child_node)(const struct fwnode_handle___12 *, struct fwnode_handle___12 *);
	struct fwnode_handle___12 * (*get_named_child_node)(const struct fwnode_handle___12 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___12 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___12 *);
	struct fwnode_handle___12 * (*graph_get_next_endpoint)(const struct fwnode_handle___12 *, struct fwnode_handle___12 *);
	struct fwnode_handle___12 * (*graph_get_remote_endpoint)(const struct fwnode_handle___12 *);
	struct fwnode_handle___12 * (*graph_get_port_parent)(struct fwnode_handle___12 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___12 *, struct fwnode_endpoint___12 *);
	int (*add_links)(struct fwnode_handle___12 *);
};

struct fwnode_endpoint___12 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___12 *local_fwnode;
};

struct fwnode_reference_args___12 {
	struct fwnode_handle___12 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct dentry_operations___12;

struct dentry___12 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___12 *d_parent;
	struct qstr d_name;
	struct inode___12 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___12 *d_op;
	struct super_block___12 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___12;

struct inode___12 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___12 *i_op;
	struct super_block___12 *i_sb;
	struct address_space___12 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___8 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___12 *i_fop;
		void (*free_inode)(struct inode___12 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___12 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct cdev___5 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___12 {
	int (*d_revalidate)(struct dentry___12 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___12 *, unsigned int);
	int (*d_hash)(const struct dentry___12 *, struct qstr *);
	int (*d_compare)(const struct dentry___12 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___12 *);
	int (*d_init)(struct dentry___12 *);
	void (*d_release)(struct dentry___12 *);
	void (*d_prune)(struct dentry___12 *);
	void (*d_iput)(struct dentry___12 *, struct inode___12 *);
	char * (*d_dname)(struct dentry___12 *, char *, int);
	struct vfsmount___12 * (*d_automount)(struct path___12 *);
	int (*d_manage)(const struct path___12 *, bool);
	struct dentry___12 * (*d_real)(struct dentry___12 *, const struct inode___12 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___12;

struct mem_dqinfo___12 {
	struct quota_format_type___12 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___12;

struct quota_info___12 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___12 *files[3];
	struct mem_dqinfo___12 info[3];
	const struct quota_format_ops___12 *ops[3];
};

struct rcuwait___12 {
	struct task_struct___15 *task;
};

struct percpu_rw_semaphore___12 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___12 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___12 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___12 rw_sem[3];
};

struct shrink_control___8;

struct shrinker___8 {
	long unsigned int (*count_objects)(struct shrinker___8 *, struct shrink_control___8 *);
	long unsigned int (*scan_objects)(struct shrinker___8 *, struct shrink_control___8 *);
	long int batch;
	int seeks;
	unsigned int flags;
	struct list_head list;
	int id;
	atomic_long_t *nr_deferred;
};

struct super_operations___12;

struct dquot_operations___12;

struct quotactl_ops___12;

struct block_device___9;

struct super_block___12 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___12 *s_type;
	const struct super_operations___12 *s_op;
	const struct dquot_operations___12 *dq_op;
	const struct quotactl_ops___12 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___12 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___9 *s_bdev;
	struct backing_dev_info___8 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___12 s_dquot;
	struct sb_writers___12 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___12 *s_d_op;
	int cleancache_poolid;
	struct shrinker___8 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___12 {
	struct dentry___12 *mnt_root;
	struct super_block___12 *mnt_sb;
	int mnt_flags;
	struct user_namespace *mnt_userns;
};

struct shrink_control___8 {
	gfp_t gfp_mask;
	int nid;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	struct mem_cgroup___8 *memcg;
};

struct psi_group___10 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___15 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___10;

struct cgroup_rstat_cpu___10;

struct cgroup___10 {
	struct cgroup_subsys_state___10 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___12 *kn;
	struct cgroup_file___10 procs_file;
	struct cgroup_file___10 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___10 *subsys[14];
	struct cgroup_root___10 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___10 *dom_cgrp;
	struct cgroup___10 *old_dom_cgrp;
	struct cgroup_rstat_cpu___10 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___10 psi;
	struct cgroup_bpf bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct io_cq___9 {
	struct request_queue___9 *q;
	struct io_context___10 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct kiocb___12 {
	struct file___12 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___12 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___6 *ki_waitq;
	};
};

struct iattr___12 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___12 *ia_file;
};

struct dquot___12 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___12 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___12 {
	int qf_fmt_id;
	const struct quota_format_ops___12 *qf_ops;
	struct module___13 *qf_owner;
	struct quota_format_type___12 *qf_next;
};

struct quota_format_ops___12 {
	int (*check_quota_file)(struct super_block___12 *, int);
	int (*read_file_info)(struct super_block___12 *, int);
	int (*write_file_info)(struct super_block___12 *, int);
	int (*free_file_info)(struct super_block___12 *, int);
	int (*read_dqblk)(struct dquot___12 *);
	int (*commit_dqblk)(struct dquot___12 *);
	int (*release_dqblk)(struct dquot___12 *);
	int (*get_next_id)(struct super_block___12 *, struct kqid *);
};

struct dquot_operations___12 {
	int (*write_dquot)(struct dquot___12 *);
	struct dquot___12 * (*alloc_dquot)(struct super_block___12 *, int);
	void (*destroy_dquot)(struct dquot___12 *);
	int (*acquire_dquot)(struct dquot___12 *);
	int (*release_dquot)(struct dquot___12 *);
	int (*mark_dirty)(struct dquot___12 *);
	int (*write_info)(struct super_block___12 *, int);
	qsize_t * (*get_reserved_space)(struct inode___12 *);
	int (*get_projid)(struct inode___12 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___12 *, qsize_t *);
	int (*get_next_id)(struct super_block___12 *, struct kqid *);
};

struct quotactl_ops___12 {
	int (*quota_on)(struct super_block___12 *, int, int, const struct path___12 *);
	int (*quota_off)(struct super_block___12 *, int);
	int (*quota_enable)(struct super_block___12 *, unsigned int);
	int (*quota_disable)(struct super_block___12 *, unsigned int);
	int (*quota_sync)(struct super_block___12 *, int);
	int (*set_info)(struct super_block___12 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___12 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___12 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___12 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___12 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___12 *, unsigned int);
};

struct writeback_control___8;

struct address_space_operations___12 {
	int (*writepage)(struct page___13 *, struct writeback_control___8 *);
	int (*readpage)(struct file___12 *, struct page___13 *);
	int (*writepages)(struct address_space___12 *, struct writeback_control___8 *);
	int (*set_page_dirty)(struct page___13 *);
	int (*readpages)(struct file___12 *, struct address_space___12 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control *);
	int (*write_begin)(struct file___12 *, struct address_space___12 *, loff_t, unsigned int, unsigned int, struct page___13 **, void **);
	int (*write_end)(struct file___12 *, struct address_space___12 *, loff_t, unsigned int, unsigned int, struct page___13 *, void *);
	sector_t (*bmap)(struct address_space___12 *, sector_t);
	void (*invalidatepage)(struct page___13 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___13 *, gfp_t);
	void (*freepage)(struct page___13 *);
	ssize_t (*direct_IO)(struct kiocb___12 *, struct iov_iter___10 *);
	int (*migratepage)(struct address_space___12 *, struct page___13 *, struct page___13 *, enum migrate_mode);
	bool (*isolate_page)(struct page___13 *, isolate_mode_t);
	void (*putback_page)(struct page___13 *);
	int (*launder_page)(struct page___13 *);
	int (*is_partially_uptodate)(struct page___13 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___13 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___12 *, struct page___13 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___12 *, sector_t *);
	void (*swap_deactivate)(struct file___12 *);
};

struct writeback_control___8 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate;
	unsigned int for_background;
	unsigned int tagged_writepages;
	unsigned int for_reclaim;
	unsigned int range_cyclic;
	unsigned int for_sync;
	unsigned int no_cgroup_owner;
	unsigned int punt_to_cgroup;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bdi_writeback___8 *wb;
	struct inode___12 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
};

struct bio_vec___10;

struct iov_iter___10 {
	u8 iter_type;
	bool data_source;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___10 *bvec;
		struct xarray *xarray;
		struct pipe_inode_info *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			unsigned int head;
			unsigned int start_head;
		};
		loff_t xarray_start;
	};
};

struct inode_operations___12 {
	struct dentry___12 * (*lookup)(struct inode___12 *, struct dentry___12 *, unsigned int);
	const char * (*get_link)(struct dentry___12 *, struct inode___12 *, struct delayed_call *);
	int (*permission)(struct user_namespace *, struct inode___12 *, int);
	struct posix_acl * (*get_acl)(struct inode___12 *, int, bool);
	int (*readlink)(struct dentry___12 *, char *, int);
	int (*create)(struct user_namespace *, struct inode___12 *, struct dentry___12 *, umode_t, bool);
	int (*link)(struct dentry___12 *, struct inode___12 *, struct dentry___12 *);
	int (*unlink)(struct inode___12 *, struct dentry___12 *);
	int (*symlink)(struct user_namespace *, struct inode___12 *, struct dentry___12 *, const char *);
	int (*mkdir)(struct user_namespace *, struct inode___12 *, struct dentry___12 *, umode_t);
	int (*rmdir)(struct inode___12 *, struct dentry___12 *);
	int (*mknod)(struct user_namespace *, struct inode___12 *, struct dentry___12 *, umode_t, dev_t);
	int (*rename)(struct user_namespace *, struct inode___12 *, struct dentry___12 *, struct inode___12 *, struct dentry___12 *, unsigned int);
	int (*setattr)(struct user_namespace *, struct dentry___12 *, struct iattr___12 *);
	int (*getattr)(struct user_namespace *, const struct path___12 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___12 *, char *, size_t);
	int (*fiemap)(struct inode___12 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___12 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___12 *, struct dentry___12 *, struct file___12 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace *, struct inode___12 *, struct dentry___12 *, umode_t);
	int (*set_acl)(struct user_namespace *, struct inode___12 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace *, struct dentry___12 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___12 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___12 {
	void (*fl_copy_lock)(struct file_lock___12 *, struct file_lock___12 *);
	void (*fl_release_private)(struct file_lock___12 *);
};

struct lock_manager_operations___12;

struct file_lock___12 {
	struct file_lock___12 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___12 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___12 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___12 *fl_ops;
	const struct lock_manager_operations___12 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___12 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___12 *);
	int (*lm_grant)(struct file_lock___12 *, int);
	bool (*lm_break)(struct file_lock___12 *);
	int (*lm_change)(struct file_lock___12 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___12 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___12 *);
};

struct fasync_struct___12 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___12 *fa_next;
	struct file___12 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___12 {
	struct inode___12 * (*alloc_inode)(struct super_block___12 *);
	void (*destroy_inode)(struct inode___12 *);
	void (*free_inode)(struct inode___12 *);
	void (*dirty_inode)(struct inode___12 *, int);
	int (*write_inode)(struct inode___12 *, struct writeback_control___8 *);
	int (*drop_inode)(struct inode___12 *);
	void (*evict_inode)(struct inode___12 *);
	void (*put_super)(struct super_block___12 *);
	int (*sync_fs)(struct super_block___12 *, int);
	int (*freeze_super)(struct super_block___12 *);
	int (*freeze_fs)(struct super_block___12 *);
	int (*thaw_super)(struct super_block___12 *);
	int (*unfreeze_fs)(struct super_block___12 *);
	int (*statfs)(struct dentry___12 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___12 *, int *, char *);
	void (*umount_begin)(struct super_block___12 *);
	int (*show_options)(struct seq_file___11 *, struct dentry___12 *);
	int (*show_devname)(struct seq_file___11 *, struct dentry___12 *);
	int (*show_path)(struct seq_file___11 *, struct dentry___12 *);
	int (*show_stats)(struct seq_file___11 *, struct dentry___12 *);
	ssize_t (*quota_read)(struct super_block___12 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___12 *, int, const char *, size_t, loff_t);
	struct dquot___12 ** (*get_dquots)(struct inode___12 *);
	long int (*nr_cached_objects)(struct super_block___12 *, struct shrink_control___8 *);
	long int (*free_cached_objects)(struct super_block___12 *, struct shrink_control___8 *);
	struct file___12 * (*real_loop)(struct file___12 *);
};

struct block_device___9 {
	sector_t bd_start_sect;
	struct disk_stats *bd_stats;
	long unsigned int bd_stamp;
	bool bd_read_only;
	dev_t bd_dev;
	int bd_openers;
	struct inode___12 *bd_inode;
	struct super_block___12 *bd_super;
	void *bd_claiming;
	struct device___14 bd_device;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct kobject___13 *bd_holder_dir;
	u8 bd_partno;
	spinlock_t bd_size_lock;
	struct gendisk___9 *bd_disk;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	struct super_block___12 *bd_fsfreeze_sb;
	struct partition_meta_info *bd_meta_info;
};

typedef void bio_end_io_t___9(struct bio___9 *);

struct bio_vec___10 {
	struct page___13 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___9;

struct bio___9 {
	struct bio___9 *bi_next;
	struct block_device___9 *bi_bdev;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	atomic_t __bi_remaining;
	struct bvec_iter bi_iter;
	bio_end_io_t___9 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___8 *bi_blkg;
	struct bio_issue bi_issue;
	u64 bi_iocost_cost;
	struct bio_crypt_ctx *bi_crypt_context;
	union {
		struct bio_integrity_payload___9 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___10 *bi_io_vec;
	struct bio_set___9 *bi_pool;
	struct bio_vec___10 bi_inline_vecs[0];
};

struct dev_pagemap_ops___12 {
	void (*page_free)(struct page___13 *);
	void (*kill)(struct dev_pagemap___12 *);
	void (*cleanup)(struct dev_pagemap___12 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___12 *);
};

struct kernel_param_ops___12 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___12 *);
	int (*get)(char *, const struct kernel_param___12 *);
	void (*free)(void *);
};

struct kparam_array___12;

struct kernel_param___12 {
	const char *name;
	struct module___13 *mod;
	const struct kernel_param_ops___12 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___12 *arr;
	};
};

struct kparam_array___12 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___12 *ops;
	void *elem;
};

struct module_attribute___12 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___12 *, struct module_kobject___12 *, char *);
	ssize_t (*store)(struct module_attribute___12 *, struct module_kobject___12 *, const char *, size_t);
	void (*setup)(struct module___13 *, const char *);
	int (*test)(struct module___13 *);
	void (*free)(struct module___13 *);
};

struct trace_event_class___8;

struct trace_event_call___8 {
	struct list_head list;
	struct trace_event_class___8 *class;
	union {
		char *name;
		struct tracepoint___9 *tp;
	};
	struct trace_event event;
	char *print_fmt;
	struct event_filter *filter;
	union {
		void *module;
		atomic_t refcnt;
	};
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
	struct bpf_prog_array *prog_array;
	int (*perf_perm)(struct trace_event_call___8 *, struct perf_event___8 *);
};

struct cgroup_namespace___10 {
	struct ns_common ns;
	struct user_namespace *user_ns;
	struct ucounts *ucounts;
	struct css_set___10 *root_cset;
};

struct irq_desc___4;

typedef void (*irq_flow_handler_t___4)(struct irq_desc___4 *);

struct irq_chip___4;

struct irq_data___4 {
	u32 mask;
	unsigned int irq;
	long unsigned int hwirq;
	struct irq_common_data___3 *common;
	struct irq_chip___4 *chip;
	struct irq_domain *domain;
	struct irq_data___4 *parent_data;
	void *chip_data;
};

struct irq_desc___4 {
	struct irq_common_data___3 irq_common_data;
	struct irq_data___4 irq_data;
	unsigned int *kstat_irqs;
	irq_flow_handler_t___4 handle_irq;
	struct irqaction___4 *action;
	unsigned int status_use_accessors;
	unsigned int core_internal_state__do_not_mess_with_it;
	unsigned int depth;
	unsigned int wake_depth;
	unsigned int tot_count;
	unsigned int irq_count;
	long unsigned int last_unhandled;
	unsigned int irqs_unhandled;
	atomic_t threads_handled;
	int threads_handled_last;
	raw_spinlock_t lock;
	struct cpumask *percpu_enabled;
	const struct cpumask *percpu_affinity;
	const struct cpumask *affinity_hint;
	struct irq_affinity_notify *affinity_notify;
	cpumask_var_t pending_mask;
	long unsigned int threads_oneshot;
	atomic_t threads_active;
	wait_queue_head_t wait_for_threads;
	unsigned int nr_actions;
	unsigned int no_suspend_depth;
	unsigned int cond_suspend_depth;
	unsigned int force_resume_depth;
	struct proc_dir_entry *dir;
	struct callback_head rcu;
	struct kobject___13 kobj;
	struct mutex request_mutex;
	int parent_irq;
	struct module___13 *owner;
	const char *name;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irq_chip___4 {
	struct device___14 *parent_device;
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___4 *);
	void (*irq_shutdown)(struct irq_data___4 *);
	void (*irq_enable)(struct irq_data___4 *);
	void (*irq_disable)(struct irq_data___4 *);
	void (*irq_ack)(struct irq_data___4 *);
	void (*irq_mask)(struct irq_data___4 *);
	void (*irq_mask_ack)(struct irq_data___4 *);
	void (*irq_unmask)(struct irq_data___4 *);
	void (*irq_eoi)(struct irq_data___4 *);
	int (*irq_set_affinity)(struct irq_data___4 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___4 *);
	int (*irq_set_type)(struct irq_data___4 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___4 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___4 *);
	void (*irq_bus_sync_unlock)(struct irq_data___4 *);
	void (*irq_cpu_online)(struct irq_data___4 *);
	void (*irq_cpu_offline)(struct irq_data___4 *);
	void (*irq_suspend)(struct irq_data___4 *);
	void (*irq_resume)(struct irq_data___4 *);
	void (*irq_pm_shutdown)(struct irq_data___4 *);
	void (*irq_calc_mask)(struct irq_data___4 *);
	void (*irq_print_chip)(struct irq_data___4 *, struct seq_file___11 *);
	int (*irq_request_resources)(struct irq_data___4 *);
	void (*irq_release_resources)(struct irq_data___4 *);
	void (*irq_compose_msi_msg)(struct irq_data___4 *, struct msi_msg *);
	void (*irq_write_msi_msg)(struct irq_data___4 *, struct msi_msg *);
	int (*irq_get_irqchip_state)(struct irq_data___4 *, enum irqchip_irq_state, bool *);
	int (*irq_set_irqchip_state)(struct irq_data___4 *, enum irqchip_irq_state, bool);
	int (*irq_set_vcpu_affinity)(struct irq_data___4 *, void *);
	void (*ipi_send_single)(struct irq_data___4 *, unsigned int);
	void (*ipi_send_mask)(struct irq_data___4 *, const struct cpumask *);
	int (*irq_nmi_setup)(struct irq_data___4 *);
	void (*irq_nmi_teardown)(struct irq_data___4 *);
	long unsigned int flags;
};

typedef struct irq_desc___4 *vector_irq_t[256];

struct cftype___10;

struct cgroup_subsys___10 {
	struct cgroup_subsys_state___10 * (*css_alloc)(struct cgroup_subsys_state___10 *);
	int (*css_online)(struct cgroup_subsys_state___10 *);
	void (*css_offline)(struct cgroup_subsys_state___10 *);
	void (*css_released)(struct cgroup_subsys_state___10 *);
	void (*css_free)(struct cgroup_subsys_state___10 *);
	void (*css_reset)(struct cgroup_subsys_state___10 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___10 *, int);
	int (*css_extra_stat_show)(struct seq_file___11 *, struct cgroup_subsys_state___10 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___15 *, struct css_set___10 *);
	void (*cancel_fork)(struct task_struct___15 *, struct css_set___10 *);
	void (*fork)(struct task_struct___15 *);
	void (*exit)(struct task_struct___15 *);
	void (*release)(struct task_struct___15 *);
	void (*bind)(struct cgroup_subsys_state___10 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___10 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___10 *dfl_cftypes;
	struct cftype___10 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___10 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___10 *updated_children;
	struct cgroup___10 *updated_next;
};

struct cgroup_root___10 {
	struct kernfs_root___12 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___10 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___10 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___10 *ss;
	struct list_head node;
	struct kernfs_ops___12 *kf_ops;
	int (*open)(struct kernfs_open_file___12 *);
	void (*release)(struct kernfs_open_file___12 *);
	u64 (*read_u64)(struct cgroup_subsys_state___10 *, struct cftype___10 *);
	s64 (*read_s64)(struct cgroup_subsys_state___10 *, struct cftype___10 *);
	int (*seq_show)(struct seq_file___11 *, void *);
	void * (*seq_start)(struct seq_file___11 *, loff_t *);
	void * (*seq_next)(struct seq_file___11 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___11 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___10 *, struct cftype___10 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___10 *, struct cftype___10 *, s64);
	ssize_t (*write)(struct kernfs_open_file___12 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___12 *, struct poll_table_struct___9 *);
};

struct block_device_operations___9;

struct gendisk___9 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	short unsigned int events;
	short unsigned int event_flags;
	struct xarray part_tbl;
	struct block_device___9 *part0;
	const struct block_device_operations___9 *fops;
	struct request_queue___9 *queue;
	void *private_data;
	int flags;
	long unsigned int state;
	struct mutex open_mutex;
	unsigned int open_partitions;
	struct backing_dev_info___8 *bdi;
	struct kobject___13 *slave_dir;
	struct list_head slave_bdevs;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___13 integrity_kobj;
	struct cdrom_device_info *cdi;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	u64 diskseq;
};

struct bio_integrity_payload___9 {
	struct bio___9 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___10 *bip_vec;
	struct bio_vec___10 bip_inline_vecs[0];
};

struct blkcg___8;

struct blkg_policy_data___8;

struct blkcg_gq___8 {
	struct request_queue___9 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___8 *blkcg;
	struct blkcg_gq___8 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_iostat_set *iostat_cpu;
	struct blkg_iostat_set iostat;
	struct blkg_policy_data___8 *pd[6];
	spinlock_t async_bio_lock;
	struct bio_list___9 async_bios;
	struct work_struct async_bio_work;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
	struct callback_head callback_head;
};

typedef void integrity_prepare_fn___9(struct request___9 *);

typedef void integrity_complete_fn___9(struct request___9 *, unsigned int);

struct blk_integrity_profile___9 {
	integrity_processing_fn *generate_fn;
	integrity_processing_fn *verify_fn;
	integrity_prepare_fn___9 *prepare_fn;
	integrity_complete_fn___9 *complete_fn;
	const char *name;
};

struct block_device_operations___9 {
	blk_qc_t (*submit_bio)(struct bio___9 *);
	int (*open)(struct block_device___9 *, fmode_t);
	void (*release)(struct gendisk___9 *, fmode_t);
	int (*rw_page)(struct block_device___9 *, sector_t, struct page___13 *, unsigned int);
	int (*ioctl)(struct block_device___9 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___9 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___9 *, unsigned int);
	void (*unlock_native_capacity)(struct gendisk___9 *);
	int (*getgeo)(struct block_device___9 *, struct hd_geometry *);
	int (*set_read_only)(struct block_device___9 *, bool);
	void (*swap_slot_free_notify)(struct block_device___9 *, long unsigned int);
	int (*report_zones)(struct gendisk___9 *, sector_t, unsigned int, report_zones_cb, void *);
	char * (*devnode)(struct gendisk___9 *, umode_t *);
	struct module___13 *owner;
	const struct pr_ops *pr_ops;
	int (*alternative_gpt_sector)(struct gendisk___9 *, sector_t *);
};

typedef void rq_end_io_fn___9(struct request___9 *, blk_status_t);

struct request___9 {
	struct request_queue___9 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int tag;
	int internal_tag;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___9 *bio;
	struct bio___9 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct llist_node ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___10 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___9 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___9 *saved_end_io;
		} flush;
	};
	struct gendisk___9 *rq_disk;
	struct block_device___9 *part;
	u64 alloc_time_ns;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int stats_sectors;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	struct bio_crypt_ctx *crypt_ctx;
	struct blk_ksm_keyslot *crypt_keyslot;
	short unsigned int write_hint;
	short unsigned int ioprio;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___9 *end_io;
	void *end_io_data;
};

struct elevator_type___9;

struct elevator_mq_ops___9 {
	int (*init_sched)(struct request_queue___9 *, struct elevator_type___9 *);
	void (*exit_sched)(struct elevator_queue___9 *);
	int (*init_hctx)(struct blk_mq_hw_ctx *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx *, unsigned int);
	void (*depth_updated)(struct blk_mq_hw_ctx *);
	bool (*allow_merge)(struct request_queue___9 *, struct request___9 *, struct bio___9 *);
	bool (*bio_merge)(struct request_queue___9 *, struct bio___9 *, unsigned int);
	int (*request_merge)(struct request_queue___9 *, struct request___9 **, struct bio___9 *);
	void (*request_merged)(struct request_queue___9 *, struct request___9 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___9 *, struct request___9 *, struct request___9 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___9 *);
	void (*finish_request)(struct request___9 *);
	void (*insert_requests)(struct blk_mq_hw_ctx *, struct list_head *, bool);
	struct request___9 * (*dispatch_request)(struct blk_mq_hw_ctx *);
	bool (*has_work)(struct blk_mq_hw_ctx *);
	void (*completed_request)(struct request___9 *, u64);
	void (*requeue_request)(struct request___9 *);
	struct request___9 * (*former_request)(struct request_queue___9 *, struct request___9 *);
	struct request___9 * (*next_request)(struct request_queue___9 *, struct request___9 *);
	void (*init_icq)(struct io_cq___9 *);
	void (*exit_icq)(struct io_cq___9 *);
};

struct elv_fs_entry___9;

struct elevator_type___9 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___9 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___9 *elevator_attrs;
	const char *elevator_name;
	const char *elevator_alias;
	const unsigned int elevator_features;
	struct module___13 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
};

struct elevator_queue___9 {
	struct elevator_type___9 *type;
	void *elevator_data;
	struct kobject___13 kobj;
	struct mutex sysfs_lock;
	unsigned int registered;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hlist_head hash[64];
};

struct elv_fs_entry___9 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___9 *, char *);
	ssize_t (*store)(struct elevator_queue___9 *, const char *, size_t);
};

struct blkcg_policy_data___8;

struct blkcg___8 {
	struct cgroup_subsys_state___10 css;
	spinlock_t lock;
	refcount_t online_pin;
	struct xarray blkg_tree;
	struct blkcg_gq___8 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___8 *cpd[6];
	struct list_head all_blkcgs_node;
	char fc_app_id[129];
	struct list_head cgwb_list;
};

struct blkcg_policy_data___8 {
	struct blkcg___8 *blkcg;
	int plid;
};

struct blkg_policy_data___8 {
	struct blkcg_gq___8 *blkg;
	int plid;
};

struct mem_cgroup_reclaim_iter___8 {
	struct mem_cgroup___8 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___8 {
	struct lruvec___8 lruvec;
	struct lruvec_stats_percpu *lruvec_stats_percpu;
	struct lruvec_stats lruvec_stats;
	long unsigned int lru_zone_size[25];
	struct mem_cgroup_reclaim_iter___8 iter;
	struct shrinker_info *shrinker_info;
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	struct mem_cgroup___8 *memcg;
};

struct obj_cgroup___8 {
	struct percpu_ref refcnt;
	struct mem_cgroup___8 *memcg;
	atomic_t nr_charged_bytes;
	union {
		struct list_head list;
		struct callback_head rcu;
	};
};

struct perf_cpu_context___8;

struct perf_output_handle___8;

struct pmu___8 {
	struct list_head entry;
	struct module___13 *module;
	struct device___14 *dev;
	const struct attribute_group___13 **attr_groups;
	const struct attribute_group___13 **attr_update;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___8 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___8 *);
	void (*pmu_disable)(struct pmu___8 *);
	int (*event_init)(struct perf_event___8 *);
	void (*event_mapped)(struct perf_event___8 *, struct mm_struct___15 *);
	void (*event_unmapped)(struct perf_event___8 *, struct mm_struct___15 *);
	int (*add)(struct perf_event___8 *, int);
	void (*del)(struct perf_event___8 *, int);
	void (*start)(struct perf_event___8 *, int);
	void (*stop)(struct perf_event___8 *, int);
	void (*read)(struct perf_event___8 *);
	void (*start_txn)(struct pmu___8 *, unsigned int);
	int (*commit_txn)(struct pmu___8 *);
	void (*cancel_txn)(struct pmu___8 *);
	int (*event_idx)(struct perf_event___8 *);
	void (*sched_task)(struct perf_event_context___8 *, bool);
	struct kmem_cache *task_ctx_cache;
	void (*swap_task_ctx)(struct perf_event_context___8 *, struct perf_event_context___8 *);
	void * (*setup_aux)(struct perf_event___8 *, void **, int, bool);
	void (*free_aux)(void *);
	long int (*snapshot_aux)(struct perf_event___8 *, struct perf_output_handle___8 *, long unsigned int);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___8 *);
	int (*aux_output_match)(struct perf_event___8 *);
	int (*filter_match)(struct perf_event___8 *);
	int (*check_period)(struct perf_event___8 *, u64);
};

struct perf_cpu_context___8 {
	struct perf_event_context___8 ctx;
	struct perf_event_context___8 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___8 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
	int heap_size;
	struct perf_event___8 **heap;
	struct perf_event___8 *heap_default[2];
};

struct perf_output_handle___8 {
	struct perf_event___8 *event;
	struct perf_buffer *rb;
	long unsigned int wakeup;
	long unsigned int size;
	u64 aux_flags;
	union {
		void *addr;
		long unsigned int head;
	};
	int page;
};

struct perf_cgroup___8 {
	struct cgroup_subsys_state___10 css;
	struct perf_cgroup_info *info;
};

struct trace_event_fields___8 {
	const char *type;
	union {
		struct {
			const char *name;
			const int size;
			const int align;
			const int is_signed;
			const int filter_type;
		};
		int (*define_fields)(struct trace_event_call___8 *);
	};
};

struct trace_event_class___8 {
	const char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct trace_event_call___8 *, enum trace_reg, void *);
	struct trace_event_fields___8 *fields_array;
	struct list_head * (*get_fields)(struct trace_event_call___8 *);
	struct list_head fields;
	int (*raw_init)(struct trace_event_call___8 *);
};

struct trace_event_file___5;

struct trace_event_buffer___5 {
	struct trace_buffer *buffer;
	struct ring_buffer_event *event;
	struct trace_event_file___5 *trace_file;
	void *entry;
	unsigned int trace_ctx;
	struct pt_regs *regs;
};

struct trace_event_file___5 {
	struct list_head list;
	struct trace_event_call___8 *event_call;
	struct event_filter *filter;
	struct dentry___12 *dir;
	struct trace_array *tr;
	struct trace_subsystem_dir *system;
	struct list_head triggers;
	long unsigned int flags;
	atomic_t sm_ref;
	atomic_t tm_ref;
};

struct trace_event_raw_x86_irq_vector {
	struct trace_entry ent;
	int vector;
	char __data[0];
};

struct trace_event_raw_vector_config {
	struct trace_entry ent;
	unsigned int irq;
	unsigned int vector;
	unsigned int cpu;
	unsigned int apicdest;
	char __data[0];
};

struct trace_event_raw_vector_mod {
	struct trace_entry ent;
	unsigned int irq;
	unsigned int vector;
	unsigned int cpu;
	unsigned int prev_vector;
	unsigned int prev_cpu;
	char __data[0];
};

struct trace_event_raw_vector_reserve {
	struct trace_entry ent;
	unsigned int irq;
	int ret;
	char __data[0];
};

struct trace_event_raw_vector_alloc {
	struct trace_entry ent;
	unsigned int irq;
	unsigned int vector;
	bool reserved;
	int ret;
	char __data[0];
};

struct trace_event_raw_vector_alloc_managed {
	struct trace_entry ent;
	unsigned int irq;
	unsigned int vector;
	int ret;
	char __data[0];
};

struct trace_event_raw_vector_activate {
	struct trace_entry ent;
	unsigned int irq;
	bool is_managed;
	bool can_reserve;
	bool reserve;
	char __data[0];
};

struct trace_event_raw_vector_teardown {
	struct trace_entry ent;
	unsigned int irq;
	bool is_managed;
	bool has_reserved;
	char __data[0];
};

struct trace_event_raw_vector_setup {
	struct trace_entry ent;
	unsigned int irq;
	bool is_legacy;
	int ret;
	char __data[0];
};

struct trace_event_raw_vector_free_moved {
	struct trace_entry ent;
	unsigned int irq;
	unsigned int cpu;
	unsigned int vector;
	bool is_managed;
	char __data[0];
};

struct trace_event_data_offsets_x86_irq_vector {};

struct trace_event_data_offsets_vector_config {};

struct trace_event_data_offsets_vector_mod {};

struct trace_event_data_offsets_vector_reserve {};

struct trace_event_data_offsets_vector_alloc {};

struct trace_event_data_offsets_vector_alloc_managed {};

struct trace_event_data_offsets_vector_activate {};

struct trace_event_data_offsets_vector_teardown {};

struct trace_event_data_offsets_vector_setup {};

struct trace_event_data_offsets_vector_free_moved {};

typedef void (*btf_trace_local_timer_entry)(void *, int);

typedef void (*btf_trace_local_timer_exit)(void *, int);

typedef void (*btf_trace_spurious_apic_entry)(void *, int);

typedef void (*btf_trace_spurious_apic_exit)(void *, int);

typedef void (*btf_trace_error_apic_entry)(void *, int);

typedef void (*btf_trace_error_apic_exit)(void *, int);

typedef void (*btf_trace_x86_platform_ipi_entry)(void *, int);

typedef void (*btf_trace_x86_platform_ipi_exit)(void *, int);

typedef void (*btf_trace_irq_work_entry)(void *, int);

typedef void (*btf_trace_irq_work_exit)(void *, int);

typedef void (*btf_trace_reschedule_entry)(void *, int);

typedef void (*btf_trace_reschedule_exit)(void *, int);

typedef void (*btf_trace_call_function_entry)(void *, int);

typedef void (*btf_trace_call_function_exit)(void *, int);

typedef void (*btf_trace_call_function_single_entry)(void *, int);

typedef void (*btf_trace_call_function_single_exit)(void *, int);

typedef void (*btf_trace_threshold_apic_entry)(void *, int);

typedef void (*btf_trace_threshold_apic_exit)(void *, int);

typedef void (*btf_trace_deferred_error_apic_entry)(void *, int);

typedef void (*btf_trace_deferred_error_apic_exit)(void *, int);

typedef void (*btf_trace_thermal_apic_entry)(void *, int);

typedef void (*btf_trace_thermal_apic_exit)(void *, int);

typedef void (*btf_trace_vector_config)(void *, unsigned int, unsigned int, unsigned int, unsigned int);

typedef void (*btf_trace_vector_update)(void *, unsigned int, unsigned int, unsigned int, unsigned int, unsigned int);

typedef void (*btf_trace_vector_clear)(void *, unsigned int, unsigned int, unsigned int, unsigned int, unsigned int);

typedef void (*btf_trace_vector_reserve_managed)(void *, unsigned int, int);

typedef void (*btf_trace_vector_reserve)(void *, unsigned int, int);

typedef void (*btf_trace_vector_alloc)(void *, unsigned int, unsigned int, bool, int);

typedef void (*btf_trace_vector_alloc_managed)(void *, unsigned int, unsigned int, int);

typedef void (*btf_trace_vector_activate)(void *, unsigned int, bool, bool, bool);

typedef void (*btf_trace_vector_deactivate)(void *, unsigned int, bool, bool, bool);

typedef void (*btf_trace_vector_teardown)(void *, unsigned int, bool, bool);

typedef void (*btf_trace_vector_setup)(void *, unsigned int, bool, int);

typedef void (*btf_trace_vector_free_moved)(void *, unsigned int, unsigned int, unsigned int, bool);

struct irq_stack {
	char stack[16384];
};

struct estack_pages {
	u32 offs;
	u16 size;
	u16 type;
};

struct irq_domain___8;

struct x86_init_irqs___4 {
	void (*pre_vector_init)();
	void (*intr_init)();
	void (*intr_mode_select)();
	void (*intr_mode_init)();
	struct irq_domain___8 * (*create_pci_msi_domain)();
};

struct irq_domain_ops___8;

struct irq_domain_chip_generic___4;

struct irq_data___5;

struct irq_domain___8 {
	struct list_head link;
	const char *name;
	const struct irq_domain_ops___8 *ops;
	void *host_data;
	unsigned int flags;
	unsigned int mapcount;
	struct fwnode_handle___12 *fwnode;
	enum irq_domain_bus_token bus_token;
	struct irq_domain_chip_generic___4 *gc;
	struct irq_domain___8 *parent;
	irq_hw_number_t hwirq_max;
	unsigned int revmap_size;
	struct xarray revmap_tree;
	struct mutex revmap_mutex;
	struct irq_data___5 *revmap[0];
};

struct x86_init_ops___4 {
	struct x86_init_resources resources;
	struct x86_init_mpparse mpparse;
	struct x86_init_irqs___4 irqs;
	struct x86_init_oem oem;
	struct x86_init_paging paging;
	struct x86_init_timers timers;
	struct x86_init_iommu iommu;
	struct x86_init_pci pci;
	struct x86_hyper_init hyper;
	struct x86_init_acpi acpi;
};

struct irqaction___5 {
	irq_handler_t handler;
	void *dev_id;
	void *percpu_dev_id;
	struct irqaction___5 *next;
	irq_handler_t thread_fn;
	struct task_struct___13 *thread;
	struct irqaction___5 *secondary;
	unsigned int irq;
	unsigned int flags;
	long unsigned int thread_flags;
	long unsigned int thread_mask;
	const char *name;
	struct proc_dir_entry *dir;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irq_desc___5;

typedef void (*irq_flow_handler_t___5)(struct irq_desc___5 *);

struct irq_chip___5;

struct irq_data___5 {
	u32 mask;
	unsigned int irq;
	long unsigned int hwirq;
	struct irq_common_data___3 *common;
	struct irq_chip___5 *chip;
	struct irq_domain___8 *domain;
	struct irq_data___5 *parent_data;
	void *chip_data;
};

struct irq_desc___5 {
	struct irq_common_data___3 irq_common_data;
	struct irq_data___5 irq_data;
	unsigned int *kstat_irqs;
	irq_flow_handler_t___5 handle_irq;
	struct irqaction___5 *action;
	unsigned int status_use_accessors;
	unsigned int core_internal_state__do_not_mess_with_it;
	unsigned int depth;
	unsigned int wake_depth;
	unsigned int tot_count;
	unsigned int irq_count;
	long unsigned int last_unhandled;
	unsigned int irqs_unhandled;
	atomic_t threads_handled;
	int threads_handled_last;
	raw_spinlock_t lock;
	struct cpumask *percpu_enabled;
	const struct cpumask *percpu_affinity;
	const struct cpumask *affinity_hint;
	struct irq_affinity_notify *affinity_notify;
	cpumask_var_t pending_mask;
	long unsigned int threads_oneshot;
	atomic_t threads_active;
	wait_queue_head_t wait_for_threads;
	unsigned int nr_actions;
	unsigned int no_suspend_depth;
	unsigned int cond_suspend_depth;
	unsigned int force_resume_depth;
	struct proc_dir_entry *dir;
	struct callback_head rcu;
	struct kobject___11 kobj;
	struct mutex request_mutex;
	int parent_irq;
	struct module *owner;
	const char *name;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irq_chip___5 {
	struct device___14 *parent_device;
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___5 *);
	void (*irq_shutdown)(struct irq_data___5 *);
	void (*irq_enable)(struct irq_data___5 *);
	void (*irq_disable)(struct irq_data___5 *);
	void (*irq_ack)(struct irq_data___5 *);
	void (*irq_mask)(struct irq_data___5 *);
	void (*irq_mask_ack)(struct irq_data___5 *);
	void (*irq_unmask)(struct irq_data___5 *);
	void (*irq_eoi)(struct irq_data___5 *);
	int (*irq_set_affinity)(struct irq_data___5 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___5 *);
	int (*irq_set_type)(struct irq_data___5 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___5 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___5 *);
	void (*irq_bus_sync_unlock)(struct irq_data___5 *);
	void (*irq_cpu_online)(struct irq_data___5 *);
	void (*irq_cpu_offline)(struct irq_data___5 *);
	void (*irq_suspend)(struct irq_data___5 *);
	void (*irq_resume)(struct irq_data___5 *);
	void (*irq_pm_shutdown)(struct irq_data___5 *);
	void (*irq_calc_mask)(struct irq_data___5 *);
	void (*irq_print_chip)(struct irq_data___5 *, struct seq_file *);
	int (*irq_request_resources)(struct irq_data___5 *);
	void (*irq_release_resources)(struct irq_data___5 *);
	void (*irq_compose_msi_msg)(struct irq_data___5 *, struct msi_msg *);
	void (*irq_write_msi_msg)(struct irq_data___5 *, struct msi_msg *);
	int (*irq_get_irqchip_state)(struct irq_data___5 *, enum irqchip_irq_state, bool *);
	int (*irq_set_irqchip_state)(struct irq_data___5 *, enum irqchip_irq_state, bool);
	int (*irq_set_vcpu_affinity)(struct irq_data___5 *, void *);
	void (*ipi_send_single)(struct irq_data___5 *, unsigned int);
	void (*ipi_send_mask)(struct irq_data___5 *, const struct cpumask *);
	int (*irq_nmi_setup)(struct irq_data___5 *);
	void (*irq_nmi_teardown)(struct irq_data___5 *);
	long unsigned int flags;
};

struct irq_chip_type___4 {
	struct irq_chip___5 chip;
	struct irq_chip_regs regs;
	irq_flow_handler_t___5 handler;
	u32 type;
	u32 mask_cache_priv;
	u32 *mask_cache;
};

struct irq_chip_generic___4 {
	raw_spinlock_t lock;
	void *reg_base;
	u32 (*reg_readl)(void *);
	void (*reg_writel)(u32, void *);
	void (*suspend)(struct irq_chip_generic___4 *);
	void (*resume)(struct irq_chip_generic___4 *);
	unsigned int irq_base;
	unsigned int irq_cnt;
	u32 mask_cache;
	u32 type_cache;
	u32 polarity_cache;
	u32 wake_enabled;
	u32 wake_active;
	unsigned int num_ct;
	void *private;
	long unsigned int installed;
	long unsigned int unused;
	struct irq_domain___8 *domain;
	struct list_head list;
	struct irq_chip_type___4 chip_types[0];
};

struct irq_domain_chip_generic___4 {
	unsigned int irqs_per_chip;
	unsigned int num_chips;
	unsigned int irq_flags_to_clear;
	unsigned int irq_flags_to_set;
	enum irq_gc_flags gc_flags;
	struct irq_chip_generic___4 *gc[0];
};

struct irq_domain_ops___8 {
	int (*match)(struct irq_domain___8 *, struct device_node___9 *, enum irq_domain_bus_token);
	int (*select)(struct irq_domain___8 *, struct irq_fwspec___7 *, enum irq_domain_bus_token);
	int (*map)(struct irq_domain___8 *, unsigned int, irq_hw_number_t);
	void (*unmap)(struct irq_domain___8 *, unsigned int);
	int (*xlate)(struct irq_domain___8 *, struct device_node___9 *, const u32 *, unsigned int, long unsigned int *, unsigned int *);
	int (*alloc)(struct irq_domain___8 *, unsigned int, unsigned int, void *);
	void (*free)(struct irq_domain___8 *, unsigned int, unsigned int);
	int (*activate)(struct irq_domain___8 *, struct irq_data___5 *, bool);
	void (*deactivate)(struct irq_domain___8 *, struct irq_data___5 *);
	int (*translate)(struct irq_domain___8 *, struct irq_fwspec___7 *, long unsigned int *, unsigned int *);
};

enum lockdown_reason {
	LOCKDOWN_NONE = 0,
	LOCKDOWN_MODULE_SIGNATURE = 1,
	LOCKDOWN_DEV_MEM = 2,
	LOCKDOWN_EFI_TEST = 3,
	LOCKDOWN_KEXEC = 4,
	LOCKDOWN_HIBERNATION = 5,
	LOCKDOWN_PCI_ACCESS = 6,
	LOCKDOWN_IOPORT = 7,
	LOCKDOWN_MSR = 8,
	LOCKDOWN_ACPI_TABLES = 9,
	LOCKDOWN_PCMCIA_CIS = 10,
	LOCKDOWN_TIOCSSERIAL = 11,
	LOCKDOWN_MODULE_PARAMETERS = 12,
	LOCKDOWN_MMIOTRACE = 13,
	LOCKDOWN_DEBUGFS = 14,
	LOCKDOWN_XMON_WR = 15,
	LOCKDOWN_BPF_WRITE_USER = 16,
	LOCKDOWN_INTEGRITY_MAX = 17,
	LOCKDOWN_KCORE = 18,
	LOCKDOWN_KPROBES = 19,
	LOCKDOWN_BPF_READ_KERNEL = 20,
	LOCKDOWN_PERF = 21,
	LOCKDOWN_TRACEFS = 22,
	LOCKDOWN_XMON_RW = 23,
	LOCKDOWN_XFRM_SECRET = 24,
	LOCKDOWN_CONFIDENTIALITY_MAX = 25,
};

enum lockdep_ok {
	LOCKDEP_STILL_OK = 0,
	LOCKDEP_NOW_UNRELIABLE = 1,
};

struct trace_event_raw_nmi_handler {
	struct trace_entry ent;
	void *handler;
	s64 delta_ns;
	int handled;
	char __data[0];
};

struct trace_event_data_offsets_nmi_handler {};

typedef void (*btf_trace_nmi_handler)(void *, void *, s64, int);

struct nmi_desc {
	raw_spinlock_t lock;
	struct list_head head;
};

struct nmi_stats {
	unsigned int normal;
	unsigned int unknown;
	unsigned int external;
	unsigned int swallow;
};

enum nmi_states {
	NMI_NOT_RUNNING = 0,
	NMI_EXECUTING = 1,
	NMI_LATCHED = 2,
};

struct user_desc {
	unsigned int entry_number;
	unsigned int base_addr;
	unsigned int limit;
	unsigned int seg_32bit: 1;
	unsigned int contents: 2;
	unsigned int read_exec_only: 1;
	unsigned int limit_in_pages: 1;
	unsigned int seg_not_present: 1;
	unsigned int useable: 1;
	unsigned int lm: 1;
	long: 63;
	long: 64;
};

struct syscall_metadata___2 {
	const char *name;
	int syscall_nr;
	int nb_args;
	const char **types;
	const char **args;
	struct list_head enter_fields;
	struct trace_event_call___7 *enter_event;
	struct trace_event_call___7 *exit_event;
};

struct tlb_state___4 {
	struct mm_struct___14 *loaded_mm;
	union {
		struct mm_struct___14 *last_user_mm;
		long unsigned int last_user_mm_spec;
	};
	u16 loaded_mm_asid;
	u16 next_asid;
	bool invalidate_other;
	short unsigned int user_pcid_flush_mask;
	long unsigned int cr4;
	struct tlb_context ctxs[6];
};

struct dentry___13;

struct super_block___13;

struct file_system_type___13 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___13 * (*mount)(struct file_system_type___13 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___13 *);
	struct module___3 *owner;
	struct file_system_type___13 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___13;

struct kiocb___13;

struct iov_iter___11;

struct poll_table_struct___10;

struct vm_area_struct___15;

struct inode___13;

struct file_lock___13;

struct page___14;

struct seq_file___12;

struct file_operations___13 {
	struct module___3 *owner;
	loff_t (*llseek)(struct file___13 *, loff_t, int);
	ssize_t (*read)(struct file___13 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___13 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___13 *, struct iov_iter___11 *);
	ssize_t (*write_iter)(struct kiocb___13 *, struct iov_iter___11 *);
	int (*iopoll)(struct kiocb___13 *, bool);
	int (*iterate)(struct file___13 *, struct dir_context *);
	int (*iterate_shared)(struct file___13 *, struct dir_context *);
	__poll_t (*poll)(struct file___13 *, struct poll_table_struct___10 *);
	long int (*unlocked_ioctl)(struct file___13 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___13 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___13 *, struct vm_area_struct___15 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___13 *, struct file___13 *);
	int (*flush)(struct file___13 *, fl_owner_t);
	int (*release)(struct inode___13 *, struct file___13 *);
	int (*fsync)(struct file___13 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___13 *, int);
	int (*lock)(struct file___13 *, int, struct file_lock___13 *);
	ssize_t (*sendpage)(struct file___13 *, struct page___14 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___13 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___13 *, long unsigned int);
	int (*flock)(struct file___13 *, int, struct file_lock___13 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___13 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___13 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___13 *, long int, struct file_lock___13 **, void **);
	long int (*fallocate)(struct file___13 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___12 *, struct file___13 *);
	ssize_t (*copy_file_range)(struct file___13 *, loff_t, struct file___13 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___13 *, loff_t, struct file___13 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___13 *, loff_t, loff_t, int);
};

struct static_call_mod___10 {
	struct static_call_mod___10 *next;
	struct module___3 *mod;
	struct static_call_site *sites;
};

struct static_call_key___10 {
	void *func;
	union {
		long unsigned int type;
		struct static_call_mod___10 *mods;
		struct static_call_site *sites;
	};
};

struct vmacache___14 {
	u64 seqnum;
	struct vm_area_struct___15 *vmas[4];
};

struct page_frag___14 {
	struct page___14 *page;
	__u32 offset;
	__u32 size;
};

struct pid___12;

struct nsproxy___13;

struct signal_struct___14;

struct bio_list___10;

struct backing_dev_info___9;

struct io_context___11;

struct css_set___11;

struct mem_cgroup___9;

struct request_queue___10;

struct vm_struct___13;

struct task_struct___16 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___16 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___3 *mm;
	struct mm_struct___3 *active_mm;
	struct vmacache___14 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int restore_sigmask: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___16 *real_parent;
	struct task_struct___16 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___16 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___12 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	struct posix_cputimers_work posix_cputimers_work;
	const struct cred *ptracer_cred;
	const struct cred *real_cred;
	const struct cred *cred;
	struct key *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___13 *nsproxy;
	struct signal_struct___14 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___16 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___10 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___9 *backing_dev_info;
	struct io_context___11 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___11 *cgroups;
	struct list_head cg_list;
	u32 closid;
	u32 rmid;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	long: 64;
	long: 64;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___14 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___9 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___9 *active_memcg;
	struct request_queue___10 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___16 *oom_reaper_list;
	struct vm_struct___13 *stack_vm_area;
	refcount_t stack_refcount;
	int patch_state;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	void *mce_vaddr;
	__u64 mce_kflags;
	u64 mce_addr;
	__u64 mce_ripv: 1;
	__u64 mce_whole_page: 1;
	__u64 __mce_reserved: 62;
	long: 2;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct callback_head mce_kill_me;
	int mce_count;
	struct llist_head kretprobe_instances;
	struct callback_head l1d_flush_kill;
	long: 64;
	struct thread_struct___9 thread;
};

struct edd {
	unsigned int mbr_signature[16];
	struct edd_info edd_info[6];
	unsigned char mbr_signature_nr;
	unsigned char edd_info_nr;
};

struct setup_data {
	__u64 next;
	__u32 type;
	__u32 len;
	__u8 data[0];
};

struct setup_indirect {
	__u32 type;
	__u32 reserved;
	__u64 len;
	__u64 addr;
};

typedef struct page___14 *pgtable_t___14;

struct address_space___13;

struct dev_pagemap___13;

struct page___14 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___13 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___14 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___14 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___3 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___13 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct core_state___14;

struct mm_struct___3 {
	struct {
		struct vm_area_struct___15 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___13 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int mmap_compat_base;
		long unsigned int mmap_compat_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[48];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___14 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___16 *owner;
		struct user_namespace *user_ns;
		struct file___13 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		bool tlb_flush_batched;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct vm_operations_struct___13;

struct vm_area_struct___15 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___15 *vm_next;
	struct vm_area_struct___15 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___3 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___13 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___13 *vm_file;
	struct file___13 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct tracepoint___10 {
	const char *name;
	struct static_key key;
	struct static_call_key___10 *static_call_key;
	void *static_call_tramp;
	void *iterator;
	int (*regfunc)();
	void (*unregfunc)();
	struct tracepoint_func *funcs;
};

struct bpf_raw_event_map___10 {
	struct tracepoint___10 *tp;
	void *bpf_func;
	u32 num_args;
	u32 writable_size;
	long: 64;
};

struct seq_operations___12 {
	void * (*start)(struct seq_file___12 *, loff_t *);
	void (*stop)(struct seq_file___12 *, void *);
	void * (*next)(struct seq_file___12 *, void *, loff_t *);
	int (*show)(struct seq_file___12 *, void *);
};

struct address_space_operations___13;

struct address_space___13 {
	struct inode___13 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___13 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct dev_pagemap_ops___13;

struct dev_pagemap___13 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___13 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vfsmount___13;

struct path___13 {
	struct vfsmount___13 *mnt;
	struct dentry___13 *dentry;
};

struct fown_struct___12 {
	rwlock_t lock;
	struct pid___12 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___13 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	long: 64;
	long: 64;
	struct path___13 f_path;
	struct inode___13 *f_inode;
	const struct file_operations___13 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___12 f_owner;
	const struct cred *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___13 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___13;

struct vm_operations_struct___13 {
	void (*open)(struct vm_area_struct___15 *);
	void (*close)(struct vm_area_struct___15 *);
	int (*may_split)(struct vm_area_struct___15 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___15 *);
	int (*mprotect)(struct vm_area_struct___15 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___13 *);
	vm_fault_t (*huge_fault)(struct vm_fault___13 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___13 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___15 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___13 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___13 *);
	int (*access)(struct vm_area_struct___15 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___15 *);
	int (*set_policy)(struct vm_area_struct___15 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___15 *, long unsigned int);
	struct page___14 * (*find_special_page)(struct vm_area_struct___15 *, long unsigned int);
};

struct core_thread___14 {
	struct task_struct___16 *task;
	struct core_thread___14 *next;
};

struct core_state___14 {
	atomic_t nr_threads;
	struct core_thread___14 dumper;
	struct completion startup;
};

struct vm_fault___13 {
	const struct {
		struct vm_area_struct___15 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___14 *cow_page;
	struct page___14 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___14 prealloc_pte;
};

struct pglist_data___9;

struct lruvec___9 {
	struct list_head lists[5];
	spinlock_t lru_lock;
	long unsigned int anon_cost;
	long unsigned int file_cost;
	atomic_long_t nonresident_age;
	long unsigned int refaults[2];
	long unsigned int flags;
	struct pglist_data___9 *pgdat;
};

struct zone___9 {
	long unsigned int _watermark[3];
	long unsigned int watermark_boost;
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[5];
	int node;
	struct pglist_data___9 *zone_pgdat;
	struct per_cpu_pages *per_cpu_pageset;
	struct per_cpu_zonestat *per_cpu_zonestats;
	int pageset_high;
	int pageset_batch;
	long unsigned int zone_start_pfn;
	atomic_long_t managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int present_early_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	seqlock_t span_seqlock;
	int initialized;
	int: 32;
	struct zone_padding _pad1_;
	struct free_area free_area[11];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	long unsigned int compact_init_migrate_pfn;
	long unsigned int compact_init_free_pfn;
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	short: 16;
	struct zone_padding _pad3_;
	atomic_long_t vm_stat[11];
	atomic_long_t vm_numa_event[6];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___9 {
	struct zone___9 *zone;
	int zone_idx;
};

struct zonelist___9 {
	struct zoneref___9 _zonerefs[5121];
};

struct pglist_data___9 {
	struct zone___9 node_zones[5];
	struct zonelist___9 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___16 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_highest_zoneidx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_highest_zoneidx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___16 *kcompactd;
	bool proactive_compact_trigger;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct deferred_split deferred_split_queue;
	struct lruvec___9 __lruvec;
	long unsigned int flags;
	long: 64;
	struct zone_padding _pad2_;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[39];
};

struct irq_domain___9;

struct x86_init_irqs___5 {
	void (*pre_vector_init)();
	void (*intr_init)();
	void (*intr_mode_select)();
	void (*intr_mode_init)();
	struct irq_domain___9 * (*create_pci_msi_domain)();
};

struct irq_domain_ops___9;

struct fwnode_handle___13;

struct irq_domain___9 {
	struct list_head link;
	const char *name;
	const struct irq_domain_ops___9 *ops;
	void *host_data;
	unsigned int flags;
	unsigned int mapcount;
	struct fwnode_handle___13 *fwnode;
	enum irq_domain_bus_token bus_token;
	struct irq_domain_chip_generic *gc;
	struct irq_domain___9 *parent;
	irq_hw_number_t hwirq_max;
	unsigned int revmap_size;
	struct xarray revmap_tree;
	struct mutex revmap_mutex;
	struct irq_data *revmap[0];
};

struct x86_init_ops___5 {
	struct x86_init_resources resources;
	struct x86_init_mpparse mpparse;
	struct x86_init_irqs___5 irqs;
	struct x86_init_oem oem;
	struct x86_init_paging paging;
	struct x86_init_timers timers;
	struct x86_init_iommu iommu;
	struct x86_init_pci pci;
	struct x86_hyper_init hyper;
	struct x86_init_acpi acpi;
};

struct kernfs_root___13;

struct kernfs_elem_dir___13 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___13 *root;
	long unsigned int rev;
};

struct kernfs_node___13;

struct kernfs_syscall_ops___13;

struct kernfs_root___13 {
	struct kernfs_node___13 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___13 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___13 {
	struct kernfs_node___13 *target_kn;
};

struct kernfs_ops___13;

struct kernfs_elem_attr___13 {
	const struct kernfs_ops___13 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___13 *notify_next;
};

struct kernfs_node___13 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___13 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___13 dir;
		struct kernfs_elem_symlink___13 symlink;
		struct kernfs_elem_attr___13 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___13;

struct kernfs_ops___13 {
	int (*open)(struct kernfs_open_file___13 *);
	void (*release)(struct kernfs_open_file___13 *);
	int (*seq_show)(struct seq_file___12 *, void *);
	void * (*seq_start)(struct seq_file___12 *, loff_t *);
	void * (*seq_next)(struct seq_file___12 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___12 *, void *);
	ssize_t (*read)(struct kernfs_open_file___13 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___13 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___13 *, struct poll_table_struct___10 *);
	int (*mmap)(struct kernfs_open_file___13 *, struct vm_area_struct___15 *);
};

struct kernfs_syscall_ops___13 {
	int (*show_options)(struct seq_file___12 *, struct kernfs_root___13 *);
	int (*mkdir)(struct kernfs_node___13 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___13 *);
	int (*rename)(struct kernfs_node___13 *, struct kernfs_node___13 *, const char *);
	int (*show_path)(struct seq_file___12 *, struct kernfs_node___13 *, struct kernfs_root___13 *);
};

struct seq_file___12 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___12 *op;
	int poll_event;
	const struct file___13 *file;
	void *private;
};

struct kernfs_open_file___13 {
	struct kernfs_node___13 *kn;
	struct file___13 *file;
	struct seq_file___12 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped;
	bool released;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___13 *vm_ops;
};

typedef void (*poll_queue_proc___10)(struct file___13 *, wait_queue_head_t *, struct poll_table_struct___10 *);

struct poll_table_struct___10 {
	poll_queue_proc___10 _qproc;
	__poll_t _key;
};

struct kobject___14;

struct bin_attribute___14;

struct attribute_group___14 {
	const char *name;
	umode_t (*is_visible)(struct kobject___14 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___14 *, struct bin_attribute___14 *, int);
	struct attribute **attrs;
	struct bin_attribute___14 **bin_attrs;
};

struct kset___13;

struct kobj_type___13;

struct kobject___14 {
	const char *name;
	struct list_head entry;
	struct kobject___14 *parent;
	struct kset___13 *kset;
	struct kobj_type___13 *ktype;
	struct kernfs_node___13 *sd;
	struct kref kref;
	unsigned int state_initialized;
	unsigned int state_in_sysfs;
	unsigned int state_add_uevent_sent;
	unsigned int state_remove_uevent_sent;
	unsigned int uevent_suppress;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bin_attribute___14 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___13 * (*f_mapping)();
	ssize_t (*read)(struct file___13 *, struct kobject___14 *, struct bin_attribute___14 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___13 *, struct kobject___14 *, struct bin_attribute___14 *, char *, loff_t, size_t);
	int (*mmap)(struct file___13 *, struct kobject___14 *, struct bin_attribute___14 *, struct vm_area_struct___15 *);
};

struct sysfs_ops___13 {
	ssize_t (*show)(struct kobject___14 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___14 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___13;

struct kset___13 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___14 kobj;
	const struct kset_uevent_ops___13 *uevent_ops;
};

struct kobj_type___13 {
	void (*release)(struct kobject___14 *);
	const struct sysfs_ops___13 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___14 **default_groups;
	const struct kobj_ns_type_operations * (*child_ns_type)(struct kobject___14 *);
	const void * (*namespace)(struct kobject___14 *);
	void (*get_ownership)(struct kobject___14 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___13 {
	int (* const filter)(struct kset___13 *, struct kobject___14 *);
	const char * (* const name)(struct kset___13 *, struct kobject___14 *);
	int (* const uevent)(struct kset___13 *, struct kobject___14 *, struct kobj_uevent_env *);
};

struct fwnode_operations___13;

struct fwnode_handle___13 {
	struct fwnode_handle___13 *secondary;
	const struct fwnode_operations___13 *ops;
	struct device___2 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct fwnode_reference_args___13;

struct fwnode_endpoint___13;

struct fwnode_operations___13 {
	struct fwnode_handle___13 * (*get)(struct fwnode_handle___13 *);
	void (*put)(struct fwnode_handle___13 *);
	bool (*device_is_available)(const struct fwnode_handle___13 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___13 *, const struct device___2 *);
	bool (*property_present)(const struct fwnode_handle___13 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___13 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___13 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___13 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___13 *);
	struct fwnode_handle___13 * (*get_parent)(const struct fwnode_handle___13 *);
	struct fwnode_handle___13 * (*get_next_child_node)(const struct fwnode_handle___13 *, struct fwnode_handle___13 *);
	struct fwnode_handle___13 * (*get_named_child_node)(const struct fwnode_handle___13 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___13 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___13 *);
	struct fwnode_handle___13 * (*graph_get_next_endpoint)(const struct fwnode_handle___13 *, struct fwnode_handle___13 *);
	struct fwnode_handle___13 * (*graph_get_remote_endpoint)(const struct fwnode_handle___13 *);
	struct fwnode_handle___13 * (*graph_get_port_parent)(struct fwnode_handle___13 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___13 *, struct fwnode_endpoint___13 *);
	int (*add_links)(struct fwnode_handle___13 *);
};

struct wakeup_source___14;

struct dev_pm_info___14 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___14 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___2 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___14;

struct bus_type___14;

struct device_driver___14;

struct dev_pm_domain___14;

struct dma_map_ops___2;

struct io_tlb_mem___2;

struct device_node___10;

struct class___14;

struct device___2 {
	struct kobject___14 kobj;
	struct device___2 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___14 *type;
	struct bus_type___14 *bus;
	struct device_driver___14 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___14 power;
	struct dev_pm_domain___14 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___9 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops___2 *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct io_tlb_mem___2 *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___10 *of_node;
	struct fwnode_handle___13 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___14 *class;
	const struct attribute_group___14 **groups;
	void (*release)(struct device___2 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fwnode_endpoint___13 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___13 *local_fwnode;
};

struct fwnode_reference_args___13 {
	struct fwnode_handle___13 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct device_node___10 {
	const char *name;
	phandle phandle;
	const char *full_name;
	struct fwnode_handle___13 fwnode;
	struct property *properties;
	struct property *deadprops;
	struct device_node___10 *parent;
	struct device_node___10 *child;
	struct device_node___10 *sibling;
	long unsigned int _flags;
	void *data;
};

struct irq_fwspec___8 {
	struct fwnode_handle___13 *fwnode;
	int param_count;
	u32 param[16];
};

struct irq_domain_ops___9 {
	int (*match)(struct irq_domain___9 *, struct device_node___10 *, enum irq_domain_bus_token);
	int (*select)(struct irq_domain___9 *, struct irq_fwspec___8 *, enum irq_domain_bus_token);
	int (*map)(struct irq_domain___9 *, unsigned int, irq_hw_number_t);
	void (*unmap)(struct irq_domain___9 *, unsigned int);
	int (*xlate)(struct irq_domain___9 *, struct device_node___10 *, const u32 *, unsigned int, long unsigned int *, unsigned int *);
	int (*alloc)(struct irq_domain___9 *, unsigned int, unsigned int, void *);
	void (*free)(struct irq_domain___9 *, unsigned int, unsigned int);
	int (*activate)(struct irq_domain___9 *, struct irq_data *, bool);
	void (*deactivate)(struct irq_domain___9 *, struct irq_data *);
	int (*translate)(struct irq_domain___9 *, struct irq_fwspec___8 *, long unsigned int *, unsigned int *);
};

struct pid_namespace___12;

struct upid___12 {
	int nr;
	struct pid_namespace___12 *ns;
};

struct pid_namespace___12 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___16 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___12 *parent;
	struct fs_pin *bacct;
	struct user_namespace *user_ns;
	struct ucounts *ucounts;
	int reboot;
	struct ns_common ns;
};

struct pid___12 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___12 numbers[1];
};

struct signal_struct___14 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___16 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___16 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper;
	unsigned int has_child_subreaper;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___12 *pids[4];
	struct pid___12 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___3 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct cgroup_namespace___11;

struct nsproxy___13 {
	atomic_t count;
	struct uts_namespace *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___12 *pid_ns_for_children;
	struct net *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___11 *cgroup_ns;
};

struct bio___10;

struct bio_list___10 {
	struct bio___10 *head;
	struct bio___10 *tail;
};

struct cgroup_subsys_state___11;

struct bdi_writeback___9 {
	struct backing_dev_info___9 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	atomic_t writeback_inodes;
	struct percpu_counter stat[4];
	long unsigned int congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	struct delayed_work bw_dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___11 *memcg_css;
	struct cgroup_subsys_state___11 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	struct list_head b_attached;
	struct list_head offline_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
};

struct backing_dev_info___9 {
	u64 id;
	struct rb_node rb_node;
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___9 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct mutex cgwb_release_mutex;
	struct rw_semaphore wb_switch_rwsem;
	wait_queue_head_t wb_waitq;
	struct device___2 *dev;
	char dev_name[64];
	struct device___2 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___13 *debug_dir;
};

struct io_cq___10;

struct io_context___11 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	struct xarray icq_tree;
	struct io_cq___10 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct cgroup___11;

struct css_set___11 {
	struct cgroup_subsys_state___11 *subsys[14];
	refcount_t refcount;
	struct css_set___11 *dom_cset;
	struct cgroup___11 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___11 *mg_src_cgrp;
	struct cgroup___11 *mg_dst_cgrp;
	struct css_set___11 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct cgroup_subsys___11;

struct cgroup_subsys_state___11 {
	struct cgroup___11 *cgroup;
	struct cgroup_subsys___11 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___11 *parent;
};

struct cgroup_file___11 {
	struct kernfs_node___13 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct obj_cgroup___9;

struct mem_cgroup_per_node___9;

struct mem_cgroup___9 {
	struct cgroup_subsys_state___11 css;
	struct mem_cgroup_id id;
	struct page_counter memory;
	union {
		struct page_counter swap;
		struct page_counter memsw;
	};
	struct page_counter kmem;
	struct page_counter tcpmem;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool oom_group;
	bool oom_lock;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___11 events_file;
	struct cgroup_file___11 events_local_file;
	struct cgroup_file___11 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	struct memcg_vmstats vmstats;
	atomic_long_t memory_events[8];
	atomic_long_t memory_events_local[8];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct obj_cgroup___9 *objcg;
	struct list_head objcg_list;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad2_;
	atomic_t moving_account;
	struct task_struct___16 *move_lock_task;
	struct memcg_vmstats_percpu *vmstats_percpu;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct memcg_cgwb_frn cgwb_frn[4];
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct deferred_split deferred_split_queue;
	struct mem_cgroup_per_node___9 *nodeinfo[0];
	long: 64;
};

struct blk_integrity_profile___10;

struct blk_integrity___10 {
	const struct blk_integrity_profile___10 *profile;
	unsigned char flags;
	unsigned char tuple_size;
	unsigned char interval_exp;
	unsigned char tag_size;
};

struct bio_set___10 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	struct bio_alloc_cache *cache;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	unsigned int back_pad;
	spinlock_t rescue_lock;
	struct bio_list___10 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	struct hlist_node cpuhp_dead;
};

struct request___10;

struct elevator_queue___10;

struct gendisk___10;

struct blkcg_gq___9;

struct request_queue___10 {
	struct request___10 *last_merge;
	struct elevator_queue___10 *elevator;
	struct percpu_ref q_usage_counter;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	const struct blk_mq_ops *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx **queue_hw_ctx;
	unsigned int nr_hw_queues;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	spinlock_t queue_lock;
	struct gendisk___10 *disk;
	struct kobject___14 kobj;
	struct kobject___14 *mq_kobj;
	struct blk_integrity___10 integrity;
	struct device___2 *dev;
	enum rpm_status rpm_status;
	long unsigned int nr_requests;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_keyslot_manager *ksm;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	atomic_t nr_active_requests_shared_sbitmap;
	struct sbitmap_queue sched_bitmap_tags;
	struct sbitmap_queue sched_breserved_tags;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___9 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int required_elevator_features;
	unsigned int nr_zones;
	long unsigned int *conv_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int max_open_zones;
	unsigned int max_active_zones;
	int node;
	struct mutex debugfs_mutex;
	struct blk_trace *blk_trace;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	struct mutex sysfs_dir_lock;
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	int mq_freeze_depth;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct mutex mq_freeze_lock;
	struct blk_mq_tag_set *tag_set;
	struct list_head tag_set_list;
	struct bio_set___10 bio_split;
	struct dentry___13 *debugfs_dir;
	struct dentry___13 *sched_debugfs_dir;
	struct dentry___13 *rqos_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	u64 write_hints[5];
};

struct vm_struct___13 {
	struct vm_struct___13 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___14 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct dev_pm_ops___14 {
	int (*prepare)(struct device___2 *);
	void (*complete)(struct device___2 *);
	int (*suspend)(struct device___2 *);
	int (*resume)(struct device___2 *);
	int (*freeze)(struct device___2 *);
	int (*thaw)(struct device___2 *);
	int (*poweroff)(struct device___2 *);
	int (*restore)(struct device___2 *);
	int (*suspend_late)(struct device___2 *);
	int (*resume_early)(struct device___2 *);
	int (*freeze_late)(struct device___2 *);
	int (*thaw_early)(struct device___2 *);
	int (*poweroff_late)(struct device___2 *);
	int (*restore_early)(struct device___2 *);
	int (*suspend_noirq)(struct device___2 *);
	int (*resume_noirq)(struct device___2 *);
	int (*freeze_noirq)(struct device___2 *);
	int (*thaw_noirq)(struct device___2 *);
	int (*poweroff_noirq)(struct device___2 *);
	int (*restore_noirq)(struct device___2 *);
	int (*runtime_suspend)(struct device___2 *);
	int (*runtime_resume)(struct device___2 *);
	int (*runtime_idle)(struct device___2 *);
};

struct wakeup_source___14 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___2 *dev;
	bool active;
	bool autosleep_enabled;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___14 {
	struct dev_pm_ops___14 ops;
	int (*start)(struct device___2 *);
	void (*detach)(struct device___2 *, bool);
	int (*activate)(struct device___2 *);
	void (*sync)(struct device___2 *);
	void (*dismiss)(struct device___2 *);
};

struct bus_type___14 {
	const char *name;
	const char *dev_name;
	struct device___2 *dev_root;
	const struct attribute_group___14 **bus_groups;
	const struct attribute_group___14 **dev_groups;
	const struct attribute_group___14 **drv_groups;
	int (*match)(struct device___2 *, struct device_driver___14 *);
	int (*uevent)(struct device___2 *, struct kobj_uevent_env *);
	int (*probe)(struct device___2 *);
	void (*sync_state)(struct device___2 *);
	void (*remove)(struct device___2 *);
	void (*shutdown)(struct device___2 *);
	int (*online)(struct device___2 *);
	int (*offline)(struct device___2 *);
	int (*suspend)(struct device___2 *, pm_message_t);
	int (*resume)(struct device___2 *);
	int (*num_vf)(struct device___2 *);
	int (*dma_configure)(struct device___2 *);
	const struct dev_pm_ops___14 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___14 {
	const char *name;
	struct bus_type___14 *bus;
	struct module___3 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___2 *);
	void (*sync_state)(struct device___2 *);
	int (*remove)(struct device___2 *);
	void (*shutdown)(struct device___2 *);
	int (*suspend)(struct device___2 *, pm_message_t);
	int (*resume)(struct device___2 *);
	const struct attribute_group___14 **groups;
	const struct attribute_group___14 **dev_groups;
	const struct dev_pm_ops___14 *pm;
	void (*coredump)(struct device___2 *);
	struct driver_private *p;
};

struct device_type___14 {
	const char *name;
	const struct attribute_group___14 **groups;
	int (*uevent)(struct device___2 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___2 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___2 *);
	const struct dev_pm_ops___14 *pm;
};

struct class___14 {
	const char *name;
	struct module___3 *owner;
	const struct attribute_group___14 **class_groups;
	const struct attribute_group___14 **dev_groups;
	struct kobject___14 *dev_kobj;
	int (*dev_uevent)(struct device___2 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___2 *, umode_t *);
	void (*class_release)(struct class___14 *);
	void (*dev_release)(struct device___2 *);
	int (*shutdown_pre)(struct device___2 *);
	const struct kobj_ns_type_operations *ns_type;
	const void * (*namespace)(struct device___2 *);
	void (*get_ownership)(struct device___2 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___14 *pm;
	struct subsys_private *p;
};

struct module_kobject___13 {
	struct kobject___14 kobj;
	struct module___3 *mod;
	struct kobject___14 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___13 {
	struct module___3 *mod;
	struct latch_tree_node node;
};

struct module_layout___13 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___13 mtn;
};

struct module_attribute___13;

struct kernel_param___13;

struct module___3 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___13 mkobj;
	struct module_attribute___13 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___14 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___13 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___13 core_layout;
	struct module_layout___13 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map___10 *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___4 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	int num_static_call_sites;
	struct static_call_site *static_call_sites;
	bool klp;
	bool klp_alive;
	struct klp_modinfo *klp_info;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dma_map_ops___2 {
	void * (*alloc)(struct device___2 *, size_t, dma_addr_t *, gfp_t, long unsigned int);
	void (*free)(struct device___2 *, size_t, void *, dma_addr_t, long unsigned int);
	struct page___14 * (*alloc_pages)(struct device___2 *, size_t, dma_addr_t *, enum dma_data_direction, gfp_t);
	void (*free_pages)(struct device___2 *, size_t, struct page___14 *, dma_addr_t, enum dma_data_direction);
	struct sg_table * (*alloc_noncontiguous)(struct device___2 *, size_t, enum dma_data_direction, gfp_t, long unsigned int);
	void (*free_noncontiguous)(struct device___2 *, size_t, struct sg_table *, enum dma_data_direction);
	int (*mmap)(struct device___2 *, struct vm_area_struct___15 *, void *, dma_addr_t, size_t, long unsigned int);
	int (*get_sgtable)(struct device___2 *, struct sg_table *, void *, dma_addr_t, size_t, long unsigned int);
	dma_addr_t (*map_page)(struct device___2 *, struct page___14 *, long unsigned int, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_page)(struct device___2 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	int (*map_sg)(struct device___2 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	void (*unmap_sg)(struct device___2 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	dma_addr_t (*map_resource)(struct device___2 *, phys_addr_t, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_resource)(struct device___2 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	void (*sync_single_for_cpu)(struct device___2 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___2 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___2 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___2 *, struct scatterlist *, int, enum dma_data_direction);
	void (*cache_sync)(struct device___2 *, void *, size_t, enum dma_data_direction);
	int (*dma_supported)(struct device___2 *, u64);
	u64 (*get_required_mask)(struct device___2 *);
	size_t (*max_mapping_size)(struct device___2 *);
	long unsigned int (*get_merge_boundary)(struct device___2 *);
};

struct io_tlb_mem___2 {
	phys_addr_t start;
	phys_addr_t end;
	long unsigned int nslabs;
	long unsigned int used;
	unsigned int index;
	spinlock_t lock;
	struct dentry___13 *debugfs;
	bool late_alloc;
	bool force_bounce;
	bool for_alloc;
	struct io_tlb_slot *slots;
};

struct kernel_param_ops___13 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___13 *);
	int (*get)(char *, const struct kernel_param___13 *);
	void (*free)(void *);
};

struct kparam_array___13;

struct kernel_param___13 {
	const char *name;
	struct module___3 *mod;
	const struct kernel_param_ops___13 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___13 *arr;
	};
};

struct kparam_array___13 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___13 *ops;
	void *elem;
};

struct module_attribute___13 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___13 *, struct module_kobject___13 *, char *);
	ssize_t (*store)(struct module_attribute___13 *, struct module_kobject___13 *, const char *, size_t);
	void (*setup)(struct module___3 *, const char *);
	int (*test)(struct module___3 *);
	void (*free)(struct module___3 *);
};

enum con_scroll {
	SM_UP = 0,
	SM_DOWN = 1,
};

struct vc_data;

struct console_font;

enum vc_intensity;

struct consw {
	struct module___3 *owner;
	const char * (*con_startup)();
	void (*con_init)(struct vc_data *, int);
	void (*con_deinit)(struct vc_data *);
	void (*con_clear)(struct vc_data *, int, int, int, int);
	void (*con_putc)(struct vc_data *, int, int, int);
	void (*con_putcs)(struct vc_data *, const short unsigned int *, int, int, int);
	void (*con_cursor)(struct vc_data *, int);
	bool (*con_scroll)(struct vc_data *, unsigned int, unsigned int, enum con_scroll, unsigned int);
	int (*con_switch)(struct vc_data *);
	int (*con_blank)(struct vc_data *, int, int);
	int (*con_font_set)(struct vc_data *, struct console_font *, unsigned int);
	int (*con_font_get)(struct vc_data *, struct console_font *);
	int (*con_font_default)(struct vc_data *, struct console_font *, char *);
	int (*con_resize)(struct vc_data *, unsigned int, unsigned int, unsigned int);
	void (*con_set_palette)(struct vc_data *, const unsigned char *);
	void (*con_scrolldelta)(struct vc_data *, int);
	int (*con_set_origin)(struct vc_data *);
	void (*con_save_screen)(struct vc_data *);
	u8 (*con_build_attr)(struct vc_data *, u8, enum vc_intensity, bool, bool, bool, bool);
	void (*con_invert_region)(struct vc_data *, u16 *, int);
	u16 * (*con_screen_pos)(const struct vc_data *, int);
	long unsigned int (*con_getxy)(struct vc_data *, long unsigned int, int *, int *);
	void (*con_flush_scrollback)(struct vc_data *);
	int (*con_debug_enter)(struct vc_data *);
	int (*con_debug_leave)(struct vc_data *);
};

struct psi_group___11 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___16 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___11;

struct cgroup_rstat_cpu___11;

struct cgroup___11 {
	struct cgroup_subsys_state___11 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___13 *kn;
	struct cgroup_file___11 procs_file;
	struct cgroup_file___11 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___11 *subsys[14];
	struct cgroup_root___11 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___11 *dom_cgrp;
	struct cgroup___11 *old_dom_cgrp;
	struct cgroup_rstat_cpu___11 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___11 psi;
	struct cgroup_bpf bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct shrink_control___9 {
	gfp_t gfp_mask;
	int nid;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	struct mem_cgroup___9 *memcg;
};

struct shrinker___9 {
	long unsigned int (*count_objects)(struct shrinker___9 *, struct shrink_control___9 *);
	long unsigned int (*scan_objects)(struct shrinker___9 *, struct shrink_control___9 *);
	long int batch;
	int seeks;
	unsigned int flags;
	struct list_head list;
	int id;
	atomic_long_t *nr_deferred;
};

struct dev_pagemap_ops___13 {
	void (*page_free)(struct page___14 *);
	void (*kill)(struct dev_pagemap___13 *);
	void (*cleanup)(struct dev_pagemap___13 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___13 *);
};

struct dentry_operations___13;

struct dentry___13 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___13 *d_parent;
	struct qstr d_name;
	struct inode___13 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___13 *d_op;
	struct super_block___13 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___13;

struct cdev___6;

struct inode___13 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___13 *i_op;
	struct super_block___13 *i_sb;
	struct address_space___13 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___9 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	long: 64;
	long: 64;
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___13 *i_fop;
		void (*free_inode)(struct inode___13 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___13 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct cdev___6 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___13 {
	int (*d_revalidate)(struct dentry___13 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___13 *, unsigned int);
	int (*d_hash)(const struct dentry___13 *, struct qstr *);
	int (*d_compare)(const struct dentry___13 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___13 *);
	int (*d_init)(struct dentry___13 *);
	void (*d_release)(struct dentry___13 *);
	void (*d_prune)(struct dentry___13 *);
	void (*d_iput)(struct dentry___13 *, struct inode___13 *);
	char * (*d_dname)(struct dentry___13 *, char *, int);
	struct vfsmount___13 * (*d_automount)(struct path___13 *);
	int (*d_manage)(const struct path___13 *, bool);
	struct dentry___13 * (*d_real)(struct dentry___13 *, const struct inode___13 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___13;

struct mem_dqinfo___13 {
	struct quota_format_type___13 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___13;

struct quota_info___13 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___13 *files[3];
	struct mem_dqinfo___13 info[3];
	const struct quota_format_ops___13 *ops[3];
};

struct rcuwait___13 {
	struct task_struct___16 *task;
};

struct percpu_rw_semaphore___13 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___13 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___13 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___13 rw_sem[3];
};

struct super_operations___13;

struct dquot_operations___13;

struct quotactl_ops___13;

struct block_device___10;

struct super_block___13 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___13 *s_type;
	const struct super_operations___13 *s_op;
	const struct dquot_operations___13 *dq_op;
	const struct quotactl_ops___13 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___13 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___10 *s_bdev;
	struct backing_dev_info___9 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___13 s_dquot;
	struct sb_writers___13 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___13 *s_d_op;
	int cleancache_poolid;
	struct shrinker___9 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___13 {
	struct dentry___13 *mnt_root;
	struct super_block___13 *mnt_sb;
	int mnt_flags;
	struct user_namespace *mnt_userns;
};

struct io_cq___10 {
	struct request_queue___10 *q;
	struct io_context___11 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct wait_page_queue___7;

struct kiocb___13 {
	struct file___13 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___13 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___7 *ki_waitq;
	};
};

struct iattr___13 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___13 *ia_file;
};

struct dquot___13 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___13 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___13 {
	int qf_fmt_id;
	const struct quota_format_ops___13 *qf_ops;
	struct module___3 *qf_owner;
	struct quota_format_type___13 *qf_next;
};

struct quota_format_ops___13 {
	int (*check_quota_file)(struct super_block___13 *, int);
	int (*read_file_info)(struct super_block___13 *, int);
	int (*write_file_info)(struct super_block___13 *, int);
	int (*free_file_info)(struct super_block___13 *, int);
	int (*read_dqblk)(struct dquot___13 *);
	int (*commit_dqblk)(struct dquot___13 *);
	int (*release_dqblk)(struct dquot___13 *);
	int (*get_next_id)(struct super_block___13 *, struct kqid *);
};

struct dquot_operations___13 {
	int (*write_dquot)(struct dquot___13 *);
	struct dquot___13 * (*alloc_dquot)(struct super_block___13 *, int);
	void (*destroy_dquot)(struct dquot___13 *);
	int (*acquire_dquot)(struct dquot___13 *);
	int (*release_dquot)(struct dquot___13 *);
	int (*mark_dirty)(struct dquot___13 *);
	int (*write_info)(struct super_block___13 *, int);
	qsize_t * (*get_reserved_space)(struct inode___13 *);
	int (*get_projid)(struct inode___13 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___13 *, qsize_t *);
	int (*get_next_id)(struct super_block___13 *, struct kqid *);
};

struct quotactl_ops___13 {
	int (*quota_on)(struct super_block___13 *, int, int, const struct path___13 *);
	int (*quota_off)(struct super_block___13 *, int);
	int (*quota_enable)(struct super_block___13 *, unsigned int);
	int (*quota_disable)(struct super_block___13 *, unsigned int);
	int (*quota_sync)(struct super_block___13 *, int);
	int (*set_info)(struct super_block___13 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___13 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___13 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___13 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___13 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___13 *, unsigned int);
};

struct wait_page_queue___7 {
	struct page___14 *page;
	int bit_nr;
	wait_queue_entry_t wait;
};

struct writeback_control___9;

struct readahead_control___7;

struct swap_info_struct___6;

struct address_space_operations___13 {
	int (*writepage)(struct page___14 *, struct writeback_control___9 *);
	int (*readpage)(struct file___13 *, struct page___14 *);
	int (*writepages)(struct address_space___13 *, struct writeback_control___9 *);
	int (*set_page_dirty)(struct page___14 *);
	int (*readpages)(struct file___13 *, struct address_space___13 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___7 *);
	int (*write_begin)(struct file___13 *, struct address_space___13 *, loff_t, unsigned int, unsigned int, struct page___14 **, void **);
	int (*write_end)(struct file___13 *, struct address_space___13 *, loff_t, unsigned int, unsigned int, struct page___14 *, void *);
	sector_t (*bmap)(struct address_space___13 *, sector_t);
	void (*invalidatepage)(struct page___14 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___14 *, gfp_t);
	void (*freepage)(struct page___14 *);
	ssize_t (*direct_IO)(struct kiocb___13 *, struct iov_iter___11 *);
	int (*migratepage)(struct address_space___13 *, struct page___14 *, struct page___14 *, enum migrate_mode);
	bool (*isolate_page)(struct page___14 *, isolate_mode_t);
	void (*putback_page)(struct page___14 *);
	int (*launder_page)(struct page___14 *);
	int (*is_partially_uptodate)(struct page___14 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___14 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___13 *, struct page___14 *);
	int (*swap_activate)(struct swap_info_struct___6 *, struct file___13 *, sector_t *);
	void (*swap_deactivate)(struct file___13 *);
};

struct writeback_control___9 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate;
	unsigned int for_background;
	unsigned int tagged_writepages;
	unsigned int for_reclaim;
	unsigned int range_cyclic;
	unsigned int for_sync;
	unsigned int no_cgroup_owner;
	unsigned int punt_to_cgroup;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bdi_writeback___9 *wb;
	struct inode___13 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
};

struct readahead_control___7 {
	struct file___13 *file;
	struct address_space___13 *mapping;
	struct file_ra_state *ra;
	long unsigned int _index;
	unsigned int _nr_pages;
	unsigned int _batch_count;
};

struct bio_vec___11;

struct iov_iter___11 {
	u8 iter_type;
	bool data_source;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___11 *bvec;
		struct xarray *xarray;
		struct pipe_inode_info *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			unsigned int head;
			unsigned int start_head;
		};
		loff_t xarray_start;
	};
};

struct swap_info_struct___6 {
	struct percpu_ref users;
	long unsigned int flags;
	short int prio;
	struct plist_node list;
	signed char type;
	unsigned int max;
	unsigned char *swap_map;
	struct swap_cluster_info *cluster_info;
	struct swap_cluster_list free_clusters;
	unsigned int lowest_bit;
	unsigned int highest_bit;
	unsigned int pages;
	unsigned int inuse_pages;
	unsigned int cluster_next;
	unsigned int cluster_nr;
	unsigned int *cluster_next_cpu;
	struct percpu_cluster *percpu_cluster;
	struct rb_root swap_extent_root;
	struct block_device___10 *bdev;
	struct file___13 *swap_file;
	unsigned int old_block_size;
	struct completion comp;
	long unsigned int *frontswap_map;
	atomic_t frontswap_pages;
	spinlock_t lock;
	spinlock_t cont_lock;
	struct work_struct discard_work;
	struct swap_cluster_list discard_clusters;
	struct plist_node avail_lists[0];
};

struct cdev___6 {
	struct kobject___14 kobj;
	struct module___3 *owner;
	const struct file_operations___13 *ops;
	struct list_head list;
	dev_t dev;
	unsigned int count;
};

struct inode_operations___13 {
	struct dentry___13 * (*lookup)(struct inode___13 *, struct dentry___13 *, unsigned int);
	const char * (*get_link)(struct dentry___13 *, struct inode___13 *, struct delayed_call *);
	int (*permission)(struct user_namespace *, struct inode___13 *, int);
	struct posix_acl * (*get_acl)(struct inode___13 *, int, bool);
	int (*readlink)(struct dentry___13 *, char *, int);
	int (*create)(struct user_namespace *, struct inode___13 *, struct dentry___13 *, umode_t, bool);
	int (*link)(struct dentry___13 *, struct inode___13 *, struct dentry___13 *);
	int (*unlink)(struct inode___13 *, struct dentry___13 *);
	int (*symlink)(struct user_namespace *, struct inode___13 *, struct dentry___13 *, const char *);
	int (*mkdir)(struct user_namespace *, struct inode___13 *, struct dentry___13 *, umode_t);
	int (*rmdir)(struct inode___13 *, struct dentry___13 *);
	int (*mknod)(struct user_namespace *, struct inode___13 *, struct dentry___13 *, umode_t, dev_t);
	int (*rename)(struct user_namespace *, struct inode___13 *, struct dentry___13 *, struct inode___13 *, struct dentry___13 *, unsigned int);
	int (*setattr)(struct user_namespace *, struct dentry___13 *, struct iattr___13 *);
	int (*getattr)(struct user_namespace *, const struct path___13 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___13 *, char *, size_t);
	int (*fiemap)(struct inode___13 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___13 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___13 *, struct dentry___13 *, struct file___13 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace *, struct inode___13 *, struct dentry___13 *, umode_t);
	int (*set_acl)(struct user_namespace *, struct inode___13 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace *, struct dentry___13 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___13 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___13 {
	void (*fl_copy_lock)(struct file_lock___13 *, struct file_lock___13 *);
	void (*fl_release_private)(struct file_lock___13 *);
};

struct fasync_struct___13;

struct lock_manager_operations___13;

struct file_lock___13 {
	struct file_lock___13 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___13 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___13 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___13 *fl_ops;
	const struct lock_manager_operations___13 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___13 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___13 *);
	int (*lm_grant)(struct file_lock___13 *, int);
	bool (*lm_break)(struct file_lock___13 *);
	int (*lm_change)(struct file_lock___13 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___13 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___13 *);
};

struct fasync_struct___13 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___13 *fa_next;
	struct file___13 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___13 {
	struct inode___13 * (*alloc_inode)(struct super_block___13 *);
	void (*destroy_inode)(struct inode___13 *);
	void (*free_inode)(struct inode___13 *);
	void (*dirty_inode)(struct inode___13 *, int);
	int (*write_inode)(struct inode___13 *, struct writeback_control___9 *);
	int (*drop_inode)(struct inode___13 *);
	void (*evict_inode)(struct inode___13 *);
	void (*put_super)(struct super_block___13 *);
	int (*sync_fs)(struct super_block___13 *, int);
	int (*freeze_super)(struct super_block___13 *);
	int (*freeze_fs)(struct super_block___13 *);
	int (*thaw_super)(struct super_block___13 *);
	int (*unfreeze_fs)(struct super_block___13 *);
	int (*statfs)(struct dentry___13 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___13 *, int *, char *);
	void (*umount_begin)(struct super_block___13 *);
	int (*show_options)(struct seq_file___12 *, struct dentry___13 *);
	int (*show_devname)(struct seq_file___12 *, struct dentry___13 *);
	int (*show_path)(struct seq_file___12 *, struct dentry___13 *);
	int (*show_stats)(struct seq_file___12 *, struct dentry___13 *);
	ssize_t (*quota_read)(struct super_block___13 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___13 *, int, const char *, size_t, loff_t);
	struct dquot___13 ** (*get_dquots)(struct inode___13 *);
	long int (*nr_cached_objects)(struct super_block___13 *, struct shrink_control___9 *);
	long int (*free_cached_objects)(struct super_block___13 *, struct shrink_control___9 *);
	struct file___13 * (*real_loop)(struct file___13 *);
};

struct block_device___10 {
	sector_t bd_start_sect;
	struct disk_stats *bd_stats;
	long unsigned int bd_stamp;
	bool bd_read_only;
	dev_t bd_dev;
	int bd_openers;
	struct inode___13 *bd_inode;
	struct super_block___13 *bd_super;
	void *bd_claiming;
	struct device___2 bd_device;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct kobject___14 *bd_holder_dir;
	u8 bd_partno;
	spinlock_t bd_size_lock;
	struct gendisk___10 *bd_disk;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	struct super_block___13 *bd_fsfreeze_sb;
	struct partition_meta_info *bd_meta_info;
};

typedef void bio_end_io_t___10(struct bio___10 *);

struct bio_vec___11 {
	struct page___14 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___10;

struct bio___10 {
	struct bio___10 *bi_next;
	struct block_device___10 *bi_bdev;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	atomic_t __bi_remaining;
	struct bvec_iter bi_iter;
	bio_end_io_t___10 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___9 *bi_blkg;
	struct bio_issue bi_issue;
	u64 bi_iocost_cost;
	struct bio_crypt_ctx *bi_crypt_context;
	union {
		struct bio_integrity_payload___10 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___11 *bi_io_vec;
	struct bio_set___10 *bi_pool;
	struct bio_vec___11 bi_inline_vecs[0];
};

struct cgroup_namespace___11 {
	struct ns_common ns;
	struct user_namespace *user_ns;
	struct ucounts *ucounts;
	struct css_set___11 *root_cset;
};

enum memblock_flags {
	MEMBLOCK_NONE = 0,
	MEMBLOCK_HOTPLUG = 1,
	MEMBLOCK_MIRROR = 2,
	MEMBLOCK_NOMAP = 4,
};

struct memblock_region {
	phys_addr_t base;
	phys_addr_t size;
	enum memblock_flags flags;
	int nid;
};

struct memblock_type {
	long unsigned int cnt;
	long unsigned int max;
	phys_addr_t total_size;
	struct memblock_region *regions;
	char *name;
};

struct memblock {
	bool bottom_up;
	phys_addr_t current_limit;
	struct memblock_type memory;
	struct memblock_type reserved;
};

struct cftype___11;

struct cgroup_subsys___11 {
	struct cgroup_subsys_state___11 * (*css_alloc)(struct cgroup_subsys_state___11 *);
	int (*css_online)(struct cgroup_subsys_state___11 *);
	void (*css_offline)(struct cgroup_subsys_state___11 *);
	void (*css_released)(struct cgroup_subsys_state___11 *);
	void (*css_free)(struct cgroup_subsys_state___11 *);
	void (*css_reset)(struct cgroup_subsys_state___11 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___11 *, int);
	int (*css_extra_stat_show)(struct seq_file___12 *, struct cgroup_subsys_state___11 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___16 *, struct css_set___11 *);
	void (*cancel_fork)(struct task_struct___16 *, struct css_set___11 *);
	void (*fork)(struct task_struct___16 *);
	void (*exit)(struct task_struct___16 *);
	void (*release)(struct task_struct___16 *);
	void (*bind)(struct cgroup_subsys_state___11 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___11 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___11 *dfl_cftypes;
	struct cftype___11 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___11 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___11 *updated_children;
	struct cgroup___11 *updated_next;
};

struct cgroup_root___11 {
	struct kernfs_root___13 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___11 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___11 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___11 *ss;
	struct list_head node;
	struct kernfs_ops___13 *kf_ops;
	int (*open)(struct kernfs_open_file___13 *);
	void (*release)(struct kernfs_open_file___13 *);
	u64 (*read_u64)(struct cgroup_subsys_state___11 *, struct cftype___11 *);
	s64 (*read_s64)(struct cgroup_subsys_state___11 *, struct cftype___11 *);
	int (*seq_show)(struct seq_file___12 *, void *);
	void * (*seq_start)(struct seq_file___12 *, loff_t *);
	void * (*seq_next)(struct seq_file___12 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___12 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___11 *, struct cftype___11 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___11 *, struct cftype___11 *, s64);
	ssize_t (*write)(struct kernfs_open_file___13 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___13 *, struct poll_table_struct___10 *);
};

struct block_device_operations___10;

struct gendisk___10 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	short unsigned int events;
	short unsigned int event_flags;
	struct xarray part_tbl;
	struct block_device___10 *part0;
	const struct block_device_operations___10 *fops;
	struct request_queue___10 *queue;
	void *private_data;
	int flags;
	long unsigned int state;
	struct mutex open_mutex;
	unsigned int open_partitions;
	struct backing_dev_info___9 *bdi;
	struct kobject___14 *slave_dir;
	struct list_head slave_bdevs;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___14 integrity_kobj;
	struct cdrom_device_info *cdi;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	u64 diskseq;
};

struct bio_integrity_payload___10 {
	struct bio___10 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___11 *bip_vec;
	struct bio_vec___11 bip_inline_vecs[0];
};

struct blkcg___9;

struct blkg_policy_data___9;

struct blkcg_gq___9 {
	struct request_queue___10 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___9 *blkcg;
	struct blkcg_gq___9 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_iostat_set *iostat_cpu;
	struct blkg_iostat_set iostat;
	struct blkg_policy_data___9 *pd[6];
	spinlock_t async_bio_lock;
	struct bio_list___10 async_bios;
	struct work_struct async_bio_work;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
	struct callback_head callback_head;
};

typedef void integrity_prepare_fn___10(struct request___10 *);

typedef void integrity_complete_fn___10(struct request___10 *, unsigned int);

struct blk_integrity_profile___10 {
	integrity_processing_fn *generate_fn;
	integrity_processing_fn *verify_fn;
	integrity_prepare_fn___10 *prepare_fn;
	integrity_complete_fn___10 *complete_fn;
	const char *name;
};

struct block_device_operations___10 {
	blk_qc_t (*submit_bio)(struct bio___10 *);
	int (*open)(struct block_device___10 *, fmode_t);
	void (*release)(struct gendisk___10 *, fmode_t);
	int (*rw_page)(struct block_device___10 *, sector_t, struct page___14 *, unsigned int);
	int (*ioctl)(struct block_device___10 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___10 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___10 *, unsigned int);
	void (*unlock_native_capacity)(struct gendisk___10 *);
	int (*getgeo)(struct block_device___10 *, struct hd_geometry *);
	int (*set_read_only)(struct block_device___10 *, bool);
	void (*swap_slot_free_notify)(struct block_device___10 *, long unsigned int);
	int (*report_zones)(struct gendisk___10 *, sector_t, unsigned int, report_zones_cb, void *);
	char * (*devnode)(struct gendisk___10 *, umode_t *);
	struct module___3 *owner;
	const struct pr_ops *pr_ops;
	int (*alternative_gpt_sector)(struct gendisk___10 *, sector_t *);
};

typedef void rq_end_io_fn___10(struct request___10 *, blk_status_t);

struct request___10 {
	struct request_queue___10 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int tag;
	int internal_tag;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___10 *bio;
	struct bio___10 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct llist_node ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___11 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___10 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___10 *saved_end_io;
		} flush;
	};
	struct gendisk___10 *rq_disk;
	struct block_device___10 *part;
	u64 alloc_time_ns;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int stats_sectors;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	struct bio_crypt_ctx *crypt_ctx;
	struct blk_ksm_keyslot *crypt_keyslot;
	short unsigned int write_hint;
	short unsigned int ioprio;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___10 *end_io;
	void *end_io_data;
};

struct elevator_type___10;

struct elevator_mq_ops___10 {
	int (*init_sched)(struct request_queue___10 *, struct elevator_type___10 *);
	void (*exit_sched)(struct elevator_queue___10 *);
	int (*init_hctx)(struct blk_mq_hw_ctx *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx *, unsigned int);
	void (*depth_updated)(struct blk_mq_hw_ctx *);
	bool (*allow_merge)(struct request_queue___10 *, struct request___10 *, struct bio___10 *);
	bool (*bio_merge)(struct request_queue___10 *, struct bio___10 *, unsigned int);
	int (*request_merge)(struct request_queue___10 *, struct request___10 **, struct bio___10 *);
	void (*request_merged)(struct request_queue___10 *, struct request___10 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___10 *, struct request___10 *, struct request___10 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___10 *);
	void (*finish_request)(struct request___10 *);
	void (*insert_requests)(struct blk_mq_hw_ctx *, struct list_head *, bool);
	struct request___10 * (*dispatch_request)(struct blk_mq_hw_ctx *);
	bool (*has_work)(struct blk_mq_hw_ctx *);
	void (*completed_request)(struct request___10 *, u64);
	void (*requeue_request)(struct request___10 *);
	struct request___10 * (*former_request)(struct request_queue___10 *, struct request___10 *);
	struct request___10 * (*next_request)(struct request_queue___10 *, struct request___10 *);
	void (*init_icq)(struct io_cq___10 *);
	void (*exit_icq)(struct io_cq___10 *);
};

struct elv_fs_entry___10;

struct elevator_type___10 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___10 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___10 *elevator_attrs;
	const char *elevator_name;
	const char *elevator_alias;
	const unsigned int elevator_features;
	struct module___3 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
};

struct elevator_queue___10 {
	struct elevator_type___10 *type;
	void *elevator_data;
	struct kobject___14 kobj;
	struct mutex sysfs_lock;
	unsigned int registered;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hlist_head hash[64];
};

struct elv_fs_entry___10 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___10 *, char *);
	ssize_t (*store)(struct elevator_queue___10 *, const char *, size_t);
};

struct blkcg_policy_data___9;

struct blkcg___9 {
	struct cgroup_subsys_state___11 css;
	spinlock_t lock;
	refcount_t online_pin;
	struct xarray blkg_tree;
	struct blkcg_gq___9 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___9 *cpd[6];
	struct list_head all_blkcgs_node;
	char fc_app_id[129];
	struct list_head cgwb_list;
};

struct blkcg_policy_data___9 {
	struct blkcg___9 *blkcg;
	int plid;
};

struct blkg_policy_data___9 {
	struct blkcg_gq___9 *blkg;
	int plid;
};

struct mem_cgroup_reclaim_iter___9 {
	struct mem_cgroup___9 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___9 {
	struct lruvec___9 lruvec;
	struct lruvec_stats_percpu *lruvec_stats_percpu;
	struct lruvec_stats lruvec_stats;
	long unsigned int lru_zone_size[25];
	struct mem_cgroup_reclaim_iter___9 iter;
	struct shrinker_info *shrinker_info;
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	struct mem_cgroup___9 *memcg;
};

struct obj_cgroup___9 {
	struct percpu_ref refcnt;
	struct mem_cgroup___9 *memcg;
	atomic_t nr_charged_bytes;
	union {
		struct list_head list;
		struct callback_head rcu;
	};
};

struct pci_dev___3;

struct x86_msi_ops {
	void (*restore_msi_irqs)(struct pci_dev___3 *);
};

struct pci_bus___3;

struct pci_slot___3;

struct pci_driver___3;

struct pci_dev___3 {
	struct list_head bus_list;
	struct pci_bus___3 *bus;
	struct pci_bus___3 *subordinate;
	void *sysdata;
	struct proc_dir_entry *procent;
	struct pci_slot___3 *slot;
	unsigned int devfn;
	short unsigned int vendor;
	short unsigned int device;
	short unsigned int subsystem_vendor;
	short unsigned int subsystem_device;
	unsigned int class;
	u8 revision;
	u8 hdr_type;
	u16 aer_cap;
	struct aer_stats *aer_stats;
	struct rcec_ea *rcec_ea;
	struct pci_dev___3 *rcec;
	u32 devcap;
	u8 pcie_cap;
	u8 msi_cap;
	u8 msix_cap;
	u8 pcie_mpss: 3;
	long: 61;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u8 rom_base_reg;
	u8 pin;
	u16 pcie_flags_reg;
	long unsigned int *dma_alias_mask;
	struct pci_driver___3 *driver;
	u64 dma_mask;
	struct device_dma_parameters dma_parms;
	pci_power_t current_state;
	unsigned int imm_ready: 1;
	long: 39;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u8 pm_cap;
	unsigned int pme_support: 5;
	unsigned int pme_poll: 1;
	unsigned int d1_support: 1;
	unsigned int d2_support: 1;
	unsigned int no_d1d2: 1;
	unsigned int no_d3cold: 1;
	unsigned int bridge_d3: 1;
	unsigned int d3cold_allowed: 1;
	unsigned int mmio_always_on: 1;
	unsigned int wakeup_prepared: 1;
	unsigned int runtime_d3cold: 1;
	unsigned int skip_bus_pm: 1;
	unsigned int ignore_hotplug: 1;
	unsigned int hotplug_user_indicators: 1;
	unsigned int clear_retrain_link: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int d3hot_delay;
	unsigned int d3cold_delay;
	struct pcie_link_state *link_state;
	unsigned int ltr_path: 1;
	long: 15;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u16 l1ss;
	unsigned int pasid_no_tlp: 1;
	unsigned int eetlp_prefix_path: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	pci_channel_state_t error_state;
	struct device___2 dev;
	int cfg_size;
	unsigned int irq;
	struct resource resource[17];
	bool match_driver;
	unsigned int transparent: 1;
	unsigned int io_window: 1;
	unsigned int pref_window: 1;
	unsigned int pref_64_window: 1;
	unsigned int multifunction: 1;
	unsigned int is_busmaster: 1;
	unsigned int no_msi: 1;
	unsigned int no_64bit_msi: 1;
	unsigned int block_cfg_access: 1;
	unsigned int broken_parity_status: 1;
	unsigned int irq_reroute_variant: 2;
	unsigned int msi_enabled: 1;
	unsigned int msix_enabled: 1;
	unsigned int ari_enabled: 1;
	unsigned int ats_enabled: 1;
	unsigned int pasid_enabled: 1;
	unsigned int pri_enabled: 1;
	unsigned int is_managed: 1;
	unsigned int needs_freset: 1;
	unsigned int state_saved: 1;
	unsigned int is_physfn: 1;
	unsigned int is_virtfn: 1;
	unsigned int is_hotplug_bridge: 1;
	unsigned int shpc_managed: 1;
	unsigned int is_thunderbolt: 1;
	unsigned int untrusted: 1;
	unsigned int external_facing: 1;
	unsigned int broken_intx_masking: 1;
	unsigned int io_window_1k: 1;
	unsigned int irq_managed: 1;
	unsigned int non_compliant_bars: 1;
	unsigned int is_probed: 1;
	unsigned int link_active_reporting: 1;
	unsigned int no_vf_scan: 1;
	unsigned int no_command_memory: 1;
	long: 47;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	pci_dev_flags_t dev_flags;
	atomic_t enable_cnt;
	u32 saved_config_space[16];
	struct hlist_head saved_cap_space;
	int rom_attr_enabled;
	struct bin_attribute___14 *res_attr[17];
	struct bin_attribute___14 *res_attr_wc[17];
	unsigned int broken_cmd_compl: 1;
	unsigned int ptm_root: 1;
	unsigned int ptm_enabled: 1;
	long: 7;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u8 ptm_granularity;
	const struct attribute_group___14 **msi_irq_groups;
	struct pci_vpd vpd;
	u16 dpc_cap;
	unsigned int dpc_rp_extensions: 1;
	long: 23;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u8 dpc_rp_log_size;
	union {
		struct pci_sriov *sriov;
		struct pci_dev___3 *physfn;
	};
	u16 ats_cap;
	u8 ats_stu;
	u16 pri_cap;
	u32 pri_reqs_alloc;
	unsigned int pasid_required: 1;
	long: 47;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u16 pasid_cap;
	u16 pasid_features;
	u16 acs_cap;
	phys_addr_t rom;
	size_t romlen;
	char *driver_override;
	long unsigned int priv_flags;
	u8 reset_methods[7];
};

struct pci_slot___3 {
	struct pci_bus___3 *bus;
	struct list_head list;
	struct hotplug_slot *hotplug;
	unsigned char number;
	struct kobject___14 kobj;
};

struct pci_ops___3;

struct pci_bus___3 {
	struct list_head node;
	struct pci_bus___3 *parent;
	struct list_head children;
	struct list_head devices;
	struct pci_dev___3 *self;
	struct list_head slots;
	struct resource *resource[4];
	struct list_head resources;
	struct resource busn_res;
	struct pci_ops___3 *ops;
	void *sysdata;
	struct proc_dir_entry *procdir;
	unsigned char number;
	unsigned char primary;
	unsigned char max_bus_speed;
	unsigned char cur_bus_speed;
	char name[48];
	short unsigned int bridge_ctl;
	pci_bus_flags_t bus_flags;
	struct device___2 *bridge;
	struct device___2 dev;
	struct bin_attribute___14 *legacy_io;
	struct bin_attribute___14 *legacy_mem;
	unsigned int is_added: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct pci_error_handlers___3;

struct pci_driver___3 {
	struct list_head node;
	const char *name;
	const struct pci_device_id *id_table;
	int (*probe)(struct pci_dev___3 *, const struct pci_device_id *);
	void (*remove)(struct pci_dev___3 *);
	int (*suspend)(struct pci_dev___3 *, pm_message_t);
	int (*resume)(struct pci_dev___3 *);
	void (*shutdown)(struct pci_dev___3 *);
	int (*sriov_configure)(struct pci_dev___3 *, int);
	int (*sriov_set_msix_vec_count)(struct pci_dev___3 *, int);
	u32 (*sriov_get_vf_total_msix)(struct pci_dev___3 *);
	const struct pci_error_handlers___3 *err_handler;
	const struct attribute_group___14 **groups;
	const struct attribute_group___14 **dev_groups;
	struct device_driver___14 driver;
	struct pci_dynids dynids;
};

struct pci_ops___3 {
	int (*add_bus)(struct pci_bus___3 *);
	void (*remove_bus)(struct pci_bus___3 *);
	void * (*map_bus)(struct pci_bus___3 *, unsigned int, int);
	int (*read)(struct pci_bus___3 *, unsigned int, int, int, u32 *);
	int (*write)(struct pci_bus___3 *, unsigned int, int, int, u32);
};

struct pci_error_handlers___3 {
	pci_ers_result_t (*error_detected)(struct pci_dev___3 *, pci_channel_state_t);
	pci_ers_result_t (*mmio_enabled)(struct pci_dev___3 *);
	pci_ers_result_t (*slot_reset)(struct pci_dev___3 *);
	void (*reset_prepare)(struct pci_dev___3 *);
	void (*reset_done)(struct pci_dev___3 *);
	void (*resume)(struct pci_dev___3 *);
};

struct irq_desc___6;

typedef void (*irq_flow_handler_t___6)(struct irq_desc___6 *);

struct irq_chip___6;

struct irq_domain___10;

struct irq_data___6 {
	u32 mask;
	unsigned int irq;
	long unsigned int hwirq;
	struct irq_common_data___3 *common;
	struct irq_chip___6 *chip;
	struct irq_domain___10 *domain;
	struct irq_data___6 *parent_data;
	void *chip_data;
};

struct irq_desc___6 {
	struct irq_common_data___3 irq_common_data;
	struct irq_data___6 irq_data;
	unsigned int *kstat_irqs;
	irq_flow_handler_t___6 handle_irq;
	struct irqaction___5 *action;
	unsigned int status_use_accessors;
	unsigned int core_internal_state__do_not_mess_with_it;
	unsigned int depth;
	unsigned int wake_depth;
	unsigned int tot_count;
	unsigned int irq_count;
	long unsigned int last_unhandled;
	unsigned int irqs_unhandled;
	atomic_t threads_handled;
	int threads_handled_last;
	raw_spinlock_t lock;
	struct cpumask *percpu_enabled;
	const struct cpumask *percpu_affinity;
	const struct cpumask *affinity_hint;
	struct irq_affinity_notify *affinity_notify;
	cpumask_var_t pending_mask;
	long unsigned int threads_oneshot;
	atomic_t threads_active;
	wait_queue_head_t wait_for_threads;
	unsigned int nr_actions;
	unsigned int no_suspend_depth;
	unsigned int cond_suspend_depth;
	unsigned int force_resume_depth;
	struct proc_dir_entry *dir;
	struct callback_head rcu;
	struct kobject___11 kobj;
	struct mutex request_mutex;
	int parent_irq;
	struct module___11 *owner;
	const char *name;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irq_domain_ops___10;

struct fwnode_handle___14;

struct irq_domain_chip_generic___5;

struct irq_domain___10 {
	struct list_head link;
	const char *name;
	const struct irq_domain_ops___10 *ops;
	void *host_data;
	unsigned int flags;
	unsigned int mapcount;
	struct fwnode_handle___14 *fwnode;
	enum irq_domain_bus_token bus_token;
	struct irq_domain_chip_generic___5 *gc;
	struct irq_domain___10 *parent;
	irq_hw_number_t hwirq_max;
	unsigned int revmap_size;
	struct xarray revmap_tree;
	struct mutex revmap_mutex;
	struct irq_data___6 *revmap[0];
};

struct fwnode_operations___14;

struct device___15;

struct fwnode_handle___14 {
	struct fwnode_handle___14 *secondary;
	const struct fwnode_operations___14 *ops;
	struct device___15 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct fwnode_reference_args___14;

struct fwnode_endpoint___14;

struct fwnode_operations___14 {
	struct fwnode_handle___14 * (*get)(struct fwnode_handle___14 *);
	void (*put)(struct fwnode_handle___14 *);
	bool (*device_is_available)(const struct fwnode_handle___14 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___14 *, const struct device___15 *);
	bool (*property_present)(const struct fwnode_handle___14 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___14 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___14 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___14 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___14 *);
	struct fwnode_handle___14 * (*get_parent)(const struct fwnode_handle___14 *);
	struct fwnode_handle___14 * (*get_next_child_node)(const struct fwnode_handle___14 *, struct fwnode_handle___14 *);
	struct fwnode_handle___14 * (*get_named_child_node)(const struct fwnode_handle___14 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___14 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___14 *);
	struct fwnode_handle___14 * (*graph_get_next_endpoint)(const struct fwnode_handle___14 *, struct fwnode_handle___14 *);
	struct fwnode_handle___14 * (*graph_get_remote_endpoint)(const struct fwnode_handle___14 *);
	struct fwnode_handle___14 * (*graph_get_port_parent)(struct fwnode_handle___14 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___14 *, struct fwnode_endpoint___14 *);
	int (*add_links)(struct fwnode_handle___14 *);
};

struct wakeup_source___15;

struct dev_pm_info___15 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___15 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___15 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___15;

struct bus_type___15;

struct device_driver___15;

struct dev_pm_domain___15;

struct device_node___11;

struct class___15;

struct device___15 {
	struct kobject___11 kobj;
	struct device___15 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___15 *type;
	struct bus_type___15 *bus;
	struct device_driver___15 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___15 power;
	struct dev_pm_domain___15 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___10 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___11 *of_node;
	struct fwnode_handle___14 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___15 *class;
	const struct attribute_group___11 **groups;
	void (*release)(struct device___15 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fwnode_endpoint___14 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___14 *local_fwnode;
};

struct fwnode_reference_args___14 {
	struct fwnode_handle___14 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct irq_chip___6 {
	struct device___15 *parent_device;
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___6 *);
	void (*irq_shutdown)(struct irq_data___6 *);
	void (*irq_enable)(struct irq_data___6 *);
	void (*irq_disable)(struct irq_data___6 *);
	void (*irq_ack)(struct irq_data___6 *);
	void (*irq_mask)(struct irq_data___6 *);
	void (*irq_mask_ack)(struct irq_data___6 *);
	void (*irq_unmask)(struct irq_data___6 *);
	void (*irq_eoi)(struct irq_data___6 *);
	int (*irq_set_affinity)(struct irq_data___6 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___6 *);
	int (*irq_set_type)(struct irq_data___6 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___6 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___6 *);
	void (*irq_bus_sync_unlock)(struct irq_data___6 *);
	void (*irq_cpu_online)(struct irq_data___6 *);
	void (*irq_cpu_offline)(struct irq_data___6 *);
	void (*irq_suspend)(struct irq_data___6 *);
	void (*irq_resume)(struct irq_data___6 *);
	void (*irq_pm_shutdown)(struct irq_data___6 *);
	void (*irq_calc_mask)(struct irq_data___6 *);
	void (*irq_print_chip)(struct irq_data___6 *, struct seq_file *);
	int (*irq_request_resources)(struct irq_data___6 *);
	void (*irq_release_resources)(struct irq_data___6 *);
	void (*irq_compose_msi_msg)(struct irq_data___6 *, struct msi_msg *);
	void (*irq_write_msi_msg)(struct irq_data___6 *, struct msi_msg *);
	int (*irq_get_irqchip_state)(struct irq_data___6 *, enum irqchip_irq_state, bool *);
	int (*irq_set_irqchip_state)(struct irq_data___6 *, enum irqchip_irq_state, bool);
	int (*irq_set_vcpu_affinity)(struct irq_data___6 *, void *);
	void (*ipi_send_single)(struct irq_data___6 *, unsigned int);
	void (*ipi_send_mask)(struct irq_data___6 *, const struct cpumask *);
	int (*irq_nmi_setup)(struct irq_data___6 *);
	void (*irq_nmi_teardown)(struct irq_data___6 *);
	long unsigned int flags;
};

struct irq_chip_type___5 {
	struct irq_chip___6 chip;
	struct irq_chip_regs regs;
	irq_flow_handler_t___6 handler;
	u32 type;
	u32 mask_cache_priv;
	u32 *mask_cache;
};

struct irq_chip_generic___5 {
	raw_spinlock_t lock;
	void *reg_base;
	u32 (*reg_readl)(void *);
	void (*reg_writel)(u32, void *);
	void (*suspend)(struct irq_chip_generic___5 *);
	void (*resume)(struct irq_chip_generic___5 *);
	unsigned int irq_base;
	unsigned int irq_cnt;
	u32 mask_cache;
	u32 type_cache;
	u32 polarity_cache;
	u32 wake_enabled;
	u32 wake_active;
	unsigned int num_ct;
	void *private;
	long unsigned int installed;
	long unsigned int unused;
	struct irq_domain___10 *domain;
	struct list_head list;
	struct irq_chip_type___5 chip_types[0];
};

struct irq_domain_chip_generic___5 {
	unsigned int irqs_per_chip;
	unsigned int num_chips;
	unsigned int irq_flags_to_clear;
	unsigned int irq_flags_to_set;
	enum irq_gc_flags gc_flags;
	struct irq_chip_generic___5 *gc[0];
};

struct device_node___11 {
	const char *name;
	phandle phandle;
	const char *full_name;
	struct fwnode_handle___14 fwnode;
	struct property *properties;
	struct property *deadprops;
	struct device_node___11 *parent;
	struct device_node___11 *child;
	struct device_node___11 *sibling;
	long unsigned int _flags;
	void *data;
};

struct irq_fwspec___9 {
	struct fwnode_handle___14 *fwnode;
	int param_count;
	u32 param[16];
};

struct irq_domain_ops___10 {
	int (*match)(struct irq_domain___10 *, struct device_node___11 *, enum irq_domain_bus_token);
	int (*select)(struct irq_domain___10 *, struct irq_fwspec___9 *, enum irq_domain_bus_token);
	int (*map)(struct irq_domain___10 *, unsigned int, irq_hw_number_t);
	void (*unmap)(struct irq_domain___10 *, unsigned int);
	int (*xlate)(struct irq_domain___10 *, struct device_node___11 *, const u32 *, unsigned int, long unsigned int *, unsigned int *);
	int (*alloc)(struct irq_domain___10 *, unsigned int, unsigned int, void *);
	void (*free)(struct irq_domain___10 *, unsigned int, unsigned int);
	int (*activate)(struct irq_domain___10 *, struct irq_data___6 *, bool);
	void (*deactivate)(struct irq_domain___10 *, struct irq_data___6 *);
	int (*translate)(struct irq_domain___10 *, struct irq_fwspec___9 *, long unsigned int *, unsigned int *);
};

struct dev_pm_ops___15 {
	int (*prepare)(struct device___15 *);
	void (*complete)(struct device___15 *);
	int (*suspend)(struct device___15 *);
	int (*resume)(struct device___15 *);
	int (*freeze)(struct device___15 *);
	int (*thaw)(struct device___15 *);
	int (*poweroff)(struct device___15 *);
	int (*restore)(struct device___15 *);
	int (*suspend_late)(struct device___15 *);
	int (*resume_early)(struct device___15 *);
	int (*freeze_late)(struct device___15 *);
	int (*thaw_early)(struct device___15 *);
	int (*poweroff_late)(struct device___15 *);
	int (*restore_early)(struct device___15 *);
	int (*suspend_noirq)(struct device___15 *);
	int (*resume_noirq)(struct device___15 *);
	int (*freeze_noirq)(struct device___15 *);
	int (*thaw_noirq)(struct device___15 *);
	int (*poweroff_noirq)(struct device___15 *);
	int (*restore_noirq)(struct device___15 *);
	int (*runtime_suspend)(struct device___15 *);
	int (*runtime_resume)(struct device___15 *);
	int (*runtime_idle)(struct device___15 *);
};

struct wakeup_source___15 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___15 *dev;
	bool active;
	bool autosleep_enabled;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___15 {
	struct dev_pm_ops___15 ops;
	int (*start)(struct device___15 *);
	void (*detach)(struct device___15 *, bool);
	int (*activate)(struct device___15 *);
	void (*sync)(struct device___15 *);
	void (*dismiss)(struct device___15 *);
};

struct bus_type___15 {
	const char *name;
	const char *dev_name;
	struct device___15 *dev_root;
	const struct attribute_group___11 **bus_groups;
	const struct attribute_group___11 **dev_groups;
	const struct attribute_group___11 **drv_groups;
	int (*match)(struct device___15 *, struct device_driver___15 *);
	int (*uevent)(struct device___15 *, struct kobj_uevent_env *);
	int (*probe)(struct device___15 *);
	void (*sync_state)(struct device___15 *);
	void (*remove)(struct device___15 *);
	void (*shutdown)(struct device___15 *);
	int (*online)(struct device___15 *);
	int (*offline)(struct device___15 *);
	int (*suspend)(struct device___15 *, pm_message_t);
	int (*resume)(struct device___15 *);
	int (*num_vf)(struct device___15 *);
	int (*dma_configure)(struct device___15 *);
	const struct dev_pm_ops___15 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___15 {
	const char *name;
	struct bus_type___15 *bus;
	struct module___11 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___15 *);
	void (*sync_state)(struct device___15 *);
	int (*remove)(struct device___15 *);
	void (*shutdown)(struct device___15 *);
	int (*suspend)(struct device___15 *, pm_message_t);
	int (*resume)(struct device___15 *);
	const struct attribute_group___11 **groups;
	const struct attribute_group___11 **dev_groups;
	const struct dev_pm_ops___15 *pm;
	void (*coredump)(struct device___15 *);
	struct driver_private *p;
};

struct device_type___15 {
	const char *name;
	const struct attribute_group___11 **groups;
	int (*uevent)(struct device___15 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___15 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___15 *);
	const struct dev_pm_ops___15 *pm;
};

struct class___15 {
	const char *name;
	struct module___11 *owner;
	const struct attribute_group___11 **class_groups;
	const struct attribute_group___11 **dev_groups;
	struct kobject___11 *dev_kobj;
	int (*dev_uevent)(struct device___15 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___15 *, umode_t *);
	void (*class_release)(struct class___15 *);
	void (*dev_release)(struct device___15 *);
	int (*shutdown_pre)(struct device___15 *);
	const struct kobj_ns_type_operations *ns_type;
	const void * (*namespace)(struct device___15 *);
	void (*get_ownership)(struct device___15 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___15 *pm;
	struct subsys_private *p;
};

struct legacy_pic {
	int nr_legacy_irqs;
	struct irq_chip___6 *chip;
	void (*mask)(unsigned int);
	void (*unmask)(unsigned int);
	void (*mask_all)();
	void (*restore_mask)();
	void (*init)(int);
	int (*probe)();
	int (*irq_pending)(unsigned int);
	void (*make_irq)(unsigned int);
};

typedef struct irq_desc *vector_irq_t___2[256];

struct legacy_pic___2 {
	int nr_legacy_irqs;
	struct irq_chip *chip;
	void (*mask)(unsigned int);
	void (*unmask)(unsigned int);
	void (*mask_all)();
	void (*restore_mask)();
	void (*init)(int);
	int (*probe)();
	int (*irq_pending)(unsigned int);
	void (*make_irq)(unsigned int);
};

enum jump_label_type {
	JUMP_LABEL_NOP = 0,
	JUMP_LABEL_JMP = 1,
};

union text_poke_insn {
	u8 text[5];
	struct {
		u8 opcode;
		s32 disp;
	} __attribute__((packed));
};

struct jump_label_patch {
	const void *code;
	int size;
};

enum {
	JL_STATE_START = 0,
	JL_STATE_NO_UPDATE = 1,
	JL_STATE_UPDATE = 2,
};

typedef short unsigned int __kernel_old_uid_t;

typedef short unsigned int __kernel_old_gid_t;

typedef struct {
	int val[2];
} __kernel_fsid_t;

typedef __kernel_old_uid_t old_uid_t;

typedef __kernel_old_gid_t old_gid_t;

struct kernel_clone_args {
	u64 flags;
	int *pidfd;
	int *child_tid;
	int *parent_tid;
	int exit_signal;
	long unsigned int stack;
	long unsigned int stack_size;
	long unsigned int tls;
	pid_t *set_tid;
	size_t set_tid_size;
	int cgroup;
	int io_thread;
	struct cgroup___9 *cgrp;
	struct css_set___9 *cset;
};

struct kstatfs {
	long int f_type;
	long int f_bsize;
	u64 f_blocks;
	u64 f_bfree;
	u64 f_bavail;
	u64 f_files;
	u64 f_ffree;
	__kernel_fsid_t f_fsid;
	long int f_namelen;
	long int f_frsize;
	long int f_flags;
	long int f_spare[4];
};

struct stat64 {
	long long unsigned int st_dev;
	unsigned char __pad0[4];
	unsigned int __st_ino;
	unsigned int st_mode;
	unsigned int st_nlink;
	unsigned int st_uid;
	unsigned int st_gid;
	long long unsigned int st_rdev;
	unsigned char __pad3[4];
	long long int st_size;
	unsigned int st_blksize;
	long long int st_blocks;
	unsigned int st_atime;
	unsigned int st_atime_nsec;
	unsigned int st_mtime;
	unsigned int st_mtime_nsec;
	unsigned int st_ctime;
	unsigned int st_ctime_nsec;
	long long unsigned int st_ino;
} __attribute__((packed));

struct mmap_arg_struct32 {
	unsigned int addr;
	unsigned int len;
	unsigned int prot;
	unsigned int flags;
	unsigned int fd;
	unsigned int offset;
};

struct vm_unmapped_area_info {
	long unsigned int flags;
	long unsigned int length;
	long unsigned int low_limit;
	long unsigned int high_limit;
	long unsigned int align_mask;
	long unsigned int align_offset;
};

enum align_flags {
	ALIGN_VA_32 = 1,
	ALIGN_VA_64 = 2,
};

struct va_alignment {
	int flags;
	long unsigned int mask;
	long unsigned int bits;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dentry___14;

struct super_block___14;

struct module___14;

struct file_system_type___14 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___14 * (*mount)(struct file_system_type___14 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___14 *);
	struct module___14 *owner;
	struct file_system_type___14 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct page___15;

typedef struct page___15 *pgtable_t___15;

struct address_space___14;

struct page_pool___3;

struct mm_struct___16;

struct dev_pagemap___14;

struct page___15 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___14 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___3 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___15 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___15 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___16 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___14 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct task_struct___17;

struct pv_cpu_ops___11 {
	void (*io_delay)();
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	void (*write_cr4)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___9 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(long unsigned int);
	void (*invalidate_io_bitmap)();
	void (*update_io_bitmap)();
	void (*wbinvd)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int);
	void (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_msr_safe)(unsigned int, int *);
	int (*write_msr_safe)(unsigned int, unsigned int, unsigned int);
	u64 (*read_pmc)(int);
	void (*start_context_switch)(struct task_struct___17 *);
	void (*end_context_switch)(struct task_struct___17 *);
};

struct vm_area_struct___16;

struct vmacache___15 {
	u64 seqnum;
	struct vm_area_struct___16 *vmas[4];
};

struct page_frag___15 {
	struct page___15 *page;
	__u32 offset;
	__u32 size;
};

struct pid___13;

struct nsproxy___14;

struct signal_struct___15;

struct pipe_inode_info___3;

struct vm_struct___14;

struct task_struct___17 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___17 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___16 *mm;
	struct mm_struct___16 *active_mm;
	struct vmacache___15 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int restore_sigmask: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___17 *real_parent;
	struct task_struct___17 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___17 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___13 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	struct posix_cputimers_work posix_cputimers_work;
	const struct cred *ptracer_cred;
	const struct cred *real_cred;
	const struct cred *cred;
	struct key *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___14 *nsproxy;
	struct signal_struct___15 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___17 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context___11 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set *cgroups;
	struct list_head cg_list;
	u32 closid;
	u32 rmid;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	struct pipe_inode_info___3 *splice_pipe;
	struct page_frag___15 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup *active_memcg;
	struct request_queue *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___17 *oom_reaper_list;
	struct vm_struct___14 *stack_vm_area;
	refcount_t stack_refcount;
	int patch_state;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	void *mce_vaddr;
	__u64 mce_kflags;
	u64 mce_addr;
	__u64 mce_ripv: 1;
	__u64 mce_whole_page: 1;
	__u64 __mce_reserved: 62;
	long: 2;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct callback_head mce_kill_me;
	int mce_count;
	struct llist_head kretprobe_instances;
	struct callback_head l1d_flush_kill;
	long: 64;
	struct thread_struct___9 thread;
};

struct pv_mmu_ops___11 {
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_one_user)(long unsigned int);
	void (*flush_tlb_multi)(const struct cpumask *, const struct flush_tlb_info___3 *);
	void (*tlb_remove_table)(struct mmu_gather *, void *);
	void (*exit_mmap)(struct mm_struct___16 *);
	struct paravirt_callee_save read_cr2;
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___16 *, struct mm_struct___16 *);
	void (*dup_mmap)(struct mm_struct___16 *, struct mm_struct___16 *);
	int (*pgd_alloc)(struct mm_struct___16 *);
	void (*pgd_free)(struct mm_struct___16 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___16 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___16 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___16 *, long unsigned int);
	void (*alloc_p4d)(struct mm_struct___16 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*release_p4d)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	pte_t (*ptep_modify_prot_start)(struct vm_area_struct___16 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct vm_area_struct___16 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_p4d)(p4d_t *, p4d_t);
	struct paravirt_callee_save p4d_val;
	struct paravirt_callee_save make_p4d;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

struct file___14;

struct core_state___15;

struct mm_struct___16 {
	struct {
		struct vm_area_struct___16 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___14 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int mmap_compat_base;
		long unsigned int mmap_compat_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[48];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___15 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___17 *owner;
		struct user_namespace *user_ns;
		struct file___14 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		bool tlb_flush_batched;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct vm_operations_struct___14;

struct vm_area_struct___16 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___16 *vm_next;
	struct vm_area_struct___16 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___16 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___14 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___14 *vm_file;
	struct file___14 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct paravirt_patch_template___11 {
	struct pv_cpu_ops___11 cpu;
	struct pv_irq_ops irq;
	struct pv_mmu_ops___11 mmu;
	struct pv_lock_ops lock;
};

struct kiocb___14;

struct iov_iter___12;

struct inode___14;

struct file_lock___14;

struct seq_file___13;

struct file_operations___14 {
	struct module___14 *owner;
	loff_t (*llseek)(struct file___14 *, loff_t, int);
	ssize_t (*read)(struct file___14 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___14 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___14 *, struct iov_iter___12 *);
	ssize_t (*write_iter)(struct kiocb___14 *, struct iov_iter___12 *);
	int (*iopoll)(struct kiocb___14 *, bool);
	int (*iterate)(struct file___14 *, struct dir_context *);
	int (*iterate_shared)(struct file___14 *, struct dir_context *);
	__poll_t (*poll)(struct file___14 *, struct poll_table_struct *);
	long int (*unlocked_ioctl)(struct file___14 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___14 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___14 *, struct vm_area_struct___16 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___14 *, struct file___14 *);
	int (*flush)(struct file___14 *, fl_owner_t);
	int (*release)(struct inode___14 *, struct file___14 *);
	int (*fsync)(struct file___14 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___14 *, int);
	int (*lock)(struct file___14 *, int, struct file_lock___14 *);
	ssize_t (*sendpage)(struct file___14 *, struct page___15 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___14 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___14 *, long unsigned int);
	int (*flock)(struct file___14 *, int, struct file_lock___14 *);
	ssize_t (*splice_write)(struct pipe_inode_info___3 *, struct file___14 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___14 *, loff_t *, struct pipe_inode_info___3 *, size_t, unsigned int);
	int (*setlease)(struct file___14 *, long int, struct file_lock___14 **, void **);
	long int (*fallocate)(struct file___14 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___13 *, struct file___14 *);
	ssize_t (*copy_file_range)(struct file___14 *, loff_t, struct file___14 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___14 *, loff_t, struct file___14 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___14 *, loff_t, loff_t, int);
};

struct seq_operations___13 {
	void * (*start)(struct seq_file___13 *, loff_t *);
	void (*stop)(struct seq_file___13 *, void *);
	void * (*next)(struct seq_file___13 *, void *, loff_t *);
	int (*show)(struct seq_file___13 *, void *);
};

struct pid_namespace___13;

struct upid___13 {
	int nr;
	struct pid_namespace___13 *ns;
};

struct pid_namespace___13 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___17 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___13 *parent;
	struct fs_pin *bacct;
	struct user_namespace *user_ns;
	struct ucounts *ucounts;
	int reboot;
	struct ns_common ns;
};

struct pid___13 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___13 numbers[1];
};

struct signal_struct___15 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___17 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___17 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper;
	unsigned int has_child_subreaper;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___13 *pids[4];
	struct pid___13 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___16 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct nsproxy___14 {
	atomic_t count;
	struct uts_namespace *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___13 *pid_ns_for_children;
	struct net___2 *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___2 *cgroup_ns;
};

struct fasync_struct___14;

struct pipe_buffer___3;

struct pipe_inode_info___3 {
	struct mutex mutex;
	wait_queue_head_t rd_wait;
	wait_queue_head_t wr_wait;
	unsigned int head;
	unsigned int tail;
	unsigned int max_usage;
	unsigned int ring_size;
	bool note_loss;
	unsigned int nr_accounted;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int r_counter;
	unsigned int w_counter;
	unsigned int poll_usage;
	struct page___15 *tmp_page;
	struct fasync_struct___14 *fasync_readers;
	struct fasync_struct___14 *fasync_writers;
	struct pipe_buffer___3 *bufs;
	struct user_struct *user;
	struct watch_queue *watch_queue;
};

struct vm_struct___14 {
	struct vm_struct___14 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___15 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct address_space_operations___14;

struct address_space___14 {
	struct inode___14 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___14 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct device___16;

struct page_pool_params___3 {
	unsigned int flags;
	unsigned int order;
	unsigned int pool_size;
	int nid;
	struct device___16 *dev;
	enum dma_data_direction dma_dir;
	unsigned int max_len;
	unsigned int offset;
};

struct pp_alloc_cache___3 {
	u32 count;
	struct page___15 *cache[128];
};

struct page_pool___3 {
	struct page_pool_params___3 p;
	struct delayed_work release_dw;
	void (*disconnect)(void *);
	long unsigned int defer_start;
	long unsigned int defer_warn;
	u32 pages_state_hold_cnt;
	unsigned int frag_offset;
	struct page___15 *frag_page;
	long int frag_users;
	long: 64;
	long: 64;
	struct pp_alloc_cache___3 alloc;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct ptr_ring ring;
	atomic_t pages_state_release_cnt;
	refcount_t user_cnt;
	u64 destroy_cnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pagemap_ops___14;

struct dev_pagemap___14 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___14 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vfsmount___14;

struct path___14 {
	struct vfsmount___14 *mnt;
	struct dentry___14 *dentry;
};

struct fown_struct___13 {
	rwlock_t lock;
	struct pid___13 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___14 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___14 f_path;
	struct inode___14 *f_inode;
	const struct file_operations___14 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___13 f_owner;
	const struct cred *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___14 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___14;

struct vm_operations_struct___14 {
	void (*open)(struct vm_area_struct___16 *);
	void (*close)(struct vm_area_struct___16 *);
	int (*may_split)(struct vm_area_struct___16 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___16 *);
	int (*mprotect)(struct vm_area_struct___16 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___14 *);
	vm_fault_t (*huge_fault)(struct vm_fault___14 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___14 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___16 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___14 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___14 *);
	int (*access)(struct vm_area_struct___16 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___16 *);
	int (*set_policy)(struct vm_area_struct___16 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___16 *, long unsigned int);
	struct page___15 * (*find_special_page)(struct vm_area_struct___16 *, long unsigned int);
};

struct core_thread___15 {
	struct task_struct___17 *task;
	struct core_thread___15 *next;
};

struct core_state___15 {
	atomic_t nr_threads;
	struct core_thread___15 dumper;
	struct completion startup;
};

struct vm_fault___14 {
	const struct {
		struct vm_area_struct___16 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___15 *cow_page;
	struct page___15 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___15 prealloc_pte;
};

struct dev_pagemap_ops___14 {
	void (*page_free)(struct page___15 *);
	void (*kill)(struct dev_pagemap___14 *);
	void (*cleanup)(struct dev_pagemap___14 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___14 *);
};

struct dentry_operations___14;

struct dentry___14 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___14 *d_parent;
	struct qstr d_name;
	struct inode___14 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___14 *d_op;
	struct super_block___14 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___14;

struct inode___14 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___14 *i_op;
	struct super_block___14 *i_sb;
	struct address_space___14 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___14 *i_fop;
		void (*free_inode)(struct inode___14 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___14 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___3 *i_pipe;
		struct cdev *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___14 {
	int (*d_revalidate)(struct dentry___14 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___14 *, unsigned int);
	int (*d_hash)(const struct dentry___14 *, struct qstr *);
	int (*d_compare)(const struct dentry___14 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___14 *);
	int (*d_init)(struct dentry___14 *);
	void (*d_release)(struct dentry___14 *);
	void (*d_prune)(struct dentry___14 *);
	void (*d_iput)(struct dentry___14 *, struct inode___14 *);
	char * (*d_dname)(struct dentry___14 *, char *, int);
	struct vfsmount___14 * (*d_automount)(struct path___14 *);
	int (*d_manage)(const struct path___14 *, bool);
	struct dentry___14 * (*d_real)(struct dentry___14 *, const struct inode___14 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___14;

struct mem_dqinfo___14 {
	struct quota_format_type___14 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___14;

struct quota_info___14 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___14 *files[3];
	struct mem_dqinfo___14 info[3];
	const struct quota_format_ops___14 *ops[3];
};

struct rcuwait___14 {
	struct task_struct___17 *task;
};

struct percpu_rw_semaphore___14 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___14 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___14 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___14 rw_sem[3];
};

struct super_operations___14;

struct dquot_operations___14;

struct quotactl_ops___14;

struct super_block___14 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___14 *s_type;
	const struct super_operations___14 *s_op;
	const struct dquot_operations___14 *dq_op;
	const struct quotactl_ops___14 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___14 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device *s_bdev;
	struct backing_dev_info *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___14 s_dquot;
	struct sb_writers___14 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___14 *s_d_op;
	int cleancache_poolid;
	struct shrinker___9 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___14 {
	struct dentry___14 *mnt_root;
	struct super_block___14 *mnt_sb;
	int mnt_flags;
	struct user_namespace *mnt_userns;
};

struct wait_page_queue___8;

struct kiocb___14 {
	struct file___14 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___14 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___8 *ki_waitq;
	};
};

struct iattr___14 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___14 *ia_file;
};

struct dquot___14 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___14 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___14 {
	int qf_fmt_id;
	const struct quota_format_ops___14 *qf_ops;
	struct module___14 *qf_owner;
	struct quota_format_type___14 *qf_next;
};

struct quota_format_ops___14 {
	int (*check_quota_file)(struct super_block___14 *, int);
	int (*read_file_info)(struct super_block___14 *, int);
	int (*write_file_info)(struct super_block___14 *, int);
	int (*free_file_info)(struct super_block___14 *, int);
	int (*read_dqblk)(struct dquot___14 *);
	int (*commit_dqblk)(struct dquot___14 *);
	int (*release_dqblk)(struct dquot___14 *);
	int (*get_next_id)(struct super_block___14 *, struct kqid *);
};

struct dquot_operations___14 {
	int (*write_dquot)(struct dquot___14 *);
	struct dquot___14 * (*alloc_dquot)(struct super_block___14 *, int);
	void (*destroy_dquot)(struct dquot___14 *);
	int (*acquire_dquot)(struct dquot___14 *);
	int (*release_dquot)(struct dquot___14 *);
	int (*mark_dirty)(struct dquot___14 *);
	int (*write_info)(struct super_block___14 *, int);
	qsize_t * (*get_reserved_space)(struct inode___14 *);
	int (*get_projid)(struct inode___14 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___14 *, qsize_t *);
	int (*get_next_id)(struct super_block___14 *, struct kqid *);
};

struct quotactl_ops___14 {
	int (*quota_on)(struct super_block___14 *, int, int, const struct path___14 *);
	int (*quota_off)(struct super_block___14 *, int);
	int (*quota_enable)(struct super_block___14 *, unsigned int);
	int (*quota_disable)(struct super_block___14 *, unsigned int);
	int (*quota_sync)(struct super_block___14 *, int);
	int (*set_info)(struct super_block___14 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___14 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___14 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___14 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___14 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___14 *, unsigned int);
};

struct kset___14;

struct kobj_type___14;

struct kernfs_node___14;

struct kobject___15 {
	const char *name;
	struct list_head entry;
	struct kobject___15 *parent;
	struct kset___14 *kset;
	struct kobj_type___14 *ktype;
	struct kernfs_node___14 *sd;
	struct kref kref;
	unsigned int state_initialized;
	unsigned int state_in_sysfs;
	unsigned int state_add_uevent_sent;
	unsigned int state_remove_uevent_sent;
	unsigned int uevent_suppress;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___14 {
	struct kobject___15 kobj;
	struct module___14 *mod;
	struct kobject___15 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___14 {
	struct module___14 *mod;
	struct latch_tree_node node;
};

struct module_layout___14 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___14 mtn;
};

struct module_attribute___14;

struct kernel_param___14;

struct module___14 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___14 mkobj;
	struct module_attribute___14 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___15 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___14 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___14 core_layout;
	struct module_layout___14 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map___10 *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___4 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	int num_static_call_sites;
	struct static_call_site *static_call_sites;
	bool klp;
	bool klp_alive;
	struct klp_modinfo *klp_info;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct wait_page_queue___8 {
	struct page___15 *page;
	int bit_nr;
	wait_queue_entry_t wait;
};

struct readahead_control___8;

struct address_space_operations___14 {
	int (*writepage)(struct page___15 *, struct writeback_control *);
	int (*readpage)(struct file___14 *, struct page___15 *);
	int (*writepages)(struct address_space___14 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___15 *);
	int (*readpages)(struct file___14 *, struct address_space___14 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___8 *);
	int (*write_begin)(struct file___14 *, struct address_space___14 *, loff_t, unsigned int, unsigned int, struct page___15 **, void **);
	int (*write_end)(struct file___14 *, struct address_space___14 *, loff_t, unsigned int, unsigned int, struct page___15 *, void *);
	sector_t (*bmap)(struct address_space___14 *, sector_t);
	void (*invalidatepage)(struct page___15 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___15 *, gfp_t);
	void (*freepage)(struct page___15 *);
	ssize_t (*direct_IO)(struct kiocb___14 *, struct iov_iter___12 *);
	int (*migratepage)(struct address_space___14 *, struct page___15 *, struct page___15 *, enum migrate_mode);
	bool (*isolate_page)(struct page___15 *, isolate_mode_t);
	void (*putback_page)(struct page___15 *);
	int (*launder_page)(struct page___15 *);
	int (*is_partially_uptodate)(struct page___15 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___15 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___14 *, struct page___15 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___14 *, sector_t *);
	void (*swap_deactivate)(struct file___14 *);
};

struct readahead_control___8 {
	struct file___14 *file;
	struct address_space___14 *mapping;
	struct file_ra_state *ra;
	long unsigned int _index;
	unsigned int _nr_pages;
	unsigned int _batch_count;
};

struct bio_vec___12;

struct iov_iter___12 {
	u8 iter_type;
	bool data_source;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___12 *bvec;
		struct xarray *xarray;
		struct pipe_inode_info___3 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			unsigned int head;
			unsigned int start_head;
		};
		loff_t xarray_start;
	};
};

struct inode_operations___14 {
	struct dentry___14 * (*lookup)(struct inode___14 *, struct dentry___14 *, unsigned int);
	const char * (*get_link)(struct dentry___14 *, struct inode___14 *, struct delayed_call *);
	int (*permission)(struct user_namespace *, struct inode___14 *, int);
	struct posix_acl * (*get_acl)(struct inode___14 *, int, bool);
	int (*readlink)(struct dentry___14 *, char *, int);
	int (*create)(struct user_namespace *, struct inode___14 *, struct dentry___14 *, umode_t, bool);
	int (*link)(struct dentry___14 *, struct inode___14 *, struct dentry___14 *);
	int (*unlink)(struct inode___14 *, struct dentry___14 *);
	int (*symlink)(struct user_namespace *, struct inode___14 *, struct dentry___14 *, const char *);
	int (*mkdir)(struct user_namespace *, struct inode___14 *, struct dentry___14 *, umode_t);
	int (*rmdir)(struct inode___14 *, struct dentry___14 *);
	int (*mknod)(struct user_namespace *, struct inode___14 *, struct dentry___14 *, umode_t, dev_t);
	int (*rename)(struct user_namespace *, struct inode___14 *, struct dentry___14 *, struct inode___14 *, struct dentry___14 *, unsigned int);
	int (*setattr)(struct user_namespace *, struct dentry___14 *, struct iattr___14 *);
	int (*getattr)(struct user_namespace *, const struct path___14 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___14 *, char *, size_t);
	int (*fiemap)(struct inode___14 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___14 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___14 *, struct dentry___14 *, struct file___14 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace *, struct inode___14 *, struct dentry___14 *, umode_t);
	int (*set_acl)(struct user_namespace *, struct inode___14 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace *, struct dentry___14 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___14 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___14 {
	void (*fl_copy_lock)(struct file_lock___14 *, struct file_lock___14 *);
	void (*fl_release_private)(struct file_lock___14 *);
};

struct lock_manager_operations___14;

struct file_lock___14 {
	struct file_lock___14 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___14 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___14 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___14 *fl_ops;
	const struct lock_manager_operations___14 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___14 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___14 *);
	int (*lm_grant)(struct file_lock___14 *, int);
	bool (*lm_break)(struct file_lock___14 *);
	int (*lm_change)(struct file_lock___14 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___14 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___14 *);
};

struct fasync_struct___14 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___14 *fa_next;
	struct file___14 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___14 {
	struct inode___14 * (*alloc_inode)(struct super_block___14 *);
	void (*destroy_inode)(struct inode___14 *);
	void (*free_inode)(struct inode___14 *);
	void (*dirty_inode)(struct inode___14 *, int);
	int (*write_inode)(struct inode___14 *, struct writeback_control *);
	int (*drop_inode)(struct inode___14 *);
	void (*evict_inode)(struct inode___14 *);
	void (*put_super)(struct super_block___14 *);
	int (*sync_fs)(struct super_block___14 *, int);
	int (*freeze_super)(struct super_block___14 *);
	int (*freeze_fs)(struct super_block___14 *);
	int (*thaw_super)(struct super_block___14 *);
	int (*unfreeze_fs)(struct super_block___14 *);
	int (*statfs)(struct dentry___14 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___14 *, int *, char *);
	void (*umount_begin)(struct super_block___14 *);
	int (*show_options)(struct seq_file___13 *, struct dentry___14 *);
	int (*show_devname)(struct seq_file___13 *, struct dentry___14 *);
	int (*show_path)(struct seq_file___13 *, struct dentry___14 *);
	int (*show_stats)(struct seq_file___13 *, struct dentry___14 *);
	ssize_t (*quota_read)(struct super_block___14 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___14 *, int, const char *, size_t, loff_t);
	struct dquot___14 ** (*get_dquots)(struct inode___14 *);
	long int (*nr_cached_objects)(struct super_block___14 *, struct shrink_control___9 *);
	long int (*free_cached_objects)(struct super_block___14 *, struct shrink_control___9 *);
	struct file___14 * (*real_loop)(struct file___14 *);
};

struct seq_file___13 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___13 *op;
	int poll_event;
	const struct file___14 *file;
	void *private;
};

struct kernfs_root___14;

struct kernfs_elem_dir___14 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___14 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___14;

struct kernfs_root___14 {
	struct kernfs_node___14 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___14 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___14 {
	struct kernfs_node___14 *target_kn;
};

struct kernfs_ops___14;

struct kernfs_elem_attr___14 {
	const struct kernfs_ops___14 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___14 *notify_next;
};

struct kernfs_node___14 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___14 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___14 dir;
		struct kernfs_elem_symlink___14 symlink;
		struct kernfs_elem_attr___14 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___14;

struct kernfs_ops___14 {
	int (*open)(struct kernfs_open_file___14 *);
	void (*release)(struct kernfs_open_file___14 *);
	int (*seq_show)(struct seq_file___13 *, void *);
	void * (*seq_start)(struct seq_file___13 *, loff_t *);
	void * (*seq_next)(struct seq_file___13 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___13 *, void *);
	ssize_t (*read)(struct kernfs_open_file___14 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___14 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___14 *, struct poll_table_struct *);
	int (*mmap)(struct kernfs_open_file___14 *, struct vm_area_struct___16 *);
};

struct kernfs_syscall_ops___14 {
	int (*show_options)(struct seq_file___13 *, struct kernfs_root___14 *);
	int (*mkdir)(struct kernfs_node___14 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___14 *);
	int (*rename)(struct kernfs_node___14 *, struct kernfs_node___14 *, const char *);
	int (*show_path)(struct seq_file___13 *, struct kernfs_node___14 *, struct kernfs_root___14 *);
};

struct kernfs_open_file___14 {
	struct kernfs_node___14 *kn;
	struct file___14 *file;
	struct seq_file___13 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped;
	bool released;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___14 *vm_ops;
};

struct bin_attribute___15;

struct attribute_group___15 {
	const char *name;
	umode_t (*is_visible)(struct kobject___15 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___15 *, struct bin_attribute___15 *, int);
	struct attribute **attrs;
	struct bin_attribute___15 **bin_attrs;
};

struct bin_attribute___15 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___14 * (*f_mapping)();
	ssize_t (*read)(struct file___14 *, struct kobject___15 *, struct bin_attribute___15 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___14 *, struct kobject___15 *, struct bin_attribute___15 *, char *, loff_t, size_t);
	int (*mmap)(struct file___14 *, struct kobject___15 *, struct bin_attribute___15 *, struct vm_area_struct___16 *);
};

struct sysfs_ops___14 {
	ssize_t (*show)(struct kobject___15 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___15 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___14;

struct kset___14 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___15 kobj;
	const struct kset_uevent_ops___14 *uevent_ops;
};

struct kobj_type___14 {
	void (*release)(struct kobject___15 *);
	const struct sysfs_ops___14 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___15 **default_groups;
	const struct kobj_ns_type_operations * (*child_ns_type)(struct kobject___15 *);
	const void * (*namespace)(struct kobject___15 *);
	void (*get_ownership)(struct kobject___15 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___14 {
	int (* const filter)(struct kset___14 *, struct kobject___15 *);
	const char * (* const name)(struct kset___14 *, struct kobject___15 *);
	int (* const uevent)(struct kset___14 *, struct kobject___15 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___14 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___14 *);
	int (*get)(char *, const struct kernel_param___14 *);
	void (*free)(void *);
};

struct kparam_array___14;

struct kernel_param___14 {
	const char *name;
	struct module___14 *mod;
	const struct kernel_param_ops___14 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___14 *arr;
	};
};

struct kparam_array___14 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___14 *ops;
	void *elem;
};

struct module_attribute___14 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___14 *, struct module_kobject___14 *, char *);
	ssize_t (*store)(struct module_attribute___14 *, struct module_kobject___14 *, const char *, size_t);
	void (*setup)(struct module___14 *, const char *);
	int (*test)(struct module___14 *);
	void (*free)(struct module___14 *);
};

struct bio_vec___12 {
	struct page___15 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

enum flow_dissector_key_id {
	FLOW_DISSECTOR_KEY_CONTROL = 0,
	FLOW_DISSECTOR_KEY_BASIC = 1,
	FLOW_DISSECTOR_KEY_IPV4_ADDRS = 2,
	FLOW_DISSECTOR_KEY_IPV6_ADDRS = 3,
	FLOW_DISSECTOR_KEY_PORTS = 4,
	FLOW_DISSECTOR_KEY_PORTS_RANGE = 5,
	FLOW_DISSECTOR_KEY_ICMP = 6,
	FLOW_DISSECTOR_KEY_ETH_ADDRS = 7,
	FLOW_DISSECTOR_KEY_TIPC = 8,
	FLOW_DISSECTOR_KEY_ARP = 9,
	FLOW_DISSECTOR_KEY_VLAN = 10,
	FLOW_DISSECTOR_KEY_FLOW_LABEL = 11,
	FLOW_DISSECTOR_KEY_GRE_KEYID = 12,
	FLOW_DISSECTOR_KEY_MPLS_ENTROPY = 13,
	FLOW_DISSECTOR_KEY_ENC_KEYID = 14,
	FLOW_DISSECTOR_KEY_ENC_IPV4_ADDRS = 15,
	FLOW_DISSECTOR_KEY_ENC_IPV6_ADDRS = 16,
	FLOW_DISSECTOR_KEY_ENC_CONTROL = 17,
	FLOW_DISSECTOR_KEY_ENC_PORTS = 18,
	FLOW_DISSECTOR_KEY_MPLS = 19,
	FLOW_DISSECTOR_KEY_TCP = 20,
	FLOW_DISSECTOR_KEY_IP = 21,
	FLOW_DISSECTOR_KEY_CVLAN = 22,
	FLOW_DISSECTOR_KEY_ENC_IP = 23,
	FLOW_DISSECTOR_KEY_ENC_OPTS = 24,
	FLOW_DISSECTOR_KEY_META = 25,
	FLOW_DISSECTOR_KEY_CT = 26,
	FLOW_DISSECTOR_KEY_HASH = 27,
	FLOW_DISSECTOR_KEY_MAX = 28,
};

enum {
	IPSTATS_MIB_NUM = 0,
	IPSTATS_MIB_INPKTS = 1,
	IPSTATS_MIB_INOCTETS = 2,
	IPSTATS_MIB_INDELIVERS = 3,
	IPSTATS_MIB_OUTFORWDATAGRAMS = 4,
	IPSTATS_MIB_OUTPKTS = 5,
	IPSTATS_MIB_OUTOCTETS = 6,
	IPSTATS_MIB_INHDRERRORS = 7,
	IPSTATS_MIB_INTOOBIGERRORS = 8,
	IPSTATS_MIB_INNOROUTES = 9,
	IPSTATS_MIB_INADDRERRORS = 10,
	IPSTATS_MIB_INUNKNOWNPROTOS = 11,
	IPSTATS_MIB_INTRUNCATEDPKTS = 12,
	IPSTATS_MIB_INDISCARDS = 13,
	IPSTATS_MIB_OUTDISCARDS = 14,
	IPSTATS_MIB_OUTNOROUTES = 15,
	IPSTATS_MIB_REASMTIMEOUT = 16,
	IPSTATS_MIB_REASMREQDS = 17,
	IPSTATS_MIB_REASMOKS = 18,
	IPSTATS_MIB_REASMFAILS = 19,
	IPSTATS_MIB_FRAGOKS = 20,
	IPSTATS_MIB_FRAGFAILS = 21,
	IPSTATS_MIB_FRAGCREATES = 22,
	IPSTATS_MIB_INMCASTPKTS = 23,
	IPSTATS_MIB_OUTMCASTPKTS = 24,
	IPSTATS_MIB_INBCASTPKTS = 25,
	IPSTATS_MIB_OUTBCASTPKTS = 26,
	IPSTATS_MIB_INMCASTOCTETS = 27,
	IPSTATS_MIB_OUTMCASTOCTETS = 28,
	IPSTATS_MIB_INBCASTOCTETS = 29,
	IPSTATS_MIB_OUTBCASTOCTETS = 30,
	IPSTATS_MIB_CSUMERRORS = 31,
	IPSTATS_MIB_NOECTPKTS = 32,
	IPSTATS_MIB_ECT1PKTS = 33,
	IPSTATS_MIB_ECT0PKTS = 34,
	IPSTATS_MIB_CEPKTS = 35,
	IPSTATS_MIB_REASM_OVERLAPS = 36,
	__IPSTATS_MIB_MAX = 37,
};

enum {
	ICMP_MIB_NUM = 0,
	ICMP_MIB_INMSGS = 1,
	ICMP_MIB_INERRORS = 2,
	ICMP_MIB_INDESTUNREACHS = 3,
	ICMP_MIB_INTIMEEXCDS = 4,
	ICMP_MIB_INPARMPROBS = 5,
	ICMP_MIB_INSRCQUENCHS = 6,
	ICMP_MIB_INREDIRECTS = 7,
	ICMP_MIB_INECHOS = 8,
	ICMP_MIB_INECHOREPS = 9,
	ICMP_MIB_INTIMESTAMPS = 10,
	ICMP_MIB_INTIMESTAMPREPS = 11,
	ICMP_MIB_INADDRMASKS = 12,
	ICMP_MIB_INADDRMASKREPS = 13,
	ICMP_MIB_OUTMSGS = 14,
	ICMP_MIB_OUTERRORS = 15,
	ICMP_MIB_OUTDESTUNREACHS = 16,
	ICMP_MIB_OUTTIMEEXCDS = 17,
	ICMP_MIB_OUTPARMPROBS = 18,
	ICMP_MIB_OUTSRCQUENCHS = 19,
	ICMP_MIB_OUTREDIRECTS = 20,
	ICMP_MIB_OUTECHOS = 21,
	ICMP_MIB_OUTECHOREPS = 22,
	ICMP_MIB_OUTTIMESTAMPS = 23,
	ICMP_MIB_OUTTIMESTAMPREPS = 24,
	ICMP_MIB_OUTADDRMASKS = 25,
	ICMP_MIB_OUTADDRMASKREPS = 26,
	ICMP_MIB_CSUMERRORS = 27,
	__ICMP_MIB_MAX = 28,
};

enum {
	ICMP6_MIB_NUM = 0,
	ICMP6_MIB_INMSGS = 1,
	ICMP6_MIB_INERRORS = 2,
	ICMP6_MIB_OUTMSGS = 3,
	ICMP6_MIB_OUTERRORS = 4,
	ICMP6_MIB_CSUMERRORS = 5,
	__ICMP6_MIB_MAX = 6,
};

enum {
	TCP_MIB_NUM = 0,
	TCP_MIB_RTOALGORITHM = 1,
	TCP_MIB_RTOMIN = 2,
	TCP_MIB_RTOMAX = 3,
	TCP_MIB_MAXCONN = 4,
	TCP_MIB_ACTIVEOPENS = 5,
	TCP_MIB_PASSIVEOPENS = 6,
	TCP_MIB_ATTEMPTFAILS = 7,
	TCP_MIB_ESTABRESETS = 8,
	TCP_MIB_CURRESTAB = 9,
	TCP_MIB_INSEGS = 10,
	TCP_MIB_OUTSEGS = 11,
	TCP_MIB_RETRANSSEGS = 12,
	TCP_MIB_INERRS = 13,
	TCP_MIB_OUTRSTS = 14,
	TCP_MIB_CSUMERRORS = 15,
	__TCP_MIB_MAX = 16,
};

enum {
	UDP_MIB_NUM = 0,
	UDP_MIB_INDATAGRAMS = 1,
	UDP_MIB_NOPORTS = 2,
	UDP_MIB_INERRORS = 3,
	UDP_MIB_OUTDATAGRAMS = 4,
	UDP_MIB_RCVBUFERRORS = 5,
	UDP_MIB_SNDBUFERRORS = 6,
	UDP_MIB_CSUMERRORS = 7,
	UDP_MIB_IGNOREDMULTI = 8,
	UDP_MIB_MEMERRORS = 9,
	__UDP_MIB_MAX = 10,
};

enum {
	LINUX_MIB_NUM = 0,
	LINUX_MIB_SYNCOOKIESSENT = 1,
	LINUX_MIB_SYNCOOKIESRECV = 2,
	LINUX_MIB_SYNCOOKIESFAILED = 3,
	LINUX_MIB_EMBRYONICRSTS = 4,
	LINUX_MIB_PRUNECALLED = 5,
	LINUX_MIB_RCVPRUNED = 6,
	LINUX_MIB_OFOPRUNED = 7,
	LINUX_MIB_OUTOFWINDOWICMPS = 8,
	LINUX_MIB_LOCKDROPPEDICMPS = 9,
	LINUX_MIB_ARPFILTER = 10,
	LINUX_MIB_TIMEWAITED = 11,
	LINUX_MIB_TIMEWAITRECYCLED = 12,
	LINUX_MIB_TIMEWAITKILLED = 13,
	LINUX_MIB_PAWSACTIVEREJECTED = 14,
	LINUX_MIB_PAWSESTABREJECTED = 15,
	LINUX_MIB_DELAYEDACKS = 16,
	LINUX_MIB_DELAYEDACKLOCKED = 17,
	LINUX_MIB_DELAYEDACKLOST = 18,
	LINUX_MIB_LISTENOVERFLOWS = 19,
	LINUX_MIB_LISTENDROPS = 20,
	LINUX_MIB_TCPHPHITS = 21,
	LINUX_MIB_TCPPUREACKS = 22,
	LINUX_MIB_TCPHPACKS = 23,
	LINUX_MIB_TCPRENORECOVERY = 24,
	LINUX_MIB_TCPSACKRECOVERY = 25,
	LINUX_MIB_TCPSACKRENEGING = 26,
	LINUX_MIB_TCPSACKREORDER = 27,
	LINUX_MIB_TCPRENOREORDER = 28,
	LINUX_MIB_TCPTSREORDER = 29,
	LINUX_MIB_TCPFULLUNDO = 30,
	LINUX_MIB_TCPPARTIALUNDO = 31,
	LINUX_MIB_TCPDSACKUNDO = 32,
	LINUX_MIB_TCPLOSSUNDO = 33,
	LINUX_MIB_TCPLOSTRETRANSMIT = 34,
	LINUX_MIB_TCPRENOFAILURES = 35,
	LINUX_MIB_TCPSACKFAILURES = 36,
	LINUX_MIB_TCPLOSSFAILURES = 37,
	LINUX_MIB_TCPFASTRETRANS = 38,
	LINUX_MIB_TCPSLOWSTARTRETRANS = 39,
	LINUX_MIB_TCPTIMEOUTS = 40,
	LINUX_MIB_TCPLOSSPROBES = 41,
	LINUX_MIB_TCPLOSSPROBERECOVERY = 42,
	LINUX_MIB_TCPRENORECOVERYFAIL = 43,
	LINUX_MIB_TCPSACKRECOVERYFAIL = 44,
	LINUX_MIB_TCPRCVCOLLAPSED = 45,
	LINUX_MIB_TCPDSACKOLDSENT = 46,
	LINUX_MIB_TCPDSACKOFOSENT = 47,
	LINUX_MIB_TCPDSACKRECV = 48,
	LINUX_MIB_TCPDSACKOFORECV = 49,
	LINUX_MIB_TCPABORTONDATA = 50,
	LINUX_MIB_TCPABORTONCLOSE = 51,
	LINUX_MIB_TCPABORTONMEMORY = 52,
	LINUX_MIB_TCPABORTONTIMEOUT = 53,
	LINUX_MIB_TCPABORTONLINGER = 54,
	LINUX_MIB_TCPABORTFAILED = 55,
	LINUX_MIB_TCPMEMORYPRESSURES = 56,
	LINUX_MIB_TCPMEMORYPRESSURESCHRONO = 57,
	LINUX_MIB_TCPSACKDISCARD = 58,
	LINUX_MIB_TCPDSACKIGNOREDOLD = 59,
	LINUX_MIB_TCPDSACKIGNOREDNOUNDO = 60,
	LINUX_MIB_TCPSPURIOUSRTOS = 61,
	LINUX_MIB_TCPMD5NOTFOUND = 62,
	LINUX_MIB_TCPMD5UNEXPECTED = 63,
	LINUX_MIB_TCPMD5FAILURE = 64,
	LINUX_MIB_SACKSHIFTED = 65,
	LINUX_MIB_SACKMERGED = 66,
	LINUX_MIB_SACKSHIFTFALLBACK = 67,
	LINUX_MIB_TCPBACKLOGDROP = 68,
	LINUX_MIB_PFMEMALLOCDROP = 69,
	LINUX_MIB_TCPMINTTLDROP = 70,
	LINUX_MIB_TCPDEFERACCEPTDROP = 71,
	LINUX_MIB_IPRPFILTER = 72,
	LINUX_MIB_TCPTIMEWAITOVERFLOW = 73,
	LINUX_MIB_TCPREQQFULLDOCOOKIES = 74,
	LINUX_MIB_TCPREQQFULLDROP = 75,
	LINUX_MIB_TCPRETRANSFAIL = 76,
	LINUX_MIB_TCPRCVCOALESCE = 77,
	LINUX_MIB_TCPBACKLOGCOALESCE = 78,
	LINUX_MIB_TCPOFOQUEUE = 79,
	LINUX_MIB_TCPOFODROP = 80,
	LINUX_MIB_TCPOFOMERGE = 81,
	LINUX_MIB_TCPCHALLENGEACK = 82,
	LINUX_MIB_TCPSYNCHALLENGE = 83,
	LINUX_MIB_TCPFASTOPENACTIVE = 84,
	LINUX_MIB_TCPFASTOPENACTIVEFAIL = 85,
	LINUX_MIB_TCPFASTOPENPASSIVE = 86,
	LINUX_MIB_TCPFASTOPENPASSIVEFAIL = 87,
	LINUX_MIB_TCPFASTOPENLISTENOVERFLOW = 88,
	LINUX_MIB_TCPFASTOPENCOOKIEREQD = 89,
	LINUX_MIB_TCPFASTOPENBLACKHOLE = 90,
	LINUX_MIB_TCPSPURIOUS_RTX_HOSTQUEUES = 91,
	LINUX_MIB_BUSYPOLLRXPACKETS = 92,
	LINUX_MIB_TCPAUTOCORKING = 93,
	LINUX_MIB_TCPFROMZEROWINDOWADV = 94,
	LINUX_MIB_TCPTOZEROWINDOWADV = 95,
	LINUX_MIB_TCPWANTZEROWINDOWADV = 96,
	LINUX_MIB_TCPSYNRETRANS = 97,
	LINUX_MIB_TCPORIGDATASENT = 98,
	LINUX_MIB_TCPHYSTARTTRAINDETECT = 99,
	LINUX_MIB_TCPHYSTARTTRAINCWND = 100,
	LINUX_MIB_TCPHYSTARTDELAYDETECT = 101,
	LINUX_MIB_TCPHYSTARTDELAYCWND = 102,
	LINUX_MIB_TCPACKSKIPPEDSYNRECV = 103,
	LINUX_MIB_TCPACKSKIPPEDPAWS = 104,
	LINUX_MIB_TCPACKSKIPPEDSEQ = 105,
	LINUX_MIB_TCPACKSKIPPEDFINWAIT2 = 106,
	LINUX_MIB_TCPACKSKIPPEDTIMEWAIT = 107,
	LINUX_MIB_TCPACKSKIPPEDCHALLENGE = 108,
	LINUX_MIB_TCPWINPROBE = 109,
	LINUX_MIB_TCPKEEPALIVE = 110,
	LINUX_MIB_TCPMTUPFAIL = 111,
	LINUX_MIB_TCPMTUPSUCCESS = 112,
	LINUX_MIB_TCPDELIVERED = 113,
	LINUX_MIB_TCPDELIVEREDCE = 114,
	LINUX_MIB_TCPACKCOMPRESSED = 115,
	LINUX_MIB_TCPZEROWINDOWDROP = 116,
	LINUX_MIB_TCPRCVQDROP = 117,
	LINUX_MIB_TCPWQUEUETOOBIG = 118,
	LINUX_MIB_TCPFASTOPENPASSIVEALTKEY = 119,
	LINUX_MIB_TCPTIMEOUTREHASH = 120,
	LINUX_MIB_TCPDUPLICATEDATAREHASH = 121,
	LINUX_MIB_TCPDSACKRECVSEGS = 122,
	LINUX_MIB_TCPDSACKIGNOREDDUBIOUS = 123,
	LINUX_MIB_TCPMIGRATEREQSUCCESS = 124,
	LINUX_MIB_TCPMIGRATEREQFAILURE = 125,
	__LINUX_MIB_MAX = 126,
};

enum {
	LINUX_MIB_XFRMNUM = 0,
	LINUX_MIB_XFRMINERROR = 1,
	LINUX_MIB_XFRMINBUFFERERROR = 2,
	LINUX_MIB_XFRMINHDRERROR = 3,
	LINUX_MIB_XFRMINNOSTATES = 4,
	LINUX_MIB_XFRMINSTATEPROTOERROR = 5,
	LINUX_MIB_XFRMINSTATEMODEERROR = 6,
	LINUX_MIB_XFRMINSTATESEQERROR = 7,
	LINUX_MIB_XFRMINSTATEEXPIRED = 8,
	LINUX_MIB_XFRMINSTATEMISMATCH = 9,
	LINUX_MIB_XFRMINSTATEINVALID = 10,
	LINUX_MIB_XFRMINTMPLMISMATCH = 11,
	LINUX_MIB_XFRMINNOPOLS = 12,
	LINUX_MIB_XFRMINPOLBLOCK = 13,
	LINUX_MIB_XFRMINPOLERROR = 14,
	LINUX_MIB_XFRMOUTERROR = 15,
	LINUX_MIB_XFRMOUTBUNDLEGENERROR = 16,
	LINUX_MIB_XFRMOUTBUNDLECHECKERROR = 17,
	LINUX_MIB_XFRMOUTNOSTATES = 18,
	LINUX_MIB_XFRMOUTSTATEPROTOERROR = 19,
	LINUX_MIB_XFRMOUTSTATEMODEERROR = 20,
	LINUX_MIB_XFRMOUTSTATESEQERROR = 21,
	LINUX_MIB_XFRMOUTSTATEEXPIRED = 22,
	LINUX_MIB_XFRMOUTPOLBLOCK = 23,
	LINUX_MIB_XFRMOUTPOLDEAD = 24,
	LINUX_MIB_XFRMOUTPOLERROR = 25,
	LINUX_MIB_XFRMFWDHDRERROR = 26,
	LINUX_MIB_XFRMOUTSTATEINVALID = 27,
	LINUX_MIB_XFRMACQUIREERROR = 28,
	__LINUX_MIB_XFRMMAX = 29,
};

enum {
	LINUX_MIB_TLSNUM = 0,
	LINUX_MIB_TLSCURRTXSW = 1,
	LINUX_MIB_TLSCURRRXSW = 2,
	LINUX_MIB_TLSCURRTXDEVICE = 3,
	LINUX_MIB_TLSCURRRXDEVICE = 4,
	LINUX_MIB_TLSTXSW = 5,
	LINUX_MIB_TLSRXSW = 6,
	LINUX_MIB_TLSTXDEVICE = 7,
	LINUX_MIB_TLSRXDEVICE = 8,
	LINUX_MIB_TLSDECRYPTERROR = 9,
	LINUX_MIB_TLSRXDEVICERESYNC = 10,
	__LINUX_MIB_TLSMAX = 11,
};

enum nf_inet_hooks {
	NF_INET_PRE_ROUTING = 0,
	NF_INET_LOCAL_IN = 1,
	NF_INET_FORWARD = 2,
	NF_INET_LOCAL_OUT = 3,
	NF_INET_POST_ROUTING = 4,
	NF_INET_NUMHOOKS = 5,
	NF_INET_INGRESS = 5,
};

enum {
	NFPROTO_UNSPEC = 0,
	NFPROTO_INET = 1,
	NFPROTO_IPV4 = 2,
	NFPROTO_ARP = 3,
	NFPROTO_NETDEV = 5,
	NFPROTO_BRIDGE = 7,
	NFPROTO_IPV6 = 10,
	NFPROTO_DECNET = 12,
	NFPROTO_NUMPROTO = 13,
};

enum tcp_conntrack {
	TCP_CONNTRACK_NONE = 0,
	TCP_CONNTRACK_SYN_SENT = 1,
	TCP_CONNTRACK_SYN_RECV = 2,
	TCP_CONNTRACK_ESTABLISHED = 3,
	TCP_CONNTRACK_FIN_WAIT = 4,
	TCP_CONNTRACK_CLOSE_WAIT = 5,
	TCP_CONNTRACK_LAST_ACK = 6,
	TCP_CONNTRACK_TIME_WAIT = 7,
	TCP_CONNTRACK_CLOSE = 8,
	TCP_CONNTRACK_LISTEN = 9,
	TCP_CONNTRACK_MAX = 10,
	TCP_CONNTRACK_IGNORE = 11,
	TCP_CONNTRACK_RETRANS = 12,
	TCP_CONNTRACK_UNACK = 13,
	TCP_CONNTRACK_TIMEOUT_MAX = 14,
};

enum ct_dccp_states {
	CT_DCCP_NONE = 0,
	CT_DCCP_REQUEST = 1,
	CT_DCCP_RESPOND = 2,
	CT_DCCP_PARTOPEN = 3,
	CT_DCCP_OPEN = 4,
	CT_DCCP_CLOSEREQ = 5,
	CT_DCCP_CLOSING = 6,
	CT_DCCP_TIMEWAIT = 7,
	CT_DCCP_IGNORE = 8,
	CT_DCCP_INVALID = 9,
	__CT_DCCP_MAX = 10,
};

enum ip_conntrack_dir {
	IP_CT_DIR_ORIGINAL = 0,
	IP_CT_DIR_REPLY = 1,
	IP_CT_DIR_MAX = 2,
};

enum sctp_conntrack {
	SCTP_CONNTRACK_NONE = 0,
	SCTP_CONNTRACK_CLOSED = 1,
	SCTP_CONNTRACK_COOKIE_WAIT = 2,
	SCTP_CONNTRACK_COOKIE_ECHOED = 3,
	SCTP_CONNTRACK_ESTABLISHED = 4,
	SCTP_CONNTRACK_SHUTDOWN_SENT = 5,
	SCTP_CONNTRACK_SHUTDOWN_RECD = 6,
	SCTP_CONNTRACK_SHUTDOWN_ACK_SENT = 7,
	SCTP_CONNTRACK_HEARTBEAT_SENT = 8,
	SCTP_CONNTRACK_HEARTBEAT_ACKED = 9,
	SCTP_CONNTRACK_MAX = 10,
};

enum udp_conntrack {
	UDP_CT_UNREPLIED = 0,
	UDP_CT_REPLIED = 1,
	UDP_CT_MAX = 2,
};

enum gre_conntrack {
	GRE_CT_UNREPLIED = 0,
	GRE_CT_REPLIED = 1,
	GRE_CT_MAX = 2,
};

enum {
	XFRM_POLICY_IN = 0,
	XFRM_POLICY_OUT = 1,
	XFRM_POLICY_FWD = 2,
	XFRM_POLICY_MASK = 3,
	XFRM_POLICY_MAX = 3,
};

enum netns_bpf_attach_type {
	NETNS_BPF_INVALID = 0,
	NETNS_BPF_FLOW_DISSECTOR = 0,
	NETNS_BPF_SK_LOOKUP = 1,
	MAX_NETNS_BPF_ATTACH_TYPE = 2,
};

struct wakeup_source___16;

struct dev_pm_info___16 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___16 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___16 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___16;

struct bus_type___16;

struct device_driver___16;

struct dev_pm_domain___16;

struct fwnode_handle___15;

struct class___16;

struct device___16 {
	struct kobject___15 kobj;
	struct device___16 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___16 *type;
	struct bus_type___16 *bus;
	struct device_driver___16 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___16 power;
	struct dev_pm_domain___16 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node *of_node;
	struct fwnode_handle___15 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___16 *class;
	const struct attribute_group___15 **groups;
	void (*release)(struct device___16 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_ops___16 {
	int (*prepare)(struct device___16 *);
	void (*complete)(struct device___16 *);
	int (*suspend)(struct device___16 *);
	int (*resume)(struct device___16 *);
	int (*freeze)(struct device___16 *);
	int (*thaw)(struct device___16 *);
	int (*poweroff)(struct device___16 *);
	int (*restore)(struct device___16 *);
	int (*suspend_late)(struct device___16 *);
	int (*resume_early)(struct device___16 *);
	int (*freeze_late)(struct device___16 *);
	int (*thaw_early)(struct device___16 *);
	int (*poweroff_late)(struct device___16 *);
	int (*restore_early)(struct device___16 *);
	int (*suspend_noirq)(struct device___16 *);
	int (*resume_noirq)(struct device___16 *);
	int (*freeze_noirq)(struct device___16 *);
	int (*thaw_noirq)(struct device___16 *);
	int (*poweroff_noirq)(struct device___16 *);
	int (*restore_noirq)(struct device___16 *);
	int (*runtime_suspend)(struct device___16 *);
	int (*runtime_resume)(struct device___16 *);
	int (*runtime_idle)(struct device___16 *);
};

struct wakeup_source___16 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___16 *dev;
	bool active;
	bool autosleep_enabled;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___16 {
	struct dev_pm_ops___16 ops;
	int (*start)(struct device___16 *);
	void (*detach)(struct device___16 *, bool);
	int (*activate)(struct device___16 *);
	void (*sync)(struct device___16 *);
	void (*dismiss)(struct device___16 *);
};

struct bus_type___16 {
	const char *name;
	const char *dev_name;
	struct device___16 *dev_root;
	const struct attribute_group___15 **bus_groups;
	const struct attribute_group___15 **dev_groups;
	const struct attribute_group___15 **drv_groups;
	int (*match)(struct device___16 *, struct device_driver___16 *);
	int (*uevent)(struct device___16 *, struct kobj_uevent_env *);
	int (*probe)(struct device___16 *);
	void (*sync_state)(struct device___16 *);
	void (*remove)(struct device___16 *);
	void (*shutdown)(struct device___16 *);
	int (*online)(struct device___16 *);
	int (*offline)(struct device___16 *);
	int (*suspend)(struct device___16 *, pm_message_t);
	int (*resume)(struct device___16 *);
	int (*num_vf)(struct device___16 *);
	int (*dma_configure)(struct device___16 *);
	const struct dev_pm_ops___16 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___16 {
	const char *name;
	struct bus_type___16 *bus;
	struct module___14 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___16 *);
	void (*sync_state)(struct device___16 *);
	int (*remove)(struct device___16 *);
	void (*shutdown)(struct device___16 *);
	int (*suspend)(struct device___16 *, pm_message_t);
	int (*resume)(struct device___16 *);
	const struct attribute_group___15 **groups;
	const struct attribute_group___15 **dev_groups;
	const struct dev_pm_ops___16 *pm;
	void (*coredump)(struct device___16 *);
	struct driver_private *p;
};

struct device_type___16 {
	const char *name;
	const struct attribute_group___15 **groups;
	int (*uevent)(struct device___16 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___16 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___16 *);
	const struct dev_pm_ops___16 *pm;
};

struct class___16 {
	const char *name;
	struct module___14 *owner;
	const struct attribute_group___15 **class_groups;
	const struct attribute_group___15 **dev_groups;
	struct kobject___15 *dev_kobj;
	int (*dev_uevent)(struct device___16 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___16 *, umode_t *);
	void (*class_release)(struct class___16 *);
	void (*dev_release)(struct device___16 *);
	int (*shutdown_pre)(struct device___16 *);
	const struct kobj_ns_type_operations *ns_type;
	const void * (*namespace)(struct device___16 *);
	void (*get_ownership)(struct device___16 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___16 *pm;
	struct subsys_private *p;
};

struct fwnode_operations___15;

struct fwnode_handle___15 {
	struct fwnode_handle___15 *secondary;
	const struct fwnode_operations___15 *ops;
	struct device___16 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct fwnode_reference_args___15;

struct fwnode_endpoint___15;

struct fwnode_operations___15 {
	struct fwnode_handle___15 * (*get)(struct fwnode_handle___15 *);
	void (*put)(struct fwnode_handle___15 *);
	bool (*device_is_available)(const struct fwnode_handle___15 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___15 *, const struct device___16 *);
	bool (*property_present)(const struct fwnode_handle___15 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___15 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___15 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___15 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___15 *);
	struct fwnode_handle___15 * (*get_parent)(const struct fwnode_handle___15 *);
	struct fwnode_handle___15 * (*get_next_child_node)(const struct fwnode_handle___15 *, struct fwnode_handle___15 *);
	struct fwnode_handle___15 * (*get_named_child_node)(const struct fwnode_handle___15 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___15 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___15 *);
	struct fwnode_handle___15 * (*graph_get_next_endpoint)(const struct fwnode_handle___15 *, struct fwnode_handle___15 *);
	struct fwnode_handle___15 * (*graph_get_remote_endpoint)(const struct fwnode_handle___15 *);
	struct fwnode_handle___15 * (*graph_get_port_parent)(struct fwnode_handle___15 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___15 *, struct fwnode_endpoint___15 *);
	int (*add_links)(struct fwnode_handle___15 *);
};

struct fwnode_endpoint___15 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___15 *local_fwnode;
};

struct fwnode_reference_args___15 {
	struct fwnode_handle___15 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct pipe_buf_operations___3;

struct pipe_buffer___3 {
	struct page___15 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___3 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___3 {
	int (*confirm)(struct pipe_inode_info___3 *, struct pipe_buffer___3 *);
	void (*release)(struct pipe_inode_info___3 *, struct pipe_buffer___3 *);
	bool (*try_steal)(struct pipe_inode_info___3 *, struct pipe_buffer___3 *);
	bool (*get)(struct pipe_inode_info___3 *, struct pipe_buffer___3 *);
};

enum skb_ext_id {
	SKB_EXT_BRIDGE_NF = 0,
	SKB_EXT_SEC_PATH = 1,
	TC_SKB_EXT = 2,
	SKB_EXT_MPTCP = 3,
	SKB_EXT_NUM = 4,
};

struct kobj_attribute {
	struct attribute attr;
	ssize_t (*show)(struct kobject___14 *, struct kobj_attribute *, char *);
	ssize_t (*store)(struct kobject___14 *, struct kobj_attribute *, const char *, size_t);
};

struct qspinlock___3 {
	union {
		atomic_t val;
		struct {
			u8 locked;
			u8 pending;
		};
		struct {
			u16 locked_pending;
			u16 tail;
		};
	};
};

typedef struct qspinlock___3 arch_spinlock_t___3;

struct raw_spinlock___3 {
	arch_spinlock_t___3 raw_lock;
};

typedef struct raw_spinlock___3 raw_spinlock_t___3;

struct spinlock___3 {
	union {
		struct raw_spinlock___3 rlock;
	};
};

typedef struct spinlock___3 spinlock_t___3;

typedef void (*swap_func_t)(void *, void *, int);

typedef int (*cmp_func_t)(const void *, const void *);

enum {
	IORES_DESC_NONE = 0,
	IORES_DESC_CRASH_KERNEL = 1,
	IORES_DESC_ACPI_TABLES = 2,
	IORES_DESC_ACPI_NV_STORAGE = 3,
	IORES_DESC_PERSISTENT_MEMORY = 4,
	IORES_DESC_PERSISTENT_MEMORY_LEGACY = 5,
	IORES_DESC_DEVICE_PRIVATE_MEMORY = 6,
	IORES_DESC_RESERVED = 7,
	IORES_DESC_SOFT_RESERVED = 8,
};

struct change_member {
	struct e820_entry *entry;
	long long unsigned int addr;
};

struct iopf_device_param;

struct iommu_fault_param;

struct iommu_fwspec;

struct dev_iommu {
	struct mutex lock;
	struct iommu_fault_param *fault_param;
	struct iopf_device_param *iopf_param;
	struct iommu_fwspec *fwspec;
	struct iommu_device *iommu_dev;
	void *priv;
};

struct of_phandle_args {
	struct device_node___10 *np;
	int args_count;
	uint32_t args[16];
};

struct iommu_fault_unrecoverable {
	__u32 reason;
	__u32 flags;
	__u32 pasid;
	__u32 perm;
	__u64 addr;
	__u64 fetch_addr;
};

struct iommu_fault_page_request {
	__u32 flags;
	__u32 pasid;
	__u32 grpid;
	__u32 perm;
	__u64 addr;
	__u64 private_data[2];
};

struct iommu_fault {
	__u32 type;
	__u32 padding;
	union {
		struct iommu_fault_unrecoverable event;
		struct iommu_fault_page_request prm;
		__u8 padding2[56];
	};
};

struct iommu_page_response {
	__u32 argsz;
	__u32 version;
	__u32 flags;
	__u32 pasid;
	__u32 grpid;
	__u32 code;
};

struct iommu_inv_addr_info {
	__u32 flags;
	__u32 archid;
	__u64 pasid;
	__u64 addr;
	__u64 granule_size;
	__u64 nb_granules;
};

struct iommu_inv_pasid_info {
	__u32 flags;
	__u32 archid;
	__u64 pasid;
};

struct iommu_cache_invalidate_info {
	__u32 argsz;
	__u32 version;
	__u8 cache;
	__u8 granularity;
	__u8 padding[6];
	union {
		struct iommu_inv_pasid_info pasid_info;
		struct iommu_inv_addr_info addr_info;
	} granu;
};

struct iommu_gpasid_bind_data_vtd {
	__u64 flags;
	__u32 pat;
	__u32 emt;
};

struct iommu_gpasid_bind_data {
	__u32 argsz;
	__u32 version;
	__u32 format;
	__u32 addr_width;
	__u64 flags;
	__u64 gpgd;
	__u64 hpasid;
	__u64 gpasid;
	__u8 padding[8];
	union {
		struct iommu_gpasid_bind_data_vtd vtd;
	} vendor;
};

typedef int (*iommu_fault_handler_t)(struct iommu_domain *, struct device___2 *, long unsigned int, int, void *);

struct iommu_domain_geometry {
	dma_addr_t aperture_start;
	dma_addr_t aperture_end;
	bool force_aperture;
};

struct iommu_dma_cookie;

struct iommu_domain {
	unsigned int type;
	const struct iommu_ops *ops;
	long unsigned int pgsize_bitmap;
	iommu_fault_handler_t handler;
	void *handler_token;
	struct iommu_domain_geometry geometry;
	struct iommu_dma_cookie *iova_cookie;
};

typedef int (*iommu_dev_fault_handler_t)(struct iommu_fault *, void *);

enum iommu_resv_type {
	IOMMU_RESV_DIRECT = 0,
	IOMMU_RESV_DIRECT_RELAXABLE = 1,
	IOMMU_RESV_RESERVED = 2,
	IOMMU_RESV_MSI = 3,
	IOMMU_RESV_SW_MSI = 4,
};

struct iommu_resv_region {
	struct list_head list;
	phys_addr_t start;
	size_t length;
	int prot;
	enum iommu_resv_type type;
};

struct iommu_iotlb_gather {
	long unsigned int start;
	long unsigned int end;
	size_t pgsize;
	struct page___14 *freelist;
	bool queued;
};

struct iommu_device {
	struct list_head list;
	const struct iommu_ops *ops;
	struct fwnode_handle___13 *fwnode;
	struct device___2 *dev;
};

struct iommu_sva {
	struct device___2 *dev;
};

struct iommu_fault_event {
	struct iommu_fault fault;
	struct list_head list;
};

struct iommu_fault_param {
	iommu_dev_fault_handler_t handler;
	void *data;
	struct list_head faults;
	struct mutex lock;
};

struct iommu_fwspec {
	const struct iommu_ops *ops;
	struct fwnode_handle___13 *iommu_fwnode;
	u32 flags;
	unsigned int num_ids;
	u32 ids[0];
};

enum dmi_field {
	DMI_NONE = 0,
	DMI_BIOS_VENDOR = 1,
	DMI_BIOS_VERSION = 2,
	DMI_BIOS_DATE = 3,
	DMI_BIOS_RELEASE = 4,
	DMI_EC_FIRMWARE_RELEASE = 5,
	DMI_SYS_VENDOR = 6,
	DMI_PRODUCT_NAME = 7,
	DMI_PRODUCT_VERSION = 8,
	DMI_PRODUCT_SERIAL = 9,
	DMI_PRODUCT_UUID = 10,
	DMI_PRODUCT_SKU = 11,
	DMI_PRODUCT_FAMILY = 12,
	DMI_BOARD_VENDOR = 13,
	DMI_BOARD_NAME = 14,
	DMI_BOARD_VERSION = 15,
	DMI_BOARD_SERIAL = 16,
	DMI_BOARD_ASSET_TAG = 17,
	DMI_CHASSIS_VENDOR = 18,
	DMI_CHASSIS_TYPE = 19,
	DMI_CHASSIS_VERSION = 20,
	DMI_CHASSIS_SERIAL = 21,
	DMI_CHASSIS_ASSET_TAG = 22,
	DMI_STRING_MAX = 23,
	DMI_OEM_STRING = 24,
};

struct pci_sysdata___3 {
	int domain;
	int node;
	struct acpi_device *companion;
	void *iommu;
	void *fwnode;
	struct pci_dev___3 *vmd_dev;
};

enum {
	NONE_FORCE_HPET_RESUME = 0,
	OLD_ICH_FORCE_HPET_RESUME = 1,
	ICH_FORCE_HPET_RESUME = 2,
	VT8237_FORCE_HPET_RESUME = 3,
	NVIDIA_FORCE_HPET_RESUME = 4,
	ATI_FORCE_HPET_RESUME = 5,
};

struct pglist_data___10;

struct lruvec___10 {
	struct list_head lists[5];
	spinlock_t lru_lock;
	long unsigned int anon_cost;
	long unsigned int file_cost;
	atomic_long_t nonresident_age;
	long unsigned int refaults[2];
	long unsigned int flags;
	struct pglist_data___10 *pgdat;
};

struct zone___10 {
	long unsigned int _watermark[3];
	long unsigned int watermark_boost;
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[5];
	int node;
	struct pglist_data___10 *zone_pgdat;
	struct per_cpu_pages *per_cpu_pageset;
	struct per_cpu_zonestat *per_cpu_zonestats;
	int pageset_high;
	int pageset_batch;
	long unsigned int zone_start_pfn;
	atomic_long_t managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int present_early_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	seqlock_t span_seqlock;
	int initialized;
	int: 32;
	struct zone_padding _pad1_;
	struct free_area free_area[11];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	long unsigned int compact_init_migrate_pfn;
	long unsigned int compact_init_free_pfn;
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	short: 16;
	struct zone_padding _pad3_;
	atomic_long_t vm_stat[11];
	atomic_long_t vm_numa_event[6];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___10 {
	struct zone___10 *zone;
	int zone_idx;
};

struct zonelist___10 {
	struct zoneref___10 _zonerefs[5121];
};

struct pglist_data___10 {
	struct zone___10 node_zones[5];
	struct zonelist___10 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___13 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_highest_zoneidx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_highest_zoneidx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___13 *kcompactd;
	bool proactive_compact_trigger;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct deferred_split deferred_split_queue;
	struct lruvec___10 __lruvec;
	long unsigned int flags;
	long: 64;
	struct zone_padding _pad2_;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[39];
};

typedef struct pglist_data___10 pg_data_t___2;

enum meminit_context {
	MEMINIT_EARLY = 0,
	MEMINIT_HOTPLUG = 1,
};

struct cpu {
	int node_id;
	int hotpluggable;
	struct device___15 dev;
};

struct x86_cpu {
	struct cpu cpu;
};

typedef u8 retpoline_thunk_t[32];

struct paravirt_patch_site {
	u8 *instr;
	u8 type;
	u8 len;
};

struct die_args {
	struct pt_regs *regs;
	const char *str;
	long int err;
	int trapnr;
	int signr;
};

struct tlb_state_shared {
	bool is_lazy;
};

struct smp_alt_module {
	struct module___12 *mod;
	char *name;
	const s32 *locks;
	const s32 *locks_end;
	u8 *text;
	u8 *text_end;
	struct list_head next;
};

typedef struct {
	struct mm_struct___14 *mm;
} temp_mm_state_t;

struct text_poke_loc {
	s32 rel_addr;
	s32 rel32;
	u8 opcode;
	const u8 text[5];
	u8 old;
};

struct bp_patching_desc {
	struct text_poke_loc *vec;
	int nr_entries;
	atomic_t refs;
};

enum {
	HW_BREAKPOINT_LEN_1 = 1,
	HW_BREAKPOINT_LEN_2 = 2,
	HW_BREAKPOINT_LEN_3 = 3,
	HW_BREAKPOINT_LEN_4 = 4,
	HW_BREAKPOINT_LEN_5 = 5,
	HW_BREAKPOINT_LEN_6 = 6,
	HW_BREAKPOINT_LEN_7 = 7,
	HW_BREAKPOINT_LEN_8 = 8,
};

enum {
	HW_BREAKPOINT_EMPTY = 0,
	HW_BREAKPOINT_R = 1,
	HW_BREAKPOINT_W = 2,
	HW_BREAKPOINT_RW = 3,
	HW_BREAKPOINT_X = 4,
	HW_BREAKPOINT_INVALID = 7,
};

typedef unsigned int u_int;

typedef long long unsigned int cycles_t;

struct system_counterval_t {
	u64 cycles;
	struct clocksource *cs;
};

typedef struct {
	seqcount_t seqcount;
} seqcount_latch_t;

struct clk;

enum cpufreq_table_sorting {
	CPUFREQ_TABLE_UNSORTED = 0,
	CPUFREQ_TABLE_SORTED_ASCENDING = 1,
	CPUFREQ_TABLE_SORTED_DESCENDING = 2,
};

struct cpufreq_cpuinfo {
	unsigned int max_freq;
	unsigned int min_freq;
	unsigned int transition_latency;
};

struct cpufreq_stats;

struct thermal_cooling_device;

struct cpufreq_governor;

struct cpufreq_frequency_table;

struct cpufreq_policy {
	cpumask_var_t cpus;
	cpumask_var_t related_cpus;
	cpumask_var_t real_cpus;
	unsigned int shared_type;
	unsigned int cpu;
	struct clk *clk;
	struct cpufreq_cpuinfo cpuinfo;
	unsigned int min;
	unsigned int max;
	unsigned int cur;
	unsigned int suspend_freq;
	unsigned int policy;
	unsigned int last_policy;
	struct cpufreq_governor *governor;
	void *governor_data;
	char last_governor[16];
	struct work_struct update;
	struct freq_constraints constraints;
	struct freq_qos_request *min_freq_req;
	struct freq_qos_request *max_freq_req;
	struct cpufreq_frequency_table *freq_table;
	enum cpufreq_table_sorting freq_table_sorted;
	struct list_head policy_list;
	struct kobject___14 kobj;
	struct completion kobj_unregister;
	struct rw_semaphore rwsem;
	bool fast_switch_possible;
	bool fast_switch_enabled;
	bool strict_target;
	unsigned int transition_delay_us;
	bool dvfs_possible_from_any_cpu;
	unsigned int cached_target_freq;
	unsigned int cached_resolved_idx;
	bool transition_ongoing;
	spinlock_t transition_lock;
	wait_queue_head_t transition_wait;
	struct task_struct___16 *transition_task;
	struct cpufreq_stats *stats;
	void *driver_data;
	struct thermal_cooling_device *cdev;
	struct notifier_block nb_min;
	struct notifier_block nb_max;
};

struct cpufreq_governor {
	char name[16];
	int (*init)(struct cpufreq_policy *);
	void (*exit)(struct cpufreq_policy *);
	int (*start)(struct cpufreq_policy *);
	void (*stop)(struct cpufreq_policy *);
	void (*limits)(struct cpufreq_policy *);
	ssize_t (*show_setspeed)(struct cpufreq_policy *, char *);
	int (*store_setspeed)(struct cpufreq_policy *, unsigned int);
	struct list_head governor_list;
	struct module *owner;
	u8 flags;
};

struct cpufreq_frequency_table {
	unsigned int flags;
	unsigned int driver_data;
	unsigned int frequency;
};

struct cpufreq_freqs {
	struct cpufreq_policy *policy;
	unsigned int old;
	unsigned int new;
	u8 flags;
};

struct cyc2ns {
	struct cyc2ns_data data[2];
	seqcount_latch_t seq;
};

struct muldiv {
	u32 multiplier;
	u32 divider;
};

struct freq_desc {
	bool use_msr_plat;
	struct muldiv muldiv[16];
	u32 freqs[16];
	u32 mask;
};

struct dmi_strmatch {
	unsigned char slot: 7;
	unsigned char exact_match: 1;
	char substr[79];
};

struct dmi_system_id {
	int (*callback)(const struct dmi_system_id *);
	const char *ident;
	struct dmi_strmatch matches[4];
	void *driver_data;
};

struct pdev_archdata {};

struct mfd_cell;

struct platform_device_id;

struct platform_device {
	const char *name;
	int id;
	bool id_auto;
	struct device___2 dev;
	u64 platform_dma_mask;
	struct device_dma_parameters dma_parms;
	u32 num_resources;
	struct resource *resource;
	const struct platform_device_id *id_entry;
	char *driver_override;
	struct mfd_cell *mfd_cell;
	struct pdev_archdata archdata;
};

struct platform_device_id {
	char name[20];
	kernel_ulong_t driver_data;
};

struct rtc_time {
	int tm_sec;
	int tm_min;
	int tm_hour;
	int tm_mday;
	int tm_mon;
	int tm_year;
	int tm_wday;
	int tm_yday;
	int tm_isdst;
};

struct pnp_device_id {
	__u8 id[8];
	kernel_ulong_t driver_data;
};

struct pnp_card_device_id {
	__u8 id[8];
	kernel_ulong_t driver_data;
	struct {
		__u8 id[8];
	} devs[8];
};

struct acpi_table_header {
	char signature[4];
	u32 length;
	u8 revision;
	u8 checksum;
	char oem_id[6];
	char oem_table_id[8];
	u32 oem_revision;
	char asl_compiler_id[4];
	u32 asl_compiler_revision;
};

struct acpi_generic_address {
	u8 space_id;
	u8 bit_width;
	u8 bit_offset;
	u8 access_width;
	u64 address;
} __attribute__((packed));

struct acpi_table_fadt {
	struct acpi_table_header header;
	u32 facs;
	u32 dsdt;
	u8 model;
	u8 preferred_profile;
	u16 sci_interrupt;
	u32 smi_command;
	u8 acpi_enable;
	u8 acpi_disable;
	u8 s4_bios_request;
	u8 pstate_control;
	u32 pm1a_event_block;
	u32 pm1b_event_block;
	u32 pm1a_control_block;
	u32 pm1b_control_block;
	u32 pm2_control_block;
	u32 pm_timer_block;
	u32 gpe0_block;
	u32 gpe1_block;
	u8 pm1_event_length;
	u8 pm1_control_length;
	u8 pm2_control_length;
	u8 pm_timer_length;
	u8 gpe0_block_length;
	u8 gpe1_block_length;
	u8 gpe1_base;
	u8 cst_control;
	u16 c2_latency;
	u16 c3_latency;
	u16 flush_size;
	u16 flush_stride;
	u8 duty_offset;
	u8 duty_width;
	u8 day_alarm;
	u8 month_alarm;
	u8 century;
	u16 boot_flags;
	u8 reserved;
	u32 flags;
	struct acpi_generic_address reset_register;
	u8 reset_value;
	u16 arm_boot_flags;
	u8 minor_revision;
	u64 Xfacs;
	u64 Xdsdt;
	struct acpi_generic_address xpm1a_event_block;
	struct acpi_generic_address xpm1b_event_block;
	struct acpi_generic_address xpm1a_control_block;
	struct acpi_generic_address xpm1b_control_block;
	struct acpi_generic_address xpm2_control_block;
	struct acpi_generic_address xpm_timer_block;
	struct acpi_generic_address xgpe0_block;
	struct acpi_generic_address xgpe1_block;
	struct acpi_generic_address sleep_control;
	struct acpi_generic_address sleep_status;
	u64 hypervisor_id;
} __attribute__((packed));

struct pnp_protocol;

struct pnp_id;

struct pnp_card {
	struct device___2 dev;
	unsigned char number;
	struct list_head global_list;
	struct list_head protocol_list;
	struct list_head devices;
	struct pnp_protocol *protocol;
	struct pnp_id *id;
	char name[50];
	unsigned char pnpver;
	unsigned char productver;
	unsigned int serial;
	unsigned char checksum;
	struct proc_dir_entry *procdir;
};

struct pnp_dev;

struct pnp_protocol {
	struct list_head protocol_list;
	char *name;
	int (*get)(struct pnp_dev *);
	int (*set)(struct pnp_dev *);
	int (*disable)(struct pnp_dev *);
	bool (*can_wakeup)(struct pnp_dev *);
	int (*suspend)(struct pnp_dev *, pm_message_t);
	int (*resume)(struct pnp_dev *);
	unsigned char number;
	struct device___2 dev;
	struct list_head cards;
	struct list_head devices;
};

struct pnp_id {
	char id[8];
	struct pnp_id *next;
};

struct pnp_card_driver;

struct pnp_card_link {
	struct pnp_card *card;
	struct pnp_card_driver *driver;
	void *driver_data;
	pm_message_t pm_state;
};

struct pnp_driver {
	const char *name;
	const struct pnp_device_id *id_table;
	unsigned int flags;
	int (*probe)(struct pnp_dev *, const struct pnp_device_id *);
	void (*remove)(struct pnp_dev *);
	void (*shutdown)(struct pnp_dev *);
	int (*suspend)(struct pnp_dev *, pm_message_t);
	int (*resume)(struct pnp_dev *);
	struct device_driver___14 driver;
};

struct pnp_card_driver {
	struct list_head global_list;
	char *name;
	const struct pnp_card_device_id *id_table;
	unsigned int flags;
	int (*probe)(struct pnp_card_link *, const struct pnp_card_device_id *);
	void (*remove)(struct pnp_card_link *);
	int (*suspend)(struct pnp_card_link *, pm_message_t);
	int (*resume)(struct pnp_card_link *);
	struct pnp_driver link;
};

struct pnp_dev {
	struct device___2 dev;
	u64 dma_mask;
	unsigned int number;
	int status;
	struct list_head global_list;
	struct list_head protocol_list;
	struct list_head card_list;
	struct list_head rdev_list;
	struct pnp_protocol *protocol;
	struct pnp_card *card;
	struct pnp_driver *driver;
	struct pnp_card_link *card_link;
	struct pnp_id *id;
	int active;
	int capabilities;
	unsigned int num_dependent_sets;
	struct list_head resources;
	struct list_head options;
	char name[50];
	int flags;
	struct proc_dir_entry *procent;
	void *data;
};

enum insn_type {
	CALL = 0,
	NOP = 1,
	JMP = 2,
	RET = 3,
};

struct ldttss_desc {
	u16 limit0;
	u16 base0;
	u16 base1: 8;
	u16 type: 5;
	u16 dpl: 2;
	u16 p: 1;
	u16 limit1: 4;
	u16 zero0: 3;
	u16 g: 1;
	u16 base2: 8;
	long: 56;
	u32 base3;
	u32 zero1;
};

typedef struct ldttss_desc tss_desc;

enum idle_boot_override {
	IDLE_NO_OVERRIDE = 0,
	IDLE_HALT = 1,
	IDLE_NOMWAIT = 2,
	IDLE_POLL = 3,
};

enum tick_broadcast_mode {
	TICK_BROADCAST_OFF = 0,
	TICK_BROADCAST_ON = 1,
	TICK_BROADCAST_FORCE = 2,
};

enum tick_broadcast_state {
	TICK_BROADCAST_EXIT = 0,
	TICK_BROADCAST_ENTER = 1,
};

struct inactive_task_frame {
	long unsigned int r15;
	long unsigned int r14;
	long unsigned int r13;
	long unsigned int r12;
	long unsigned int bx;
	long unsigned int bp;
	long unsigned int ret_addr;
};

struct fork_frame {
	struct inactive_task_frame frame;
	struct pt_regs regs;
};

struct ssb_state {
	struct ssb_state *shared_state;
	raw_spinlock_t lock;
	unsigned int disable_state;
	long unsigned int local_state;
};

struct fpu_state_config {
	unsigned int max_size;
	unsigned int default_size;
	u64 max_features;
	u64 default_features;
	u64 legacy_features;
};

struct pkru_state {
	u32 pkru;
	u32 pad;
};

struct fpu_guest {
	struct fpstate *fpstate;
};

struct membuf {
	void *p;
	size_t left;
};

enum xstate_copy_mode {
	XSTATE_COPY_FP = 0,
	XSTATE_COPY_FX = 1,
	XSTATE_COPY_XSAVE = 2,
};

struct trace_event_raw_x86_fpu {
	struct trace_entry ent;
	struct fpu *fpu;
	bool load_fpu;
	u64 xfeatures;
	u64 xcomp_bv;
	char __data[0];
};

struct trace_event_data_offsets_x86_fpu {};

typedef void (*btf_trace_x86_fpu_before_save)(void *, struct fpu *);

typedef void (*btf_trace_x86_fpu_after_save)(void *, struct fpu *);

typedef void (*btf_trace_x86_fpu_before_restore)(void *, struct fpu *);

typedef void (*btf_trace_x86_fpu_after_restore)(void *, struct fpu *);

typedef void (*btf_trace_x86_fpu_regs_activated)(void *, struct fpu *);

typedef void (*btf_trace_x86_fpu_regs_deactivated)(void *, struct fpu *);

typedef void (*btf_trace_x86_fpu_init_state)(void *, struct fpu *);

typedef void (*btf_trace_x86_fpu_dropped)(void *, struct fpu *);

typedef void (*btf_trace_x86_fpu_copy_src)(void *, struct fpu *);

typedef void (*btf_trace_x86_fpu_copy_dst)(void *, struct fpu *);

typedef void (*btf_trace_x86_fpu_xstate_check_failed)(void *, struct fpu *);

struct _fpreg {
	__u16 significand[4];
	__u16 exponent;
};

struct _fpxreg {
	__u16 significand[4];
	__u16 exponent;
	__u16 padding[3];
};

struct user_i387_ia32_struct {
	u32 cwd;
	u32 swd;
	u32 twd;
	u32 fip;
	u32 fcs;
	u32 foo;
	u32 fos;
	u32 st_space[20];
};

struct user_regset;

typedef int user_regset_active_fn(struct task_struct___16 *, const struct user_regset *);

typedef int user_regset_get2_fn(struct task_struct___16 *, const struct user_regset *, struct membuf);

typedef int user_regset_set_fn(struct task_struct___16 *, const struct user_regset *, unsigned int, unsigned int, const void *, const void *);

typedef int user_regset_writeback_fn(struct task_struct___16 *, const struct user_regset *, int);

struct user_regset {
	user_regset_get2_fn *regset_get;
	user_regset_set_fn *set;
	user_regset_active_fn *active;
	user_regset_writeback_fn *writeback;
	unsigned int n;
	unsigned int size;
	unsigned int align;
	unsigned int bias;
	unsigned int core_note_type;
};

struct _fpx_sw_bytes {
	__u32 magic1;
	__u32 extended_size;
	__u64 xfeatures;
	__u32 xstate_size;
	__u32 padding[7];
};

struct _xmmreg {
	__u32 element[4];
};

struct _fpstate_32 {
	__u32 cw;
	__u32 sw;
	__u32 tag;
	__u32 ipoff;
	__u32 cssel;
	__u32 dataoff;
	__u32 datasel;
	struct _fpreg _st[8];
	__u16 status;
	__u16 magic;
	__u32 _fxsr_env[6];
	__u32 mxcsr;
	__u32 reserved;
	struct _fpxreg _fxsr_st[8];
	struct _xmmreg _xmm[8];
	union {
		__u32 padding1[44];
		__u32 padding[44];
	};
	union {
		__u32 padding2[12];
		struct _fpx_sw_bytes sw_reserved;
	};
};

struct user_regset___2;

typedef int user_regset_active_fn___2(struct task_struct___14 *, const struct user_regset___2 *);

typedef int user_regset_get2_fn___2(struct task_struct___14 *, const struct user_regset___2 *, struct membuf);

typedef int user_regset_set_fn___2(struct task_struct___14 *, const struct user_regset___2 *, unsigned int, unsigned int, const void *, const void *);

typedef int user_regset_writeback_fn___2(struct task_struct___14 *, const struct user_regset___2 *, int);

struct user_regset___2 {
	user_regset_get2_fn___2 *regset_get;
	user_regset_set_fn___2 *set;
	user_regset_active_fn___2 *active;
	user_regset_writeback_fn___2 *writeback;
	unsigned int n;
	unsigned int size;
	unsigned int align;
	unsigned int bias;
	unsigned int core_note_type;
};

struct user_regset_view {
	const char *name;
	const struct user_regset___2 *regsets;
	unsigned int n;
	u32 e_flags;
	u16 e_machine;
	u8 ei_osabi;
};

enum x86_regset {
	REGSET_GENERAL = 0,
	REGSET_FP = 1,
	REGSET_XFP = 2,
	REGSET_IOPERM64 = 2,
	REGSET_XSTATE = 3,
	REGSET_TLS = 4,
	REGSET_IOPERM32 = 5,
};

struct pt_regs_offset {
	const char *name;
	int offset;
};

struct dentry___15;

struct super_block___15;

struct module___15;

struct file_system_type___15 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___15 * (*mount)(struct file_system_type___15 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___15 *);
	struct module___15 *owner;
	struct file_system_type___15 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___15;

struct kiocb___15;

struct iov_iter___13;

struct vm_area_struct___17;

struct inode___15;

struct file_lock___15;

struct page___16;

struct pipe_inode_info___4;

struct seq_file___14;

struct file_operations___15 {
	struct module___15 *owner;
	loff_t (*llseek)(struct file___15 *, loff_t, int);
	ssize_t (*read)(struct file___15 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___15 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___15 *, struct iov_iter___13 *);
	ssize_t (*write_iter)(struct kiocb___15 *, struct iov_iter___13 *);
	int (*iopoll)(struct kiocb___15 *, bool);
	int (*iterate)(struct file___15 *, struct dir_context *);
	int (*iterate_shared)(struct file___15 *, struct dir_context *);
	__poll_t (*poll)(struct file___15 *, struct poll_table_struct *);
	long int (*unlocked_ioctl)(struct file___15 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___15 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___15 *, struct vm_area_struct___17 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___15 *, struct file___15 *);
	int (*flush)(struct file___15 *, fl_owner_t);
	int (*release)(struct inode___15 *, struct file___15 *);
	int (*fsync)(struct file___15 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___15 *, int);
	int (*lock)(struct file___15 *, int, struct file_lock___15 *);
	ssize_t (*sendpage)(struct file___15 *, struct page___16 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___15 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___15 *, long unsigned int);
	int (*flock)(struct file___15 *, int, struct file_lock___15 *);
	ssize_t (*splice_write)(struct pipe_inode_info___4 *, struct file___15 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___15 *, loff_t *, struct pipe_inode_info___4 *, size_t, unsigned int);
	int (*setlease)(struct file___15 *, long int, struct file_lock___15 **, void **);
	long int (*fallocate)(struct file___15 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___14 *, struct file___15 *);
	ssize_t (*copy_file_range)(struct file___15 *, loff_t, struct file___15 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___15 *, loff_t, struct file___15 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___15 *, loff_t, loff_t, int);
};

typedef struct page___16 *pgtable_t___16;

struct address_space___15;

struct page_pool___4;

struct mm_struct___17;

struct dev_pagemap___15;

struct page___16 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___15 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___4 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___16 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___16 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___17 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___15 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct task_struct___18;

struct pv_cpu_ops___12 {
	void (*io_delay)();
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	void (*write_cr4)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___9 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(long unsigned int);
	void (*invalidate_io_bitmap)();
	void (*update_io_bitmap)();
	void (*wbinvd)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int);
	void (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_msr_safe)(unsigned int, int *);
	int (*write_msr_safe)(unsigned int, unsigned int, unsigned int);
	u64 (*read_pmc)(int);
	void (*start_context_switch)(struct task_struct___18 *);
	void (*end_context_switch)(struct task_struct___18 *);
};

struct vmacache___16 {
	u64 seqnum;
	struct vm_area_struct___17 *vmas[4];
};

struct page_frag___16 {
	struct page___16 *page;
	__u32 offset;
	__u32 size;
};

struct pid___14;

struct nsproxy___15;

struct signal_struct___16;

struct vm_struct___15;

struct task_struct___18 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___18 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___17 *mm;
	struct mm_struct___17 *active_mm;
	struct vmacache___16 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int restore_sigmask: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___18 *real_parent;
	struct task_struct___18 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___18 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___14 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	struct posix_cputimers_work posix_cputimers_work;
	const struct cred *ptracer_cred;
	const struct cred *real_cred;
	const struct cred *cred;
	struct key *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___15 *nsproxy;
	struct signal_struct___16 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___18 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context___11 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set *cgroups;
	struct list_head cg_list;
	u32 closid;
	u32 rmid;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	struct pipe_inode_info___4 *splice_pipe;
	struct page_frag___16 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup *active_memcg;
	struct request_queue *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___18 *oom_reaper_list;
	struct vm_struct___15 *stack_vm_area;
	refcount_t stack_refcount;
	int patch_state;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	void *mce_vaddr;
	__u64 mce_kflags;
	u64 mce_addr;
	__u64 mce_ripv: 1;
	__u64 mce_whole_page: 1;
	__u64 __mce_reserved: 62;
	long: 2;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct callback_head mce_kill_me;
	int mce_count;
	struct llist_head kretprobe_instances;
	struct callback_head l1d_flush_kill;
	long: 64;
	struct thread_struct___9 thread;
};

struct pv_mmu_ops___12 {
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_one_user)(long unsigned int);
	void (*flush_tlb_multi)(const struct cpumask *, const struct flush_tlb_info___3 *);
	void (*tlb_remove_table)(struct mmu_gather *, void *);
	void (*exit_mmap)(struct mm_struct___17 *);
	struct paravirt_callee_save read_cr2;
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___17 *, struct mm_struct___17 *);
	void (*dup_mmap)(struct mm_struct___17 *, struct mm_struct___17 *);
	int (*pgd_alloc)(struct mm_struct___17 *);
	void (*pgd_free)(struct mm_struct___17 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___17 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___17 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___17 *, long unsigned int);
	void (*alloc_p4d)(struct mm_struct___17 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*release_p4d)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	pte_t (*ptep_modify_prot_start)(struct vm_area_struct___17 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct vm_area_struct___17 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_p4d)(p4d_t *, p4d_t);
	struct paravirt_callee_save p4d_val;
	struct paravirt_callee_save make_p4d;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

struct core_state___16;

struct mm_struct___17 {
	struct {
		struct vm_area_struct___17 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___15 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int mmap_compat_base;
		long unsigned int mmap_compat_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[48];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___16 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___18 *owner;
		struct user_namespace *user_ns;
		struct file___15 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		bool tlb_flush_batched;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct vm_operations_struct___15;

struct vm_area_struct___17 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___17 *vm_next;
	struct vm_area_struct___17 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___17 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___15 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___15 *vm_file;
	struct file___15 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct paravirt_patch_template___12 {
	struct pv_cpu_ops___12 cpu;
	struct pv_irq_ops irq;
	struct pv_mmu_ops___12 mmu;
	struct pv_lock_ops lock;
};

struct seq_operations___14 {
	void * (*start)(struct seq_file___14 *, loff_t *);
	void (*stop)(struct seq_file___14 *, void *);
	void * (*next)(struct seq_file___14 *, void *, loff_t *);
	int (*show)(struct seq_file___14 *, void *);
};

struct pid_namespace___14;

struct upid___14 {
	int nr;
	struct pid_namespace___14 *ns;
};

struct pid_namespace___14 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___18 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___14 *parent;
	struct fs_pin *bacct;
	struct user_namespace *user_ns;
	struct ucounts *ucounts;
	int reboot;
	struct ns_common ns;
};

struct pid___14 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___14 numbers[1];
};

struct signal_struct___16 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___18 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___18 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___14 *pids[4];
	struct pid___14 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___17 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct nsproxy___15 {
	atomic_t count;
	struct uts_namespace *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___14 *pid_ns_for_children;
	struct net___2 *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___2 *cgroup_ns;
};

struct fasync_struct___15;

struct pipe_buffer___4;

struct pipe_inode_info___4 {
	struct mutex mutex;
	wait_queue_head_t rd_wait;
	wait_queue_head_t wr_wait;
	unsigned int head;
	unsigned int tail;
	unsigned int max_usage;
	unsigned int ring_size;
	bool note_loss;
	unsigned int nr_accounted;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int r_counter;
	unsigned int w_counter;
	unsigned int poll_usage;
	struct page___16 *tmp_page;
	struct fasync_struct___15 *fasync_readers;
	struct fasync_struct___15 *fasync_writers;
	struct pipe_buffer___4 *bufs;
	struct user_struct *user;
	struct watch_queue *watch_queue;
};

struct vm_struct___15 {
	struct vm_struct___15 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___16 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct address_space_operations___15;

struct address_space___15 {
	struct inode___15 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___15 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct device___17;

struct page_pool_params___4 {
	unsigned int flags;
	unsigned int order;
	unsigned int pool_size;
	int nid;
	struct device___17 *dev;
	enum dma_data_direction dma_dir;
	unsigned int max_len;
	unsigned int offset;
};

struct pp_alloc_cache___4 {
	u32 count;
	struct page___16 *cache[128];
};

struct page_pool___4 {
	struct page_pool_params___4 p;
	struct delayed_work release_dw;
	void (*disconnect)(void *);
	long unsigned int defer_start;
	long unsigned int defer_warn;
	u32 pages_state_hold_cnt;
	unsigned int frag_offset;
	struct page___16 *frag_page;
	long int frag_users;
	long: 64;
	long: 64;
	struct pp_alloc_cache___4 alloc;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct ptr_ring ring;
	atomic_t pages_state_release_cnt;
	refcount_t user_cnt;
	u64 destroy_cnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pagemap_ops___15;

struct dev_pagemap___15 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___15 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vfsmount___15;

struct path___15 {
	struct vfsmount___15 *mnt;
	struct dentry___15 *dentry;
};

struct fown_struct___14 {
	rwlock_t lock;
	struct pid___14 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___15 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___15 f_path;
	struct inode___15 *f_inode;
	const struct file_operations___15 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___14 f_owner;
	const struct cred *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___15 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___15;

struct vm_operations_struct___15 {
	void (*open)(struct vm_area_struct___17 *);
	void (*close)(struct vm_area_struct___17 *);
	int (*may_split)(struct vm_area_struct___17 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___17 *);
	int (*mprotect)(struct vm_area_struct___17 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___15 *);
	vm_fault_t (*huge_fault)(struct vm_fault___15 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___15 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___17 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___15 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___15 *);
	int (*access)(struct vm_area_struct___17 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___17 *);
	int (*set_policy)(struct vm_area_struct___17 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___17 *, long unsigned int);
	struct page___16 * (*find_special_page)(struct vm_area_struct___17 *, long unsigned int);
};

struct core_thread___16 {
	struct task_struct___18 *task;
	struct core_thread___16 *next;
};

struct core_state___16 {
	atomic_t nr_threads;
	struct core_thread___16 dumper;
	struct completion startup;
};

struct vm_fault___15 {
	const struct {
		struct vm_area_struct___17 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___16 *cow_page;
	struct page___16 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___16 prealloc_pte;
};

struct irq_domain_ops___11;

struct fwnode_handle___16;

struct irq_domain___11 {
	struct list_head link;
	const char *name;
	const struct irq_domain_ops___11 *ops;
	void *host_data;
	unsigned int flags;
	unsigned int mapcount;
	struct fwnode_handle___16 *fwnode;
	enum irq_domain_bus_token bus_token;
	struct irq_domain_chip_generic *gc;
	struct irq_domain___11 *parent;
	irq_hw_number_t hwirq_max;
	unsigned int revmap_size;
	struct xarray revmap_tree;
	struct mutex revmap_mutex;
	struct irq_data *revmap[0];
};

struct kernfs_root___15;

struct kernfs_elem_dir___15 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___15 *root;
	long unsigned int rev;
};

struct kernfs_node___15;

struct kernfs_syscall_ops___15;

struct kernfs_root___15 {
	struct kernfs_node___15 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___15 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___15 {
	struct kernfs_node___15 *target_kn;
};

struct kernfs_ops___15;

struct kernfs_elem_attr___15 {
	const struct kernfs_ops___15 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___15 *notify_next;
};

struct kernfs_node___15 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___15 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___15 dir;
		struct kernfs_elem_symlink___15 symlink;
		struct kernfs_elem_attr___15 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___15;

struct kernfs_ops___15 {
	int (*open)(struct kernfs_open_file___15 *);
	void (*release)(struct kernfs_open_file___15 *);
	int (*seq_show)(struct seq_file___14 *, void *);
	void * (*seq_start)(struct seq_file___14 *, loff_t *);
	void * (*seq_next)(struct seq_file___14 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___14 *, void *);
	ssize_t (*read)(struct kernfs_open_file___15 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___15 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___15 *, struct poll_table_struct *);
	int (*mmap)(struct kernfs_open_file___15 *, struct vm_area_struct___17 *);
};

struct kernfs_syscall_ops___15 {
	int (*show_options)(struct seq_file___14 *, struct kernfs_root___15 *);
	int (*mkdir)(struct kernfs_node___15 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___15 *);
	int (*rename)(struct kernfs_node___15 *, struct kernfs_node___15 *, const char *);
	int (*show_path)(struct seq_file___14 *, struct kernfs_node___15 *, struct kernfs_root___15 *);
};

struct seq_file___14 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___14 *op;
	int poll_event;
	const struct file___15 *file;
	void *private;
};

struct kernfs_open_file___15 {
	struct kernfs_node___15 *kn;
	struct file___15 *file;
	struct seq_file___14 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___15 *vm_ops;
};

struct kobject___16;

struct bin_attribute___16;

struct attribute_group___16 {
	const char *name;
	umode_t (*is_visible)(struct kobject___16 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___16 *, struct bin_attribute___16 *, int);
	struct attribute **attrs;
	struct bin_attribute___16 **bin_attrs;
};

struct kset___15;

struct kobj_type___15;

struct kobject___16 {
	const char *name;
	struct list_head entry;
	struct kobject___16 *parent;
	struct kset___15 *kset;
	struct kobj_type___15 *ktype;
	struct kernfs_node___15 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bin_attribute___16 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___15 * (*f_mapping)();
	ssize_t (*read)(struct file___15 *, struct kobject___16 *, struct bin_attribute___16 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___15 *, struct kobject___16 *, struct bin_attribute___16 *, char *, loff_t, size_t);
	int (*mmap)(struct file___15 *, struct kobject___16 *, struct bin_attribute___16 *, struct vm_area_struct___17 *);
};

struct sysfs_ops___15 {
	ssize_t (*show)(struct kobject___16 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___16 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___15;

struct kset___15 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___16 kobj;
	const struct kset_uevent_ops___15 *uevent_ops;
};

struct kobj_type___15 {
	void (*release)(struct kobject___16 *);
	const struct sysfs_ops___15 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___16 **default_groups;
	const struct kobj_ns_type_operations * (*child_ns_type)(struct kobject___16 *);
	const void * (*namespace)(struct kobject___16 *);
	void (*get_ownership)(struct kobject___16 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___15 {
	int (* const filter)(struct kset___15 *, struct kobject___16 *);
	const char * (* const name)(struct kset___15 *, struct kobject___16 *);
	int (* const uevent)(struct kset___15 *, struct kobject___16 *, struct kobj_uevent_env *);
};

struct wakeup_source___17;

struct dev_pm_info___17 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___17 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___17 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___17;

struct bus_type___17;

struct device_driver___17;

struct dev_pm_domain___17;

struct io_tlb_mem___3;

struct device_node___12;

struct class___17;

struct dev_iommu___2;

struct device___17 {
	struct kobject___16 kobj;
	struct device___17 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___17 *type;
	struct bus_type___17 *bus;
	struct device_driver___17 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___17 power;
	struct dev_pm_domain___17 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___11 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct io_tlb_mem___3 *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___12 *of_node;
	struct fwnode_handle___16 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___17 *class;
	const struct attribute_group___16 **groups;
	void (*release)(struct device___17 *);
	struct iommu_group *iommu_group;
	struct dev_iommu___2 *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_ops___17 {
	int (*prepare)(struct device___17 *);
	void (*complete)(struct device___17 *);
	int (*suspend)(struct device___17 *);
	int (*resume)(struct device___17 *);
	int (*freeze)(struct device___17 *);
	int (*thaw)(struct device___17 *);
	int (*poweroff)(struct device___17 *);
	int (*restore)(struct device___17 *);
	int (*suspend_late)(struct device___17 *);
	int (*resume_early)(struct device___17 *);
	int (*freeze_late)(struct device___17 *);
	int (*thaw_early)(struct device___17 *);
	int (*poweroff_late)(struct device___17 *);
	int (*restore_early)(struct device___17 *);
	int (*suspend_noirq)(struct device___17 *);
	int (*resume_noirq)(struct device___17 *);
	int (*freeze_noirq)(struct device___17 *);
	int (*thaw_noirq)(struct device___17 *);
	int (*poweroff_noirq)(struct device___17 *);
	int (*restore_noirq)(struct device___17 *);
	int (*runtime_suspend)(struct device___17 *);
	int (*runtime_resume)(struct device___17 *);
	int (*runtime_idle)(struct device___17 *);
};

struct wakeup_source___17 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___17 *dev;
	bool active: 1;
	bool autosleep_enabled: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___17 {
	struct dev_pm_ops___17 ops;
	int (*start)(struct device___17 *);
	void (*detach)(struct device___17 *, bool);
	int (*activate)(struct device___17 *);
	void (*sync)(struct device___17 *);
	void (*dismiss)(struct device___17 *);
};

struct iommu_ops___2;

struct bus_type___17 {
	const char *name;
	const char *dev_name;
	struct device___17 *dev_root;
	const struct attribute_group___16 **bus_groups;
	const struct attribute_group___16 **dev_groups;
	const struct attribute_group___16 **drv_groups;
	int (*match)(struct device___17 *, struct device_driver___17 *);
	int (*uevent)(struct device___17 *, struct kobj_uevent_env *);
	int (*probe)(struct device___17 *);
	void (*sync_state)(struct device___17 *);
	void (*remove)(struct device___17 *);
	void (*shutdown)(struct device___17 *);
	int (*online)(struct device___17 *);
	int (*offline)(struct device___17 *);
	int (*suspend)(struct device___17 *, pm_message_t);
	int (*resume)(struct device___17 *);
	int (*num_vf)(struct device___17 *);
	int (*dma_configure)(struct device___17 *);
	const struct dev_pm_ops___17 *pm;
	const struct iommu_ops___2 *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___17 {
	const char *name;
	struct bus_type___17 *bus;
	struct module___15 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___17 *);
	void (*sync_state)(struct device___17 *);
	int (*remove)(struct device___17 *);
	void (*shutdown)(struct device___17 *);
	int (*suspend)(struct device___17 *, pm_message_t);
	int (*resume)(struct device___17 *);
	const struct attribute_group___16 **groups;
	const struct attribute_group___16 **dev_groups;
	const struct dev_pm_ops___17 *pm;
	void (*coredump)(struct device___17 *);
	struct driver_private *p;
};

struct iommu_domain___2;

struct iommu_iotlb_gather___2;

struct iommu_device___2;

struct of_phandle_args___2;

struct iommu_sva___2;

struct iommu_ops___2 {
	bool (*capable)(enum iommu_cap);
	struct iommu_domain___2 * (*domain_alloc)(unsigned int);
	void (*domain_free)(struct iommu_domain___2 *);
	int (*attach_dev)(struct iommu_domain___2 *, struct device___17 *);
	void (*detach_dev)(struct iommu_domain___2 *, struct device___17 *);
	int (*map)(struct iommu_domain___2 *, long unsigned int, phys_addr_t, size_t, int, gfp_t);
	int (*map_pages)(struct iommu_domain___2 *, long unsigned int, phys_addr_t, size_t, size_t, int, gfp_t, size_t *);
	size_t (*unmap)(struct iommu_domain___2 *, long unsigned int, size_t, struct iommu_iotlb_gather___2 *);
	size_t (*unmap_pages)(struct iommu_domain___2 *, long unsigned int, size_t, size_t, struct iommu_iotlb_gather___2 *);
	void (*flush_iotlb_all)(struct iommu_domain___2 *);
	void (*iotlb_sync_map)(struct iommu_domain___2 *, long unsigned int, size_t);
	void (*iotlb_sync)(struct iommu_domain___2 *, struct iommu_iotlb_gather___2 *);
	phys_addr_t (*iova_to_phys)(struct iommu_domain___2 *, dma_addr_t);
	struct iommu_device___2 * (*probe_device)(struct device___17 *);
	void (*release_device)(struct device___17 *);
	void (*probe_finalize)(struct device___17 *);
	struct iommu_group * (*device_group)(struct device___17 *);
	int (*enable_nesting)(struct iommu_domain___2 *);
	int (*set_pgtable_quirks)(struct iommu_domain___2 *, long unsigned int);
	void (*get_resv_regions)(struct device___17 *, struct list_head *);
	void (*put_resv_regions)(struct device___17 *, struct list_head *);
	void (*apply_resv_region)(struct device___17 *, struct iommu_domain___2 *, struct iommu_resv_region *);
	int (*of_xlate)(struct device___17 *, struct of_phandle_args___2 *);
	bool (*is_attach_deferred)(struct iommu_domain___2 *, struct device___17 *);
	bool (*dev_has_feat)(struct device___17 *, enum iommu_dev_features);
	bool (*dev_feat_enabled)(struct device___17 *, enum iommu_dev_features);
	int (*dev_enable_feat)(struct device___17 *, enum iommu_dev_features);
	int (*dev_disable_feat)(struct device___17 *, enum iommu_dev_features);
	int (*aux_attach_dev)(struct iommu_domain___2 *, struct device___17 *);
	void (*aux_detach_dev)(struct iommu_domain___2 *, struct device___17 *);
	int (*aux_get_pasid)(struct iommu_domain___2 *, struct device___17 *);
	struct iommu_sva___2 * (*sva_bind)(struct device___17 *, struct mm_struct___17 *, void *);
	void (*sva_unbind)(struct iommu_sva___2 *);
	u32 (*sva_get_pasid)(struct iommu_sva___2 *);
	int (*page_response)(struct device___17 *, struct iommu_fault_event *, struct iommu_page_response *);
	int (*cache_invalidate)(struct iommu_domain___2 *, struct device___17 *, struct iommu_cache_invalidate_info *);
	int (*sva_bind_gpasid)(struct iommu_domain___2 *, struct device___17 *, struct iommu_gpasid_bind_data *);
	int (*sva_unbind_gpasid)(struct device___17 *, u32);
	int (*def_domain_type)(struct device___17 *);
	long unsigned int pgsize_bitmap;
	struct module___15 *owner;
};

struct device_type___17 {
	const char *name;
	const struct attribute_group___16 **groups;
	int (*uevent)(struct device___17 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___17 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___17 *);
	const struct dev_pm_ops___17 *pm;
};

struct class___17 {
	const char *name;
	struct module___15 *owner;
	const struct attribute_group___16 **class_groups;
	const struct attribute_group___16 **dev_groups;
	struct kobject___16 *dev_kobj;
	int (*dev_uevent)(struct device___17 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___17 *, umode_t *);
	void (*class_release)(struct class___17 *);
	void (*dev_release)(struct device___17 *);
	int (*shutdown_pre)(struct device___17 *);
	const struct kobj_ns_type_operations *ns_type;
	const void * (*namespace)(struct device___17 *);
	void (*get_ownership)(struct device___17 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___17 *pm;
	struct subsys_private *p;
};

struct module_kobject___15 {
	struct kobject___16 kobj;
	struct module___15 *mod;
	struct kobject___16 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___15 {
	struct module___15 *mod;
	struct latch_tree_node node;
};

struct module_layout___15 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___15 mtn;
};

struct module_attribute___15;

struct kernel_param___15;

struct module___15 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___15 mkobj;
	struct module_attribute___15 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___16 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___15 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___15 core_layout;
	struct module_layout___15 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map___10 *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___4 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	int num_static_call_sites;
	struct static_call_site *static_call_sites;
	bool klp;
	bool klp_alive;
	struct klp_modinfo *klp_info;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct io_tlb_mem___3 {
	phys_addr_t start;
	phys_addr_t end;
	long unsigned int nslabs;
	long unsigned int used;
	unsigned int index;
	spinlock_t lock;
	struct dentry___15 *debugfs;
	bool late_alloc;
	bool force_bounce;
	bool for_alloc;
	struct io_tlb_slot *slots;
};

struct fwnode_operations___16;

struct fwnode_handle___16 {
	struct fwnode_handle___16 *secondary;
	const struct fwnode_operations___16 *ops;
	struct device___17 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct device_node___12 {
	const char *name;
	phandle phandle;
	const char *full_name;
	struct fwnode_handle___16 fwnode;
	struct property *properties;
	struct property *deadprops;
	struct device_node___12 *parent;
	struct device_node___12 *child;
	struct device_node___12 *sibling;
	long unsigned int _flags;
	void *data;
};

struct iommu_fwspec___2;

struct dev_iommu___2 {
	struct mutex lock;
	struct iommu_fault_param *fault_param;
	struct iopf_device_param *iopf_param;
	struct iommu_fwspec___2 *fwspec;
	struct iommu_device___2 *iommu_dev;
	void *priv;
};

struct dev_pagemap_ops___15 {
	void (*page_free)(struct page___16 *);
	void (*kill)(struct dev_pagemap___15 *);
	void (*cleanup)(struct dev_pagemap___15 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___15 *);
};

struct dentry_operations___15;

struct dentry___15 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___15 *d_parent;
	struct qstr d_name;
	struct inode___15 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___15 *d_op;
	struct super_block___15 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___15;

struct inode___15 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___15 *i_op;
	struct super_block___15 *i_sb;
	struct address_space___15 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___15 *i_fop;
		void (*free_inode)(struct inode___15 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___15 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___4 *i_pipe;
		struct cdev *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___15 {
	int (*d_revalidate)(struct dentry___15 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___15 *, unsigned int);
	int (*d_hash)(const struct dentry___15 *, struct qstr *);
	int (*d_compare)(const struct dentry___15 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___15 *);
	int (*d_init)(struct dentry___15 *);
	void (*d_release)(struct dentry___15 *);
	void (*d_prune)(struct dentry___15 *);
	void (*d_iput)(struct dentry___15 *, struct inode___15 *);
	char * (*d_dname)(struct dentry___15 *, char *, int);
	struct vfsmount___15 * (*d_automount)(struct path___15 *);
	int (*d_manage)(const struct path___15 *, bool);
	struct dentry___15 * (*d_real)(struct dentry___15 *, const struct inode___15 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___15;

struct mem_dqinfo___15 {
	struct quota_format_type___15 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___15;

struct quota_info___15 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___15 *files[3];
	struct mem_dqinfo___15 info[3];
	const struct quota_format_ops___15 *ops[3];
};

struct rcuwait___15 {
	struct task_struct___18 *task;
};

struct percpu_rw_semaphore___15 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___15 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___15 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___15 rw_sem[3];
};

struct super_operations___15;

struct dquot_operations___15;

struct quotactl_ops___15;

struct super_block___15 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___15 *s_type;
	const struct super_operations___15 *s_op;
	const struct dquot_operations___15 *dq_op;
	const struct quotactl_ops___15 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___15 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device *s_bdev;
	struct backing_dev_info *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___15 s_dquot;
	struct sb_writers___15 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___15 *s_d_op;
	int cleancache_poolid;
	struct shrinker___9 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___15 {
	struct dentry___15 *mnt_root;
	struct super_block___15 *mnt_sb;
	int mnt_flags;
	struct user_namespace *mnt_userns;
};

struct wait_page_queue___9;

struct kiocb___15 {
	struct file___15 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___15 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___9 *ki_waitq;
	};
};

struct iattr___15 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___15 *ia_file;
};

struct dquot___15 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___15 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___15 {
	int qf_fmt_id;
	const struct quota_format_ops___15 *qf_ops;
	struct module___15 *qf_owner;
	struct quota_format_type___15 *qf_next;
};

struct quota_format_ops___15 {
	int (*check_quota_file)(struct super_block___15 *, int);
	int (*read_file_info)(struct super_block___15 *, int);
	int (*write_file_info)(struct super_block___15 *, int);
	int (*free_file_info)(struct super_block___15 *, int);
	int (*read_dqblk)(struct dquot___15 *);
	int (*commit_dqblk)(struct dquot___15 *);
	int (*release_dqblk)(struct dquot___15 *);
	int (*get_next_id)(struct super_block___15 *, struct kqid *);
};

struct dquot_operations___15 {
	int (*write_dquot)(struct dquot___15 *);
	struct dquot___15 * (*alloc_dquot)(struct super_block___15 *, int);
	void (*destroy_dquot)(struct dquot___15 *);
	int (*acquire_dquot)(struct dquot___15 *);
	int (*release_dquot)(struct dquot___15 *);
	int (*mark_dirty)(struct dquot___15 *);
	int (*write_info)(struct super_block___15 *, int);
	qsize_t * (*get_reserved_space)(struct inode___15 *);
	int (*get_projid)(struct inode___15 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___15 *, qsize_t *);
	int (*get_next_id)(struct super_block___15 *, struct kqid *);
};

struct quotactl_ops___15 {
	int (*quota_on)(struct super_block___15 *, int, int, const struct path___15 *);
	int (*quota_off)(struct super_block___15 *, int);
	int (*quota_enable)(struct super_block___15 *, unsigned int);
	int (*quota_disable)(struct super_block___15 *, unsigned int);
	int (*quota_sync)(struct super_block___15 *, int);
	int (*set_info)(struct super_block___15 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___15 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___15 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___15 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___15 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___15 *, unsigned int);
};

struct wait_page_queue___9 {
	struct page___16 *page;
	int bit_nr;
	wait_queue_entry_t wait;
};

struct readahead_control___9;

struct address_space_operations___15 {
	int (*writepage)(struct page___16 *, struct writeback_control *);
	int (*readpage)(struct file___15 *, struct page___16 *);
	int (*writepages)(struct address_space___15 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___16 *);
	int (*readpages)(struct file___15 *, struct address_space___15 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___9 *);
	int (*write_begin)(struct file___15 *, struct address_space___15 *, loff_t, unsigned int, unsigned int, struct page___16 **, void **);
	int (*write_end)(struct file___15 *, struct address_space___15 *, loff_t, unsigned int, unsigned int, struct page___16 *, void *);
	sector_t (*bmap)(struct address_space___15 *, sector_t);
	void (*invalidatepage)(struct page___16 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___16 *, gfp_t);
	void (*freepage)(struct page___16 *);
	ssize_t (*direct_IO)(struct kiocb___15 *, struct iov_iter___13 *);
	int (*migratepage)(struct address_space___15 *, struct page___16 *, struct page___16 *, enum migrate_mode);
	bool (*isolate_page)(struct page___16 *, isolate_mode_t);
	void (*putback_page)(struct page___16 *);
	int (*launder_page)(struct page___16 *);
	int (*is_partially_uptodate)(struct page___16 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___16 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___15 *, struct page___16 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___15 *, sector_t *);
	void (*swap_deactivate)(struct file___15 *);
};

struct readahead_control___9 {
	struct file___15 *file;
	struct address_space___15 *mapping;
	struct file_ra_state *ra;
	long unsigned int _index;
	unsigned int _nr_pages;
	unsigned int _batch_count;
};

struct bio_vec___13;

struct iov_iter___13 {
	u8 iter_type;
	bool data_source;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___13 *bvec;
		struct xarray *xarray;
		struct pipe_inode_info___4 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			unsigned int head;
			unsigned int start_head;
		};
		loff_t xarray_start;
	};
};

struct inode_operations___15 {
	struct dentry___15 * (*lookup)(struct inode___15 *, struct dentry___15 *, unsigned int);
	const char * (*get_link)(struct dentry___15 *, struct inode___15 *, struct delayed_call *);
	int (*permission)(struct user_namespace *, struct inode___15 *, int);
	struct posix_acl * (*get_acl)(struct inode___15 *, int, bool);
	int (*readlink)(struct dentry___15 *, char *, int);
	int (*create)(struct user_namespace *, struct inode___15 *, struct dentry___15 *, umode_t, bool);
	int (*link)(struct dentry___15 *, struct inode___15 *, struct dentry___15 *);
	int (*unlink)(struct inode___15 *, struct dentry___15 *);
	int (*symlink)(struct user_namespace *, struct inode___15 *, struct dentry___15 *, const char *);
	int (*mkdir)(struct user_namespace *, struct inode___15 *, struct dentry___15 *, umode_t);
	int (*rmdir)(struct inode___15 *, struct dentry___15 *);
	int (*mknod)(struct user_namespace *, struct inode___15 *, struct dentry___15 *, umode_t, dev_t);
	int (*rename)(struct user_namespace *, struct inode___15 *, struct dentry___15 *, struct inode___15 *, struct dentry___15 *, unsigned int);
	int (*setattr)(struct user_namespace *, struct dentry___15 *, struct iattr___15 *);
	int (*getattr)(struct user_namespace *, const struct path___15 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___15 *, char *, size_t);
	int (*fiemap)(struct inode___15 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___15 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___15 *, struct dentry___15 *, struct file___15 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace *, struct inode___15 *, struct dentry___15 *, umode_t);
	int (*set_acl)(struct user_namespace *, struct inode___15 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace *, struct dentry___15 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___15 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___15 {
	void (*fl_copy_lock)(struct file_lock___15 *, struct file_lock___15 *);
	void (*fl_release_private)(struct file_lock___15 *);
};

struct lock_manager_operations___15;

struct file_lock___15 {
	struct file_lock___15 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___15 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___15 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___15 *fl_ops;
	const struct lock_manager_operations___15 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___15 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___15 *);
	int (*lm_grant)(struct file_lock___15 *, int);
	bool (*lm_break)(struct file_lock___15 *);
	int (*lm_change)(struct file_lock___15 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___15 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___15 *);
};

struct fasync_struct___15 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___15 *fa_next;
	struct file___15 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___15 {
	struct inode___15 * (*alloc_inode)(struct super_block___15 *);
	void (*destroy_inode)(struct inode___15 *);
	void (*free_inode)(struct inode___15 *);
	void (*dirty_inode)(struct inode___15 *, int);
	int (*write_inode)(struct inode___15 *, struct writeback_control *);
	int (*drop_inode)(struct inode___15 *);
	void (*evict_inode)(struct inode___15 *);
	void (*put_super)(struct super_block___15 *);
	int (*sync_fs)(struct super_block___15 *, int);
	int (*freeze_super)(struct super_block___15 *);
	int (*freeze_fs)(struct super_block___15 *);
	int (*thaw_super)(struct super_block___15 *);
	int (*unfreeze_fs)(struct super_block___15 *);
	int (*statfs)(struct dentry___15 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___15 *, int *, char *);
	void (*umount_begin)(struct super_block___15 *);
	int (*show_options)(struct seq_file___14 *, struct dentry___15 *);
	int (*show_devname)(struct seq_file___14 *, struct dentry___15 *);
	int (*show_path)(struct seq_file___14 *, struct dentry___15 *);
	int (*show_stats)(struct seq_file___14 *, struct dentry___15 *);
	ssize_t (*quota_read)(struct super_block___15 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___15 *, int, const char *, size_t, loff_t);
	struct dquot___15 ** (*get_dquots)(struct inode___15 *);
	long int (*nr_cached_objects)(struct super_block___15 *, struct shrink_control___9 *);
	long int (*free_cached_objects)(struct super_block___15 *, struct shrink_control___9 *);
	struct file___15 * (*real_loop)(struct file___15 *);
};

struct fwnode_reference_args___16;

struct fwnode_endpoint___16;

struct fwnode_operations___16 {
	struct fwnode_handle___16 * (*get)(struct fwnode_handle___16 *);
	void (*put)(struct fwnode_handle___16 *);
	bool (*device_is_available)(const struct fwnode_handle___16 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___16 *, const struct device___17 *);
	bool (*property_present)(const struct fwnode_handle___16 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___16 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___16 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___16 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___16 *);
	struct fwnode_handle___16 * (*get_parent)(const struct fwnode_handle___16 *);
	struct fwnode_handle___16 * (*get_next_child_node)(const struct fwnode_handle___16 *, struct fwnode_handle___16 *);
	struct fwnode_handle___16 * (*get_named_child_node)(const struct fwnode_handle___16 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___16 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___16 *);
	struct fwnode_handle___16 * (*graph_get_next_endpoint)(const struct fwnode_handle___16 *, struct fwnode_handle___16 *);
	struct fwnode_handle___16 * (*graph_get_remote_endpoint)(const struct fwnode_handle___16 *);
	struct fwnode_handle___16 * (*graph_get_port_parent)(struct fwnode_handle___16 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___16 *, struct fwnode_endpoint___16 *);
	int (*add_links)(struct fwnode_handle___16 *);
};

struct fwnode_endpoint___16 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___16 *local_fwnode;
};

struct fwnode_reference_args___16 {
	struct fwnode_handle___16 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct of_phandle_args___2 {
	struct device_node___12 *np;
	int args_count;
	uint32_t args[16];
};

typedef int (*iommu_fault_handler_t___2)(struct iommu_domain___2 *, struct device___17 *, long unsigned int, int, void *);

struct iommu_domain___2 {
	unsigned int type;
	const struct iommu_ops___2 *ops;
	long unsigned int pgsize_bitmap;
	iommu_fault_handler_t___2 handler;
	void *handler_token;
	struct iommu_domain_geometry geometry;
	struct iommu_dma_cookie *iova_cookie;
};

struct iommu_iotlb_gather___2 {
	long unsigned int start;
	long unsigned int end;
	size_t pgsize;
	struct page___16 *freelist;
	bool queued;
};

struct iommu_device___2 {
	struct list_head list;
	const struct iommu_ops___2 *ops;
	struct fwnode_handle___16 *fwnode;
	struct device___17 *dev;
};

struct iommu_sva___2 {
	struct device___17 *dev;
};

struct iommu_fwspec___2 {
	const struct iommu_ops___2 *ops;
	struct fwnode_handle___16 *iommu_fwnode;
	u32 flags;
	unsigned int num_ids;
	u32 ids[0];
};

struct irq_fwspec___10 {
	struct fwnode_handle___16 *fwnode;
	int param_count;
	u32 param[16];
};

struct irq_domain_ops___11 {
	int (*match)(struct irq_domain___11 *, struct device_node___12 *, enum irq_domain_bus_token);
	int (*select)(struct irq_domain___11 *, struct irq_fwspec___10 *, enum irq_domain_bus_token);
	int (*map)(struct irq_domain___11 *, unsigned int, irq_hw_number_t);
	void (*unmap)(struct irq_domain___11 *, unsigned int);
	int (*xlate)(struct irq_domain___11 *, struct device_node___12 *, const u32 *, unsigned int, long unsigned int *, unsigned int *);
	int (*alloc)(struct irq_domain___11 *, unsigned int, unsigned int, void *);
	void (*free)(struct irq_domain___11 *, unsigned int, unsigned int);
	int (*activate)(struct irq_domain___11 *, struct irq_data *, bool);
	void (*deactivate)(struct irq_domain___11 *, struct irq_data *);
	int (*translate)(struct irq_domain___11 *, struct irq_fwspec___10 *, long unsigned int *, unsigned int *);
};

struct kernel_param_ops___15 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___15 *);
	int (*get)(char *, const struct kernel_param___15 *);
	void (*free)(void *);
};

struct kparam_array___15;

struct kernel_param___15 {
	const char *name;
	struct module___15 *mod;
	const struct kernel_param_ops___15 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___15 *arr;
	};
};

struct kparam_array___15 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___15 *ops;
	void *elem;
};

struct module_attribute___15 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___15 *, struct module_kobject___15 *, char *);
	ssize_t (*store)(struct module_attribute___15 *, struct module_kobject___15 *, const char *, size_t);
	void (*setup)(struct module___15 *, const char *);
	int (*test)(struct module___15 *);
	void (*free)(struct module___15 *);
};

struct bio_vec___13 {
	struct page___16 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct pipe_buf_operations___4;

struct pipe_buffer___4 {
	struct page___16 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___4 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___4 {
	int (*confirm)(struct pipe_inode_info___4 *, struct pipe_buffer___4 *);
	void (*release)(struct pipe_inode_info___4 *, struct pipe_buffer___4 *);
	bool (*try_steal)(struct pipe_inode_info___4 *, struct pipe_buffer___4 *);
	bool (*get)(struct pipe_inode_info___4 *, struct pipe_buffer___4 *);
};

enum {
	TB_SHUTDOWN_REBOOT = 0,
	TB_SHUTDOWN_S5 = 1,
	TB_SHUTDOWN_S4 = 2,
	TB_SHUTDOWN_S3 = 3,
	TB_SHUTDOWN_HALT = 4,
	TB_SHUTDOWN_WFS = 5,
};

struct tboot_mac_region {
	u64 start;
	u32 size;
} __attribute__((packed));

struct tboot_acpi_generic_address {
	u8 space_id;
	u8 bit_width;
	u8 bit_offset;
	u8 access_width;
	u64 address;
} __attribute__((packed));

struct tboot_acpi_sleep_info {
	struct tboot_acpi_generic_address pm1a_cnt_blk;
	struct tboot_acpi_generic_address pm1b_cnt_blk;
	struct tboot_acpi_generic_address pm1a_evt_blk;
	struct tboot_acpi_generic_address pm1b_evt_blk;
	u16 pm1a_cnt_val;
	u16 pm1b_cnt_val;
	u64 wakeup_vector;
	u32 vector_width;
	u64 kernel_s3_resume_vector;
} __attribute__((packed));

struct tboot {
	u8 uuid[16];
	u32 version;
	u32 log_addr;
	u32 shutdown_entry;
	u32 shutdown_type;
	struct tboot_acpi_sleep_info acpi_sinfo;
	u32 tboot_base;
	u32 tboot_size;
	u8 num_mac_regions;
	struct tboot_mac_region mac_regions[32];
	u8 s3_key[64];
	u8 reserved_align[3];
	u32 num_in_wfs;
} __attribute__((packed));

struct sha1_hash {
	u8 hash[20];
};

struct sinit_mle_data {
	u32 version;
	struct sha1_hash bios_acm_id;
	u32 edx_senter_flags;
	u64 mseg_valid;
	struct sha1_hash sinit_hash;
	struct sha1_hash mle_hash;
	struct sha1_hash stm_hash;
	struct sha1_hash lcp_policy_hash;
	u32 lcp_policy_control;
	u32 rlp_wakeup_addr;
	u32 reserved;
	u32 num_mdrs;
	u32 mdrs_off;
	u32 num_vtd_dmars;
	u32 vtd_dmars_off;
} __attribute__((packed));

typedef bool (*stack_trace_consume_fn)(void *, long unsigned int);

struct stack_frame_user {
	const void *next_fp;
	long unsigned int ret_addr;
};

enum cache_type {
	CACHE_TYPE_NOCACHE = 0,
	CACHE_TYPE_INST = 1,
	CACHE_TYPE_DATA = 2,
	CACHE_TYPE_SEPARATE = 3,
	CACHE_TYPE_UNIFIED = 4,
};

struct cacheinfo {
	unsigned int id;
	enum cache_type type;
	unsigned int level;
	unsigned int coherency_line_size;
	unsigned int number_of_sets;
	unsigned int ways_of_associativity;
	unsigned int physical_line_partition;
	unsigned int size;
	cpumask_t shared_cpu_map;
	unsigned int attributes;
	void *fw_token;
	bool disable_sysfs;
	void *priv;
};

struct cpu_cacheinfo {
	struct cacheinfo *info_list;
	unsigned int num_levels;
	unsigned int num_leaves;
	bool cpu_map_populated;
};

struct amd_l3_cache {
	unsigned int indices;
	u8 subcaches[4];
};

struct threshold_block {
	unsigned int block;
	unsigned int bank;
	unsigned int cpu;
	u32 address;
	u16 interrupt_enable;
	bool interrupt_capable;
	u16 threshold_limit;
	struct kobject___14 kobj;
	struct list_head miscj;
};

struct threshold_bank {
	struct kobject___14 *kobj;
	struct threshold_block *blocks;
	refcount_t cpus;
	unsigned int shared;
};

struct amd_northbridge {
	struct pci_dev___3 *root;
	struct pci_dev___3 *misc;
	struct pci_dev___3 *link;
	struct amd_l3_cache l3_cache;
	struct threshold_bank *bank4;
};

struct _cache_table {
	unsigned char descriptor;
	char cache_type;
	short int size;
};

enum _cache_type {
	CTYPE_NULL = 0,
	CTYPE_DATA = 1,
	CTYPE_INST = 2,
	CTYPE_UNIFIED = 3,
};

union _cpuid4_leaf_eax {
	struct {
		enum _cache_type type: 5;
		unsigned int level: 3;
		unsigned int is_self_initializing: 1;
		unsigned int is_fully_associative: 1;
		unsigned int reserved: 4;
		unsigned int num_threads_sharing: 12;
		unsigned int num_cores_on_die: 6;
	} split;
	u32 full;
};

union _cpuid4_leaf_ebx {
	struct {
		unsigned int coherency_line_size: 12;
		unsigned int physical_line_partition: 10;
		unsigned int ways_of_associativity: 10;
	} split;
	u32 full;
};

union _cpuid4_leaf_ecx {
	struct {
		unsigned int number_of_sets: 32;
	} split;
	u32 full;
};

struct _cpuid4_info_regs {
	union _cpuid4_leaf_eax eax;
	union _cpuid4_leaf_ebx ebx;
	union _cpuid4_leaf_ecx ecx;
	unsigned int id;
	long unsigned int size;
	struct amd_northbridge *nb;
};

union l1_cache {
	struct {
		unsigned int line_size: 8;
		unsigned int lines_per_tag: 8;
		unsigned int assoc: 8;
		unsigned int size_in_kb: 8;
	};
	unsigned int val;
};

union l2_cache {
	struct {
		unsigned int line_size: 8;
		unsigned int lines_per_tag: 4;
		unsigned int assoc: 4;
		unsigned int size_in_kb: 16;
	};
	unsigned int val;
};

union l3_cache {
	struct {
		unsigned int line_size: 8;
		unsigned int lines_per_tag: 4;
		unsigned int assoc: 4;
		unsigned int res: 2;
		unsigned int size_encoded: 14;
	};
	unsigned int val;
};

struct cpuid_bit {
	u16 feature;
	u8 reg;
	u8 bit;
	u32 level;
	u32 sub_leaf;
};

enum cpuid_leafs {
	CPUID_1_EDX = 0,
	CPUID_8000_0001_EDX = 1,
	CPUID_8086_0001_EDX = 2,
	CPUID_LNX_1 = 3,
	CPUID_1_ECX = 4,
	CPUID_C000_0001_EDX = 5,
	CPUID_8000_0001_ECX = 6,
	CPUID_LNX_2 = 7,
	CPUID_LNX_3 = 8,
	CPUID_7_0_EBX = 9,
	CPUID_D_1_EAX = 10,
	CPUID_LNX_4 = 11,
	CPUID_7_1_EAX = 12,
	CPUID_8000_0008_EBX = 13,
	CPUID_6_EAX = 14,
	CPUID_8000_000A_EDX = 15,
	CPUID_7_ECX = 16,
	CPUID_8000_0007_EBX = 17,
	CPUID_7_EDX = 18,
	CPUID_8000_001F_EAX = 19,
};

enum kgdb_bptype {
	BP_BREAKPOINT = 0,
	BP_HARDWARE_BREAKPOINT = 1,
	BP_WRITE_WATCHPOINT = 2,
	BP_READ_WATCHPOINT = 3,
	BP_ACCESS_WATCHPOINT = 4,
	BP_POKE_BREAKPOINT = 5,
};

struct kgdb_arch {
	unsigned char gdb_bpt_instr[1];
	long unsigned int flags;
	int (*set_breakpoint)(long unsigned int, char *);
	int (*remove_breakpoint)(long unsigned int, char *);
	int (*set_hw_breakpoint)(long unsigned int, int, enum kgdb_bptype);
	int (*remove_hw_breakpoint)(long unsigned int, int, enum kgdb_bptype);
	void (*disable_hw_break)(struct pt_regs *);
	void (*remove_all_hw_break)();
	void (*correct_hw_break)();
	void (*enable_nmi)(bool);
};

struct cpu_entry_area___2 {
	char gdt[4096];
	struct entry_stack_page entry_stack_page;
	struct tss_struct tss;
	struct cea_exception_stacks estacks;
	struct debug_store cpu_debug_store;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct debug_store_buffers cpu_debug_buffers;
};

struct tlb_state___5 {
	struct mm_struct___2 *loaded_mm;
	union {
		struct mm_struct___2 *last_user_mm;
		long unsigned int last_user_mm_spec;
	};
	u16 loaded_mm_asid;
	u16 next_asid;
	bool invalidate_other;
	short unsigned int user_pcid_flush_mask;
	long unsigned int cr4;
	struct tlb_context ctxs[6];
};

struct cpu_dev {
	const char *c_vendor;
	const char *c_ident[2];
	void (*c_early_init)(struct cpuinfo_x86___2 *);
	void (*c_bsp_init)(struct cpuinfo_x86___2 *);
	void (*c_init)(struct cpuinfo_x86___2 *);
	void (*c_identify)(struct cpuinfo_x86___2 *);
	void (*c_detect_tlb)(struct cpuinfo_x86___2 *);
	int c_x86_vendor;
};

struct cpuid_dependent_feature {
	u32 feature;
	u32 level;
};

enum spectre_v2_mitigation {
	SPECTRE_V2_NONE = 0,
	SPECTRE_V2_RETPOLINE = 1,
	SPECTRE_V2_LFENCE = 2,
	SPECTRE_V2_EIBRS = 3,
	SPECTRE_V2_EIBRS_RETPOLINE = 4,
	SPECTRE_V2_EIBRS_LFENCE = 5,
};

enum spectre_v2_user_mitigation {
	SPECTRE_V2_USER_NONE = 0,
	SPECTRE_V2_USER_STRICT = 1,
	SPECTRE_V2_USER_STRICT_PREFERRED = 2,
	SPECTRE_V2_USER_PRCTL = 3,
	SPECTRE_V2_USER_SECCOMP = 4,
};

enum ssb_mitigation {
	SPEC_STORE_BYPASS_NONE = 0,
	SPEC_STORE_BYPASS_DISABLE = 1,
	SPEC_STORE_BYPASS_PRCTL = 2,
	SPEC_STORE_BYPASS_SECCOMP = 3,
};

enum l1tf_mitigations {
	L1TF_MITIGATION_OFF = 0,
	L1TF_MITIGATION_FLUSH_NOWARN = 1,
	L1TF_MITIGATION_FLUSH = 2,
	L1TF_MITIGATION_FLUSH_NOSMT = 3,
	L1TF_MITIGATION_FULL = 4,
	L1TF_MITIGATION_FULL_FORCE = 5,
};

enum mds_mitigations {
	MDS_MITIGATION_OFF = 0,
	MDS_MITIGATION_FULL = 1,
	MDS_MITIGATION_VMWERV = 2,
};

enum cpuhp_smt_control {
	CPU_SMT_ENABLED = 0,
	CPU_SMT_DISABLED = 1,
	CPU_SMT_FORCE_DISABLED = 2,
	CPU_SMT_NOT_SUPPORTED = 3,
	CPU_SMT_NOT_IMPLEMENTED = 4,
};

enum vmx_l1d_flush_state {
	VMENTER_L1D_FLUSH_AUTO = 0,
	VMENTER_L1D_FLUSH_NEVER = 1,
	VMENTER_L1D_FLUSH_COND = 2,
	VMENTER_L1D_FLUSH_ALWAYS = 3,
	VMENTER_L1D_FLUSH_EPT_DISABLED = 4,
	VMENTER_L1D_FLUSH_NOT_REQUIRED = 5,
};

enum taa_mitigations {
	TAA_MITIGATION_OFF = 0,
	TAA_MITIGATION_UCODE_NEEDED = 1,
	TAA_MITIGATION_VERW = 2,
	TAA_MITIGATION_TSX_DISABLED = 3,
};

enum srbds_mitigations {
	SRBDS_MITIGATION_OFF = 0,
	SRBDS_MITIGATION_UCODE_NEEDED = 1,
	SRBDS_MITIGATION_FULL = 2,
	SRBDS_MITIGATION_TSX_OFF = 3,
	SRBDS_MITIGATION_HYPERVISOR = 4,
};

enum l1d_flush_mitigations {
	L1D_FLUSH_OFF = 0,
	L1D_FLUSH_ON = 1,
};

enum spectre_v1_mitigation {
	SPECTRE_V1_MITIGATION_NONE = 0,
	SPECTRE_V1_MITIGATION_AUTO = 1,
};

enum spectre_v2_mitigation_cmd {
	SPECTRE_V2_CMD_NONE = 0,
	SPECTRE_V2_CMD_AUTO = 1,
	SPECTRE_V2_CMD_FORCE = 2,
	SPECTRE_V2_CMD_RETPOLINE = 3,
	SPECTRE_V2_CMD_RETPOLINE_GENERIC = 4,
	SPECTRE_V2_CMD_RETPOLINE_LFENCE = 5,
	SPECTRE_V2_CMD_EIBRS = 6,
	SPECTRE_V2_CMD_EIBRS_RETPOLINE = 7,
	SPECTRE_V2_CMD_EIBRS_LFENCE = 8,
};

enum spectre_v2_user_cmd {
	SPECTRE_V2_USER_CMD_NONE = 0,
	SPECTRE_V2_USER_CMD_AUTO = 1,
	SPECTRE_V2_USER_CMD_FORCE = 2,
	SPECTRE_V2_USER_CMD_PRCTL = 3,
	SPECTRE_V2_USER_CMD_PRCTL_IBPB = 4,
	SPECTRE_V2_USER_CMD_SECCOMP = 5,
	SPECTRE_V2_USER_CMD_SECCOMP_IBPB = 6,
};

enum ssb_mitigation_cmd {
	SPEC_STORE_BYPASS_CMD_NONE = 0,
	SPEC_STORE_BYPASS_CMD_AUTO = 1,
	SPEC_STORE_BYPASS_CMD_ON = 2,
	SPEC_STORE_BYPASS_CMD_PRCTL = 3,
	SPEC_STORE_BYPASS_CMD_SECCOMP = 4,
};

enum hk_flags {
	HK_FLAG_TIMER = 1,
	HK_FLAG_RCU = 2,
	HK_FLAG_MISC = 4,
	HK_FLAG_SCHED = 8,
	HK_FLAG_TICK = 16,
	HK_FLAG_DOMAIN = 32,
	HK_FLAG_WQ = 64,
	HK_FLAG_MANAGED_IRQ = 128,
	HK_FLAG_KTHREAD = 256,
};

struct aperfmperf_sample {
	unsigned int khz;
	atomic_t scfpending;
	ktime_t time;
	u64 aperf;
	u64 mperf;
};

struct cpuid_dep {
	unsigned int feature;
	unsigned int depends;
};

struct device_attribute___3 {
	struct attribute attr;
	ssize_t (*show)(struct device___2 *, struct device_attribute___3 *, char *);
	ssize_t (*store)(struct device___2 *, struct device_attribute___3 *, const char *, size_t);
};

enum vmx_feature_leafs {
	MISC_FEATURES = 0,
	PRIMARY_CTLS = 1,
	SECONDARY_CTLS = 2,
	NR_VMX_FEATURE_WORDS = 3,
};

struct cpu_dev___2 {
	const char *c_vendor;
	const char *c_ident[2];
	void (*c_early_init)(struct cpuinfo_x86 *);
	void (*c_bsp_init)(struct cpuinfo_x86 *);
	void (*c_init)(struct cpuinfo_x86 *);
	void (*c_identify)(struct cpuinfo_x86 *);
	void (*c_detect_tlb)(struct cpuinfo_x86 *);
	int c_x86_vendor;
};

struct _tlb_table {
	unsigned char descriptor;
	char tlb_type;
	unsigned int entries;
	char info[128];
};

enum tsx_ctrl_states {
	TSX_CTRL_ENABLE = 0,
	TSX_CTRL_DISABLE = 1,
	TSX_CTRL_RTM_ALWAYS_ABORT = 2,
	TSX_CTRL_NOT_SUPPORTED = 3,
};

enum split_lock_detect_state {
	sld_off = 0,
	sld_warn = 1,
	sld_fatal = 2,
	sld_ratelimit = 3,
};

struct sku_microcode {
	u8 model;
	u8 stepping;
	u32 microcode;
};

struct cpuid_regs {
	u32 eax;
	u32 ebx;
	u32 ecx;
	u32 edx;
};

enum pconfig_target {
	INVALID_TARGET = 0,
	MKTME_TARGET = 1,
	PCONFIG_TARGET_NR = 2,
};

enum {
	PCONFIG_CPUID_SUBLEAF_INVALID = 0,
	PCONFIG_CPUID_SUBLEAF_TARGETID = 1,
};

struct device_attribute___4 {
	struct attribute attr;
	ssize_t (*show)(struct device___15 *, struct device_attribute___4 *, char *);
	ssize_t (*store)(struct device___15 *, struct device_attribute___4 *, const char *, size_t);
};

struct x86_cpuinit_ops___2 {
	void (*setup_percpu_clockev)();
	void (*early_percpu_clock_init)();
	void (*fixup_cpu_id)(struct cpuinfo_x86___2 *, int);
};

enum task_work_notify_mode {
	TWA_NONE = 0,
	TWA_RESUME = 1,
	TWA_SIGNAL = 2,
};

struct device_attribute___5 {
	struct attribute attr;
	ssize_t (*show)(struct device___12 *, struct device_attribute___5 *, char *);
	ssize_t (*store)(struct device___12 *, struct device_attribute___5 *, const char *, size_t);
};

struct dev_ext_attribute___2 {
	struct device_attribute___5 attr;
	void *var;
};

enum mf_flags {
	MF_COUNT_INCREASED = 1,
	MF_ACTION_REQUIRED = 2,
	MF_MUST_KILL = 4,
	MF_SOFT_OFFLINE = 8,
};

struct mce {
	__u64 status;
	__u64 misc;
	__u64 addr;
	__u64 mcgstatus;
	__u64 ip;
	__u64 tsc;
	__u64 time;
	__u8 cpuvendor;
	__u8 inject_flags;
	__u8 severity;
	__u8 pad;
	__u32 cpuid;
	__u8 cs;
	__u8 bank;
	__u8 cpu;
	__u8 finished;
	__u32 extcpu;
	__u32 socketid;
	__u32 apicid;
	__u64 mcgcap;
	__u64 synd;
	__u64 ipid;
	__u64 ppin;
	__u32 microcode;
	__u64 kflags;
};

enum mce_notifier_prios {
	MCE_PRIO_LOWEST = 0,
	MCE_PRIO_MCELOG = 1,
	MCE_PRIO_EDAC = 2,
	MCE_PRIO_NFIT = 3,
	MCE_PRIO_EXTLOG = 4,
	MCE_PRIO_UC = 5,
	MCE_PRIO_EARLY = 6,
	MCE_PRIO_CEC = 7,
	MCE_PRIO_HIGHEST = 7,
};

typedef long unsigned int mce_banks_t[1];

enum mcp_flags {
	MCP_TIMESTAMP = 1,
	MCP_UC = 2,
	MCP_DONTLOG = 4,
	MCP_QUEUE_LOG = 8,
};

enum severity_level {
	MCE_NO_SEVERITY = 0,
	MCE_DEFERRED_SEVERITY = 1,
	MCE_UCNA_SEVERITY = 1,
	MCE_KEEP_SEVERITY = 2,
	MCE_SOME_SEVERITY = 3,
	MCE_AO_SEVERITY = 4,
	MCE_UC_SEVERITY = 5,
	MCE_AR_SEVERITY = 6,
	MCE_PANIC_SEVERITY = 7,
};

struct mce_evt_llist {
	struct llist_node llnode;
	struct mce mce;
};

struct mca_config {
	bool dont_log_ce;
	bool cmci_disabled;
	bool ignore_ce;
	bool print_all;
	__u64 lmce_disabled: 1;
	__u64 disabled: 1;
	__u64 ser: 1;
	__u64 recovery: 1;
	__u64 bios_cmci_threshold: 1;
	__u64 __reserved: 59;
	long: 5;
	long: 64;
	s8 bootlog;
	int tolerant;
	int monarch_timeout;
	int panic_timeout;
	u32 rip_msr;
};

struct mce_vendor_flags {
	__u64 overflow_recov: 1;
	__u64 succor: 1;
	__u64 smca: 1;
	__u64 amd_threshold: 1;
	__u64 __reserved_0: 60;
};

struct mca_msr_regs {
	u32 (*ctl)(int);
	u32 (*status)(int);
	u32 (*addr)(int);
	u32 (*misc)(int);
};

struct trace_event_raw_mce_record {
	struct trace_entry ent;
	u64 mcgcap;
	u64 mcgstatus;
	u64 status;
	u64 addr;
	u64 misc;
	u64 synd;
	u64 ipid;
	u64 ip;
	u64 tsc;
	u64 walltime;
	u32 cpu;
	u32 cpuid;
	u32 apicid;
	u32 socketid;
	u8 cs;
	u8 bank;
	u8 cpuvendor;
	char __data[0];
};

struct trace_event_data_offsets_mce_record {};

typedef void (*btf_trace_mce_record)(void *, struct mce *);

struct mce_bank {
	u64 ctl;
	bool init;
};

struct mce_bank_dev {
	struct device_attribute___5 attr;
	char attrname[16];
	u8 bank;
};

enum context {
	IN_KERNEL = 1,
	IN_USER = 2,
	IN_KERNEL_RECOV = 3,
};

enum ser {
	SER_REQUIRED = 1,
	NO_SER = 2,
};

enum exception {
	EXCP_CONTEXT = 1,
	NO_EXCP = 2,
};

struct severity {
	u64 mask;
	u64 result;
	unsigned char sev;
	unsigned char mcgmask;
	unsigned char mcgres;
	unsigned char ser;
	unsigned char context;
	unsigned char excp;
	unsigned char covered;
	unsigned char cpu_model;
	unsigned char cpu_minstepping;
	unsigned char bank_lo;
	unsigned char bank_hi;
	char *msg;
};

struct ratelimit_state___2 {
	raw_spinlock_t___2 lock;
	int interval;
	int burst;
	int printed;
	int missed;
	long unsigned int begin;
	long unsigned int flags;
};

struct rw_semaphore___2 {
	atomic_long_t count;
	atomic_long_t owner;
	struct optimistic_spin_queue osq;
	raw_spinlock_t___2 wait_lock;
	struct list_head wait_list;
};

struct blocking_notifier_head___2 {
	struct rw_semaphore___2 rwsem;
	struct notifier_block *head;
};

struct gen_pool;

typedef long unsigned int (*genpool_algo_t)(long unsigned int *, long unsigned int, long unsigned int, unsigned int, void *, struct gen_pool *, long unsigned int);

struct gen_pool {
	spinlock_t___2 lock;
	struct list_head chunks;
	int min_alloc_order;
	genpool_algo_t algo;
	void *data;
	const char *name;
};

enum {
	CMCI_STORM_NONE = 0,
	CMCI_STORM_ACTIVE = 1,
	CMCI_STORM_SUBSIDED = 2,
};

struct pci_bus___4;

struct pci_slot___4;

struct pci_driver___4;

struct pci_dev___4 {
	struct list_head bus_list;
	struct pci_bus___4 *bus;
	struct pci_bus___4 *subordinate;
	void *sysdata;
	struct proc_dir_entry *procent;
	struct pci_slot___4 *slot;
	unsigned int devfn;
	short unsigned int vendor;
	short unsigned int device;
	short unsigned int subsystem_vendor;
	short unsigned int subsystem_device;
	unsigned int class;
	u8 revision;
	u8 hdr_type;
	u16 aer_cap;
	struct aer_stats *aer_stats;
	struct rcec_ea *rcec_ea;
	struct pci_dev___4 *rcec;
	u32 devcap;
	u8 pcie_cap;
	u8 msi_cap;
	u8 msix_cap;
	u8 pcie_mpss: 3;
	long: 61;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u8 rom_base_reg;
	u8 pin;
	u16 pcie_flags_reg;
	long unsigned int *dma_alias_mask;
	struct pci_driver___4 *driver;
	u64 dma_mask;
	struct device_dma_parameters dma_parms;
	pci_power_t current_state;
	unsigned int imm_ready: 1;
	long: 39;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u8 pm_cap;
	unsigned int pme_support: 5;
	unsigned int pme_poll: 1;
	unsigned int d1_support: 1;
	unsigned int d2_support: 1;
	unsigned int no_d1d2: 1;
	unsigned int no_d3cold: 1;
	unsigned int bridge_d3: 1;
	unsigned int d3cold_allowed: 1;
	unsigned int mmio_always_on: 1;
	unsigned int wakeup_prepared: 1;
	unsigned int runtime_d3cold: 1;
	unsigned int skip_bus_pm: 1;
	unsigned int ignore_hotplug: 1;
	unsigned int hotplug_user_indicators: 1;
	unsigned int clear_retrain_link: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int d3hot_delay;
	unsigned int d3cold_delay;
	struct pcie_link_state *link_state;
	unsigned int ltr_path: 1;
	long: 15;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u16 l1ss;
	unsigned int pasid_no_tlp: 1;
	unsigned int eetlp_prefix_path: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	pci_channel_state_t error_state;
	struct device___12 dev;
	int cfg_size;
	unsigned int irq;
	struct resource resource[17];
	bool match_driver;
	unsigned int transparent: 1;
	unsigned int io_window: 1;
	unsigned int pref_window: 1;
	unsigned int pref_64_window: 1;
	unsigned int multifunction: 1;
	unsigned int is_busmaster: 1;
	unsigned int no_msi: 1;
	unsigned int no_64bit_msi: 1;
	unsigned int block_cfg_access: 1;
	unsigned int broken_parity_status: 1;
	unsigned int irq_reroute_variant: 2;
	unsigned int msi_enabled: 1;
	unsigned int msix_enabled: 1;
	unsigned int ari_enabled: 1;
	unsigned int ats_enabled: 1;
	unsigned int pasid_enabled: 1;
	unsigned int pri_enabled: 1;
	unsigned int is_managed: 1;
	unsigned int needs_freset: 1;
	unsigned int state_saved: 1;
	unsigned int is_physfn: 1;
	unsigned int is_virtfn: 1;
	unsigned int is_hotplug_bridge: 1;
	unsigned int shpc_managed: 1;
	unsigned int is_thunderbolt: 1;
	unsigned int untrusted: 1;
	unsigned int external_facing: 1;
	unsigned int broken_intx_masking: 1;
	unsigned int io_window_1k: 1;
	unsigned int irq_managed: 1;
	unsigned int non_compliant_bars: 1;
	unsigned int is_probed: 1;
	unsigned int link_active_reporting: 1;
	unsigned int no_vf_scan: 1;
	unsigned int no_command_memory: 1;
	long: 47;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	pci_dev_flags_t dev_flags;
	atomic_t enable_cnt;
	u32 saved_config_space[16];
	struct hlist_head saved_cap_space;
	int rom_attr_enabled;
	struct bin_attribute___12 *res_attr[17];
	struct bin_attribute___12 *res_attr_wc[17];
	unsigned int broken_cmd_compl: 1;
	unsigned int ptm_root: 1;
	unsigned int ptm_enabled: 1;
	long: 7;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u8 ptm_granularity;
	const struct attribute_group___12 **msi_irq_groups;
	struct pci_vpd vpd;
	u16 dpc_cap;
	unsigned int dpc_rp_extensions: 1;
	long: 23;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u8 dpc_rp_log_size;
	union {
		struct pci_sriov *sriov;
		struct pci_dev___4 *physfn;
	};
	u16 ats_cap;
	u8 ats_stu;
	u16 pri_cap;
	u32 pri_reqs_alloc;
	unsigned int pasid_required: 1;
	long: 47;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u16 pasid_cap;
	u16 pasid_features;
	u16 acs_cap;
	phys_addr_t rom;
	size_t romlen;
	char *driver_override;
	long unsigned int priv_flags;
	u8 reset_methods[7];
};

enum kobject_action {
	KOBJ_ADD = 0,
	KOBJ_REMOVE = 1,
	KOBJ_CHANGE = 2,
	KOBJ_MOVE = 3,
	KOBJ_ONLINE = 4,
	KOBJ_OFFLINE = 5,
	KOBJ_BIND = 6,
	KOBJ_UNBIND = 7,
};

struct pci_slot___4 {
	struct pci_bus___4 *bus;
	struct list_head list;
	struct hotplug_slot *hotplug;
	unsigned char number;
	struct kobject___12 kobj;
};

struct pci_ops___4;

struct pci_bus___4 {
	struct list_head node;
	struct pci_bus___4 *parent;
	struct list_head children;
	struct list_head devices;
	struct pci_dev___4 *self;
	struct list_head slots;
	struct resource *resource[4];
	struct list_head resources;
	struct resource busn_res;
	struct pci_ops___4 *ops;
	void *sysdata;
	struct proc_dir_entry *procdir;
	unsigned char number;
	unsigned char primary;
	unsigned char max_bus_speed;
	unsigned char cur_bus_speed;
	char name[48];
	short unsigned int bridge_ctl;
	pci_bus_flags_t bus_flags;
	struct device___12 *bridge;
	struct device___12 dev;
	struct bin_attribute___12 *legacy_io;
	struct bin_attribute___12 *legacy_mem;
	unsigned int is_added: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct pci_error_handlers___4;

struct pci_driver___4 {
	struct list_head node;
	const char *name;
	const struct pci_device_id *id_table;
	int (*probe)(struct pci_dev___4 *, const struct pci_device_id *);
	void (*remove)(struct pci_dev___4 *);
	int (*suspend)(struct pci_dev___4 *, pm_message_t);
	int (*resume)(struct pci_dev___4 *);
	void (*shutdown)(struct pci_dev___4 *);
	int (*sriov_configure)(struct pci_dev___4 *, int);
	int (*sriov_set_msix_vec_count)(struct pci_dev___4 *, int);
	u32 (*sriov_get_vf_total_msix)(struct pci_dev___4 *);
	const struct pci_error_handlers___4 *err_handler;
	const struct attribute_group___12 **groups;
	const struct attribute_group___12 **dev_groups;
	struct device_driver___11 driver;
	struct pci_dynids dynids;
};

struct pci_ops___4 {
	int (*add_bus)(struct pci_bus___4 *);
	void (*remove_bus)(struct pci_bus___4 *);
	void * (*map_bus)(struct pci_bus___4 *, unsigned int, int);
	int (*read)(struct pci_bus___4 *, unsigned int, int, int, u32 *);
	int (*write)(struct pci_bus___4 *, unsigned int, int, int, u32);
};

struct pci_error_handlers___4 {
	pci_ers_result_t (*error_detected)(struct pci_dev___4 *, pci_channel_state_t);
	pci_ers_result_t (*mmio_enabled)(struct pci_dev___4 *);
	pci_ers_result_t (*slot_reset)(struct pci_dev___4 *);
	void (*reset_prepare)(struct pci_dev___4 *);
	void (*reset_done)(struct pci_dev___4 *);
	void (*resume)(struct pci_dev___4 *);
};

struct threshold_block___2 {
	unsigned int block;
	unsigned int bank;
	unsigned int cpu;
	u32 address;
	u16 interrupt_enable;
	bool interrupt_capable;
	u16 threshold_limit;
	struct kobject___12 kobj;
	struct list_head miscj;
};

struct threshold_bank___2 {
	struct kobject___12 *kobj;
	struct threshold_block___2 *blocks;
	refcount_t cpus;
	unsigned int shared;
};

struct amd_northbridge___2 {
	struct pci_dev___4 *root;
	struct pci_dev___4 *misc;
	struct pci_dev___4 *link;
	struct amd_l3_cache l3_cache;
	struct threshold_bank___2 *bank4;
};

enum smca_bank_types {
	SMCA_LS = 0,
	SMCA_LS_V2 = 1,
	SMCA_IF = 2,
	SMCA_L2_CACHE = 3,
	SMCA_DE = 4,
	SMCA_RESERVED = 5,
	SMCA_EX = 6,
	SMCA_FP = 7,
	SMCA_L3_CACHE = 8,
	SMCA_CS = 9,
	SMCA_CS_V2 = 10,
	SMCA_PIE = 11,
	SMCA_UMC = 12,
	SMCA_UMC_V2 = 13,
	SMCA_PB = 14,
	SMCA_PSP = 15,
	SMCA_PSP_V2 = 16,
	SMCA_SMU = 17,
	SMCA_SMU_V2 = 18,
	SMCA_MP5 = 19,
	SMCA_NBIO = 20,
	SMCA_PCIE = 21,
	SMCA_PCIE_V2 = 22,
	SMCA_XGMI_PCS = 23,
	SMCA_XGMI_PHY = 24,
	SMCA_WAFL_PHY = 25,
	N_SMCA_BANK_TYPES = 26,
};

struct smca_hwid {
	unsigned int bank_type;
	u32 hwid_mcatype;
	u8 count;
};

struct smca_bank {
	struct smca_hwid *hwid;
	u32 id;
	u8 sysfs_id;
};

struct smca_bank_name {
	const char *name;
	const char *long_name;
};

struct thresh_restart {
	struct threshold_block___2 *b;
	int reset;
	int set_lvt_off;
	int lvt_off;
	u16 old_limit;
};

struct threshold_attr {
	struct attribute attr;
	ssize_t (*show)(struct threshold_block___2 *, char *);
	ssize_t (*store)(struct threshold_block___2 *, const char *, size_t);
};

enum {
	CPER_SEV_RECOVERABLE = 0,
	CPER_SEV_FATAL = 1,
	CPER_SEV_CORRECTED = 2,
	CPER_SEV_INFORMATIONAL = 3,
};

struct cper_record_header {
	char signature[4];
	u16 revision;
	u32 signature_end;
	u16 section_count;
	u32 error_severity;
	u32 validation_bits;
	u32 record_length;
	u64 timestamp;
	guid_t platform_id;
	guid_t partition_id;
	guid_t creator_id;
	guid_t notification_type;
	u64 record_id;
	u32 flags;
	u64 persistence_information;
	u8 reserved[12];
} __attribute__((packed));

struct cper_section_descriptor {
	u32 section_offset;
	u32 section_length;
	u16 revision;
	u8 validation_bits;
	u8 reserved;
	u32 flags;
	guid_t section_type;
	guid_t fru_id;
	u32 section_severity;
	u8 fru_text[20];
};

struct cper_ia_proc_ctx {
	u16 reg_ctx_type;
	u16 reg_arr_size;
	u32 msr_addr;
	u64 mm_reg_addr;
};

struct cper_sec_mem_err {
	u64 validation_bits;
	u64 error_status;
	u64 physical_addr;
	u64 physical_addr_mask;
	u16 node;
	u16 card;
	u16 module;
	u16 bank;
	u16 device;
	u16 row;
	u16 column;
	u16 bit_pos;
	u64 requestor_id;
	u64 responder_id;
	u64 target_id;
	u8 error_type;
	u8 extended;
	u16 rank;
	u16 mem_array_handle;
	u16 mem_dev_handle;
};

enum {
	GHES_SEV_NO = 0,
	GHES_SEV_CORRECTED = 1,
	GHES_SEV_RECOVERABLE = 2,
	GHES_SEV_PANIC = 3,
};

struct cper_mce_record {
	struct cper_record_header hdr;
	struct cper_section_descriptor sec_hdr;
	struct mce mce;
};

struct miscdevice {
	int minor;
	const char *name;
	const struct file_operations___13 *fops;
	struct list_head list;
	struct device___2 *parent;
	struct device___2 *this_device;
	const struct attribute_group___14 **groups;
	const char *nodename;
	umode_t mode;
};

typedef struct poll_table_struct___10 poll_table;

struct mce_log_buffer {
	char signature[12];
	unsigned int len;
	unsigned int next;
	unsigned int flags;
	unsigned int recordlen;
	struct mce entry[0];
};

typedef int (*cpu_stop_fn_t)(void *);

typedef __u8 mtrr_type;

struct mtrr_ops {
	u32 vendor;
	u32 use_intel_if;
	void (*set)(unsigned int, long unsigned int, long unsigned int, mtrr_type);
	void (*set_all)();
	void (*get)(unsigned int, long unsigned int *, long unsigned int *, mtrr_type *);
	int (*get_free_region)(long unsigned int, long unsigned int, int);
	int (*validate_add_page)(long unsigned int, long unsigned int, unsigned int);
	int (*have_wrcomb)();
};

struct set_mtrr_data {
	long unsigned int smp_base;
	long unsigned int smp_size;
	unsigned int smp_reg;
	mtrr_type smp_type;
};

struct mtrr_value {
	mtrr_type ltype;
	long unsigned int lbase;
	long unsigned int lsize;
};

struct proc_ops {
	unsigned int proc_flags;
	int (*proc_open)(struct inode___13 *, struct file___13 *);
	ssize_t (*proc_read)(struct file___13 *, char *, size_t, loff_t *);
	ssize_t (*proc_read_iter)(struct kiocb___13 *, struct iov_iter___11 *);
	ssize_t (*proc_write)(struct file___13 *, const char *, size_t, loff_t *);
	loff_t (*proc_lseek)(struct file___13 *, loff_t, int);
	int (*proc_release)(struct inode___13 *, struct file___13 *);
	__poll_t (*proc_poll)(struct file___13 *, struct poll_table_struct *);
	long int (*proc_ioctl)(struct file___13 *, unsigned int, long unsigned int);
	long int (*proc_compat_ioctl)(struct file___13 *, unsigned int, long unsigned int);
	int (*proc_mmap)(struct file___13 *, struct vm_area_struct___15 *);
	long unsigned int (*proc_get_unmapped_area)(struct file___13 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
};

struct mtrr_sentry {
	__u64 base;
	__u32 size;
	__u32 type;
};

struct mtrr_gentry {
	__u64 base;
	__u32 size;
	__u32 regnum;
	__u32 type;
	__u32 _pad;
};

typedef u32 compat_uint_t;

struct mtrr_sentry32 {
	compat_ulong_t base;
	compat_uint_t size;
	compat_uint_t type;
};

struct mtrr_gentry32 {
	compat_ulong_t regnum;
	compat_uint_t base;
	compat_uint_t size;
	compat_uint_t type;
};

struct mtrr_var_range {
	__u32 base_lo;
	__u32 base_hi;
	__u32 mask_lo;
	__u32 mask_hi;
};

struct mtrr_state_type {
	struct mtrr_var_range var_ranges[256];
	mtrr_type fixed_ranges[88];
	unsigned char enabled;
	unsigned char have_fixed;
	mtrr_type def_type;
};

struct fixed_range_block {
	int base_msr;
	int ranges;
};

struct var_mtrr_range_state {
	long unsigned int base_pfn;
	long unsigned int size_pfn;
	mtrr_type type;
};

struct var_mtrr_state {
	long unsigned int range_startk;
	long unsigned int range_sizek;
	long unsigned int chunk_sizek;
	long unsigned int gran_sizek;
	unsigned int reg;
};

struct mtrr_cleanup_result {
	long unsigned int gran_sizek;
	long unsigned int chunk_sizek;
	long unsigned int lose_cover_sizek;
	unsigned int num_reg;
	int bad;
};

struct subsys_interface {
	const char *name;
	struct bus_type___12 *subsys;
	struct list_head node;
	int (*add_dev)(struct device___13 *, struct subsys_interface *);
	void (*remove_dev)(struct device___13 *, struct subsys_interface *);
};

struct platform_device___2 {
	const char *name;
	int id;
	bool id_auto;
	struct device___13 dev;
	u64 platform_dma_mask;
	struct device_dma_parameters dma_parms;
	u32 num_resources;
	struct resource *resource;
	const struct platform_device_id *id_entry;
	char *driver_override;
	struct mfd_cell *mfd_cell;
	struct pdev_archdata archdata;
};

struct property_entry;

struct platform_device_info {
	struct device___13 *parent;
	struct fwnode_handle___11 *fwnode;
	bool of_node_reused;
	const char *name;
	int id;
	const struct resource *res;
	unsigned int num_res;
	const void *data;
	size_t size_data;
	u64 dma_mask;
	const struct property_entry *properties;
};

struct miscdevice___2 {
	int minor;
	const char *name;
	const struct file_operations___2 *fops;
	struct list_head list;
	struct device___13 *parent;
	struct device___13 *this_device;
	const struct attribute_group **groups;
	const char *nodename;
	umode_t mode;
};

struct builtin_fw {
	char *name;
	void *data;
	long unsigned int size;
};

struct cpio_data {
	void *data;
	size_t size;
	char name[18];
};

struct cpu_signature {
	unsigned int sig;
	unsigned int pf;
	unsigned int rev;
};

enum ucode_state {
	UCODE_OK = 0,
	UCODE_NEW = 1,
	UCODE_UPDATED = 2,
	UCODE_NFOUND = 3,
	UCODE_ERROR = 4,
};

struct microcode_ops {
	enum ucode_state (*request_microcode_user)(int, const void *, size_t);
	enum ucode_state (*request_microcode_fw)(int, struct device___13 *, bool);
	void (*microcode_fini_cpu)(int);
	enum ucode_state (*apply_microcode)(int);
	int (*collect_cpu_info)(int, struct cpu_signature *);
};

struct ucode_cpu_info {
	struct cpu_signature cpu_sig;
	int valid;
	void *mc;
};

struct cpu_info_ctx {
	struct cpu_signature *cpu_sig;
	int err;
};

struct firmware {
	size_t size;
	const u8 *data;
	void *priv;
};

struct ucode_patch {
	struct list_head plist;
	void *data;
	u32 patch_id;
	u16 equiv_cpu;
};

struct microcode_header_intel {
	unsigned int hdrver;
	unsigned int rev;
	unsigned int date;
	unsigned int sig;
	unsigned int cksum;
	unsigned int ldrver;
	unsigned int pf;
	unsigned int datasize;
	unsigned int totalsize;
	unsigned int reserved[3];
};

struct microcode_intel {
	struct microcode_header_intel hdr;
	unsigned int bits[0];
};

struct extended_signature {
	unsigned int sig;
	unsigned int pf;
	unsigned int cksum;
};

struct extended_sigtable {
	unsigned int count;
	unsigned int cksum;
	unsigned int reserved[3];
	struct extended_signature sigs[0];
};

struct equiv_cpu_entry {
	u32 installed_cpu;
	u32 fixed_errata_mask;
	u32 fixed_errata_compare;
	u16 equiv_cpu;
	u16 res;
};

struct microcode_header_amd {
	u32 data_code;
	u32 patch_id;
	u16 mc_patch_data_id;
	u8 mc_patch_data_len;
	u8 init_flag;
	u32 mc_patch_data_checksum;
	u32 nb_dev_id;
	u32 sb_dev_id;
	u16 processor_rev_id;
	u8 nb_rev_id;
	u8 sb_rev_id;
	u8 bios_api_rev;
	u8 reserved1[3];
	u32 match_reg[8];
};

struct microcode_amd {
	struct microcode_header_amd hdr;
	unsigned int mpb[0];
};

struct equiv_cpu_table {
	unsigned int num_entries;
	struct equiv_cpu_entry *entry;
};

struct cont_desc {
	struct microcode_amd *mc;
	u32 cpuid_1_eax;
	u32 psize;
	u8 *data;
	size_t size;
};

struct fs_context___3;

struct dentry___16;

struct super_block___16;

struct file_system_type___16 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context___3 *);
	const struct fs_parameter_spec *parameters;
	struct dentry___16 * (*mount)(struct file_system_type___16 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___16 *);
	struct module *owner;
	struct file_system_type___16 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___16;

struct kiocb___16;

struct vm_area_struct___18;

struct inode___16;

struct file_lock___16;

struct page___17;

struct file_operations___16 {
	struct module *owner;
	loff_t (*llseek)(struct file___16 *, loff_t, int);
	ssize_t (*read)(struct file___16 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___16 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___16 *, struct iov_iter *);
	ssize_t (*write_iter)(struct kiocb___16 *, struct iov_iter *);
	int (*iopoll)(struct kiocb___16 *, bool);
	int (*iterate)(struct file___16 *, struct dir_context *);
	int (*iterate_shared)(struct file___16 *, struct dir_context *);
	__poll_t (*poll)(struct file___16 *, struct poll_table_struct *);
	long int (*unlocked_ioctl)(struct file___16 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___16 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___16 *, struct vm_area_struct___18 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___16 *, struct file___16 *);
	int (*flush)(struct file___16 *, fl_owner_t);
	int (*release)(struct inode___16 *, struct file___16 *);
	int (*fsync)(struct file___16 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___16 *, int);
	int (*lock)(struct file___16 *, int, struct file_lock___16 *);
	ssize_t (*sendpage)(struct file___16 *, struct page___17 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___16 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___16 *, long unsigned int);
	int (*flock)(struct file___16 *, int, struct file_lock___16 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___16 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___16 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___16 *, long int, struct file_lock___16 **, void **);
	long int (*fallocate)(struct file___16 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file *, struct file___16 *);
	ssize_t (*copy_file_range)(struct file___16 *, loff_t, struct file___16 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___16 *, loff_t, struct file___16 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___16 *, loff_t, loff_t, int);
};

union rcu_special___2 {
	struct {
		u8 blocked;
		u8 need_qs;
		u8 exp_hint;
		u8 need_mb;
	} b;
	u32 s;
};

struct vmacache___17 {
	u64 seqnum;
	struct vm_area_struct___18 *vmas[4];
};

struct page_frag___17 {
	struct page___17 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___18;

struct signal_struct___17;

struct task_struct___19 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___19 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special___2 trc_reader_special;
	int: 32;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___18 *mm;
	struct mm_struct___18 *active_mm;
	struct vmacache___17 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int restore_sigmask: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___19 *real_parent;
	struct task_struct___19 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___19 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___14 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	struct posix_cputimers_work posix_cputimers_work;
	const struct cred *ptracer_cred;
	const struct cred *real_cred;
	const struct cred *cred;
	struct key *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy *nsproxy;
	struct signal_struct___17 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___19 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context___11 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set *cgroups;
	struct list_head cg_list;
	u32 closid;
	u32 rmid;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	long: 64;
	long: 64;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___17 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup *active_memcg;
	struct request_queue *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___19 *oom_reaper_list;
	struct vm_struct___3 *stack_vm_area;
	refcount_t stack_refcount;
	int patch_state;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	void *mce_vaddr;
	__u64 mce_kflags;
	u64 mce_addr;
	__u64 mce_ripv: 1;
	__u64 mce_whole_page: 1;
	__u64 __mce_reserved: 62;
	long: 2;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct callback_head mce_kill_me;
	int mce_count;
	struct llist_head kretprobe_instances;
	struct callback_head l1d_flush_kill;
	long: 64;
	struct thread_struct___9 thread;
};

typedef struct page___17 *pgtable_t___17;

struct address_space___16;

struct dev_pagemap___16;

struct page___17 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___16 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___4 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___17 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___17 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___18 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___16 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct pv_cpu_ops___13 {
	void (*io_delay)();
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	void (*write_cr4)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___9 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(long unsigned int);
	void (*invalidate_io_bitmap)();
	void (*update_io_bitmap)();
	void (*wbinvd)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int);
	void (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_msr_safe)(unsigned int, int *);
	int (*write_msr_safe)(unsigned int, unsigned int, unsigned int);
	u64 (*read_pmc)(int);
	void (*start_context_switch)(struct task_struct___19 *);
	void (*end_context_switch)(struct task_struct___19 *);
};

struct pv_mmu_ops___13 {
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_one_user)(long unsigned int);
	void (*flush_tlb_multi)(const struct cpumask *, const struct flush_tlb_info___3 *);
	void (*tlb_remove_table)(struct mmu_gather *, void *);
	void (*exit_mmap)(struct mm_struct___18 *);
	struct paravirt_callee_save read_cr2;
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___18 *, struct mm_struct___18 *);
	void (*dup_mmap)(struct mm_struct___18 *, struct mm_struct___18 *);
	int (*pgd_alloc)(struct mm_struct___18 *);
	void (*pgd_free)(struct mm_struct___18 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___18 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___18 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___18 *, long unsigned int);
	void (*alloc_p4d)(struct mm_struct___18 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*release_p4d)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	pte_t (*ptep_modify_prot_start)(struct vm_area_struct___18 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct vm_area_struct___18 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_p4d)(p4d_t *, p4d_t);
	struct paravirt_callee_save p4d_val;
	struct paravirt_callee_save make_p4d;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

struct core_state___17;

struct mm_struct___18 {
	struct {
		struct vm_area_struct___18 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___16 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int mmap_compat_base;
		long unsigned int mmap_compat_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[48];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___17 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___19 *owner;
		struct user_namespace *user_ns;
		struct file___16 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		bool tlb_flush_batched;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct vm_operations_struct___16;

struct vm_area_struct___18 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___18 *vm_next;
	struct vm_area_struct___18 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___18 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___16 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___16 *vm_file;
	struct file___16 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct paravirt_patch_template___13 {
	struct pv_cpu_ops___13 cpu;
	struct pv_irq_ops irq;
	struct pv_mmu_ops___13 mmu;
	struct pv_lock_ops lock;
};

struct address_space_operations___16;

struct address_space___16 {
	struct inode___16 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___16 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct dev_pagemap_ops___16;

struct dev_pagemap___16 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___16 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vfsmount___16;

struct path___16 {
	struct vfsmount___16 *mnt;
	struct dentry___16 *dentry;
};

struct file___16 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	long: 64;
	long: 64;
	struct path___16 f_path;
	struct inode___16 *f_inode;
	const struct file_operations___16 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___14 f_owner;
	const struct cred *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___16 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___16;

struct vm_operations_struct___16 {
	void (*open)(struct vm_area_struct___18 *);
	void (*close)(struct vm_area_struct___18 *);
	int (*may_split)(struct vm_area_struct___18 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___18 *);
	int (*mprotect)(struct vm_area_struct___18 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___16 *);
	vm_fault_t (*huge_fault)(struct vm_fault___16 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___16 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___18 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___16 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___16 *);
	int (*access)(struct vm_area_struct___18 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___18 *);
	int (*set_policy)(struct vm_area_struct___18 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___18 *, long unsigned int);
	struct page___17 * (*find_special_page)(struct vm_area_struct___18 *, long unsigned int);
};

struct core_thread___17 {
	struct task_struct___19 *task;
	struct core_thread___17 *next;
};

struct core_state___17 {
	atomic_t nr_threads;
	struct core_thread___17 dumper;
	struct completion startup;
};

struct vm_fault___16 {
	const struct {
		struct vm_area_struct___18 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___17 *cow_page;
	struct page___17 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___17 prealloc_pte;
};

struct signal_struct___17 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___19 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___19 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___14 *pids[4];
	struct pid___14 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___18 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct kernfs_root___16;

struct kernfs_elem_dir___16 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___16 *root;
	long unsigned int rev;
};

struct kernfs_node___16;

struct kernfs_syscall_ops___16;

struct kernfs_root___16 {
	struct kernfs_node___16 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___16 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___16 {
	struct kernfs_node___16 *target_kn;
};

struct kernfs_ops___16;

struct kernfs_elem_attr___16 {
	const struct kernfs_ops___16 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___16 *notify_next;
};

struct kernfs_node___16 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___16 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___16 dir;
		struct kernfs_elem_symlink___16 symlink;
		struct kernfs_elem_attr___16 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___16;

struct kernfs_ops___16 {
	int (*open)(struct kernfs_open_file___16 *);
	void (*release)(struct kernfs_open_file___16 *);
	int (*seq_show)(struct seq_file *, void *);
	void * (*seq_start)(struct seq_file *, loff_t *);
	void * (*seq_next)(struct seq_file *, void *, loff_t *);
	void (*seq_stop)(struct seq_file *, void *);
	ssize_t (*read)(struct kernfs_open_file___16 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___16 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___16 *, struct poll_table_struct *);
	int (*mmap)(struct kernfs_open_file___16 *, struct vm_area_struct___18 *);
};

struct kernfs_syscall_ops___16 {
	int (*show_options)(struct seq_file *, struct kernfs_root___16 *);
	int (*mkdir)(struct kernfs_node___16 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___16 *);
	int (*rename)(struct kernfs_node___16 *, struct kernfs_node___16 *, const char *);
	int (*show_path)(struct seq_file *, struct kernfs_node___16 *, struct kernfs_root___16 *);
};

struct kernfs_open_file___16 {
	struct kernfs_node___16 *kn;
	struct file___16 *file;
	struct seq_file *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___16 *vm_ops;
};

enum resctrl_conf_type {
	CDP_NONE = 0,
	CDP_CODE = 1,
	CDP_DATA = 2,
};

struct resctrl_staged_config {
	u32 new_ctrl;
	bool have_new_ctrl;
};

struct mbm_state;

struct pseudo_lock_region;

struct rdt_domain {
	struct list_head list;
	int id;
	struct cpumask cpu_mask;
	long unsigned int *rmid_busy_llc;
	struct mbm_state *mbm_total;
	struct mbm_state *mbm_local;
	struct delayed_work mbm_over;
	struct delayed_work cqm_limbo;
	int mbm_work_cpu;
	int cqm_work_cpu;
	struct pseudo_lock_region *plr;
	struct resctrl_staged_config staged_config[3];
};

struct mbm_state {
	u64 chunks;
	u64 prev_msr;
	u64 prev_bw_msr;
	u32 prev_bw;
	u32 delta_bw;
	bool delta_comp;
};

struct resctrl_schema;

struct pseudo_lock_region {
	struct resctrl_schema *s;
	struct rdt_domain *d;
	u32 cbm;
	wait_queue_head_t lock_thread_wq;
	int thread_done;
	int cpu;
	unsigned int line_size;
	unsigned int size;
	void *kmem;
	unsigned int minor;
	struct dentry___16 *debugfs_dir;
	struct list_head pm_reqs;
};

struct resctrl_cache {
	unsigned int cbm_len;
	unsigned int min_cbm_bits;
	unsigned int shareable_bits;
	bool arch_has_sparse_bitmaps;
	bool arch_has_empty_bitmaps;
	bool arch_has_per_cpu_cfg;
};

enum membw_throttle_mode {
	THREAD_THROTTLE_UNDEFINED = 0,
	THREAD_THROTTLE_MAX = 1,
	THREAD_THROTTLE_PER_THREAD = 2,
};

struct resctrl_membw {
	u32 min_bw;
	u32 bw_gran;
	u32 delay_linear;
	bool arch_needs_linear;
	enum membw_throttle_mode throttle_mode;
	bool mba_sc;
	u32 *mb_map;
};

struct rdt_parse_data;

struct rdt_resource {
	int rid;
	bool alloc_enabled;
	bool mon_enabled;
	bool alloc_capable;
	bool mon_capable;
	int num_rmid;
	int cache_level;
	struct resctrl_cache cache;
	struct resctrl_membw membw;
	struct list_head domains;
	char *name;
	int data_width;
	u32 default_ctrl;
	const char *format_str;
	int (*parse_ctrlval)(struct rdt_parse_data *, struct resctrl_schema *, struct rdt_domain *);
	struct list_head evt_list;
	long unsigned int fflags;
	bool cdp_capable;
};

struct rdtgroup;

struct rdt_parse_data {
	struct rdtgroup *rdtgrp;
	char *buf;
};

struct resctrl_schema {
	struct list_head list;
	char name[8];
	enum resctrl_conf_type conf_type;
	struct rdt_resource *res;
	u32 num_closid;
};

struct dentry_operations___16;

struct dentry___16 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___16 *d_parent;
	struct qstr d_name;
	struct inode___16 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___16 *d_op;
	struct super_block___16 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___16;

struct inode___16 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___16 *i_op;
	struct super_block___16 *i_sb;
	struct address_space___16 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	long: 64;
	long: 64;
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___16 *i_fop;
		void (*free_inode)(struct inode___16 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___16 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___4 *i_pipe;
		struct cdev *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___16 {
	int (*d_revalidate)(struct dentry___16 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___16 *, unsigned int);
	int (*d_hash)(const struct dentry___16 *, struct qstr *);
	int (*d_compare)(const struct dentry___16 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___16 *);
	int (*d_init)(struct dentry___16 *);
	void (*d_release)(struct dentry___16 *);
	void (*d_prune)(struct dentry___16 *);
	void (*d_iput)(struct dentry___16 *, struct inode___16 *);
	char * (*d_dname)(struct dentry___16 *, char *, int);
	struct vfsmount___16 * (*d_automount)(struct path___16 *);
	int (*d_manage)(const struct path___16 *, bool);
	struct dentry___16 * (*d_real)(struct dentry___16 *, const struct inode___16 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___16;

struct mem_dqinfo___16 {
	struct quota_format_type___16 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___16;

struct quota_info___16 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___16 *files[3];
	struct mem_dqinfo___16 info[3];
	const struct quota_format_ops___16 *ops[3];
};

struct rcuwait___16 {
	struct task_struct___19 *task;
};

struct percpu_rw_semaphore___16 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___16 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___16 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___16 rw_sem[3];
};

struct super_operations___16;

struct dquot_operations___16;

struct quotactl_ops___16;

struct super_block___16 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___16 *s_type;
	const struct super_operations___16 *s_op;
	const struct dquot_operations___16 *dq_op;
	const struct quotactl_ops___16 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___16 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device *s_bdev;
	struct backing_dev_info *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___16 s_dquot;
	struct sb_writers___16 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___16 *s_d_op;
	int cleancache_poolid;
	struct shrinker___9 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___16 {
	struct dentry___16 *mnt_root;
	struct super_block___16 *mnt_sb;
	int mnt_flags;
	struct user_namespace *mnt_userns;
};

struct kiocb___16 {
	struct file___16 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___16 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___9 *ki_waitq;
	};
};

struct iattr___16 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___16 *ia_file;
};

struct dquot___16 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___16 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___16 {
	int qf_fmt_id;
	const struct quota_format_ops___16 *qf_ops;
	struct module *qf_owner;
	struct quota_format_type___16 *qf_next;
};

struct quota_format_ops___16 {
	int (*check_quota_file)(struct super_block___16 *, int);
	int (*read_file_info)(struct super_block___16 *, int);
	int (*write_file_info)(struct super_block___16 *, int);
	int (*free_file_info)(struct super_block___16 *, int);
	int (*read_dqblk)(struct dquot___16 *);
	int (*commit_dqblk)(struct dquot___16 *);
	int (*release_dqblk)(struct dquot___16 *);
	int (*get_next_id)(struct super_block___16 *, struct kqid *);
};

struct dquot_operations___16 {
	int (*write_dquot)(struct dquot___16 *);
	struct dquot___16 * (*alloc_dquot)(struct super_block___16 *, int);
	void (*destroy_dquot)(struct dquot___16 *);
	int (*acquire_dquot)(struct dquot___16 *);
	int (*release_dquot)(struct dquot___16 *);
	int (*mark_dirty)(struct dquot___16 *);
	int (*write_info)(struct super_block___16 *, int);
	qsize_t * (*get_reserved_space)(struct inode___16 *);
	int (*get_projid)(struct inode___16 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___16 *, qsize_t *);
	int (*get_next_id)(struct super_block___16 *, struct kqid *);
};

struct quotactl_ops___16 {
	int (*quota_on)(struct super_block___16 *, int, int, const struct path___16 *);
	int (*quota_off)(struct super_block___16 *, int);
	int (*quota_enable)(struct super_block___16 *, unsigned int);
	int (*quota_disable)(struct super_block___16 *, unsigned int);
	int (*quota_sync)(struct super_block___16 *, int);
	int (*set_info)(struct super_block___16 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___16 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___16 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___16 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___16 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___16 *, unsigned int);
};

struct address_space_operations___16 {
	int (*writepage)(struct page___17 *, struct writeback_control *);
	int (*readpage)(struct file___16 *, struct page___17 *);
	int (*writepages)(struct address_space___16 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___17 *);
	int (*readpages)(struct file___16 *, struct address_space___16 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control *);
	int (*write_begin)(struct file___16 *, struct address_space___16 *, loff_t, unsigned int, unsigned int, struct page___17 **, void **);
	int (*write_end)(struct file___16 *, struct address_space___16 *, loff_t, unsigned int, unsigned int, struct page___17 *, void *);
	sector_t (*bmap)(struct address_space___16 *, sector_t);
	void (*invalidatepage)(struct page___17 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___17 *, gfp_t);
	void (*freepage)(struct page___17 *);
	ssize_t (*direct_IO)(struct kiocb___16 *, struct iov_iter *);
	int (*migratepage)(struct address_space___16 *, struct page___17 *, struct page___17 *, enum migrate_mode);
	bool (*isolate_page)(struct page___17 *, isolate_mode_t);
	void (*putback_page)(struct page___17 *);
	int (*launder_page)(struct page___17 *);
	int (*is_partially_uptodate)(struct page___17 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___17 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___16 *, struct page___17 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___16 *, sector_t *);
	void (*swap_deactivate)(struct file___16 *);
};

struct inode_operations___16 {
	struct dentry___16 * (*lookup)(struct inode___16 *, struct dentry___16 *, unsigned int);
	const char * (*get_link)(struct dentry___16 *, struct inode___16 *, struct delayed_call *);
	int (*permission)(struct user_namespace *, struct inode___16 *, int);
	struct posix_acl * (*get_acl)(struct inode___16 *, int, bool);
	int (*readlink)(struct dentry___16 *, char *, int);
	int (*create)(struct user_namespace *, struct inode___16 *, struct dentry___16 *, umode_t, bool);
	int (*link)(struct dentry___16 *, struct inode___16 *, struct dentry___16 *);
	int (*unlink)(struct inode___16 *, struct dentry___16 *);
	int (*symlink)(struct user_namespace *, struct inode___16 *, struct dentry___16 *, const char *);
	int (*mkdir)(struct user_namespace *, struct inode___16 *, struct dentry___16 *, umode_t);
	int (*rmdir)(struct inode___16 *, struct dentry___16 *);
	int (*mknod)(struct user_namespace *, struct inode___16 *, struct dentry___16 *, umode_t, dev_t);
	int (*rename)(struct user_namespace *, struct inode___16 *, struct dentry___16 *, struct inode___16 *, struct dentry___16 *, unsigned int);
	int (*setattr)(struct user_namespace *, struct dentry___16 *, struct iattr___16 *);
	int (*getattr)(struct user_namespace *, const struct path___16 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___16 *, char *, size_t);
	int (*fiemap)(struct inode___16 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___16 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___16 *, struct dentry___16 *, struct file___16 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace *, struct inode___16 *, struct dentry___16 *, umode_t);
	int (*set_acl)(struct user_namespace *, struct inode___16 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace *, struct dentry___16 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___16 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___16 {
	void (*fl_copy_lock)(struct file_lock___16 *, struct file_lock___16 *);
	void (*fl_release_private)(struct file_lock___16 *);
};

struct fasync_struct___16;

struct lock_manager_operations___16;

struct file_lock___16 {
	struct file_lock___16 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___16 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___16 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___16 *fl_ops;
	const struct lock_manager_operations___16 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___16 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___16 *);
	int (*lm_grant)(struct file_lock___16 *, int);
	bool (*lm_break)(struct file_lock___16 *);
	int (*lm_change)(struct file_lock___16 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___16 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___16 *);
};

struct fasync_struct___16 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___16 *fa_next;
	struct file___16 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___16 {
	struct inode___16 * (*alloc_inode)(struct super_block___16 *);
	void (*destroy_inode)(struct inode___16 *);
	void (*free_inode)(struct inode___16 *);
	void (*dirty_inode)(struct inode___16 *, int);
	int (*write_inode)(struct inode___16 *, struct writeback_control *);
	int (*drop_inode)(struct inode___16 *);
	void (*evict_inode)(struct inode___16 *);
	void (*put_super)(struct super_block___16 *);
	int (*sync_fs)(struct super_block___16 *, int);
	int (*freeze_super)(struct super_block___16 *);
	int (*freeze_fs)(struct super_block___16 *);
	int (*thaw_super)(struct super_block___16 *);
	int (*unfreeze_fs)(struct super_block___16 *);
	int (*statfs)(struct dentry___16 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___16 *, int *, char *);
	void (*umount_begin)(struct super_block___16 *);
	int (*show_options)(struct seq_file *, struct dentry___16 *);
	int (*show_devname)(struct seq_file *, struct dentry___16 *);
	int (*show_path)(struct seq_file *, struct dentry___16 *);
	int (*show_stats)(struct seq_file *, struct dentry___16 *);
	ssize_t (*quota_read)(struct super_block___16 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___16 *, int, const char *, size_t, loff_t);
	struct dquot___16 ** (*get_dquots)(struct inode___16 *);
	long int (*nr_cached_objects)(struct super_block___16 *, struct shrink_control___9 *);
	long int (*free_cached_objects)(struct super_block___16 *, struct shrink_control___9 *);
	struct file___16 * (*real_loop)(struct file___16 *);
};

struct fs_context_operations___3;

struct fs_context___3 {
	const struct fs_context_operations___3 *ops;
	struct mutex uapi_mutex;
	struct file_system_type___16 *fs_type;
	void *fs_private;
	void *sget_key;
	struct dentry___16 *root;
	struct user_namespace *user_ns;
	struct net *net_ns;
	const struct cred *cred;
	struct p_log log;
	const char *source;
	void *security;
	void *s_fs_info;
	unsigned int sb_flags;
	unsigned int sb_flags_mask;
	unsigned int s_iflags;
	unsigned int lsm_flags;
	enum fs_context_purpose purpose: 8;
	enum fs_context_phase phase: 8;
	bool need_free: 1;
	bool global: 1;
	bool oldapi: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pagemap_ops___16 {
	void (*page_free)(struct page___17 *);
	void (*kill)(struct dev_pagemap___16 *);
	void (*cleanup)(struct dev_pagemap___16 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___16 *);
};

struct fs_parameter___3 {
	const char *key;
	enum fs_value_type type: 8;
	long: 56;
	long: 64;
	union {
		char *string;
		void *blob;
		struct filename *name;
		struct file___16 *file;
	};
	size_t size;
	int dirfd;
};

struct fs_context_operations___3 {
	void (*free)(struct fs_context___3 *);
	int (*dup)(struct fs_context___3 *, struct fs_context___3 *);
	int (*parse_param)(struct fs_context___3 *, struct fs_parameter___3 *);
	int (*parse_monolithic)(struct fs_context___3 *, void *);
	int (*get_tree)(struct fs_context___3 *);
	int (*reconfigure)(struct fs_context___3 *);
};

enum rdt_group_type {
	RDTCTRL_GROUP = 0,
	RDTMON_GROUP = 1,
	RDT_NUM_GROUP = 2,
};

struct mongroup {
	struct kernfs_node___16 *mon_data_kn;
	struct rdtgroup *parent;
	struct list_head crdtgrp_list;
	u32 rmid;
};

enum rdtgrp_mode {
	RDT_MODE_SHAREABLE = 0,
	RDT_MODE_EXCLUSIVE = 1,
	RDT_MODE_PSEUDO_LOCKSETUP = 2,
	RDT_MODE_PSEUDO_LOCKED = 3,
	RDT_NUM_MODES = 4,
};

struct rdtgroup {
	struct kernfs_node___16 *kn;
	struct list_head rdtgroup_list;
	u32 closid;
	struct cpumask cpu_mask;
	int flags;
	atomic_t waitcount;
	enum rdt_group_type type;
	struct mongroup mon;
	enum rdtgrp_mode mode;
	struct pseudo_lock_region *plr;
};

struct rdt_hw_domain {
	struct rdt_domain d_resctrl;
	u32 *ctrl_val;
	u32 *mbps_val;
};

struct msr_param {
	struct rdt_resource *res;
	u32 low;
	u32 high;
};

struct rdt_hw_resource {
	struct rdt_resource r_resctrl;
	u32 num_closid;
	unsigned int msr_base;
	void (*msr_update)(struct rdt_domain *, struct msr_param *, struct rdt_resource *);
	unsigned int mon_scale;
	unsigned int mbm_width;
	bool cdp_enabled;
};

enum resctrl_res_level {
	RDT_RESOURCE_L3 = 0,
	RDT_RESOURCE_L2 = 1,
	RDT_RESOURCE_MBA = 2,
	RDT_NUM_RESOURCES = 3,
};

union cpuid_0x10_1_eax {
	struct {
		unsigned int cbm_len: 5;
	} split;
	unsigned int full;
};

union cpuid_0x10_3_eax {
	struct {
		unsigned int max_delay: 12;
	} split;
	unsigned int full;
};

union cpuid_0x10_x_edx {
	struct {
		unsigned int cos_max: 16;
	} split;
	unsigned int full;
};

enum {
	RDT_FLAG_CMT = 0,
	RDT_FLAG_MBM_TOTAL = 1,
	RDT_FLAG_MBM_LOCAL = 2,
	RDT_FLAG_L3_CAT = 3,
	RDT_FLAG_L3_CDP = 4,
	RDT_FLAG_L2_CAT = 5,
	RDT_FLAG_L2_CDP = 6,
	RDT_FLAG_MBA = 7,
};

struct rdt_options {
	char *name;
	int flag;
	bool force_off;
	bool force_on;
};

typedef unsigned int uint;

enum kernfs_node_type {
	KERNFS_DIR = 1,
	KERNFS_FILE = 2,
	KERNFS_LINK = 4,
};

enum kernfs_root_flag {
	KERNFS_ROOT_CREATE_DEACTIVATED = 1,
	KERNFS_ROOT_EXTRA_OPEN_PERM_CHECK = 2,
	KERNFS_ROOT_SUPPORT_EXPORTOP = 4,
	KERNFS_ROOT_SUPPORT_USER_XATTR = 8,
};

struct kernfs_fs_context {
	struct kernfs_root *root;
	void *ns_tag;
	long unsigned int magic;
	bool new_sb_created;
};

struct pseudo_lock_region___2;

struct rdt_domain___2 {
	struct list_head list;
	int id;
	struct cpumask cpu_mask;
	long unsigned int *rmid_busy_llc;
	struct mbm_state *mbm_total;
	struct mbm_state *mbm_local;
	struct delayed_work mbm_over;
	struct delayed_work cqm_limbo;
	int mbm_work_cpu;
	int cqm_work_cpu;
	struct pseudo_lock_region___2 *plr;
	struct resctrl_staged_config staged_config[3];
};

struct resctrl_schema___2;

struct pseudo_lock_region___2 {
	struct resctrl_schema___2 *s;
	struct rdt_domain___2 *d;
	u32 cbm;
	wait_queue_head_t lock_thread_wq;
	int thread_done;
	int cpu;
	unsigned int line_size;
	unsigned int size;
	void *kmem;
	unsigned int minor;
	struct dentry___2 *debugfs_dir;
	struct list_head pm_reqs;
};

struct rdt_parse_data___2;

struct rdt_resource___2 {
	int rid;
	bool alloc_enabled;
	bool mon_enabled;
	bool alloc_capable;
	bool mon_capable;
	int num_rmid;
	int cache_level;
	struct resctrl_cache cache;
	struct resctrl_membw membw;
	struct list_head domains;
	char *name;
	int data_width;
	u32 default_ctrl;
	const char *format_str;
	int (*parse_ctrlval)(struct rdt_parse_data___2 *, struct resctrl_schema___2 *, struct rdt_domain___2 *);
	struct list_head evt_list;
	long unsigned int fflags;
	bool cdp_capable;
};

struct rdtgroup___2;

struct rdt_parse_data___2 {
	struct rdtgroup___2 *rdtgrp;
	char *buf;
};

struct resctrl_schema___2 {
	struct list_head list;
	char name[8];
	enum resctrl_conf_type conf_type;
	struct rdt_resource___2 *res;
	u32 num_closid;
};

struct rdt_fs_context {
	struct kernfs_fs_context kfc;
	bool enable_cdpl2;
	bool enable_cdpl3;
	bool enable_mba_mbps;
};

struct mon_evt {
	u32 evtid;
	char *name;
	struct list_head list;
};

union mon_data_bits {
	void *priv;
	struct {
		unsigned int rid: 10;
		unsigned int evtid: 8;
		unsigned int domid: 14;
	} u;
};

struct rmid_read {
	struct rdtgroup___2 *rgrp;
	struct rdt_resource___2 *r;
	struct rdt_domain___2 *d;
	int evtid;
	bool first;
	u64 val;
};

struct mongroup___2 {
	struct kernfs_node *mon_data_kn;
	struct rdtgroup___2 *parent;
	struct list_head crdtgrp_list;
	u32 rmid;
};

struct rdtgroup___2 {
	struct kernfs_node *kn;
	struct list_head rdtgroup_list;
	u32 closid;
	struct cpumask cpu_mask;
	int flags;
	atomic_t waitcount;
	enum rdt_group_type type;
	struct mongroup___2 mon;
	enum rdtgrp_mode mode;
	struct pseudo_lock_region___2 *plr;
};

struct rftype {
	char *name;
	umode_t mode;
	const struct kernfs_ops *kf_ops;
	long unsigned int flags;
	long unsigned int fflags;
	int (*seq_show)(struct kernfs_open_file *, struct seq_file___2 *, void *);
	ssize_t (*write)(struct kernfs_open_file *, char *, size_t, loff_t);
};

struct rdt_hw_domain___2 {
	struct rdt_domain___2 d_resctrl;
	u32 *ctrl_val;
	u32 *mbps_val;
};

struct msr_param___2 {
	struct rdt_resource___2 *res;
	u32 low;
	u32 high;
};

struct rdt_hw_resource___2 {
	struct rdt_resource___2 r_resctrl;
	u32 num_closid;
	unsigned int msr_base;
	void (*msr_update)(struct rdt_domain___2 *, struct msr_param___2 *, struct rdt_resource___2 *);
	unsigned int mon_scale;
	unsigned int mbm_width;
	bool cdp_enabled;
};

enum rdt_param {
	Opt_cdp = 0,
	Opt_cdpl2 = 1,
	Opt_mba_mbps = 2,
	nr__rdt_params = 3,
};

struct rmid_entry {
	u32 rmid;
	int busy;
	struct list_head list;
};

struct mbm_correction_factor_table {
	u32 rmidthreshold;
	u64 cf;
};

struct fs_context___4;

struct dentry___17;

struct super_block___17;

struct module___16;

struct file_system_type___17 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context___4 *);
	const struct fs_parameter_spec *parameters;
	struct dentry___17 * (*mount)(struct file_system_type___17 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___17 *);
	struct module___16 *owner;
	struct file_system_type___17 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___17;

struct kiocb___17;

struct poll_table_struct___11;

struct vm_area_struct___19;

struct inode___17;

struct file_lock___17;

struct page___18;

struct seq_file___15;

struct file_operations___17 {
	struct module___16 *owner;
	loff_t (*llseek)(struct file___17 *, loff_t, int);
	ssize_t (*read)(struct file___17 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___17 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___17 *, struct iov_iter___13 *);
	ssize_t (*write_iter)(struct kiocb___17 *, struct iov_iter___13 *);
	int (*iopoll)(struct kiocb___17 *, bool);
	int (*iterate)(struct file___17 *, struct dir_context *);
	int (*iterate_shared)(struct file___17 *, struct dir_context *);
	__poll_t (*poll)(struct file___17 *, struct poll_table_struct___11 *);
	long int (*unlocked_ioctl)(struct file___17 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___17 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___17 *, struct vm_area_struct___19 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___17 *, struct file___17 *);
	int (*flush)(struct file___17 *, fl_owner_t);
	int (*release)(struct inode___17 *, struct file___17 *);
	int (*fsync)(struct file___17 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___17 *, int);
	int (*lock)(struct file___17 *, int, struct file_lock___17 *);
	ssize_t (*sendpage)(struct file___17 *, struct page___18 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___17 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___17 *, long unsigned int);
	int (*flock)(struct file___17 *, int, struct file_lock___17 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___17 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___17 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___17 *, long int, struct file_lock___17 **, void **);
	long int (*fallocate)(struct file___17 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___15 *, struct file___17 *);
	ssize_t (*copy_file_range)(struct file___17 *, loff_t, struct file___17 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___17 *, loff_t, struct file___17 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___17 *, loff_t, loff_t, int);
};

struct static_call_mod___11 {
	struct static_call_mod___11 *next;
	struct module___16 *mod;
	struct static_call_site *sites;
};

struct static_call_key___11 {
	void *func;
	union {
		long unsigned int type;
		struct static_call_mod___11 *mods;
		struct static_call_site *sites;
	};
};

struct vmacache___18 {
	u64 seqnum;
	struct vm_area_struct___19 *vmas[4];
};

struct page_frag___18 {
	struct page___18 *page;
	__u32 offset;
	__u32 size;
};

struct perf_event___9;

struct thread_struct___10 {
	struct desc_struct tls_array[3];
	long unsigned int sp;
	short unsigned int es;
	short unsigned int ds;
	short unsigned int fsindex;
	short unsigned int gsindex;
	long unsigned int fsbase;
	long unsigned int gsbase;
	struct perf_event___9 *ptrace_bps[4];
	long unsigned int virtual_dr6;
	long unsigned int ptrace_dr7;
	long unsigned int cr2;
	long unsigned int trap_nr;
	long unsigned int error_code;
	struct io_bitmap *io_bitmap;
	long unsigned int iopl_emul;
	unsigned int iopl_warn: 1;
	unsigned int sig_on_uaccess_err: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u32 pkru;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct fpu fpu;
};

struct mm_struct___19;

struct pid___15;

struct nsproxy___16;

struct signal_struct___18;

struct css_set___12;

struct perf_event_context___9;

struct task_struct___20 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___20 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___19 *mm;
	struct mm_struct___19 *active_mm;
	struct vmacache___18 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int restore_sigmask: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___20 *real_parent;
	struct task_struct___20 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___20 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___15 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	struct posix_cputimers_work posix_cputimers_work;
	const struct cred *ptracer_cred;
	const struct cred *real_cred;
	const struct cred *cred;
	struct key *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___16 *nsproxy;
	struct signal_struct___18 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___20 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context___11 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___12 *cgroups;
	struct list_head cg_list;
	u32 closid;
	u32 rmid;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___9 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	long: 64;
	long: 64;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___18 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup *active_memcg;
	struct request_queue *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___20 *oom_reaper_list;
	struct vm_struct___3 *stack_vm_area;
	refcount_t stack_refcount;
	int patch_state;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	void *mce_vaddr;
	__u64 mce_kflags;
	u64 mce_addr;
	__u64 mce_ripv: 1;
	__u64 mce_whole_page: 1;
	__u64 __mce_reserved: 62;
	long: 2;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct callback_head mce_kill_me;
	int mce_count;
	struct llist_head kretprobe_instances;
	struct callback_head l1d_flush_kill;
	long: 64;
	struct thread_struct___10 thread;
};

typedef struct page___18 *pgtable_t___18;

struct address_space___17;

struct dev_pagemap___17;

struct page___18 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___17 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___4 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___18 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___18 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___19 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___17 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct pv_cpu_ops___14 {
	void (*io_delay)();
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	void (*write_cr4)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___10 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(long unsigned int);
	void (*invalidate_io_bitmap)();
	void (*update_io_bitmap)();
	void (*wbinvd)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int);
	void (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_msr_safe)(unsigned int, int *);
	int (*write_msr_safe)(unsigned int, unsigned int, unsigned int);
	u64 (*read_pmc)(int);
	void (*start_context_switch)(struct task_struct___20 *);
	void (*end_context_switch)(struct task_struct___20 *);
};

struct pv_mmu_ops___14 {
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_one_user)(long unsigned int);
	void (*flush_tlb_multi)(const struct cpumask *, const struct flush_tlb_info___3 *);
	void (*tlb_remove_table)(struct mmu_gather *, void *);
	void (*exit_mmap)(struct mm_struct___19 *);
	struct paravirt_callee_save read_cr2;
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___19 *, struct mm_struct___19 *);
	void (*dup_mmap)(struct mm_struct___19 *, struct mm_struct___19 *);
	int (*pgd_alloc)(struct mm_struct___19 *);
	void (*pgd_free)(struct mm_struct___19 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___19 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___19 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___19 *, long unsigned int);
	void (*alloc_p4d)(struct mm_struct___19 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*release_p4d)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	pte_t (*ptep_modify_prot_start)(struct vm_area_struct___19 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct vm_area_struct___19 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_p4d)(p4d_t *, p4d_t);
	struct paravirt_callee_save p4d_val;
	struct paravirt_callee_save make_p4d;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

struct core_state___18;

struct mm_struct___19 {
	struct {
		struct vm_area_struct___19 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___17 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int mmap_compat_base;
		long unsigned int mmap_compat_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[48];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___18 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___20 *owner;
		struct user_namespace *user_ns;
		struct file___17 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		bool tlb_flush_batched;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct vm_operations_struct___17;

struct vm_area_struct___19 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___19 *vm_next;
	struct vm_area_struct___19 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___19 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___17 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___17 *vm_file;
	struct file___17 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct paravirt_patch_template___14 {
	struct pv_cpu_ops___14 cpu;
	struct pv_irq_ops irq;
	struct pv_mmu_ops___14 mmu;
	struct pv_lock_ops lock;
};

struct tracepoint___11 {
	const char *name;
	struct static_key key;
	struct static_call_key___11 *static_call_key;
	void *static_call_tramp;
	void *iterator;
	int (*regfunc)();
	void (*unregfunc)();
	struct tracepoint_func *funcs;
};

struct bpf_raw_event_map___11 {
	struct tracepoint___11 *tp;
	void *bpf_func;
	u32 num_args;
	u32 writable_size;
	long: 64;
};

struct seq_operations___15 {
	void * (*start)(struct seq_file___15 *, loff_t *);
	void (*stop)(struct seq_file___15 *, void *);
	void * (*next)(struct seq_file___15 *, void *, loff_t *);
	int (*show)(struct seq_file___15 *, void *);
};

struct hw_perf_event___9 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___20 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	union {
		struct {
			u64 last_period;
			local64_t period_left;
		};
		struct {
			u64 saved_metric;
			u64 saved_slots;
		};
	};
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___9)(struct perf_event___9 *, struct perf_sample_data *, struct pt_regs *);

struct pmu___9;

struct fasync_struct___17;

struct pid_namespace___15;

struct trace_event_call___9;

struct perf_cgroup___9;

struct perf_event___9 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___9 *group_leader;
	struct pmu___9 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___9 hw;
	struct perf_event_context___9 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___9 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___20 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct perf_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___17 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	long unsigned int pending_addr;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	struct perf_addr_filter_range *addr_filter_ranges;
	long unsigned int addr_filters_gen;
	struct perf_event___9 *aux_event;
	void (*destroy)(struct perf_event___9 *);
	struct callback_head callback_head;
	struct pid_namespace___15 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___9 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___9 orig_overflow_handler;
	struct bpf_prog *prog;
	u64 bpf_cookie;
	struct trace_event_call___9 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___9 *cgrp;
	void *security;
	struct list_head sb_list;
};

struct upid___15 {
	int nr;
	struct pid_namespace___15 *ns;
};

struct pid_namespace___15 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___20 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___15 *parent;
	struct fs_pin *bacct;
	struct user_namespace *user_ns;
	struct ucounts *ucounts;
	int reboot;
	struct ns_common ns;
};

struct pid___15 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___15 numbers[1];
};

struct signal_struct___18 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___20 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___20 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___15 *pids[4];
	struct pid___15 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___19 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct cgroup_namespace___12;

struct nsproxy___16 {
	atomic_t count;
	struct uts_namespace *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___15 *pid_ns_for_children;
	struct net *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___12 *cgroup_ns;
};

struct cgroup_subsys_state___12;

struct cgroup___12;

struct css_set___12 {
	struct cgroup_subsys_state___12 *subsys[14];
	refcount_t refcount;
	struct css_set___12 *dom_cset;
	struct cgroup___12 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___12 *mg_src_cgrp;
	struct cgroup___12 *mg_dst_cgrp;
	struct css_set___12 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___9 {
	struct pmu___9 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	int rotate_necessary;
	refcount_t refcount;
	struct task_struct___20 *task;
	u64 time;
	u64 timestamp;
	u64 timeoffset;
	struct perf_event_context___9 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

struct address_space_operations___17;

struct address_space___17 {
	struct inode___17 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___17 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct dev_pagemap_ops___17;

struct dev_pagemap___17 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___17 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vfsmount___17;

struct path___17 {
	struct vfsmount___17 *mnt;
	struct dentry___17 *dentry;
};

struct fown_struct___15 {
	rwlock_t lock;
	struct pid___15 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___17 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	long: 64;
	long: 64;
	struct path___17 f_path;
	struct inode___17 *f_inode;
	const struct file_operations___17 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___15 f_owner;
	const struct cred *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___17 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___17;

struct vm_operations_struct___17 {
	void (*open)(struct vm_area_struct___19 *);
	void (*close)(struct vm_area_struct___19 *);
	int (*may_split)(struct vm_area_struct___19 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___19 *);
	int (*mprotect)(struct vm_area_struct___19 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___17 *);
	vm_fault_t (*huge_fault)(struct vm_fault___17 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___17 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___19 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___17 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___17 *);
	int (*access)(struct vm_area_struct___19 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___19 *);
	int (*set_policy)(struct vm_area_struct___19 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___19 *, long unsigned int);
	struct page___18 * (*find_special_page)(struct vm_area_struct___19 *, long unsigned int);
};

struct core_thread___18 {
	struct task_struct___20 *task;
	struct core_thread___18 *next;
};

struct core_state___18 {
	atomic_t nr_threads;
	struct core_thread___18 dumper;
	struct completion startup;
};

struct vm_fault___17 {
	const struct {
		struct vm_area_struct___19 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___18 *cow_page;
	struct page___18 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___18 prealloc_pte;
};

struct kernfs_root___17;

struct kernfs_elem_dir___17 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___17 *root;
	long unsigned int rev;
};

struct kernfs_node___17;

struct kernfs_syscall_ops___17;

struct kernfs_root___17 {
	struct kernfs_node___17 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___17 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___17 {
	struct kernfs_node___17 *target_kn;
};

struct kernfs_ops___17;

struct kernfs_elem_attr___17 {
	const struct kernfs_ops___17 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___17 *notify_next;
};

struct kernfs_node___17 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___17 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___17 dir;
		struct kernfs_elem_symlink___17 symlink;
		struct kernfs_elem_attr___17 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___17;

struct kernfs_ops___17 {
	int (*open)(struct kernfs_open_file___17 *);
	void (*release)(struct kernfs_open_file___17 *);
	int (*seq_show)(struct seq_file___15 *, void *);
	void * (*seq_start)(struct seq_file___15 *, loff_t *);
	void * (*seq_next)(struct seq_file___15 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___15 *, void *);
	ssize_t (*read)(struct kernfs_open_file___17 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___17 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___17 *, struct poll_table_struct___11 *);
	int (*mmap)(struct kernfs_open_file___17 *, struct vm_area_struct___19 *);
};

struct kernfs_syscall_ops___17 {
	int (*show_options)(struct seq_file___15 *, struct kernfs_root___17 *);
	int (*mkdir)(struct kernfs_node___17 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___17 *);
	int (*rename)(struct kernfs_node___17 *, struct kernfs_node___17 *, const char *);
	int (*show_path)(struct seq_file___15 *, struct kernfs_node___17 *, struct kernfs_root___17 *);
};

struct seq_file___15 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___15 *op;
	int poll_event;
	const struct file___17 *file;
	void *private;
};

struct kernfs_open_file___17 {
	struct kernfs_node___17 *kn;
	struct file___17 *file;
	struct seq_file___15 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___17 *vm_ops;
};

typedef void (*poll_queue_proc___11)(struct file___17 *, wait_queue_head_t *, struct poll_table_struct___11 *);

struct poll_table_struct___11 {
	poll_queue_proc___11 _qproc;
	__poll_t _key;
};

struct kobject___17;

struct bin_attribute___17;

struct attribute_group___17 {
	const char *name;
	umode_t (*is_visible)(struct kobject___17 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___17 *, struct bin_attribute___17 *, int);
	struct attribute **attrs;
	struct bin_attribute___17 **bin_attrs;
};

struct kset___16;

struct kobj_type___16;

struct kobject___17 {
	const char *name;
	struct list_head entry;
	struct kobject___17 *parent;
	struct kset___16 *kset;
	struct kobj_type___16 *ktype;
	struct kernfs_node___17 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bin_attribute___17 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___17 * (*f_mapping)();
	ssize_t (*read)(struct file___17 *, struct kobject___17 *, struct bin_attribute___17 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___17 *, struct kobject___17 *, struct bin_attribute___17 *, char *, loff_t, size_t);
	int (*mmap)(struct file___17 *, struct kobject___17 *, struct bin_attribute___17 *, struct vm_area_struct___19 *);
};

struct sysfs_ops___16 {
	ssize_t (*show)(struct kobject___17 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___17 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___16;

struct kset___16 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___17 kobj;
	const struct kset_uevent_ops___16 *uevent_ops;
};

struct kobj_type___16 {
	void (*release)(struct kobject___17 *);
	const struct sysfs_ops___16 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___17 **default_groups;
	const struct kobj_ns_type_operations * (*child_ns_type)(struct kobject___17 *);
	const void * (*namespace)(struct kobject___17 *);
	void (*get_ownership)(struct kobject___17 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___16 {
	int (* const filter)(struct kset___16 *, struct kobject___17 *);
	const char * (* const name)(struct kset___16 *, struct kobject___17 *);
	int (* const uevent)(struct kset___16 *, struct kobject___17 *, struct kobj_uevent_env *);
};

struct wakeup_source___18;

struct device___18;

struct dev_pm_qos___2;

struct dev_pm_info___18 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___18 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___18 *, s32);
	struct dev_pm_qos___2 *qos;
};

struct device_type___18;

struct bus_type___18;

struct device_driver___18;

struct dev_pm_domain___18;

struct class___18;

struct device___18 {
	struct kobject___17 kobj;
	struct device___18 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___18 *type;
	struct bus_type___18 *bus;
	struct device_driver___18 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___18 power;
	struct dev_pm_domain___18 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node *of_node;
	struct fwnode_handle___5 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___18 *class;
	const struct attribute_group___17 **groups;
	void (*release)(struct device___18 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_ops___18 {
	int (*prepare)(struct device___18 *);
	void (*complete)(struct device___18 *);
	int (*suspend)(struct device___18 *);
	int (*resume)(struct device___18 *);
	int (*freeze)(struct device___18 *);
	int (*thaw)(struct device___18 *);
	int (*poweroff)(struct device___18 *);
	int (*restore)(struct device___18 *);
	int (*suspend_late)(struct device___18 *);
	int (*resume_early)(struct device___18 *);
	int (*freeze_late)(struct device___18 *);
	int (*thaw_early)(struct device___18 *);
	int (*poweroff_late)(struct device___18 *);
	int (*restore_early)(struct device___18 *);
	int (*suspend_noirq)(struct device___18 *);
	int (*resume_noirq)(struct device___18 *);
	int (*freeze_noirq)(struct device___18 *);
	int (*thaw_noirq)(struct device___18 *);
	int (*poweroff_noirq)(struct device___18 *);
	int (*restore_noirq)(struct device___18 *);
	int (*runtime_suspend)(struct device___18 *);
	int (*runtime_resume)(struct device___18 *);
	int (*runtime_idle)(struct device___18 *);
};

struct wakeup_source___18 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___18 *dev;
	bool active: 1;
	bool autosleep_enabled: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_qos_request___2;

struct dev_pm_qos___2 {
	struct pm_qos_constraints resume_latency;
	struct pm_qos_constraints latency_tolerance;
	struct freq_constraints freq;
	struct pm_qos_flags flags;
	struct dev_pm_qos_request___2 *resume_latency_req;
	struct dev_pm_qos_request___2 *latency_tolerance_req;
	struct dev_pm_qos_request___2 *flags_req;
};

struct dev_pm_domain___18 {
	struct dev_pm_ops___18 ops;
	int (*start)(struct device___18 *);
	void (*detach)(struct device___18 *, bool);
	int (*activate)(struct device___18 *);
	void (*sync)(struct device___18 *);
	void (*dismiss)(struct device___18 *);
};

struct bus_type___18 {
	const char *name;
	const char *dev_name;
	struct device___18 *dev_root;
	const struct attribute_group___17 **bus_groups;
	const struct attribute_group___17 **dev_groups;
	const struct attribute_group___17 **drv_groups;
	int (*match)(struct device___18 *, struct device_driver___18 *);
	int (*uevent)(struct device___18 *, struct kobj_uevent_env *);
	int (*probe)(struct device___18 *);
	void (*sync_state)(struct device___18 *);
	void (*remove)(struct device___18 *);
	void (*shutdown)(struct device___18 *);
	int (*online)(struct device___18 *);
	int (*offline)(struct device___18 *);
	int (*suspend)(struct device___18 *, pm_message_t);
	int (*resume)(struct device___18 *);
	int (*num_vf)(struct device___18 *);
	int (*dma_configure)(struct device___18 *);
	const struct dev_pm_ops___18 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___18 {
	const char *name;
	struct bus_type___18 *bus;
	struct module___16 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___18 *);
	void (*sync_state)(struct device___18 *);
	int (*remove)(struct device___18 *);
	void (*shutdown)(struct device___18 *);
	int (*suspend)(struct device___18 *, pm_message_t);
	int (*resume)(struct device___18 *);
	const struct attribute_group___17 **groups;
	const struct attribute_group___17 **dev_groups;
	const struct dev_pm_ops___18 *pm;
	void (*coredump)(struct device___18 *);
	struct driver_private *p;
};

struct device_type___18 {
	const char *name;
	const struct attribute_group___17 **groups;
	int (*uevent)(struct device___18 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___18 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___18 *);
	const struct dev_pm_ops___18 *pm;
};

struct class___18 {
	const char *name;
	struct module___16 *owner;
	const struct attribute_group___17 **class_groups;
	const struct attribute_group___17 **dev_groups;
	struct kobject___17 *dev_kobj;
	int (*dev_uevent)(struct device___18 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___18 *, umode_t *);
	void (*class_release)(struct class___18 *);
	void (*dev_release)(struct device___18 *);
	int (*shutdown_pre)(struct device___18 *);
	const struct kobj_ns_type_operations *ns_type;
	const void * (*namespace)(struct device___18 *);
	void (*get_ownership)(struct device___18 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___18 *pm;
	struct subsys_private *p;
};

struct module_kobject___16 {
	struct kobject___17 kobj;
	struct module___16 *mod;
	struct kobject___17 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___16 {
	struct module___16 *mod;
	struct latch_tree_node node;
};

struct module_layout___16 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___16 mtn;
};

struct module_attribute___16;

struct kernel_param___16;

struct module___16 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___16 mkobj;
	struct module_attribute___16 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___17 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___16 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___16 core_layout;
	struct module_layout___16 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map___11 *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___9 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	int num_static_call_sites;
	struct static_call_site *static_call_sites;
	bool klp;
	bool klp_alive;
	struct klp_modinfo *klp_info;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dentry_operations___17;

struct dentry___17 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___17 *d_parent;
	struct qstr d_name;
	struct inode___17 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___17 *d_op;
	struct super_block___17 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___17;

struct inode___17 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___17 *i_op;
	struct super_block___17 *i_sb;
	struct address_space___17 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	long: 64;
	long: 64;
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___17 *i_fop;
		void (*free_inode)(struct inode___17 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___17 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___4 *i_pipe;
		struct cdev *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___17 {
	int (*d_revalidate)(struct dentry___17 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___17 *, unsigned int);
	int (*d_hash)(const struct dentry___17 *, struct qstr *);
	int (*d_compare)(const struct dentry___17 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___17 *);
	int (*d_init)(struct dentry___17 *);
	void (*d_release)(struct dentry___17 *);
	void (*d_prune)(struct dentry___17 *);
	void (*d_iput)(struct dentry___17 *, struct inode___17 *);
	char * (*d_dname)(struct dentry___17 *, char *, int);
	struct vfsmount___17 * (*d_automount)(struct path___17 *);
	int (*d_manage)(const struct path___17 *, bool);
	struct dentry___17 * (*d_real)(struct dentry___17 *, const struct inode___17 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___17;

struct mem_dqinfo___17 {
	struct quota_format_type___17 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___17;

struct quota_info___17 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___17 *files[3];
	struct mem_dqinfo___17 info[3];
	const struct quota_format_ops___17 *ops[3];
};

struct rcuwait___17 {
	struct task_struct___20 *task;
};

struct percpu_rw_semaphore___17 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___17 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___17 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___17 rw_sem[3];
};

struct super_operations___17;

struct dquot_operations___17;

struct quotactl_ops___17;

struct super_block___17 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___17 *s_type;
	const struct super_operations___17 *s_op;
	const struct dquot_operations___17 *dq_op;
	const struct quotactl_ops___17 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___17 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device *s_bdev;
	struct backing_dev_info *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___17 s_dquot;
	struct sb_writers___17 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___17 *s_d_op;
	int cleancache_poolid;
	struct shrinker___9 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___17 {
	struct dentry___17 *mnt_root;
	struct super_block___17 *mnt_sb;
	int mnt_flags;
	struct user_namespace *mnt_userns;
};

struct cgroup_subsys___12;

struct cgroup_subsys_state___12 {
	struct cgroup___12 *cgroup;
	struct cgroup_subsys___12 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___12 *parent;
};

struct cgroup_file___12 {
	struct kernfs_node___17 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct psi_group___12 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___20 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___12;

struct cgroup_rstat_cpu___12;

struct cgroup___12 {
	struct cgroup_subsys_state___12 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___17 *kn;
	struct cgroup_file___12 procs_file;
	struct cgroup_file___12 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___12 *subsys[14];
	struct cgroup_root___12 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___12 *dom_cgrp;
	struct cgroup___12 *old_dom_cgrp;
	struct cgroup_rstat_cpu___12 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___12 psi;
	struct cgroup_bpf bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct kiocb___17 {
	struct file___17 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___17 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___9 *ki_waitq;
	};
};

struct iattr___17 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___17 *ia_file;
};

struct dquot___17 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___17 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___17 {
	int qf_fmt_id;
	const struct quota_format_ops___17 *qf_ops;
	struct module___16 *qf_owner;
	struct quota_format_type___17 *qf_next;
};

struct quota_format_ops___17 {
	int (*check_quota_file)(struct super_block___17 *, int);
	int (*read_file_info)(struct super_block___17 *, int);
	int (*write_file_info)(struct super_block___17 *, int);
	int (*free_file_info)(struct super_block___17 *, int);
	int (*read_dqblk)(struct dquot___17 *);
	int (*commit_dqblk)(struct dquot___17 *);
	int (*release_dqblk)(struct dquot___17 *);
	int (*get_next_id)(struct super_block___17 *, struct kqid *);
};

struct dquot_operations___17 {
	int (*write_dquot)(struct dquot___17 *);
	struct dquot___17 * (*alloc_dquot)(struct super_block___17 *, int);
	void (*destroy_dquot)(struct dquot___17 *);
	int (*acquire_dquot)(struct dquot___17 *);
	int (*release_dquot)(struct dquot___17 *);
	int (*mark_dirty)(struct dquot___17 *);
	int (*write_info)(struct super_block___17 *, int);
	qsize_t * (*get_reserved_space)(struct inode___17 *);
	int (*get_projid)(struct inode___17 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___17 *, qsize_t *);
	int (*get_next_id)(struct super_block___17 *, struct kqid *);
};

struct quotactl_ops___17 {
	int (*quota_on)(struct super_block___17 *, int, int, const struct path___17 *);
	int (*quota_off)(struct super_block___17 *, int);
	int (*quota_enable)(struct super_block___17 *, unsigned int);
	int (*quota_disable)(struct super_block___17 *, unsigned int);
	int (*quota_sync)(struct super_block___17 *, int);
	int (*set_info)(struct super_block___17 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___17 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___17 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___17 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___17 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___17 *, unsigned int);
};

struct address_space_operations___17 {
	int (*writepage)(struct page___18 *, struct writeback_control *);
	int (*readpage)(struct file___17 *, struct page___18 *);
	int (*writepages)(struct address_space___17 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___18 *);
	int (*readpages)(struct file___17 *, struct address_space___17 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control *);
	int (*write_begin)(struct file___17 *, struct address_space___17 *, loff_t, unsigned int, unsigned int, struct page___18 **, void **);
	int (*write_end)(struct file___17 *, struct address_space___17 *, loff_t, unsigned int, unsigned int, struct page___18 *, void *);
	sector_t (*bmap)(struct address_space___17 *, sector_t);
	void (*invalidatepage)(struct page___18 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___18 *, gfp_t);
	void (*freepage)(struct page___18 *);
	ssize_t (*direct_IO)(struct kiocb___17 *, struct iov_iter___13 *);
	int (*migratepage)(struct address_space___17 *, struct page___18 *, struct page___18 *, enum migrate_mode);
	bool (*isolate_page)(struct page___18 *, isolate_mode_t);
	void (*putback_page)(struct page___18 *);
	int (*launder_page)(struct page___18 *);
	int (*is_partially_uptodate)(struct page___18 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___18 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___17 *, struct page___18 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___17 *, sector_t *);
	void (*swap_deactivate)(struct file___17 *);
};

struct inode_operations___17 {
	struct dentry___17 * (*lookup)(struct inode___17 *, struct dentry___17 *, unsigned int);
	const char * (*get_link)(struct dentry___17 *, struct inode___17 *, struct delayed_call *);
	int (*permission)(struct user_namespace *, struct inode___17 *, int);
	struct posix_acl * (*get_acl)(struct inode___17 *, int, bool);
	int (*readlink)(struct dentry___17 *, char *, int);
	int (*create)(struct user_namespace *, struct inode___17 *, struct dentry___17 *, umode_t, bool);
	int (*link)(struct dentry___17 *, struct inode___17 *, struct dentry___17 *);
	int (*unlink)(struct inode___17 *, struct dentry___17 *);
	int (*symlink)(struct user_namespace *, struct inode___17 *, struct dentry___17 *, const char *);
	int (*mkdir)(struct user_namespace *, struct inode___17 *, struct dentry___17 *, umode_t);
	int (*rmdir)(struct inode___17 *, struct dentry___17 *);
	int (*mknod)(struct user_namespace *, struct inode___17 *, struct dentry___17 *, umode_t, dev_t);
	int (*rename)(struct user_namespace *, struct inode___17 *, struct dentry___17 *, struct inode___17 *, struct dentry___17 *, unsigned int);
	int (*setattr)(struct user_namespace *, struct dentry___17 *, struct iattr___17 *);
	int (*getattr)(struct user_namespace *, const struct path___17 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___17 *, char *, size_t);
	int (*fiemap)(struct inode___17 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___17 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___17 *, struct dentry___17 *, struct file___17 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace *, struct inode___17 *, struct dentry___17 *, umode_t);
	int (*set_acl)(struct user_namespace *, struct inode___17 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace *, struct dentry___17 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___17 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___17 {
	void (*fl_copy_lock)(struct file_lock___17 *, struct file_lock___17 *);
	void (*fl_release_private)(struct file_lock___17 *);
};

struct lock_manager_operations___17;

struct file_lock___17 {
	struct file_lock___17 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___17 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___17 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___17 *fl_ops;
	const struct lock_manager_operations___17 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___17 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___17 *);
	int (*lm_grant)(struct file_lock___17 *, int);
	bool (*lm_break)(struct file_lock___17 *);
	int (*lm_change)(struct file_lock___17 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___17 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___17 *);
};

struct fasync_struct___17 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___17 *fa_next;
	struct file___17 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___17 {
	struct inode___17 * (*alloc_inode)(struct super_block___17 *);
	void (*destroy_inode)(struct inode___17 *);
	void (*free_inode)(struct inode___17 *);
	void (*dirty_inode)(struct inode___17 *, int);
	int (*write_inode)(struct inode___17 *, struct writeback_control *);
	int (*drop_inode)(struct inode___17 *);
	void (*evict_inode)(struct inode___17 *);
	void (*put_super)(struct super_block___17 *);
	int (*sync_fs)(struct super_block___17 *, int);
	int (*freeze_super)(struct super_block___17 *);
	int (*freeze_fs)(struct super_block___17 *);
	int (*thaw_super)(struct super_block___17 *);
	int (*unfreeze_fs)(struct super_block___17 *);
	int (*statfs)(struct dentry___17 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___17 *, int *, char *);
	void (*umount_begin)(struct super_block___17 *);
	int (*show_options)(struct seq_file___15 *, struct dentry___17 *);
	int (*show_devname)(struct seq_file___15 *, struct dentry___17 *);
	int (*show_path)(struct seq_file___15 *, struct dentry___17 *);
	int (*show_stats)(struct seq_file___15 *, struct dentry___17 *);
	ssize_t (*quota_read)(struct super_block___17 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___17 *, int, const char *, size_t, loff_t);
	struct dquot___17 ** (*get_dquots)(struct inode___17 *);
	long int (*nr_cached_objects)(struct super_block___17 *, struct shrink_control___9 *);
	long int (*free_cached_objects)(struct super_block___17 *, struct shrink_control___9 *);
	struct file___17 * (*real_loop)(struct file___17 *);
};

struct fc_log___3;

struct p_log___3 {
	const char *prefix;
	struct fc_log___3 *log;
};

struct fs_context_operations___4;

struct fs_context___4 {
	const struct fs_context_operations___4 *ops;
	struct mutex uapi_mutex;
	struct file_system_type___17 *fs_type;
	void *fs_private;
	void *sget_key;
	struct dentry___17 *root;
	struct user_namespace *user_ns;
	struct net *net_ns;
	const struct cred *cred;
	struct p_log___3 log;
	const char *source;
	void *security;
	void *s_fs_info;
	unsigned int sb_flags;
	unsigned int sb_flags_mask;
	unsigned int s_iflags;
	unsigned int lsm_flags;
	enum fs_context_purpose purpose: 8;
	enum fs_context_phase phase: 8;
	bool need_free: 1;
	bool global: 1;
	bool oldapi: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pagemap_ops___17 {
	void (*page_free)(struct page___18 *);
	void (*kill)(struct dev_pagemap___17 *);
	void (*cleanup)(struct dev_pagemap___17 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___17 *);
};

struct cgroup_namespace___12 {
	struct ns_common ns;
	struct user_namespace *user_ns;
	struct ucounts *ucounts;
	struct css_set___12 *root_cset;
};

struct perf_cpu_context___9;

struct perf_output_handle___9;

struct pmu___9 {
	struct list_head entry;
	struct module___16 *module;
	struct device___18 *dev;
	const struct attribute_group___17 **attr_groups;
	const struct attribute_group___17 **attr_update;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___9 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___9 *);
	void (*pmu_disable)(struct pmu___9 *);
	int (*event_init)(struct perf_event___9 *);
	void (*event_mapped)(struct perf_event___9 *, struct mm_struct___19 *);
	void (*event_unmapped)(struct perf_event___9 *, struct mm_struct___19 *);
	int (*add)(struct perf_event___9 *, int);
	void (*del)(struct perf_event___9 *, int);
	void (*start)(struct perf_event___9 *, int);
	void (*stop)(struct perf_event___9 *, int);
	void (*read)(struct perf_event___9 *);
	void (*start_txn)(struct pmu___9 *, unsigned int);
	int (*commit_txn)(struct pmu___9 *);
	void (*cancel_txn)(struct pmu___9 *);
	int (*event_idx)(struct perf_event___9 *);
	void (*sched_task)(struct perf_event_context___9 *, bool);
	struct kmem_cache *task_ctx_cache;
	void (*swap_task_ctx)(struct perf_event_context___9 *, struct perf_event_context___9 *);
	void * (*setup_aux)(struct perf_event___9 *, void **, int, bool);
	void (*free_aux)(void *);
	long int (*snapshot_aux)(struct perf_event___9 *, struct perf_output_handle___9 *, long unsigned int);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___9 *);
	int (*aux_output_match)(struct perf_event___9 *);
	int (*filter_match)(struct perf_event___9 *);
	int (*check_period)(struct perf_event___9 *, u64);
};

struct kernel_param_ops___16 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___16 *);
	int (*get)(char *, const struct kernel_param___16 *);
	void (*free)(void *);
};

struct kparam_array___16;

struct kernel_param___16 {
	const char *name;
	struct module___16 *mod;
	const struct kernel_param_ops___16 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___16 *arr;
	};
};

struct kparam_array___16 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___16 *ops;
	void *elem;
};

struct module_attribute___16 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___16 *, struct module_kobject___16 *, char *);
	ssize_t (*store)(struct module_attribute___16 *, struct module_kobject___16 *, const char *, size_t);
	void (*setup)(struct module___16 *, const char *);
	int (*test)(struct module___16 *);
	void (*free)(struct module___16 *);
};

struct trace_event_class___9;

struct trace_event_call___9 {
	struct list_head list;
	struct trace_event_class___9 *class;
	union {
		char *name;
		struct tracepoint___11 *tp;
	};
	struct trace_event event;
	char *print_fmt;
	struct event_filter *filter;
	union {
		void *module;
		atomic_t refcnt;
	};
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
	struct bpf_prog_array *prog_array;
	int (*perf_perm)(struct trace_event_call___9 *, struct perf_event___9 *);
};

struct cftype___12;

struct cgroup_subsys___12 {
	struct cgroup_subsys_state___12 * (*css_alloc)(struct cgroup_subsys_state___12 *);
	int (*css_online)(struct cgroup_subsys_state___12 *);
	void (*css_offline)(struct cgroup_subsys_state___12 *);
	void (*css_released)(struct cgroup_subsys_state___12 *);
	void (*css_free)(struct cgroup_subsys_state___12 *);
	void (*css_reset)(struct cgroup_subsys_state___12 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___12 *, int);
	int (*css_extra_stat_show)(struct seq_file___15 *, struct cgroup_subsys_state___12 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___20 *, struct css_set___12 *);
	void (*cancel_fork)(struct task_struct___20 *, struct css_set___12 *);
	void (*fork)(struct task_struct___20 *);
	void (*exit)(struct task_struct___20 *);
	void (*release)(struct task_struct___20 *);
	void (*bind)(struct cgroup_subsys_state___12 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___12 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___12 *dfl_cftypes;
	struct cftype___12 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___12 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___12 *updated_children;
	struct cgroup___12 *updated_next;
};

struct cgroup_root___12 {
	struct kernfs_root___17 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___12 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___12 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___12 *ss;
	struct list_head node;
	struct kernfs_ops___17 *kf_ops;
	int (*open)(struct kernfs_open_file___17 *);
	void (*release)(struct kernfs_open_file___17 *);
	u64 (*read_u64)(struct cgroup_subsys_state___12 *, struct cftype___12 *);
	s64 (*read_s64)(struct cgroup_subsys_state___12 *, struct cftype___12 *);
	int (*seq_show)(struct seq_file___15 *, void *);
	void * (*seq_start)(struct seq_file___15 *, loff_t *);
	void * (*seq_next)(struct seq_file___15 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___15 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___12 *, struct cftype___12 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___12 *, struct cftype___12 *, s64);
	ssize_t (*write)(struct kernfs_open_file___17 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___17 *, struct poll_table_struct___11 *);
};

struct perf_cpu_context___9 {
	struct perf_event_context___9 ctx;
	struct perf_event_context___9 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___9 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
	int heap_size;
	struct perf_event___9 **heap;
	struct perf_event___9 *heap_default[2];
};

struct perf_output_handle___9 {
	struct perf_event___9 *event;
	struct perf_buffer *rb;
	long unsigned int wakeup;
	long unsigned int size;
	u64 aux_flags;
	union {
		void *addr;
		long unsigned int head;
	};
	int page;
};

struct perf_cgroup___9 {
	struct cgroup_subsys_state___12 css;
	struct perf_cgroup_info *info;
};

struct dev_pm_qos_request___2 {
	enum dev_pm_qos_req_type type;
	union {
		struct plist_node pnode;
		struct pm_qos_flags_request flr;
		struct freq_qos_request freq;
	} data;
	struct device___18 *dev;
};

struct pseudo_lock_region___3;

struct rdt_domain___3 {
	struct list_head list;
	int id;
	struct cpumask cpu_mask;
	long unsigned int *rmid_busy_llc;
	struct mbm_state *mbm_total;
	struct mbm_state *mbm_local;
	struct delayed_work mbm_over;
	struct delayed_work cqm_limbo;
	int mbm_work_cpu;
	int cqm_work_cpu;
	struct pseudo_lock_region___3 *plr;
	struct resctrl_staged_config staged_config[3];
};

struct resctrl_schema___3;

struct pseudo_lock_region___3 {
	struct resctrl_schema___3 *s;
	struct rdt_domain___3 *d;
	u32 cbm;
	wait_queue_head_t lock_thread_wq;
	int thread_done;
	int cpu;
	unsigned int line_size;
	unsigned int size;
	void *kmem;
	unsigned int minor;
	struct dentry___17 *debugfs_dir;
	struct list_head pm_reqs;
};

struct rdt_parse_data___3;

struct rdt_resource___3 {
	int rid;
	bool alloc_enabled;
	bool mon_enabled;
	bool alloc_capable;
	bool mon_capable;
	int num_rmid;
	int cache_level;
	struct resctrl_cache cache;
	struct resctrl_membw membw;
	struct list_head domains;
	char *name;
	int data_width;
	u32 default_ctrl;
	const char *format_str;
	int (*parse_ctrlval)(struct rdt_parse_data___3 *, struct resctrl_schema___3 *, struct rdt_domain___3 *);
	struct list_head evt_list;
	long unsigned int fflags;
	bool cdp_capable;
};

struct rdtgroup___3;

struct rdt_parse_data___3 {
	struct rdtgroup___3 *rdtgrp;
	char *buf;
};

struct resctrl_schema___3 {
	struct list_head list;
	char name[8];
	enum resctrl_conf_type conf_type;
	struct rdt_resource___3 *res;
	u32 num_closid;
};

struct fs_parameter___4 {
	const char *key;
	enum fs_value_type type: 8;
	long: 56;
	long: 64;
	union {
		char *string;
		void *blob;
		struct filename *name;
		struct file___17 *file;
	};
	size_t size;
	int dirfd;
};

struct fc_log___3 {
	refcount_t usage;
	u8 head;
	u8 tail;
	u8 need_free;
	struct module___16 *owner;
	char *buffer[8];
};

struct fs_context_operations___4 {
	void (*free)(struct fs_context___4 *);
	int (*dup)(struct fs_context___4 *, struct fs_context___4 *);
	int (*parse_param)(struct fs_context___4 *, struct fs_parameter___4 *);
	int (*parse_monolithic)(struct fs_context___4 *, void *);
	int (*get_tree)(struct fs_context___4 *);
	int (*reconfigure)(struct fs_context___4 *);
};

struct mongroup___3 {
	struct kernfs_node___17 *mon_data_kn;
	struct rdtgroup___3 *parent;
	struct list_head crdtgrp_list;
	u32 rmid;
};

struct rdtgroup___3 {
	struct kernfs_node___17 *kn;
	struct list_head rdtgroup_list;
	u32 closid;
	struct cpumask cpu_mask;
	int flags;
	atomic_t waitcount;
	enum rdt_group_type type;
	struct mongroup___3 mon;
	enum rdtgrp_mode mode;
	struct pseudo_lock_region___3 *plr;
};

struct msr_param___3 {
	struct rdt_resource___3 *res;
	u32 low;
	u32 high;
};

struct rdt_hw_resource___3 {
	struct rdt_resource___3 r_resctrl;
	u32 num_closid;
	unsigned int msr_base;
	void (*msr_update)(struct rdt_domain___3 *, struct msr_param___3 *, struct rdt_resource___3 *);
	unsigned int mon_scale;
	unsigned int mbm_width;
	bool cdp_enabled;
};

struct trace_event_fields___9 {
	const char *type;
	union {
		struct {
			const char *name;
			const int size;
			const int align;
			const int is_signed;
			const int filter_type;
		};
		int (*define_fields)(struct trace_event_call___9 *);
	};
};

struct trace_event_class___9 {
	const char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct trace_event_call___9 *, enum trace_reg, void *);
	struct trace_event_fields___9 *fields_array;
	struct list_head * (*get_fields)(struct trace_event_call___9 *);
	struct list_head fields;
	int (*raw_init)(struct trace_event_call___9 *);
};

struct trace_event_file___6;

struct trace_event_buffer___6 {
	struct trace_buffer *buffer;
	struct ring_buffer_event *event;
	struct trace_event_file___6 *trace_file;
	void *entry;
	unsigned int trace_ctx;
	struct pt_regs *regs;
};

struct trace_event_file___6 {
	struct list_head list;
	struct trace_event_call___9 *event_call;
	struct event_filter *filter;
	struct dentry___17 *dir;
	struct trace_array *tr;
	struct trace_subsystem_dir *system;
	struct list_head triggers;
	long unsigned int flags;
	atomic_t sm_ref;
	atomic_t tm_ref;
};

struct trace_event_raw_pseudo_lock_mem_latency {
	struct trace_entry ent;
	u32 latency;
	char __data[0];
};

struct trace_event_raw_pseudo_lock_l2 {
	struct trace_entry ent;
	u64 l2_hits;
	u64 l2_miss;
	char __data[0];
};

struct trace_event_raw_pseudo_lock_l3 {
	struct trace_entry ent;
	u64 l3_hits;
	u64 l3_miss;
	char __data[0];
};

struct trace_event_data_offsets_pseudo_lock_mem_latency {};

struct trace_event_data_offsets_pseudo_lock_l2 {};

struct trace_event_data_offsets_pseudo_lock_l3 {};

typedef void (*btf_trace_pseudo_lock_mem_latency)(void *, u32);

typedef void (*btf_trace_pseudo_lock_l2)(void *, u64, u64);

typedef void (*btf_trace_pseudo_lock_l3)(void *, u64, u64);

struct pseudo_lock_pm_req {
	struct list_head list;
	struct dev_pm_qos_request___2 req;
};

struct residency_counts {
	u64 miss_before;
	u64 hits_before;
	u64 miss_after;
	u64 hits_after;
};

struct miscdevice___3 {
	int minor;
	const char *name;
	const struct file_operations___11 *fops;
	struct list_head list;
	struct device___12 *parent;
	struct device___12 *this_device;
	const struct attribute_group___12 **groups;
	const char *nodename;
	umode_t mode;
};

enum mmu_notifier_event {
	MMU_NOTIFY_UNMAP = 0,
	MMU_NOTIFY_CLEAR = 1,
	MMU_NOTIFY_PROTECTION_VMA = 2,
	MMU_NOTIFY_PROTECTION_PAGE = 3,
	MMU_NOTIFY_SOFT_DIRTY = 4,
	MMU_NOTIFY_RELEASE = 5,
	MMU_NOTIFY_MIGRATE = 6,
	MMU_NOTIFY_EXCLUSIVE = 7,
};

struct mmu_notifier;

struct mmu_notifier_range;

struct mmu_notifier_ops {
	void (*release)(struct mmu_notifier *, struct mm_struct___14 *);
	int (*clear_flush_young)(struct mmu_notifier *, struct mm_struct___14 *, long unsigned int, long unsigned int);
	int (*clear_young)(struct mmu_notifier *, struct mm_struct___14 *, long unsigned int, long unsigned int);
	int (*test_young)(struct mmu_notifier *, struct mm_struct___14 *, long unsigned int);
	void (*change_pte)(struct mmu_notifier *, struct mm_struct___14 *, long unsigned int, pte_t);
	int (*invalidate_range_start)(struct mmu_notifier *, const struct mmu_notifier_range *);
	void (*invalidate_range_end)(struct mmu_notifier *, const struct mmu_notifier_range *);
	void (*invalidate_range)(struct mmu_notifier *, struct mm_struct___14 *, long unsigned int, long unsigned int);
	struct mmu_notifier * (*alloc_notifier)(struct mm_struct___14 *);
	void (*free_notifier)(struct mmu_notifier *);
};

struct mmu_notifier {
	struct hlist_node hlist;
	const struct mmu_notifier_ops *ops;
	struct mm_struct___14 *mm;
	struct callback_head rcu;
	unsigned int users;
};

struct mmu_notifier_range {
	struct vm_area_struct___13 *vma;
	struct mm_struct___14 *mm;
	long unsigned int start;
	long unsigned int end;
	unsigned int flags;
	enum mmu_notifier_event event;
	void *owner;
};

enum sgx_page_type {
	SGX_PAGE_TYPE_SECS = 0,
	SGX_PAGE_TYPE_TCS = 1,
	SGX_PAGE_TYPE_REG = 2,
	SGX_PAGE_TYPE_VA = 3,
	SGX_PAGE_TYPE_TRIM = 4,
};

struct sgx_encl_page;

struct sgx_epc_page {
	unsigned int section;
	unsigned int flags;
	struct sgx_encl_page *owner;
	struct list_head list;
};

struct sgx_encl;

struct sgx_va_page;

struct sgx_encl_page {
	long unsigned int desc;
	long unsigned int vm_max_prot_bits;
	struct sgx_epc_page *epc_page;
	struct sgx_encl *encl;
	struct sgx_va_page *va_page;
};

struct sgx_encl {
	long unsigned int base;
	long unsigned int size;
	long unsigned int flags;
	unsigned int page_cnt;
	unsigned int secs_child_cnt;
	struct mutex lock;
	struct xarray page_array;
	struct sgx_encl_page secs;
	long unsigned int attributes;
	long unsigned int attributes_mask;
	cpumask_t cpumask;
	struct file___11 *backing;
	struct kref refcount;
	struct list_head va_pages;
	long unsigned int mm_list_version;
	struct list_head mm_list;
	spinlock_t mm_lock;
	struct srcu_struct srcu;
};

struct sgx_va_page {
	struct sgx_epc_page *epc_page;
	long unsigned int slots[8];
	struct list_head list;
};

struct sgx_encl_mm {
	struct sgx_encl *encl;
	struct mm_struct___14 *mm;
	struct list_head list;
	struct mmu_notifier mmu_notifier;
};

typedef unsigned int xa_mark_t;

struct xa_node {
	unsigned char shift;
	unsigned char offset;
	unsigned char count;
	unsigned char nr_values;
	struct xa_node *parent;
	struct xarray *array;
	union {
		struct list_head private_list;
		struct callback_head callback_head;
	};
	long: 64;
	long: 64;
	void *slots[64];
	union {
		long unsigned int tags[3];
		long unsigned int marks[3];
	};
};

typedef void (*xa_update_node_t)(struct xa_node *);

struct xa_state {
	struct xarray *xa;
	long unsigned int xa_index;
	unsigned char xa_shift;
	unsigned char xa_sibs;
	unsigned char xa_offset;
	unsigned char xa_pad;
	struct xa_node *xa_node;
	struct xa_node *xa_alloc;
	xa_update_node_t xa_update;
};

enum {
	XA_CHECK_SCHED = 4096,
};

enum sgx_encls_function {
	ECREATE = 0,
	EADD = 1,
	EINIT = 2,
	EREMOVE = 3,
	EDGBRD = 4,
	EDGBWR = 5,
	EEXTEND = 6,
	ELDU = 8,
	EBLOCK = 9,
	EPA = 10,
	EWB = 11,
	ETRACK = 12,
	EAUG = 13,
	EMODPR = 14,
	EMODT = 15,
};

struct sgx_pageinfo {
	u64 addr;
	u64 contents;
	u64 metadata;
	u64 secs;
};

struct mmu_notifier___2;

struct mmu_notifier_range___2;

struct mmu_notifier_ops___2 {
	void (*release)(struct mmu_notifier___2 *, struct mm_struct___2 *);
	int (*clear_flush_young)(struct mmu_notifier___2 *, struct mm_struct___2 *, long unsigned int, long unsigned int);
	int (*clear_young)(struct mmu_notifier___2 *, struct mm_struct___2 *, long unsigned int, long unsigned int);
	int (*test_young)(struct mmu_notifier___2 *, struct mm_struct___2 *, long unsigned int);
	void (*change_pte)(struct mmu_notifier___2 *, struct mm_struct___2 *, long unsigned int, pte_t);
	int (*invalidate_range_start)(struct mmu_notifier___2 *, const struct mmu_notifier_range___2 *);
	void (*invalidate_range_end)(struct mmu_notifier___2 *, const struct mmu_notifier_range___2 *);
	void (*invalidate_range)(struct mmu_notifier___2 *, struct mm_struct___2 *, long unsigned int, long unsigned int);
	struct mmu_notifier___2 * (*alloc_notifier)(struct mm_struct___2 *);
	void (*free_notifier)(struct mmu_notifier___2 *);
};

struct mmu_notifier___2 {
	struct hlist_node hlist;
	const struct mmu_notifier_ops___2 *ops;
	struct mm_struct___2 *mm;
	struct callback_head rcu;
	unsigned int users;
};

struct mmu_notifier_range___2 {
	struct vm_area_struct___2 *vma;
	struct mm_struct___2 *mm;
	long unsigned int start;
	long unsigned int end;
	unsigned int flags;
	enum mmu_notifier_event event;
	void *owner;
};

struct sgx_encl_page___2;

struct sgx_epc_page___2 {
	unsigned int section;
	unsigned int flags;
	struct sgx_encl_page___2 *owner;
	struct list_head list;
};

struct sgx_encl___2;

struct sgx_va_page___2;

struct sgx_encl_page___2 {
	long unsigned int desc;
	long unsigned int vm_max_prot_bits;
	struct sgx_epc_page___2 *epc_page;
	struct sgx_encl___2 *encl;
	struct sgx_va_page___2 *va_page;
};

struct sgx_numa_node {
	struct list_head free_page_list;
	spinlock_t lock;
};

struct sgx_epc_section {
	long unsigned int phys_addr;
	void *virt_addr;
	struct sgx_epc_page___2 *pages;
	struct sgx_numa_node *node;
};

struct sgx_encl___2 {
	long unsigned int base;
	long unsigned int size;
	long unsigned int flags;
	unsigned int page_cnt;
	unsigned int secs_child_cnt;
	struct mutex lock;
	struct xarray page_array;
	struct sgx_encl_page___2 secs;
	long unsigned int attributes;
	long unsigned int attributes_mask;
	cpumask_t cpumask;
	struct file___2 *backing;
	struct kref refcount;
	struct list_head va_pages;
	long unsigned int mm_list_version;
	struct list_head mm_list;
	spinlock_t mm_lock;
	struct srcu_struct srcu;
};

struct sgx_va_page___2 {
	struct sgx_epc_page___2 *epc_page;
	long unsigned int slots[8];
	struct list_head list;
};

enum sgx_encl_flags {
	SGX_ENCL_IOCTL = 1,
	SGX_ENCL_DEBUG = 2,
	SGX_ENCL_CREATED = 4,
	SGX_ENCL_INITIALIZED = 8,
};

struct sgx_encl_mm___2 {
	struct sgx_encl___2 *encl;
	struct mm_struct___2 *mm;
	struct list_head list;
	struct mmu_notifier___2 mmu_notifier;
};

struct sgx_backing {
	long unsigned int page_index;
	struct page___2 *contents;
	struct page___2 *pcmd;
	long unsigned int pcmd_offset;
};

enum sgx_return_code {
	SGX_NOT_TRACKED = 11,
	SGX_CHILD_PRESENT = 13,
	SGX_INVALID_EINITTOKEN = 16,
	SGX_UNMASKED_EVENT = 128,
};

enum sgx_attribute {
	SGX_ATTR_INIT = 1,
	SGX_ATTR_DEBUG = 2,
	SGX_ATTR_MODE64BIT = 4,
	SGX_ATTR_PROVISIONKEY = 16,
	SGX_ATTR_EINITTOKENKEY = 32,
	SGX_ATTR_KSS = 128,
};

struct sgx_secs {
	u64 size;
	u64 base;
	u32 ssa_frame_size;
	u32 miscselect;
	u8 reserved1[24];
	u64 attributes;
	u64 xfrm;
	u32 mrenclave[8];
	u8 reserved2[32];
	u32 mrsigner[8];
	u8 reserved3[32];
	u32 config_id[16];
	u16 isv_prod_id;
	u16 isv_svn;
	u16 config_svn;
	u8 reserved4[3834];
};

enum sgx_secinfo_flags {
	SGX_SECINFO_R = 1,
	SGX_SECINFO_W = 2,
	SGX_SECINFO_X = 4,
	SGX_SECINFO_SECS = 0,
	SGX_SECINFO_TCS = 256,
	SGX_SECINFO_REG = 512,
	SGX_SECINFO_VA = 768,
	SGX_SECINFO_TRIM = 1024,
};

struct sgx_secinfo {
	u64 flags;
	u8 reserved[56];
};

struct sgx_sigstruct_header {
	u64 header1[2];
	u32 vendor;
	u32 date;
	u64 header2[2];
	u32 swdefined;
	u8 reserved1[84];
};

struct sgx_sigstruct_body {
	u32 miscselect;
	u32 misc_mask;
	u8 reserved2[20];
	u64 attributes;
	u64 xfrm;
	u64 attributes_mask;
	u64 xfrm_mask;
	u8 mrenclave[32];
	u8 reserved3[32];
	u16 isvprodid;
	u16 isvsvn;
} __attribute__((packed));

struct sgx_sigstruct {
	struct sgx_sigstruct_header header;
	u8 modulus[384];
	u32 exponent;
	u8 signature[384];
	struct sgx_sigstruct_body body;
	u8 reserved4[12];
	u8 q1[384];
	u8 q2[384];
} __attribute__((packed));

struct crypto_alg;

struct crypto_tfm {
	u32 crt_flags;
	int node;
	void (*exit)(struct crypto_tfm *);
	struct crypto_alg *__crt_alg;
	void *__crt_ctx[0];
};

struct cipher_alg {
	unsigned int cia_min_keysize;
	unsigned int cia_max_keysize;
	int (*cia_setkey)(struct crypto_tfm *, const u8 *, unsigned int);
	void (*cia_encrypt)(struct crypto_tfm *, u8 *, const u8 *);
	void (*cia_decrypt)(struct crypto_tfm *, u8 *, const u8 *);
};

struct compress_alg {
	int (*coa_compress)(struct crypto_tfm *, const u8 *, unsigned int, u8 *, unsigned int *);
	int (*coa_decompress)(struct crypto_tfm *, const u8 *, unsigned int, u8 *, unsigned int *);
};

struct crypto_istat_aead {
	atomic64_t encrypt_cnt;
	atomic64_t encrypt_tlen;
	atomic64_t decrypt_cnt;
	atomic64_t decrypt_tlen;
	atomic64_t err_cnt;
};

struct crypto_istat_akcipher {
	atomic64_t encrypt_cnt;
	atomic64_t encrypt_tlen;
	atomic64_t decrypt_cnt;
	atomic64_t decrypt_tlen;
	atomic64_t verify_cnt;
	atomic64_t sign_cnt;
	atomic64_t err_cnt;
};

struct crypto_istat_cipher {
	atomic64_t encrypt_cnt;
	atomic64_t encrypt_tlen;
	atomic64_t decrypt_cnt;
	atomic64_t decrypt_tlen;
	atomic64_t err_cnt;
};

struct crypto_istat_compress {
	atomic64_t compress_cnt;
	atomic64_t compress_tlen;
	atomic64_t decompress_cnt;
	atomic64_t decompress_tlen;
	atomic64_t err_cnt;
};

struct crypto_istat_hash {
	atomic64_t hash_cnt;
	atomic64_t hash_tlen;
	atomic64_t err_cnt;
};

struct crypto_istat_kpp {
	atomic64_t setsecret_cnt;
	atomic64_t generate_public_key_cnt;
	atomic64_t compute_shared_secret_cnt;
	atomic64_t err_cnt;
};

struct crypto_istat_rng {
	atomic64_t generate_cnt;
	atomic64_t generate_tlen;
	atomic64_t seed_cnt;
	atomic64_t err_cnt;
};

struct crypto_type;

struct crypto_alg {
	struct list_head cra_list;
	struct list_head cra_users;
	u32 cra_flags;
	unsigned int cra_blocksize;
	unsigned int cra_ctxsize;
	unsigned int cra_alignmask;
	int cra_priority;
	refcount_t cra_refcnt;
	char cra_name[128];
	char cra_driver_name[128];
	const struct crypto_type *cra_type;
	union {
		struct cipher_alg cipher;
		struct compress_alg compress;
	} cra_u;
	int (*cra_init)(struct crypto_tfm *);
	void (*cra_exit)(struct crypto_tfm *);
	void (*cra_destroy)(struct crypto_alg *);
	struct module___2 *cra_module;
	union {
		struct crypto_istat_aead aead;
		struct crypto_istat_akcipher akcipher;
		struct crypto_istat_cipher cipher;
		struct crypto_istat_compress compress;
		struct crypto_istat_hash hash;
		struct crypto_istat_rng rng;
		struct crypto_istat_kpp kpp;
	} stats;
};

struct crypto_shash;

struct shash_desc {
	struct crypto_shash *tfm;
	void *__ctx[0];
};

struct crypto_shash {
	unsigned int descsize;
	struct crypto_tfm base;
};

enum sgx_page_flags {
	SGX_PAGE_MEASURE = 1,
};

struct sgx_enclave_create {
	__u64 src;
};

struct sgx_enclave_add_pages {
	__u64 src;
	__u64 offset;
	__u64 length;
	__u64 secinfo;
	__u64 flags;
	__u64 count;
};

struct sgx_enclave_init {
	__u64 sigstruct;
};

struct sgx_enclave_provision {
	__u64 fd;
};

struct sgx_epc_section___2 {
	long unsigned int phys_addr;
	void *virt_addr;
	struct sgx_epc_page *pages;
	struct sgx_numa_node *node;
};

struct sgx_backing___2 {
	long unsigned int page_index;
	struct page___12 *contents;
	struct page___12 *pcmd;
	long unsigned int pcmd_offset;
};

struct sgx_vepc {
	struct xarray page_array;
	struct mutex lock;
};

struct smp_ops___3 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*crash_stop_other_cpus)();
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___13 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct vmcb_seg {
	u16 selector;
	u16 attrib;
	u32 limit;
	u64 base;
};

struct vmcb_save_area {
	struct vmcb_seg es;
	struct vmcb_seg cs;
	struct vmcb_seg ss;
	struct vmcb_seg ds;
	struct vmcb_seg fs;
	struct vmcb_seg gs;
	struct vmcb_seg gdtr;
	struct vmcb_seg ldtr;
	struct vmcb_seg idtr;
	struct vmcb_seg tr;
	u8 reserved_1[43];
	u8 cpl;
	u8 reserved_2[4];
	u64 efer;
	u8 reserved_3[104];
	u64 xss;
	u64 cr4;
	u64 cr3;
	u64 cr0;
	u64 dr7;
	u64 dr6;
	u64 rflags;
	u64 rip;
	u8 reserved_4[88];
	u64 rsp;
	u8 reserved_5[24];
	u64 rax;
	u64 star;
	u64 lstar;
	u64 cstar;
	u64 sfmask;
	u64 kernel_gs_base;
	u64 sysenter_cs;
	u64 sysenter_esp;
	u64 sysenter_eip;
	u64 cr2;
	u8 reserved_6[32];
	u64 g_pat;
	u64 dbgctl;
	u64 br_from;
	u64 br_to;
	u64 last_excp_from;
	u64 last_excp_to;
	u8 reserved_7[72];
	u32 spec_ctrl;
	u8 reserved_7b[4];
	u32 pkru;
	u8 reserved_7a[20];
	u64 reserved_8;
	u64 rcx;
	u64 rdx;
	u64 rbx;
	u64 reserved_9;
	u64 rbp;
	u64 rsi;
	u64 rdi;
	u64 r8;
	u64 r9;
	u64 r10;
	u64 r11;
	u64 r12;
	u64 r13;
	u64 r14;
	u64 r15;
	u8 reserved_10[16];
	u64 sw_exit_code;
	u64 sw_exit_info_1;
	u64 sw_exit_info_2;
	u64 sw_scratch;
	u8 reserved_11[56];
	u64 xcr0;
	u8 valid_bitmap[16];
	u64 x87_state_gpa;
};

struct ghcb {
	struct vmcb_save_area save;
	u8 reserved_save[1016];
	u8 shared_buffer[2032];
	u8 reserved_1[10];
	u16 protocol_version;
	u32 ghcb_usage;
};

enum intercept_words {
	INTERCEPT_CR = 0,
	INTERCEPT_DR = 1,
	INTERCEPT_EXCEPTION = 2,
	INTERCEPT_WORD3 = 3,
	INTERCEPT_WORD4 = 4,
	INTERCEPT_WORD5 = 5,
	MAX_INTERCEPT = 6,
};

struct vmware_steal_time {
	union {
		uint64_t clock;
		struct {
			uint32_t clock_low;
			uint32_t clock_high;
		};
	};
	uint64_t reserved[7];
};

struct dentry___18;

struct super_block___18;

struct module___17;

struct file_system_type___18 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___18 * (*mount)(struct file_system_type___18 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___18 *);
	struct module___17 *owner;
	struct file_system_type___18 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct page___19;

typedef struct page___19 *pgtable_t___19;

struct address_space___18;

struct mm_struct___20;

struct dev_pagemap___18;

struct page___19 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___18 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___4 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___19 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___19 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___20 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___18 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct thread_struct___11;

struct task_struct___21;

struct pv_cpu_ops___15 {
	void (*io_delay)();
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	void (*write_cr4)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___11 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(long unsigned int);
	void (*invalidate_io_bitmap)();
	void (*update_io_bitmap)();
	void (*wbinvd)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int);
	void (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_msr_safe)(unsigned int, int *);
	int (*write_msr_safe)(unsigned int, unsigned int, unsigned int);
	u64 (*read_pmc)(int);
	void (*start_context_switch)(struct task_struct___21 *);
	void (*end_context_switch)(struct task_struct___21 *);
};

struct perf_event___10;

struct thread_struct___11 {
	struct desc_struct tls_array[3];
	long unsigned int sp;
	short unsigned int es;
	short unsigned int ds;
	short unsigned int fsindex;
	short unsigned int gsindex;
	long unsigned int fsbase;
	long unsigned int gsbase;
	struct perf_event___10 *ptrace_bps[4];
	long unsigned int virtual_dr6;
	long unsigned int ptrace_dr7;
	long unsigned int cr2;
	long unsigned int trap_nr;
	long unsigned int error_code;
	struct io_bitmap *io_bitmap;
	long unsigned int iopl_emul;
	unsigned int iopl_warn: 1;
	unsigned int sig_on_uaccess_err: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u32 pkru;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct fpu fpu;
};

struct vm_area_struct___20;

struct vmacache___19 {
	u64 seqnum;
	struct vm_area_struct___20 *vmas[4];
};

struct page_frag___19 {
	struct page___19 *page;
	__u32 offset;
	__u32 size;
};

struct pid___16;

struct nsproxy___17;

struct signal_struct___19;

struct bio_list___11;

struct backing_dev_info___10;

struct io_context___12;

struct css_set___13;

struct perf_event_context___10;

struct mem_cgroup___10;

struct request_queue___11;

struct vm_struct___16;

struct task_struct___21 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___21 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___20 *mm;
	struct mm_struct___20 *active_mm;
	struct vmacache___19 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int restore_sigmask: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___21 *real_parent;
	struct task_struct___21 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___21 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___16 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	struct posix_cputimers_work posix_cputimers_work;
	const struct cred *ptracer_cred;
	const struct cred *real_cred;
	const struct cred *cred;
	struct key *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___17 *nsproxy;
	struct signal_struct___19 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___21 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___11 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___10 *backing_dev_info;
	struct io_context___12 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___13 *cgroups;
	struct list_head cg_list;
	u32 closid;
	u32 rmid;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___10 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	long: 64;
	long: 64;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___19 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___10 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___10 *active_memcg;
	struct request_queue___11 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___21 *oom_reaper_list;
	struct vm_struct___16 *stack_vm_area;
	refcount_t stack_refcount;
	int patch_state;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	void *mce_vaddr;
	__u64 mce_kflags;
	u64 mce_addr;
	__u64 mce_ripv: 1;
	__u64 mce_whole_page: 1;
	__u64 __mce_reserved: 62;
	long: 2;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct callback_head mce_kill_me;
	int mce_count;
	struct llist_head kretprobe_instances;
	struct callback_head l1d_flush_kill;
	long: 64;
	struct thread_struct___11 thread;
};

struct pv_mmu_ops___15 {
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_one_user)(long unsigned int);
	void (*flush_tlb_multi)(const struct cpumask *, const struct flush_tlb_info___3 *);
	void (*tlb_remove_table)(struct mmu_gather *, void *);
	void (*exit_mmap)(struct mm_struct___20 *);
	struct paravirt_callee_save read_cr2;
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___20 *, struct mm_struct___20 *);
	void (*dup_mmap)(struct mm_struct___20 *, struct mm_struct___20 *);
	int (*pgd_alloc)(struct mm_struct___20 *);
	void (*pgd_free)(struct mm_struct___20 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___20 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___20 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___20 *, long unsigned int);
	void (*alloc_p4d)(struct mm_struct___20 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*release_p4d)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	pte_t (*ptep_modify_prot_start)(struct vm_area_struct___20 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct vm_area_struct___20 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_p4d)(p4d_t *, p4d_t);
	struct paravirt_callee_save p4d_val;
	struct paravirt_callee_save make_p4d;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

struct file___18;

struct core_state___19;

struct mm_struct___20 {
	struct {
		struct vm_area_struct___20 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___18 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int mmap_compat_base;
		long unsigned int mmap_compat_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[48];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___19 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___21 *owner;
		struct user_namespace *user_ns;
		struct file___18 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		bool tlb_flush_batched;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct vm_operations_struct___18;

struct vm_area_struct___20 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___20 *vm_next;
	struct vm_area_struct___20 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___20 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___18 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___18 *vm_file;
	struct file___18 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct paravirt_patch_template___15 {
	struct pv_cpu_ops___15 cpu;
	struct pv_irq_ops irq;
	struct pv_mmu_ops___15 mmu;
	struct pv_lock_ops lock;
};

struct kiocb___18;

struct iov_iter___14;

struct poll_table_struct___12;

struct inode___18;

struct file_lock___18;

struct seq_file___16;

struct file_operations___18 {
	struct module___17 *owner;
	loff_t (*llseek)(struct file___18 *, loff_t, int);
	ssize_t (*read)(struct file___18 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___18 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___18 *, struct iov_iter___14 *);
	ssize_t (*write_iter)(struct kiocb___18 *, struct iov_iter___14 *);
	int (*iopoll)(struct kiocb___18 *, bool);
	int (*iterate)(struct file___18 *, struct dir_context *);
	int (*iterate_shared)(struct file___18 *, struct dir_context *);
	__poll_t (*poll)(struct file___18 *, struct poll_table_struct___12 *);
	long int (*unlocked_ioctl)(struct file___18 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___18 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___18 *, struct vm_area_struct___20 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___18 *, struct file___18 *);
	int (*flush)(struct file___18 *, fl_owner_t);
	int (*release)(struct inode___18 *, struct file___18 *);
	int (*fsync)(struct file___18 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___18 *, int);
	int (*lock)(struct file___18 *, int, struct file_lock___18 *);
	ssize_t (*sendpage)(struct file___18 *, struct page___19 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___18 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___18 *, long unsigned int);
	int (*flock)(struct file___18 *, int, struct file_lock___18 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___18 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___18 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___18 *, long int, struct file_lock___18 **, void **);
	long int (*fallocate)(struct file___18 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___16 *, struct file___18 *);
	ssize_t (*copy_file_range)(struct file___18 *, loff_t, struct file___18 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___18 *, loff_t, struct file___18 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___18 *, loff_t, loff_t, int);
};

struct static_call_mod___12 {
	struct static_call_mod___12 *next;
	struct module___17 *mod;
	struct static_call_site *sites;
};

struct static_call_key___12 {
	void *func;
	union {
		long unsigned int type;
		struct static_call_mod___12 *mods;
		struct static_call_site *sites;
	};
};

struct tracepoint___12 {
	const char *name;
	struct static_key key;
	struct static_call_key___12 *static_call_key;
	void *static_call_tramp;
	void *iterator;
	int (*regfunc)();
	void (*unregfunc)();
	struct tracepoint_func *funcs;
};

struct bpf_raw_event_map___12 {
	struct tracepoint___12 *tp;
	void *bpf_func;
	u32 num_args;
	u32 writable_size;
	long: 64;
};

struct seq_operations___16 {
	void * (*start)(struct seq_file___16 *, loff_t *);
	void (*stop)(struct seq_file___16 *, void *);
	void * (*next)(struct seq_file___16 *, void *, loff_t *);
	int (*show)(struct seq_file___16 *, void *);
};

struct hw_perf_event___10 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___21 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	union {
		struct {
			u64 last_period;
			local64_t period_left;
		};
		struct {
			u64 saved_metric;
			u64 saved_slots;
		};
	};
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___10)(struct perf_event___10 *, struct perf_sample_data *, struct pt_regs *);

struct pmu___10;

struct fasync_struct___18;

struct pid_namespace___16;

struct trace_event_call___10;

struct perf_cgroup___10;

struct perf_event___10 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___10 *group_leader;
	struct pmu___10 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___10 hw;
	struct perf_event_context___10 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___10 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___21 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct perf_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___18 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	long unsigned int pending_addr;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	struct perf_addr_filter_range *addr_filter_ranges;
	long unsigned int addr_filters_gen;
	struct perf_event___10 *aux_event;
	void (*destroy)(struct perf_event___10 *);
	struct callback_head callback_head;
	struct pid_namespace___16 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___10 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___10 orig_overflow_handler;
	struct bpf_prog *prog;
	u64 bpf_cookie;
	struct trace_event_call___10 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___10 *cgrp;
	void *security;
	struct list_head sb_list;
};

struct smp_ops___4 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*crash_stop_other_cpus)();
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___21 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct address_space_operations___18;

struct address_space___18 {
	struct inode___18 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___18 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct dev_pagemap_ops___18;

struct dev_pagemap___18 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___18 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vfsmount___18;

struct path___18 {
	struct vfsmount___18 *mnt;
	struct dentry___18 *dentry;
};

struct fown_struct___16 {
	rwlock_t lock;
	struct pid___16 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___18 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	long: 64;
	long: 64;
	struct path___18 f_path;
	struct inode___18 *f_inode;
	const struct file_operations___18 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___16 f_owner;
	const struct cred *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___18 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___18;

struct vm_operations_struct___18 {
	void (*open)(struct vm_area_struct___20 *);
	void (*close)(struct vm_area_struct___20 *);
	int (*may_split)(struct vm_area_struct___20 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___20 *);
	int (*mprotect)(struct vm_area_struct___20 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___18 *);
	vm_fault_t (*huge_fault)(struct vm_fault___18 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___18 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___20 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___18 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___18 *);
	int (*access)(struct vm_area_struct___20 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___20 *);
	int (*set_policy)(struct vm_area_struct___20 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___20 *, long unsigned int);
	struct page___19 * (*find_special_page)(struct vm_area_struct___20 *, long unsigned int);
};

struct core_thread___19 {
	struct task_struct___21 *task;
	struct core_thread___19 *next;
};

struct core_state___19 {
	atomic_t nr_threads;
	struct core_thread___19 dumper;
	struct completion startup;
};

struct vm_fault___18 {
	const struct {
		struct vm_area_struct___20 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___19 *cow_page;
	struct page___19 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___19 prealloc_pte;
};

struct pglist_data___11;

struct lruvec___11 {
	struct list_head lists[5];
	spinlock_t lru_lock;
	long unsigned int anon_cost;
	long unsigned int file_cost;
	atomic_long_t nonresident_age;
	long unsigned int refaults[2];
	long unsigned int flags;
	struct pglist_data___11 *pgdat;
};

struct zone___11 {
	long unsigned int _watermark[3];
	long unsigned int watermark_boost;
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[5];
	int node;
	struct pglist_data___11 *zone_pgdat;
	struct per_cpu_pages *per_cpu_pageset;
	struct per_cpu_zonestat *per_cpu_zonestats;
	int pageset_high;
	int pageset_batch;
	long unsigned int zone_start_pfn;
	atomic_long_t managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int present_early_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	seqlock_t span_seqlock;
	int initialized;
	int: 32;
	struct zone_padding _pad1_;
	struct free_area free_area[11];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	long unsigned int compact_init_migrate_pfn;
	long unsigned int compact_init_free_pfn;
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	short: 16;
	struct zone_padding _pad3_;
	atomic_long_t vm_stat[11];
	atomic_long_t vm_numa_event[6];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___11 {
	struct zone___11 *zone;
	int zone_idx;
};

struct zonelist___11 {
	struct zoneref___11 _zonerefs[5121];
};

struct pglist_data___11 {
	struct zone___11 node_zones[5];
	struct zonelist___11 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___21 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_highest_zoneidx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_highest_zoneidx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___21 *kcompactd;
	bool proactive_compact_trigger;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct deferred_split deferred_split_queue;
	struct lruvec___11 __lruvec;
	long unsigned int flags;
	long: 64;
	struct zone_padding _pad2_;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[39];
};

struct irq_domain_ops___12;

struct fwnode_handle___17;

struct irq_domain_chip_generic___6;

struct irq_data___7;

struct irq_domain___12 {
	struct list_head link;
	const char *name;
	const struct irq_domain_ops___12 *ops;
	void *host_data;
	unsigned int flags;
	unsigned int mapcount;
	struct fwnode_handle___17 *fwnode;
	enum irq_domain_bus_token bus_token;
	struct irq_domain_chip_generic___6 *gc;
	struct irq_domain___12 *parent;
	irq_hw_number_t hwirq_max;
	unsigned int revmap_size;
	struct xarray revmap_tree;
	struct mutex revmap_mutex;
	struct irq_data___7 *revmap[0];
};

struct kernfs_root___18;

struct kernfs_elem_dir___18 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___18 *root;
	long unsigned int rev;
};

struct kernfs_node___18;

struct kernfs_syscall_ops___18;

struct kernfs_root___18 {
	struct kernfs_node___18 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___18 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___18 {
	struct kernfs_node___18 *target_kn;
};

struct kernfs_ops___18;

struct kernfs_elem_attr___18 {
	const struct kernfs_ops___18 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___18 *notify_next;
};

struct kernfs_node___18 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___18 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___18 dir;
		struct kernfs_elem_symlink___18 symlink;
		struct kernfs_elem_attr___18 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___18;

struct kernfs_ops___18 {
	int (*open)(struct kernfs_open_file___18 *);
	void (*release)(struct kernfs_open_file___18 *);
	int (*seq_show)(struct seq_file___16 *, void *);
	void * (*seq_start)(struct seq_file___16 *, loff_t *);
	void * (*seq_next)(struct seq_file___16 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___16 *, void *);
	ssize_t (*read)(struct kernfs_open_file___18 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___18 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___18 *, struct poll_table_struct___12 *);
	int (*mmap)(struct kernfs_open_file___18 *, struct vm_area_struct___20 *);
};

struct kernfs_syscall_ops___18 {
	int (*show_options)(struct seq_file___16 *, struct kernfs_root___18 *);
	int (*mkdir)(struct kernfs_node___18 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___18 *);
	int (*rename)(struct kernfs_node___18 *, struct kernfs_node___18 *, const char *);
	int (*show_path)(struct seq_file___16 *, struct kernfs_node___18 *, struct kernfs_root___18 *);
};

struct seq_file___16 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___16 *op;
	int poll_event;
	const struct file___18 *file;
	void *private;
};

struct kernfs_open_file___18 {
	struct kernfs_node___18 *kn;
	struct file___18 *file;
	struct seq_file___16 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___18 *vm_ops;
};

typedef void (*poll_queue_proc___12)(struct file___18 *, wait_queue_head_t *, struct poll_table_struct___12 *);

struct poll_table_struct___12 {
	poll_queue_proc___12 _qproc;
	__poll_t _key;
};

struct kobject___18;

struct bin_attribute___18;

struct attribute_group___18 {
	const char *name;
	umode_t (*is_visible)(struct kobject___18 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___18 *, struct bin_attribute___18 *, int);
	struct attribute **attrs;
	struct bin_attribute___18 **bin_attrs;
};

struct kset___17;

struct kobj_type___17;

struct kobject___18 {
	const char *name;
	struct list_head entry;
	struct kobject___18 *parent;
	struct kset___17 *kset;
	struct kobj_type___17 *ktype;
	struct kernfs_node___18 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bin_attribute___18 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___18 * (*f_mapping)();
	ssize_t (*read)(struct file___18 *, struct kobject___18 *, struct bin_attribute___18 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___18 *, struct kobject___18 *, struct bin_attribute___18 *, char *, loff_t, size_t);
	int (*mmap)(struct file___18 *, struct kobject___18 *, struct bin_attribute___18 *, struct vm_area_struct___20 *);
};

struct sysfs_ops___17 {
	ssize_t (*show)(struct kobject___18 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___18 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___17;

struct kset___17 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___18 kobj;
	const struct kset_uevent_ops___17 *uevent_ops;
};

struct kobj_type___17 {
	void (*release)(struct kobject___18 *);
	const struct sysfs_ops___17 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___18 **default_groups;
	const struct kobj_ns_type_operations * (*child_ns_type)(struct kobject___18 *);
	const void * (*namespace)(struct kobject___18 *);
	void (*get_ownership)(struct kobject___18 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___17 {
	int (* const filter)(struct kset___17 *, struct kobject___18 *);
	const char * (* const name)(struct kset___17 *, struct kobject___18 *);
	int (* const uevent)(struct kset___17 *, struct kobject___18 *, struct kobj_uevent_env *);
};

struct fwnode_operations___17;

struct device___19;

struct fwnode_handle___17 {
	struct fwnode_handle___17 *secondary;
	const struct fwnode_operations___17 *ops;
	struct device___19 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct fwnode_reference_args___17;

struct fwnode_endpoint___17;

struct fwnode_operations___17 {
	struct fwnode_handle___17 * (*get)(struct fwnode_handle___17 *);
	void (*put)(struct fwnode_handle___17 *);
	bool (*device_is_available)(const struct fwnode_handle___17 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___17 *, const struct device___19 *);
	bool (*property_present)(const struct fwnode_handle___17 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___17 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___17 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___17 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___17 *);
	struct fwnode_handle___17 * (*get_parent)(const struct fwnode_handle___17 *);
	struct fwnode_handle___17 * (*get_next_child_node)(const struct fwnode_handle___17 *, struct fwnode_handle___17 *);
	struct fwnode_handle___17 * (*get_named_child_node)(const struct fwnode_handle___17 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___17 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___17 *);
	struct fwnode_handle___17 * (*graph_get_next_endpoint)(const struct fwnode_handle___17 *, struct fwnode_handle___17 *);
	struct fwnode_handle___17 * (*graph_get_remote_endpoint)(const struct fwnode_handle___17 *);
	struct fwnode_handle___17 * (*graph_get_port_parent)(struct fwnode_handle___17 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___17 *, struct fwnode_endpoint___17 *);
	int (*add_links)(struct fwnode_handle___17 *);
};

struct wakeup_source___19;

struct dev_pm_info___19 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___19 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___19 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___19;

struct bus_type___19;

struct device_driver___19;

struct dev_pm_domain___19;

struct device_node___13;

struct class___19;

struct device___19 {
	struct kobject___18 kobj;
	struct device___19 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___19 *type;
	struct bus_type___19 *bus;
	struct device_driver___19 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___19 power;
	struct dev_pm_domain___19 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___12 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___13 *of_node;
	struct fwnode_handle___17 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___19 *class;
	const struct attribute_group___18 **groups;
	void (*release)(struct device___19 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fwnode_endpoint___17 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___17 *local_fwnode;
};

struct fwnode_reference_args___17 {
	struct fwnode_handle___17 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct device_node___13 {
	const char *name;
	phandle phandle;
	const char *full_name;
	struct fwnode_handle___17 fwnode;
	struct property *properties;
	struct property *deadprops;
	struct device_node___13 *parent;
	struct device_node___13 *child;
	struct device_node___13 *sibling;
	long unsigned int _flags;
	void *data;
};

struct vm_struct___16 {
	struct vm_struct___16 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___19 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct module_kobject___17 {
	struct kobject___18 kobj;
	struct module___17 *mod;
	struct kobject___18 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___17 {
	struct module___17 *mod;
	struct latch_tree_node node;
};

struct module_layout___17 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___17 mtn;
};

struct module_attribute___17;

struct kernel_param___17;

struct module___17 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___17 mkobj;
	struct module_attribute___17 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___18 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___17 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___17 core_layout;
	struct module_layout___17 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map___12 *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___10 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	int num_static_call_sites;
	struct static_call_site *static_call_sites;
	bool klp;
	bool klp_alive;
	struct klp_modinfo *klp_info;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct upid___16 {
	int nr;
	struct pid_namespace___16 *ns;
};

struct pid_namespace___16 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___21 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___16 *parent;
	struct fs_pin *bacct;
	struct user_namespace *user_ns;
	struct ucounts *ucounts;
	int reboot;
	struct ns_common ns;
};

struct pid___16 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___16 numbers[1];
};

struct signal_struct___19 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___21 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___21 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___16 *pids[4];
	struct pid___16 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___20 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct cgroup_namespace___13;

struct nsproxy___17 {
	atomic_t count;
	struct uts_namespace *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___16 *pid_ns_for_children;
	struct net *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___13 *cgroup_ns;
};

struct bio___11;

struct bio_list___11 {
	struct bio___11 *head;
	struct bio___11 *tail;
};

struct cgroup_subsys_state___13;

struct bdi_writeback___10 {
	struct backing_dev_info___10 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	atomic_t writeback_inodes;
	struct percpu_counter stat[4];
	long unsigned int congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	struct delayed_work bw_dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___13 *memcg_css;
	struct cgroup_subsys_state___13 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	struct list_head b_attached;
	struct list_head offline_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
};

struct backing_dev_info___10 {
	u64 id;
	struct rb_node rb_node;
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___10 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct mutex cgwb_release_mutex;
	struct rw_semaphore wb_switch_rwsem;
	wait_queue_head_t wb_waitq;
	struct device___19 *dev;
	char dev_name[64];
	struct device___19 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___18 *debug_dir;
};

struct io_cq___11;

struct io_context___12 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	struct xarray icq_tree;
	struct io_cq___11 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct cgroup___13;

struct css_set___13 {
	struct cgroup_subsys_state___13 *subsys[14];
	refcount_t refcount;
	struct css_set___13 *dom_cset;
	struct cgroup___13 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___13 *mg_src_cgrp;
	struct cgroup___13 *mg_dst_cgrp;
	struct css_set___13 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___10 {
	struct pmu___10 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	int rotate_necessary;
	refcount_t refcount;
	struct task_struct___21 *task;
	u64 time;
	u64 timestamp;
	u64 timeoffset;
	struct perf_event_context___10 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

struct cgroup_subsys___13;

struct cgroup_subsys_state___13 {
	struct cgroup___13 *cgroup;
	struct cgroup_subsys___13 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___13 *parent;
};

struct cgroup_file___13 {
	struct kernfs_node___18 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct obj_cgroup___10;

struct mem_cgroup_per_node___10;

struct mem_cgroup___10 {
	struct cgroup_subsys_state___13 css;
	struct mem_cgroup_id id;
	struct page_counter memory;
	union {
		struct page_counter swap;
		struct page_counter memsw;
	};
	struct page_counter kmem;
	struct page_counter tcpmem;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool oom_group;
	bool oom_lock;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___13 events_file;
	struct cgroup_file___13 events_local_file;
	struct cgroup_file___13 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	struct memcg_vmstats vmstats;
	atomic_long_t memory_events[8];
	atomic_long_t memory_events_local[8];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct obj_cgroup___10 *objcg;
	struct list_head objcg_list;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad2_;
	atomic_t moving_account;
	struct task_struct___21 *move_lock_task;
	struct memcg_vmstats_percpu *vmstats_percpu;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct memcg_cgwb_frn cgwb_frn[4];
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct deferred_split deferred_split_queue;
	struct mem_cgroup_per_node___10 *nodeinfo[0];
	long: 64;
};

struct blk_integrity_profile___11;

struct blk_integrity___11 {
	const struct blk_integrity_profile___11 *profile;
	unsigned char flags;
	unsigned char tuple_size;
	unsigned char interval_exp;
	unsigned char tag_size;
};

struct bio_set___11 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	struct bio_alloc_cache *cache;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	unsigned int back_pad;
	spinlock_t rescue_lock;
	struct bio_list___11 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	struct hlist_node cpuhp_dead;
};

struct request___11;

struct elevator_queue___11;

struct gendisk___11;

struct blkcg_gq___10;

struct request_queue___11 {
	struct request___11 *last_merge;
	struct elevator_queue___11 *elevator;
	struct percpu_ref q_usage_counter;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	const struct blk_mq_ops *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx **queue_hw_ctx;
	unsigned int nr_hw_queues;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	spinlock_t queue_lock;
	struct gendisk___11 *disk;
	struct kobject___18 kobj;
	struct kobject___18 *mq_kobj;
	struct blk_integrity___11 integrity;
	struct device___19 *dev;
	enum rpm_status rpm_status;
	long unsigned int nr_requests;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_keyslot_manager *ksm;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	atomic_t nr_active_requests_shared_sbitmap;
	struct sbitmap_queue sched_bitmap_tags;
	struct sbitmap_queue sched_breserved_tags;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___10 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int required_elevator_features;
	unsigned int nr_zones;
	long unsigned int *conv_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int max_open_zones;
	unsigned int max_active_zones;
	int node;
	struct mutex debugfs_mutex;
	struct blk_trace *blk_trace;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	struct mutex sysfs_dir_lock;
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	int mq_freeze_depth;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct mutex mq_freeze_lock;
	struct blk_mq_tag_set *tag_set;
	struct list_head tag_set_list;
	struct bio_set___11 bio_split;
	struct dentry___18 *debugfs_dir;
	struct dentry___18 *sched_debugfs_dir;
	struct dentry___18 *rqos_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	u64 write_hints[5];
};

struct dentry_operations___18;

struct dentry___18 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___18 *d_parent;
	struct qstr d_name;
	struct inode___18 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___18 *d_op;
	struct super_block___18 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___18;

struct cdev___7;

struct inode___18 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___18 *i_op;
	struct super_block___18 *i_sb;
	struct address_space___18 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___10 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	long: 64;
	long: 64;
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___18 *i_fop;
		void (*free_inode)(struct inode___18 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___18 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct cdev___7 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___18 {
	int (*d_revalidate)(struct dentry___18 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___18 *, unsigned int);
	int (*d_hash)(const struct dentry___18 *, struct qstr *);
	int (*d_compare)(const struct dentry___18 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___18 *);
	int (*d_init)(struct dentry___18 *);
	void (*d_release)(struct dentry___18 *);
	void (*d_prune)(struct dentry___18 *);
	void (*d_iput)(struct dentry___18 *, struct inode___18 *);
	char * (*d_dname)(struct dentry___18 *, char *, int);
	struct vfsmount___18 * (*d_automount)(struct path___18 *);
	int (*d_manage)(const struct path___18 *, bool);
	struct dentry___18 * (*d_real)(struct dentry___18 *, const struct inode___18 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___18;

struct mem_dqinfo___18 {
	struct quota_format_type___18 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___18;

struct quota_info___18 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___18 *files[3];
	struct mem_dqinfo___18 info[3];
	const struct quota_format_ops___18 *ops[3];
};

struct rcuwait___18 {
	struct task_struct___21 *task;
};

struct percpu_rw_semaphore___18 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___18 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___18 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___18 rw_sem[3];
};

struct shrink_control___10;

struct shrinker___10 {
	long unsigned int (*count_objects)(struct shrinker___10 *, struct shrink_control___10 *);
	long unsigned int (*scan_objects)(struct shrinker___10 *, struct shrink_control___10 *);
	long int batch;
	int seeks;
	unsigned int flags;
	struct list_head list;
	int id;
	atomic_long_t *nr_deferred;
};

struct super_operations___18;

struct dquot_operations___18;

struct quotactl_ops___18;

struct block_device___11;

struct super_block___18 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___18 *s_type;
	const struct super_operations___18 *s_op;
	const struct dquot_operations___18 *dq_op;
	const struct quotactl_ops___18 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___18 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___11 *s_bdev;
	struct backing_dev_info___10 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___18 s_dquot;
	struct sb_writers___18 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___18 *s_d_op;
	int cleancache_poolid;
	struct shrinker___10 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___18 {
	struct dentry___18 *mnt_root;
	struct super_block___18 *mnt_sb;
	int mnt_flags;
	struct user_namespace *mnt_userns;
};

struct shrink_control___10 {
	gfp_t gfp_mask;
	int nid;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	struct mem_cgroup___10 *memcg;
};

struct psi_group___13 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___21 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___13;

struct cgroup_rstat_cpu___13;

struct cgroup___13 {
	struct cgroup_subsys_state___13 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___18 *kn;
	struct cgroup_file___13 procs_file;
	struct cgroup_file___13 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___13 *subsys[14];
	struct cgroup_root___13 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___13 *dom_cgrp;
	struct cgroup___13 *old_dom_cgrp;
	struct cgroup_rstat_cpu___13 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___13 psi;
	struct cgroup_bpf bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct io_cq___11 {
	struct request_queue___11 *q;
	struct io_context___12 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct kiocb___18 {
	struct file___18 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___18 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___9 *ki_waitq;
	};
};

struct iattr___18 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___18 *ia_file;
};

struct dquot___18 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___18 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___18 {
	int qf_fmt_id;
	const struct quota_format_ops___18 *qf_ops;
	struct module___17 *qf_owner;
	struct quota_format_type___18 *qf_next;
};

struct quota_format_ops___18 {
	int (*check_quota_file)(struct super_block___18 *, int);
	int (*read_file_info)(struct super_block___18 *, int);
	int (*write_file_info)(struct super_block___18 *, int);
	int (*free_file_info)(struct super_block___18 *, int);
	int (*read_dqblk)(struct dquot___18 *);
	int (*commit_dqblk)(struct dquot___18 *);
	int (*release_dqblk)(struct dquot___18 *);
	int (*get_next_id)(struct super_block___18 *, struct kqid *);
};

struct dquot_operations___18 {
	int (*write_dquot)(struct dquot___18 *);
	struct dquot___18 * (*alloc_dquot)(struct super_block___18 *, int);
	void (*destroy_dquot)(struct dquot___18 *);
	int (*acquire_dquot)(struct dquot___18 *);
	int (*release_dquot)(struct dquot___18 *);
	int (*mark_dirty)(struct dquot___18 *);
	int (*write_info)(struct super_block___18 *, int);
	qsize_t * (*get_reserved_space)(struct inode___18 *);
	int (*get_projid)(struct inode___18 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___18 *, qsize_t *);
	int (*get_next_id)(struct super_block___18 *, struct kqid *);
};

struct quotactl_ops___18 {
	int (*quota_on)(struct super_block___18 *, int, int, const struct path___18 *);
	int (*quota_off)(struct super_block___18 *, int);
	int (*quota_enable)(struct super_block___18 *, unsigned int);
	int (*quota_disable)(struct super_block___18 *, unsigned int);
	int (*quota_sync)(struct super_block___18 *, int);
	int (*set_info)(struct super_block___18 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___18 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___18 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___18 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___18 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___18 *, unsigned int);
};

struct writeback_control___10;

struct address_space_operations___18 {
	int (*writepage)(struct page___19 *, struct writeback_control___10 *);
	int (*readpage)(struct file___18 *, struct page___19 *);
	int (*writepages)(struct address_space___18 *, struct writeback_control___10 *);
	int (*set_page_dirty)(struct page___19 *);
	int (*readpages)(struct file___18 *, struct address_space___18 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control *);
	int (*write_begin)(struct file___18 *, struct address_space___18 *, loff_t, unsigned int, unsigned int, struct page___19 **, void **);
	int (*write_end)(struct file___18 *, struct address_space___18 *, loff_t, unsigned int, unsigned int, struct page___19 *, void *);
	sector_t (*bmap)(struct address_space___18 *, sector_t);
	void (*invalidatepage)(struct page___19 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___19 *, gfp_t);
	void (*freepage)(struct page___19 *);
	ssize_t (*direct_IO)(struct kiocb___18 *, struct iov_iter___14 *);
	int (*migratepage)(struct address_space___18 *, struct page___19 *, struct page___19 *, enum migrate_mode);
	bool (*isolate_page)(struct page___19 *, isolate_mode_t);
	void (*putback_page)(struct page___19 *);
	int (*launder_page)(struct page___19 *);
	int (*is_partially_uptodate)(struct page___19 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___19 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___18 *, struct page___19 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___18 *, sector_t *);
	void (*swap_deactivate)(struct file___18 *);
};

struct writeback_control___10 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	unsigned int no_cgroup_owner: 1;
	unsigned int punt_to_cgroup: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bdi_writeback___10 *wb;
	struct inode___18 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
};

struct bio_vec___14;

struct iov_iter___14 {
	u8 iter_type;
	bool data_source;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___14 *bvec;
		struct xarray *xarray;
		struct pipe_inode_info *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			unsigned int head;
			unsigned int start_head;
		};
		loff_t xarray_start;
	};
};

struct cdev___7 {
	struct kobject___18 kobj;
	struct module___17 *owner;
	const struct file_operations___18 *ops;
	struct list_head list;
	dev_t dev;
	unsigned int count;
};

struct inode_operations___18 {
	struct dentry___18 * (*lookup)(struct inode___18 *, struct dentry___18 *, unsigned int);
	const char * (*get_link)(struct dentry___18 *, struct inode___18 *, struct delayed_call *);
	int (*permission)(struct user_namespace *, struct inode___18 *, int);
	struct posix_acl * (*get_acl)(struct inode___18 *, int, bool);
	int (*readlink)(struct dentry___18 *, char *, int);
	int (*create)(struct user_namespace *, struct inode___18 *, struct dentry___18 *, umode_t, bool);
	int (*link)(struct dentry___18 *, struct inode___18 *, struct dentry___18 *);
	int (*unlink)(struct inode___18 *, struct dentry___18 *);
	int (*symlink)(struct user_namespace *, struct inode___18 *, struct dentry___18 *, const char *);
	int (*mkdir)(struct user_namespace *, struct inode___18 *, struct dentry___18 *, umode_t);
	int (*rmdir)(struct inode___18 *, struct dentry___18 *);
	int (*mknod)(struct user_namespace *, struct inode___18 *, struct dentry___18 *, umode_t, dev_t);
	int (*rename)(struct user_namespace *, struct inode___18 *, struct dentry___18 *, struct inode___18 *, struct dentry___18 *, unsigned int);
	int (*setattr)(struct user_namespace *, struct dentry___18 *, struct iattr___18 *);
	int (*getattr)(struct user_namespace *, const struct path___18 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___18 *, char *, size_t);
	int (*fiemap)(struct inode___18 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___18 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___18 *, struct dentry___18 *, struct file___18 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace *, struct inode___18 *, struct dentry___18 *, umode_t);
	int (*set_acl)(struct user_namespace *, struct inode___18 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace *, struct dentry___18 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___18 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___18 {
	void (*fl_copy_lock)(struct file_lock___18 *, struct file_lock___18 *);
	void (*fl_release_private)(struct file_lock___18 *);
};

struct lock_manager_operations___18;

struct file_lock___18 {
	struct file_lock___18 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___18 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___18 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___18 *fl_ops;
	const struct lock_manager_operations___18 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___18 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___18 *);
	int (*lm_grant)(struct file_lock___18 *, int);
	bool (*lm_break)(struct file_lock___18 *);
	int (*lm_change)(struct file_lock___18 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___18 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___18 *);
};

struct fasync_struct___18 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___18 *fa_next;
	struct file___18 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___18 {
	struct inode___18 * (*alloc_inode)(struct super_block___18 *);
	void (*destroy_inode)(struct inode___18 *);
	void (*free_inode)(struct inode___18 *);
	void (*dirty_inode)(struct inode___18 *, int);
	int (*write_inode)(struct inode___18 *, struct writeback_control___10 *);
	int (*drop_inode)(struct inode___18 *);
	void (*evict_inode)(struct inode___18 *);
	void (*put_super)(struct super_block___18 *);
	int (*sync_fs)(struct super_block___18 *, int);
	int (*freeze_super)(struct super_block___18 *);
	int (*freeze_fs)(struct super_block___18 *);
	int (*thaw_super)(struct super_block___18 *);
	int (*unfreeze_fs)(struct super_block___18 *);
	int (*statfs)(struct dentry___18 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___18 *, int *, char *);
	void (*umount_begin)(struct super_block___18 *);
	int (*show_options)(struct seq_file___16 *, struct dentry___18 *);
	int (*show_devname)(struct seq_file___16 *, struct dentry___18 *);
	int (*show_path)(struct seq_file___16 *, struct dentry___18 *);
	int (*show_stats)(struct seq_file___16 *, struct dentry___18 *);
	ssize_t (*quota_read)(struct super_block___18 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___18 *, int, const char *, size_t, loff_t);
	struct dquot___18 ** (*get_dquots)(struct inode___18 *);
	long int (*nr_cached_objects)(struct super_block___18 *, struct shrink_control___10 *);
	long int (*free_cached_objects)(struct super_block___18 *, struct shrink_control___10 *);
	struct file___18 * (*real_loop)(struct file___18 *);
};

struct block_device___11 {
	sector_t bd_start_sect;
	struct disk_stats *bd_stats;
	long unsigned int bd_stamp;
	bool bd_read_only;
	dev_t bd_dev;
	int bd_openers;
	struct inode___18 *bd_inode;
	struct super_block___18 *bd_super;
	void *bd_claiming;
	struct device___19 bd_device;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct kobject___18 *bd_holder_dir;
	u8 bd_partno;
	spinlock_t bd_size_lock;
	struct gendisk___11 *bd_disk;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	struct super_block___18 *bd_fsfreeze_sb;
	struct partition_meta_info *bd_meta_info;
};

typedef void bio_end_io_t___11(struct bio___11 *);

struct bio_vec___14 {
	struct page___19 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___11;

struct bio___11 {
	struct bio___11 *bi_next;
	struct block_device___11 *bi_bdev;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	atomic_t __bi_remaining;
	struct bvec_iter bi_iter;
	bio_end_io_t___11 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___10 *bi_blkg;
	struct bio_issue bi_issue;
	u64 bi_iocost_cost;
	struct bio_crypt_ctx *bi_crypt_context;
	union {
		struct bio_integrity_payload___11 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___14 *bi_io_vec;
	struct bio_set___11 *bi_pool;
	struct bio_vec___14 bi_inline_vecs[0];
};

struct irqaction___6 {
	irq_handler_t handler;
	void *dev_id;
	void *percpu_dev_id;
	struct irqaction___6 *next;
	irq_handler_t thread_fn;
	struct task_struct___21 *thread;
	struct irqaction___6 *secondary;
	unsigned int irq;
	unsigned int flags;
	long unsigned int thread_flags;
	long unsigned int thread_mask;
	const char *name;
	struct proc_dir_entry *dir;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_ops___19 {
	int (*prepare)(struct device___19 *);
	void (*complete)(struct device___19 *);
	int (*suspend)(struct device___19 *);
	int (*resume)(struct device___19 *);
	int (*freeze)(struct device___19 *);
	int (*thaw)(struct device___19 *);
	int (*poweroff)(struct device___19 *);
	int (*restore)(struct device___19 *);
	int (*suspend_late)(struct device___19 *);
	int (*resume_early)(struct device___19 *);
	int (*freeze_late)(struct device___19 *);
	int (*thaw_early)(struct device___19 *);
	int (*poweroff_late)(struct device___19 *);
	int (*restore_early)(struct device___19 *);
	int (*suspend_noirq)(struct device___19 *);
	int (*resume_noirq)(struct device___19 *);
	int (*freeze_noirq)(struct device___19 *);
	int (*thaw_noirq)(struct device___19 *);
	int (*poweroff_noirq)(struct device___19 *);
	int (*restore_noirq)(struct device___19 *);
	int (*runtime_suspend)(struct device___19 *);
	int (*runtime_resume)(struct device___19 *);
	int (*runtime_idle)(struct device___19 *);
};

struct wakeup_source___19 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___19 *dev;
	bool active: 1;
	bool autosleep_enabled: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___19 {
	struct dev_pm_ops___19 ops;
	int (*start)(struct device___19 *);
	void (*detach)(struct device___19 *, bool);
	int (*activate)(struct device___19 *);
	void (*sync)(struct device___19 *);
	void (*dismiss)(struct device___19 *);
};

struct bus_type___19 {
	const char *name;
	const char *dev_name;
	struct device___19 *dev_root;
	const struct attribute_group___18 **bus_groups;
	const struct attribute_group___18 **dev_groups;
	const struct attribute_group___18 **drv_groups;
	int (*match)(struct device___19 *, struct device_driver___19 *);
	int (*uevent)(struct device___19 *, struct kobj_uevent_env *);
	int (*probe)(struct device___19 *);
	void (*sync_state)(struct device___19 *);
	void (*remove)(struct device___19 *);
	void (*shutdown)(struct device___19 *);
	int (*online)(struct device___19 *);
	int (*offline)(struct device___19 *);
	int (*suspend)(struct device___19 *, pm_message_t);
	int (*resume)(struct device___19 *);
	int (*num_vf)(struct device___19 *);
	int (*dma_configure)(struct device___19 *);
	const struct dev_pm_ops___19 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___19 {
	const char *name;
	struct bus_type___19 *bus;
	struct module___17 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___19 *);
	void (*sync_state)(struct device___19 *);
	int (*remove)(struct device___19 *);
	void (*shutdown)(struct device___19 *);
	int (*suspend)(struct device___19 *, pm_message_t);
	int (*resume)(struct device___19 *);
	const struct attribute_group___18 **groups;
	const struct attribute_group___18 **dev_groups;
	const struct dev_pm_ops___19 *pm;
	void (*coredump)(struct device___19 *);
	struct driver_private *p;
};

struct device_type___19 {
	const char *name;
	const struct attribute_group___18 **groups;
	int (*uevent)(struct device___19 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___19 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___19 *);
	const struct dev_pm_ops___19 *pm;
};

struct class___19 {
	const char *name;
	struct module___17 *owner;
	const struct attribute_group___18 **class_groups;
	const struct attribute_group___18 **dev_groups;
	struct kobject___18 *dev_kobj;
	int (*dev_uevent)(struct device___19 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___19 *, umode_t *);
	void (*class_release)(struct class___19 *);
	void (*dev_release)(struct device___19 *);
	int (*shutdown_pre)(struct device___19 *);
	const struct kobj_ns_type_operations *ns_type;
	const void * (*namespace)(struct device___19 *);
	void (*get_ownership)(struct device___19 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___19 *pm;
	struct subsys_private *p;
};

struct irq_desc___7;

typedef void (*irq_flow_handler_t___7)(struct irq_desc___7 *);

struct msi_desc___4;

struct irq_common_data___4 {
	unsigned int state_use_accessors;
	unsigned int node;
	void *handler_data;
	struct msi_desc___4 *msi_desc;
	cpumask_var_t affinity;
	cpumask_var_t effective_affinity;
};

struct irq_chip___7;

struct irq_data___7 {
	u32 mask;
	unsigned int irq;
	long unsigned int hwirq;
	struct irq_common_data___4 *common;
	struct irq_chip___7 *chip;
	struct irq_domain___12 *domain;
	struct irq_data___7 *parent_data;
	void *chip_data;
};

struct irq_desc___7 {
	struct irq_common_data___4 irq_common_data;
	struct irq_data___7 irq_data;
	unsigned int *kstat_irqs;
	irq_flow_handler_t___7 handle_irq;
	struct irqaction___6 *action;
	unsigned int status_use_accessors;
	unsigned int core_internal_state__do_not_mess_with_it;
	unsigned int depth;
	unsigned int wake_depth;
	unsigned int tot_count;
	unsigned int irq_count;
	long unsigned int last_unhandled;
	unsigned int irqs_unhandled;
	atomic_t threads_handled;
	int threads_handled_last;
	raw_spinlock_t lock;
	struct cpumask *percpu_enabled;
	const struct cpumask *percpu_affinity;
	const struct cpumask *affinity_hint;
	struct irq_affinity_notify *affinity_notify;
	cpumask_var_t pending_mask;
	long unsigned int threads_oneshot;
	atomic_t threads_active;
	wait_queue_head_t wait_for_threads;
	unsigned int nr_actions;
	unsigned int no_suspend_depth;
	unsigned int cond_suspend_depth;
	unsigned int force_resume_depth;
	struct proc_dir_entry *dir;
	struct callback_head rcu;
	struct kobject___18 kobj;
	struct mutex request_mutex;
	int parent_irq;
	struct module___17 *owner;
	const char *name;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct msi_desc___4 {
	struct list_head list;
	unsigned int irq;
	unsigned int nvec_used;
	struct device___19 *dev;
	struct msi_msg msg;
	struct irq_affinity_desc *affinity;
	const void *iommu_cookie;
	void (*write_msi_msg)(struct msi_desc___4 *, void *);
	void *write_msi_msg_data;
	union {
		struct {
			union {
				u32 msi_mask;
				u32 msix_ctrl;
			};
			struct {
				u8 is_msix: 1;
				u8 multiple: 3;
				u8 multi_cap: 3;
				u8 can_mask: 1;
				u8 is_64: 1;
				u8 is_virtual: 1;
				u16 entry_nr;
				unsigned int default_irq;
			} msi_attrib;
			union {
				u8 mask_pos;
				void *mask_base;
			};
		};
		struct platform_msi_desc platform;
		struct fsl_mc_msi_desc fsl_mc;
		struct ti_sci_inta_msi_desc inta;
	};
};

struct irq_chip___7 {
	struct device___19 *parent_device;
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___7 *);
	void (*irq_shutdown)(struct irq_data___7 *);
	void (*irq_enable)(struct irq_data___7 *);
	void (*irq_disable)(struct irq_data___7 *);
	void (*irq_ack)(struct irq_data___7 *);
	void (*irq_mask)(struct irq_data___7 *);
	void (*irq_mask_ack)(struct irq_data___7 *);
	void (*irq_unmask)(struct irq_data___7 *);
	void (*irq_eoi)(struct irq_data___7 *);
	int (*irq_set_affinity)(struct irq_data___7 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___7 *);
	int (*irq_set_type)(struct irq_data___7 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___7 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___7 *);
	void (*irq_bus_sync_unlock)(struct irq_data___7 *);
	void (*irq_cpu_online)(struct irq_data___7 *);
	void (*irq_cpu_offline)(struct irq_data___7 *);
	void (*irq_suspend)(struct irq_data___7 *);
	void (*irq_resume)(struct irq_data___7 *);
	void (*irq_pm_shutdown)(struct irq_data___7 *);
	void (*irq_calc_mask)(struct irq_data___7 *);
	void (*irq_print_chip)(struct irq_data___7 *, struct seq_file___16 *);
	int (*irq_request_resources)(struct irq_data___7 *);
	void (*irq_release_resources)(struct irq_data___7 *);
	void (*irq_compose_msi_msg)(struct irq_data___7 *, struct msi_msg *);
	void (*irq_write_msi_msg)(struct irq_data___7 *, struct msi_msg *);
	int (*irq_get_irqchip_state)(struct irq_data___7 *, enum irqchip_irq_state, bool *);
	int (*irq_set_irqchip_state)(struct irq_data___7 *, enum irqchip_irq_state, bool);
	int (*irq_set_vcpu_affinity)(struct irq_data___7 *, void *);
	void (*ipi_send_single)(struct irq_data___7 *, unsigned int);
	void (*ipi_send_mask)(struct irq_data___7 *, const struct cpumask *);
	int (*irq_nmi_setup)(struct irq_data___7 *);
	void (*irq_nmi_teardown)(struct irq_data___7 *);
	long unsigned int flags;
};

struct irq_chip_type___6 {
	struct irq_chip___7 chip;
	struct irq_chip_regs regs;
	irq_flow_handler_t___7 handler;
	u32 type;
	u32 mask_cache_priv;
	u32 *mask_cache;
};

struct irq_chip_generic___6 {
	raw_spinlock_t lock;
	void *reg_base;
	u32 (*reg_readl)(void *);
	void (*reg_writel)(u32, void *);
	void (*suspend)(struct irq_chip_generic___6 *);
	void (*resume)(struct irq_chip_generic___6 *);
	unsigned int irq_base;
	unsigned int irq_cnt;
	u32 mask_cache;
	u32 type_cache;
	u32 polarity_cache;
	u32 wake_enabled;
	u32 wake_active;
	unsigned int num_ct;
	void *private;
	long unsigned int installed;
	long unsigned int unused;
	struct irq_domain___12 *domain;
	struct list_head list;
	struct irq_chip_type___6 chip_types[0];
};

struct irq_domain_chip_generic___6 {
	unsigned int irqs_per_chip;
	unsigned int num_chips;
	unsigned int irq_flags_to_clear;
	unsigned int irq_flags_to_set;
	enum irq_gc_flags gc_flags;
	struct irq_chip_generic___6 *gc[0];
};

struct dev_pagemap_ops___18 {
	void (*page_free)(struct page___19 *);
	void (*kill)(struct dev_pagemap___18 *);
	void (*cleanup)(struct dev_pagemap___18 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___18 *);
};

struct cgroup_namespace___13 {
	struct ns_common ns;
	struct user_namespace *user_ns;
	struct ucounts *ucounts;
	struct css_set___13 *root_cset;
};

struct kernel_param_ops___17 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___17 *);
	int (*get)(char *, const struct kernel_param___17 *);
	void (*free)(void *);
};

struct kparam_array___17;

struct kernel_param___17 {
	const char *name;
	struct module___17 *mod;
	const struct kernel_param_ops___17 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___17 *arr;
	};
};

struct kparam_array___17 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___17 *ops;
	void *elem;
};

struct module_attribute___17 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___17 *, struct module_kobject___17 *, char *);
	ssize_t (*store)(struct module_attribute___17 *, struct module_kobject___17 *, const char *, size_t);
	void (*setup)(struct module___17 *, const char *);
	int (*test)(struct module___17 *);
	void (*free)(struct module___17 *);
};

struct trace_event_class___10;

struct trace_event_call___10 {
	struct list_head list;
	struct trace_event_class___10 *class;
	union {
		char *name;
		struct tracepoint___12 *tp;
	};
	struct trace_event event;
	char *print_fmt;
	struct event_filter *filter;
	union {
		void *module;
		atomic_t refcnt;
	};
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
	struct bpf_prog_array *prog_array;
	int (*perf_perm)(struct trace_event_call___10 *, struct perf_event___10 *);
};

struct irq_fwspec___11 {
	struct fwnode_handle___17 *fwnode;
	int param_count;
	u32 param[16];
};

struct irq_domain_ops___12 {
	int (*match)(struct irq_domain___12 *, struct device_node___13 *, enum irq_domain_bus_token);
	int (*select)(struct irq_domain___12 *, struct irq_fwspec___11 *, enum irq_domain_bus_token);
	int (*map)(struct irq_domain___12 *, unsigned int, irq_hw_number_t);
	void (*unmap)(struct irq_domain___12 *, unsigned int);
	int (*xlate)(struct irq_domain___12 *, struct device_node___13 *, const u32 *, unsigned int, long unsigned int *, unsigned int *);
	int (*alloc)(struct irq_domain___12 *, unsigned int, unsigned int, void *);
	void (*free)(struct irq_domain___12 *, unsigned int, unsigned int);
	int (*activate)(struct irq_domain___12 *, struct irq_data___7 *, bool);
	void (*deactivate)(struct irq_domain___12 *, struct irq_data___7 *);
	int (*translate)(struct irq_domain___12 *, struct irq_fwspec___11 *, long unsigned int *, unsigned int *);
};

struct cftype___13;

struct cgroup_subsys___13 {
	struct cgroup_subsys_state___13 * (*css_alloc)(struct cgroup_subsys_state___13 *);
	int (*css_online)(struct cgroup_subsys_state___13 *);
	void (*css_offline)(struct cgroup_subsys_state___13 *);
	void (*css_released)(struct cgroup_subsys_state___13 *);
	void (*css_free)(struct cgroup_subsys_state___13 *);
	void (*css_reset)(struct cgroup_subsys_state___13 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___13 *, int);
	int (*css_extra_stat_show)(struct seq_file___16 *, struct cgroup_subsys_state___13 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___21 *, struct css_set___13 *);
	void (*cancel_fork)(struct task_struct___21 *, struct css_set___13 *);
	void (*fork)(struct task_struct___21 *);
	void (*exit)(struct task_struct___21 *);
	void (*release)(struct task_struct___21 *);
	void (*bind)(struct cgroup_subsys_state___13 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___13 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___13 *dfl_cftypes;
	struct cftype___13 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___13 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___13 *updated_children;
	struct cgroup___13 *updated_next;
};

struct cgroup_root___13 {
	struct kernfs_root___18 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___13 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___13 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___13 *ss;
	struct list_head node;
	struct kernfs_ops___18 *kf_ops;
	int (*open)(struct kernfs_open_file___18 *);
	void (*release)(struct kernfs_open_file___18 *);
	u64 (*read_u64)(struct cgroup_subsys_state___13 *, struct cftype___13 *);
	s64 (*read_s64)(struct cgroup_subsys_state___13 *, struct cftype___13 *);
	int (*seq_show)(struct seq_file___16 *, void *);
	void * (*seq_start)(struct seq_file___16 *, loff_t *);
	void * (*seq_next)(struct seq_file___16 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___16 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___13 *, struct cftype___13 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___13 *, struct cftype___13 *, s64);
	ssize_t (*write)(struct kernfs_open_file___18 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___18 *, struct poll_table_struct___12 *);
};

struct block_device_operations___11;

struct gendisk___11 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	short unsigned int events;
	short unsigned int event_flags;
	struct xarray part_tbl;
	struct block_device___11 *part0;
	const struct block_device_operations___11 *fops;
	struct request_queue___11 *queue;
	void *private_data;
	int flags;
	long unsigned int state;
	struct mutex open_mutex;
	unsigned int open_partitions;
	struct backing_dev_info___10 *bdi;
	struct kobject___18 *slave_dir;
	struct list_head slave_bdevs;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___18 integrity_kobj;
	struct cdrom_device_info *cdi;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	u64 diskseq;
};

struct bio_integrity_payload___11 {
	struct bio___11 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___14 *bip_vec;
	struct bio_vec___14 bip_inline_vecs[0];
};

struct blkcg___10;

struct blkg_policy_data___10;

struct blkcg_gq___10 {
	struct request_queue___11 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___10 *blkcg;
	struct blkcg_gq___10 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_iostat_set *iostat_cpu;
	struct blkg_iostat_set iostat;
	struct blkg_policy_data___10 *pd[6];
	spinlock_t async_bio_lock;
	struct bio_list___11 async_bios;
	struct work_struct async_bio_work;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
	struct callback_head callback_head;
};

typedef void integrity_prepare_fn___11(struct request___11 *);

typedef void integrity_complete_fn___11(struct request___11 *, unsigned int);

struct blk_integrity_profile___11 {
	integrity_processing_fn *generate_fn;
	integrity_processing_fn *verify_fn;
	integrity_prepare_fn___11 *prepare_fn;
	integrity_complete_fn___11 *complete_fn;
	const char *name;
};

struct block_device_operations___11 {
	blk_qc_t (*submit_bio)(struct bio___11 *);
	int (*open)(struct block_device___11 *, fmode_t);
	void (*release)(struct gendisk___11 *, fmode_t);
	int (*rw_page)(struct block_device___11 *, sector_t, struct page___19 *, unsigned int);
	int (*ioctl)(struct block_device___11 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___11 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___11 *, unsigned int);
	void (*unlock_native_capacity)(struct gendisk___11 *);
	int (*getgeo)(struct block_device___11 *, struct hd_geometry *);
	int (*set_read_only)(struct block_device___11 *, bool);
	void (*swap_slot_free_notify)(struct block_device___11 *, long unsigned int);
	int (*report_zones)(struct gendisk___11 *, sector_t, unsigned int, report_zones_cb, void *);
	char * (*devnode)(struct gendisk___11 *, umode_t *);
	struct module___17 *owner;
	const struct pr_ops *pr_ops;
	int (*alternative_gpt_sector)(struct gendisk___11 *, sector_t *);
};

typedef void rq_end_io_fn___11(struct request___11 *, blk_status_t);

struct request___11 {
	struct request_queue___11 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int tag;
	int internal_tag;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___11 *bio;
	struct bio___11 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct llist_node ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___14 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___11 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___11 *saved_end_io;
		} flush;
	};
	struct gendisk___11 *rq_disk;
	struct block_device___11 *part;
	u64 alloc_time_ns;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int stats_sectors;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	struct bio_crypt_ctx *crypt_ctx;
	struct blk_ksm_keyslot *crypt_keyslot;
	short unsigned int write_hint;
	short unsigned int ioprio;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___11 *end_io;
	void *end_io_data;
};

struct elevator_type___11;

struct elevator_mq_ops___11 {
	int (*init_sched)(struct request_queue___11 *, struct elevator_type___11 *);
	void (*exit_sched)(struct elevator_queue___11 *);
	int (*init_hctx)(struct blk_mq_hw_ctx *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx *, unsigned int);
	void (*depth_updated)(struct blk_mq_hw_ctx *);
	bool (*allow_merge)(struct request_queue___11 *, struct request___11 *, struct bio___11 *);
	bool (*bio_merge)(struct request_queue___11 *, struct bio___11 *, unsigned int);
	int (*request_merge)(struct request_queue___11 *, struct request___11 **, struct bio___11 *);
	void (*request_merged)(struct request_queue___11 *, struct request___11 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___11 *, struct request___11 *, struct request___11 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___11 *);
	void (*finish_request)(struct request___11 *);
	void (*insert_requests)(struct blk_mq_hw_ctx *, struct list_head *, bool);
	struct request___11 * (*dispatch_request)(struct blk_mq_hw_ctx *);
	bool (*has_work)(struct blk_mq_hw_ctx *);
	void (*completed_request)(struct request___11 *, u64);
	void (*requeue_request)(struct request___11 *);
	struct request___11 * (*former_request)(struct request_queue___11 *, struct request___11 *);
	struct request___11 * (*next_request)(struct request_queue___11 *, struct request___11 *);
	void (*init_icq)(struct io_cq___11 *);
	void (*exit_icq)(struct io_cq___11 *);
};

struct elv_fs_entry___11;

struct elevator_type___11 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___11 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___11 *elevator_attrs;
	const char *elevator_name;
	const char *elevator_alias;
	const unsigned int elevator_features;
	struct module___17 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
};

struct elevator_queue___11 {
	struct elevator_type___11 *type;
	void *elevator_data;
	struct kobject___18 kobj;
	struct mutex sysfs_lock;
	unsigned int registered: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hlist_head hash[64];
};

struct elv_fs_entry___11 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___11 *, char *);
	ssize_t (*store)(struct elevator_queue___11 *, const char *, size_t);
};

struct blkcg_policy_data___10;

struct blkcg___10 {
	struct cgroup_subsys_state___13 css;
	spinlock_t lock;
	refcount_t online_pin;
	struct xarray blkg_tree;
	struct blkcg_gq___10 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___10 *cpd[6];
	struct list_head all_blkcgs_node;
	char fc_app_id[129];
	struct list_head cgwb_list;
};

struct blkcg_policy_data___10 {
	struct blkcg___10 *blkcg;
	int plid;
};

struct blkg_policy_data___10 {
	struct blkcg_gq___10 *blkg;
	int plid;
};

struct mem_cgroup_reclaim_iter___10 {
	struct mem_cgroup___10 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___10 {
	struct lruvec___11 lruvec;
	struct lruvec_stats_percpu *lruvec_stats_percpu;
	struct lruvec_stats lruvec_stats;
	long unsigned int lru_zone_size[25];
	struct mem_cgroup_reclaim_iter___10 iter;
	struct shrinker_info *shrinker_info;
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	struct mem_cgroup___10 *memcg;
};

struct obj_cgroup___10 {
	struct percpu_ref refcnt;
	struct mem_cgroup___10 *memcg;
	atomic_t nr_charged_bytes;
	union {
		struct list_head list;
		struct callback_head rcu;
	};
};

struct perf_cpu_context___10;

struct perf_output_handle___10;

struct pmu___10 {
	struct list_head entry;
	struct module___17 *module;
	struct device___19 *dev;
	const struct attribute_group___18 **attr_groups;
	const struct attribute_group___18 **attr_update;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___10 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___10 *);
	void (*pmu_disable)(struct pmu___10 *);
	int (*event_init)(struct perf_event___10 *);
	void (*event_mapped)(struct perf_event___10 *, struct mm_struct___20 *);
	void (*event_unmapped)(struct perf_event___10 *, struct mm_struct___20 *);
	int (*add)(struct perf_event___10 *, int);
	void (*del)(struct perf_event___10 *, int);
	void (*start)(struct perf_event___10 *, int);
	void (*stop)(struct perf_event___10 *, int);
	void (*read)(struct perf_event___10 *);
	void (*start_txn)(struct pmu___10 *, unsigned int);
	int (*commit_txn)(struct pmu___10 *);
	void (*cancel_txn)(struct pmu___10 *);
	int (*event_idx)(struct perf_event___10 *);
	void (*sched_task)(struct perf_event_context___10 *, bool);
	struct kmem_cache *task_ctx_cache;
	void (*swap_task_ctx)(struct perf_event_context___10 *, struct perf_event_context___10 *);
	void * (*setup_aux)(struct perf_event___10 *, void **, int, bool);
	void (*free_aux)(void *);
	long int (*snapshot_aux)(struct perf_event___10 *, struct perf_output_handle___10 *, long unsigned int);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___10 *);
	int (*aux_output_match)(struct perf_event___10 *);
	int (*filter_match)(struct perf_event___10 *);
	int (*check_period)(struct perf_event___10 *, u64);
};

struct perf_cpu_context___10 {
	struct perf_event_context___10 ctx;
	struct perf_event_context___10 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___10 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
	int heap_size;
	struct perf_event___10 **heap;
	struct perf_event___10 *heap_default[2];
};

struct perf_output_handle___10 {
	struct perf_event___10 *event;
	struct perf_buffer *rb;
	long unsigned int wakeup;
	long unsigned int size;
	u64 aux_flags;
	union {
		void *addr;
		long unsigned int head;
	};
	int page;
};

struct perf_cgroup___10 {
	struct cgroup_subsys_state___13 css;
	struct perf_cgroup_info *info;
};

struct trace_event_fields___10 {
	const char *type;
	union {
		struct {
			const char *name;
			const int size;
			const int align;
			const int is_signed;
			const int filter_type;
		};
		int (*define_fields)(struct trace_event_call___10 *);
	};
};

struct trace_event_class___10 {
	const char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct trace_event_call___10 *, enum trace_reg, void *);
	struct trace_event_fields___10 *fields_array;
	struct list_head * (*get_fields)(struct trace_event_call___10 *);
	struct list_head fields;
	int (*raw_init)(struct trace_event_call___10 *);
};

struct irq_desc___8;

typedef void (*irq_flow_handler_t___8)(struct irq_desc___8 *);

struct msi_desc___5;

struct irq_common_data___5 {
	unsigned int state_use_accessors;
	unsigned int node;
	void *handler_data;
	struct msi_desc___5 *msi_desc;
	cpumask_var_t affinity;
	cpumask_var_t effective_affinity;
};

struct irq_chip___8;

struct irq_domain___13;

struct irq_data___8 {
	u32 mask;
	unsigned int irq;
	long unsigned int hwirq;
	struct irq_common_data___5 *common;
	struct irq_chip___8 *chip;
	struct irq_domain___13 *domain;
	struct irq_data___8 *parent_data;
	void *chip_data;
};

struct irq_desc___8 {
	struct irq_common_data___5 irq_common_data;
	struct irq_data___8 irq_data;
	unsigned int *kstat_irqs;
	irq_flow_handler_t___8 handle_irq;
	struct irqaction___6 *action;
	unsigned int status_use_accessors;
	unsigned int core_internal_state__do_not_mess_with_it;
	unsigned int depth;
	unsigned int wake_depth;
	unsigned int tot_count;
	unsigned int irq_count;
	long unsigned int last_unhandled;
	unsigned int irqs_unhandled;
	atomic_t threads_handled;
	int threads_handled_last;
	raw_spinlock_t lock;
	struct cpumask *percpu_enabled;
	const struct cpumask *percpu_affinity;
	const struct cpumask *affinity_hint;
	struct irq_affinity_notify *affinity_notify;
	cpumask_var_t pending_mask;
	long unsigned int threads_oneshot;
	atomic_t threads_active;
	wait_queue_head_t wait_for_threads;
	unsigned int nr_actions;
	unsigned int no_suspend_depth;
	unsigned int cond_suspend_depth;
	unsigned int force_resume_depth;
	struct proc_dir_entry *dir;
	struct callback_head rcu;
	struct kobject___18 kobj;
	struct mutex request_mutex;
	int parent_irq;
	struct module___17 *owner;
	const char *name;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct mpc_intsrc {
	unsigned char type;
	unsigned char irqtype;
	short unsigned int irqflag;
	unsigned char srcbus;
	unsigned char srcbusirq;
	unsigned char dstapic;
	unsigned char dstirq;
};

enum mp_irq_source_types {
	mp_INT = 0,
	mp_NMI = 1,
	mp_SMI = 2,
	mp_ExtINT = 3,
};

enum mp_bustype {
	MP_BUS_ISA = 1,
	MP_BUS_EISA = 2,
	MP_BUS_PCI = 3,
};

struct x86_init_irqs___6 {
	void (*pre_vector_init)();
	void (*intr_init)();
	void (*intr_mode_select)();
	void (*intr_mode_init)();
	struct irq_domain___13 * (*create_pci_msi_domain)();
};

struct irq_domain_ops___13;

struct fwnode_handle___18;

struct irq_domain_chip_generic___7;

struct irq_domain___13 {
	struct list_head link;
	const char *name;
	const struct irq_domain_ops___13 *ops;
	void *host_data;
	unsigned int flags;
	unsigned int mapcount;
	struct fwnode_handle___18 *fwnode;
	enum irq_domain_bus_token bus_token;
	struct irq_domain_chip_generic___7 *gc;
	struct irq_domain___13 *parent;
	irq_hw_number_t hwirq_max;
	unsigned int revmap_size;
	struct xarray revmap_tree;
	struct mutex revmap_mutex;
	struct irq_data___8 *revmap[0];
};

struct x86_init_ops___6 {
	struct x86_init_resources resources;
	struct x86_init_mpparse mpparse;
	struct x86_init_irqs___6 irqs;
	struct x86_init_oem oem;
	struct x86_init_paging paging;
	struct x86_init_timers timers;
	struct x86_init_iommu iommu;
	struct x86_init_pci pci;
	struct x86_hyper_init hyper;
	struct x86_init_acpi acpi;
};

struct wakeup_source___20;

struct device___20;

struct dev_pm_qos___3;

struct dev_pm_info___20 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___20 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___20 *, s32);
	struct dev_pm_qos___3 *qos;
};

struct device_type___20;

struct bus_type___20;

struct device_driver___20;

struct dev_pm_domain___20;

struct device_node___14;

struct class___20;

struct device___20 {
	struct kobject___18 kobj;
	struct device___20 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___20 *type;
	struct bus_type___20 *bus;
	struct device_driver___20 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___20 power;
	struct dev_pm_domain___20 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___13 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___14 *of_node;
	struct fwnode_handle___18 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___20 *class;
	const struct attribute_group___18 **groups;
	void (*release)(struct device___20 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct pci_bus___5;

struct pci_slot___5;

struct pci_driver___5;

struct pci_dev___5 {
	struct list_head bus_list;
	struct pci_bus___5 *bus;
	struct pci_bus___5 *subordinate;
	void *sysdata;
	struct proc_dir_entry *procent;
	struct pci_slot___5 *slot;
	unsigned int devfn;
	short unsigned int vendor;
	short unsigned int device;
	short unsigned int subsystem_vendor;
	short unsigned int subsystem_device;
	unsigned int class;
	u8 revision;
	u8 hdr_type;
	u16 aer_cap;
	struct aer_stats *aer_stats;
	struct rcec_ea *rcec_ea;
	struct pci_dev___5 *rcec;
	u32 devcap;
	u8 pcie_cap;
	u8 msi_cap;
	u8 msix_cap;
	u8 pcie_mpss: 3;
	long: 61;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u8 rom_base_reg;
	u8 pin;
	u16 pcie_flags_reg;
	long unsigned int *dma_alias_mask;
	struct pci_driver___5 *driver;
	u64 dma_mask;
	struct device_dma_parameters dma_parms;
	pci_power_t current_state;
	unsigned int imm_ready: 1;
	long: 39;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u8 pm_cap;
	unsigned int pme_support: 5;
	unsigned int pme_poll: 1;
	unsigned int d1_support: 1;
	unsigned int d2_support: 1;
	unsigned int no_d1d2: 1;
	unsigned int no_d3cold: 1;
	unsigned int bridge_d3: 1;
	unsigned int d3cold_allowed: 1;
	unsigned int mmio_always_on: 1;
	unsigned int wakeup_prepared: 1;
	unsigned int runtime_d3cold: 1;
	unsigned int skip_bus_pm: 1;
	unsigned int ignore_hotplug: 1;
	unsigned int hotplug_user_indicators: 1;
	unsigned int clear_retrain_link: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int d3hot_delay;
	unsigned int d3cold_delay;
	struct pcie_link_state *link_state;
	unsigned int ltr_path: 1;
	long: 15;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u16 l1ss;
	unsigned int pasid_no_tlp: 1;
	unsigned int eetlp_prefix_path: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	pci_channel_state_t error_state;
	struct device___20 dev;
	int cfg_size;
	unsigned int irq;
	struct resource resource[17];
	bool match_driver;
	unsigned int transparent: 1;
	unsigned int io_window: 1;
	unsigned int pref_window: 1;
	unsigned int pref_64_window: 1;
	unsigned int multifunction: 1;
	unsigned int is_busmaster: 1;
	unsigned int no_msi: 1;
	unsigned int no_64bit_msi: 1;
	unsigned int block_cfg_access: 1;
	unsigned int broken_parity_status: 1;
	unsigned int irq_reroute_variant: 2;
	unsigned int msi_enabled: 1;
	unsigned int msix_enabled: 1;
	unsigned int ari_enabled: 1;
	unsigned int ats_enabled: 1;
	unsigned int pasid_enabled: 1;
	unsigned int pri_enabled: 1;
	unsigned int is_managed: 1;
	unsigned int needs_freset: 1;
	unsigned int state_saved: 1;
	unsigned int is_physfn: 1;
	unsigned int is_virtfn: 1;
	unsigned int is_hotplug_bridge: 1;
	unsigned int shpc_managed: 1;
	unsigned int is_thunderbolt: 1;
	unsigned int untrusted: 1;
	unsigned int external_facing: 1;
	unsigned int broken_intx_masking: 1;
	unsigned int io_window_1k: 1;
	unsigned int irq_managed: 1;
	unsigned int non_compliant_bars: 1;
	unsigned int is_probed: 1;
	unsigned int link_active_reporting: 1;
	unsigned int no_vf_scan: 1;
	unsigned int no_command_memory: 1;
	long: 47;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	pci_dev_flags_t dev_flags;
	atomic_t enable_cnt;
	u32 saved_config_space[16];
	struct hlist_head saved_cap_space;
	int rom_attr_enabled;
	struct bin_attribute___18 *res_attr[17];
	struct bin_attribute___18 *res_attr_wc[17];
	unsigned int broken_cmd_compl: 1;
	unsigned int ptm_root: 1;
	unsigned int ptm_enabled: 1;
	long: 7;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u8 ptm_granularity;
	const struct attribute_group___18 **msi_irq_groups;
	struct pci_vpd vpd;
	u16 dpc_cap;
	unsigned int dpc_rp_extensions: 1;
	long: 23;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u8 dpc_rp_log_size;
	union {
		struct pci_sriov *sriov;
		struct pci_dev___5 *physfn;
	};
	u16 ats_cap;
	u8 ats_stu;
	u16 pri_cap;
	u32 pri_reqs_alloc;
	unsigned int pasid_required: 1;
	long: 47;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u16 pasid_cap;
	u16 pasid_features;
	u16 acs_cap;
	phys_addr_t rom;
	size_t romlen;
	char *driver_override;
	long unsigned int priv_flags;
	u8 reset_methods[7];
};

struct fwnode_operations___18;

struct fwnode_handle___18 {
	struct fwnode_handle___18 *secondary;
	const struct fwnode_operations___18 *ops;
	struct device___20 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct fwnode_reference_args___18;

struct fwnode_endpoint___18;

struct fwnode_operations___18 {
	struct fwnode_handle___18 * (*get)(struct fwnode_handle___18 *);
	void (*put)(struct fwnode_handle___18 *);
	bool (*device_is_available)(const struct fwnode_handle___18 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___18 *, const struct device___20 *);
	bool (*property_present)(const struct fwnode_handle___18 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___18 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___18 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___18 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___18 *);
	struct fwnode_handle___18 * (*get_parent)(const struct fwnode_handle___18 *);
	struct fwnode_handle___18 * (*get_next_child_node)(const struct fwnode_handle___18 *, struct fwnode_handle___18 *);
	struct fwnode_handle___18 * (*get_named_child_node)(const struct fwnode_handle___18 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___18 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___18 *);
	struct fwnode_handle___18 * (*graph_get_next_endpoint)(const struct fwnode_handle___18 *, struct fwnode_handle___18 *);
	struct fwnode_handle___18 * (*graph_get_remote_endpoint)(const struct fwnode_handle___18 *);
	struct fwnode_handle___18 * (*graph_get_port_parent)(struct fwnode_handle___18 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___18 *, struct fwnode_endpoint___18 *);
	int (*add_links)(struct fwnode_handle___18 *);
};

struct fwnode_endpoint___18 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___18 *local_fwnode;
};

struct fwnode_reference_args___18 {
	struct fwnode_handle___18 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct device_node___14 {
	const char *name;
	phandle phandle;
	const char *full_name;
	struct fwnode_handle___18 fwnode;
	struct property *properties;
	struct property *deadprops;
	struct device_node___14 *parent;
	struct device_node___14 *child;
	struct device_node___14 *sibling;
	long unsigned int _flags;
	void *data;
};

struct irq_fwspec___12 {
	struct fwnode_handle___18 *fwnode;
	int param_count;
	u32 param[16];
};

struct irq_domain_ops___13 {
	int (*match)(struct irq_domain___13 *, struct device_node___14 *, enum irq_domain_bus_token);
	int (*select)(struct irq_domain___13 *, struct irq_fwspec___12 *, enum irq_domain_bus_token);
	int (*map)(struct irq_domain___13 *, unsigned int, irq_hw_number_t);
	void (*unmap)(struct irq_domain___13 *, unsigned int);
	int (*xlate)(struct irq_domain___13 *, struct device_node___14 *, const u32 *, unsigned int, long unsigned int *, unsigned int *);
	int (*alloc)(struct irq_domain___13 *, unsigned int, unsigned int, void *);
	void (*free)(struct irq_domain___13 *, unsigned int, unsigned int);
	int (*activate)(struct irq_domain___13 *, struct irq_data___8 *, bool);
	void (*deactivate)(struct irq_domain___13 *, struct irq_data___8 *);
	int (*translate)(struct irq_domain___13 *, struct irq_fwspec___12 *, long unsigned int *, unsigned int *);
};

struct irq_chip_generic___7;

struct irq_domain_chip_generic___7 {
	unsigned int irqs_per_chip;
	unsigned int num_chips;
	unsigned int irq_flags_to_clear;
	unsigned int irq_flags_to_set;
	enum irq_gc_flags gc_flags;
	struct irq_chip_generic___7 *gc[0];
};

struct dev_pm_ops___20 {
	int (*prepare)(struct device___20 *);
	void (*complete)(struct device___20 *);
	int (*suspend)(struct device___20 *);
	int (*resume)(struct device___20 *);
	int (*freeze)(struct device___20 *);
	int (*thaw)(struct device___20 *);
	int (*poweroff)(struct device___20 *);
	int (*restore)(struct device___20 *);
	int (*suspend_late)(struct device___20 *);
	int (*resume_early)(struct device___20 *);
	int (*freeze_late)(struct device___20 *);
	int (*thaw_early)(struct device___20 *);
	int (*poweroff_late)(struct device___20 *);
	int (*restore_early)(struct device___20 *);
	int (*suspend_noirq)(struct device___20 *);
	int (*resume_noirq)(struct device___20 *);
	int (*freeze_noirq)(struct device___20 *);
	int (*thaw_noirq)(struct device___20 *);
	int (*poweroff_noirq)(struct device___20 *);
	int (*restore_noirq)(struct device___20 *);
	int (*runtime_suspend)(struct device___20 *);
	int (*runtime_resume)(struct device___20 *);
	int (*runtime_idle)(struct device___20 *);
};

struct wakeup_source___20 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___20 *dev;
	bool active: 1;
	bool autosleep_enabled: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_qos_request___3;

struct dev_pm_qos___3 {
	struct pm_qos_constraints resume_latency;
	struct pm_qos_constraints latency_tolerance;
	struct freq_constraints freq;
	struct pm_qos_flags flags;
	struct dev_pm_qos_request___3 *resume_latency_req;
	struct dev_pm_qos_request___3 *latency_tolerance_req;
	struct dev_pm_qos_request___3 *flags_req;
};

struct dev_pm_domain___20 {
	struct dev_pm_ops___20 ops;
	int (*start)(struct device___20 *);
	void (*detach)(struct device___20 *, bool);
	int (*activate)(struct device___20 *);
	void (*sync)(struct device___20 *);
	void (*dismiss)(struct device___20 *);
};

struct bus_type___20 {
	const char *name;
	const char *dev_name;
	struct device___20 *dev_root;
	const struct attribute_group___18 **bus_groups;
	const struct attribute_group___18 **dev_groups;
	const struct attribute_group___18 **drv_groups;
	int (*match)(struct device___20 *, struct device_driver___20 *);
	int (*uevent)(struct device___20 *, struct kobj_uevent_env *);
	int (*probe)(struct device___20 *);
	void (*sync_state)(struct device___20 *);
	void (*remove)(struct device___20 *);
	void (*shutdown)(struct device___20 *);
	int (*online)(struct device___20 *);
	int (*offline)(struct device___20 *);
	int (*suspend)(struct device___20 *, pm_message_t);
	int (*resume)(struct device___20 *);
	int (*num_vf)(struct device___20 *);
	int (*dma_configure)(struct device___20 *);
	const struct dev_pm_ops___20 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___20 {
	const char *name;
	struct bus_type___20 *bus;
	struct module___17 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___20 *);
	void (*sync_state)(struct device___20 *);
	int (*remove)(struct device___20 *);
	void (*shutdown)(struct device___20 *);
	int (*suspend)(struct device___20 *, pm_message_t);
	int (*resume)(struct device___20 *);
	const struct attribute_group___18 **groups;
	const struct attribute_group___18 **dev_groups;
	const struct dev_pm_ops___20 *pm;
	void (*coredump)(struct device___20 *);
	struct driver_private *p;
};

struct device_type___20 {
	const char *name;
	const struct attribute_group___18 **groups;
	int (*uevent)(struct device___20 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___20 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___20 *);
	const struct dev_pm_ops___20 *pm;
};

struct class___20 {
	const char *name;
	struct module___17 *owner;
	const struct attribute_group___18 **class_groups;
	const struct attribute_group___18 **dev_groups;
	struct kobject___18 *dev_kobj;
	int (*dev_uevent)(struct device___20 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___20 *, umode_t *);
	void (*class_release)(struct class___20 *);
	void (*dev_release)(struct device___20 *);
	int (*shutdown_pre)(struct device___20 *);
	const struct kobj_ns_type_operations *ns_type;
	const void * (*namespace)(struct device___20 *);
	void (*get_ownership)(struct device___20 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___20 *pm;
	struct subsys_private *p;
};

typedef u64 acpi_io_address;

typedef u64 acpi_physical_address;

typedef char *acpi_string;

typedef void *acpi_handle;

typedef u32 acpi_object_type;

typedef u8 acpi_adr_space_type;

union acpi_object {
	acpi_object_type type;
	struct {
		acpi_object_type type;
		u64 value;
	} integer;
	struct {
		acpi_object_type type;
		u32 length;
		char *pointer;
	} string;
	struct {
		acpi_object_type type;
		u32 length;
		u8 *pointer;
	} buffer;
	struct {
		acpi_object_type type;
		u32 count;
		union acpi_object *elements;
	} package;
	struct {
		acpi_object_type type;
		acpi_object_type actual_type;
		acpi_handle handle;
	} reference;
	struct {
		acpi_object_type type;
		u32 proc_id;
		acpi_io_address pblk_address;
		u32 pblk_length;
	} processor;
	struct {
		acpi_object_type type;
		u32 system_level;
		u32 resource_order;
	} power_resource;
};

struct acpi_object_list {
	u32 count;
	union acpi_object *pointer;
};

struct acpi_subtable_header {
	u8 type;
	u8 length;
};

struct acpi_table_boot {
	struct acpi_table_header header;
	u8 cmos_index;
	u8 reserved[3];
};

struct acpi_hmat_structure {
	u16 type;
	u16 reserved;
	u32 length;
};

struct acpi_table_hpet {
	struct acpi_table_header header;
	u32 id;
	struct acpi_generic_address address;
	u8 sequence;
	u16 minimum_tick;
	u8 flags;
} __attribute__((packed));

struct acpi_table_madt {
	struct acpi_table_header header;
	u32 address;
	u32 flags;
};

enum acpi_madt_type {
	ACPI_MADT_TYPE_LOCAL_APIC = 0,
	ACPI_MADT_TYPE_IO_APIC = 1,
	ACPI_MADT_TYPE_INTERRUPT_OVERRIDE = 2,
	ACPI_MADT_TYPE_NMI_SOURCE = 3,
	ACPI_MADT_TYPE_LOCAL_APIC_NMI = 4,
	ACPI_MADT_TYPE_LOCAL_APIC_OVERRIDE = 5,
	ACPI_MADT_TYPE_IO_SAPIC = 6,
	ACPI_MADT_TYPE_LOCAL_SAPIC = 7,
	ACPI_MADT_TYPE_INTERRUPT_SOURCE = 8,
	ACPI_MADT_TYPE_LOCAL_X2APIC = 9,
	ACPI_MADT_TYPE_LOCAL_X2APIC_NMI = 10,
	ACPI_MADT_TYPE_GENERIC_INTERRUPT = 11,
	ACPI_MADT_TYPE_GENERIC_DISTRIBUTOR = 12,
	ACPI_MADT_TYPE_GENERIC_MSI_FRAME = 13,
	ACPI_MADT_TYPE_GENERIC_REDISTRIBUTOR = 14,
	ACPI_MADT_TYPE_GENERIC_TRANSLATOR = 15,
	ACPI_MADT_TYPE_MULTIPROC_WAKEUP = 16,
	ACPI_MADT_TYPE_RESERVED = 17,
};

struct acpi_madt_local_apic {
	struct acpi_subtable_header header;
	u8 processor_id;
	u8 id;
	u32 lapic_flags;
};

struct acpi_madt_io_apic {
	struct acpi_subtable_header header;
	u8 id;
	u8 reserved;
	u32 address;
	u32 global_irq_base;
};

struct acpi_madt_interrupt_override {
	struct acpi_subtable_header header;
	u8 bus;
	u8 source_irq;
	u32 global_irq;
	u16 inti_flags;
} __attribute__((packed));

struct acpi_madt_nmi_source {
	struct acpi_subtable_header header;
	u16 inti_flags;
	u32 global_irq;
};

struct acpi_madt_local_apic_nmi {
	struct acpi_subtable_header header;
	u8 processor_id;
	u16 inti_flags;
	u8 lint;
} __attribute__((packed));

struct acpi_madt_local_apic_override {
	struct acpi_subtable_header header;
	u16 reserved;
	u64 address;
} __attribute__((packed));

struct acpi_madt_local_sapic {
	struct acpi_subtable_header header;
	u8 processor_id;
	u8 id;
	u8 eid;
	u8 reserved[3];
	u32 lapic_flags;
	u32 uid;
	char uid_string[1];
} __attribute__((packed));

struct acpi_madt_local_x2apic {
	struct acpi_subtable_header header;
	u16 reserved;
	u32 local_apic_id;
	u32 lapic_flags;
	u32 uid;
};

struct acpi_madt_local_x2apic_nmi {
	struct acpi_subtable_header header;
	u16 inti_flags;
	u32 uid;
	u8 lint;
	u8 reserved[3];
};

struct acpi_prmt_module_header {
	u16 revision;
	u16 length;
};

struct pci_ops___5;

struct pci_bus___5 {
	struct list_head node;
	struct pci_bus___5 *parent;
	struct list_head children;
	struct list_head devices;
	struct pci_dev___5 *self;
	struct list_head slots;
	struct resource *resource[4];
	struct list_head resources;
	struct resource busn_res;
	struct pci_ops___5 *ops;
	void *sysdata;
	struct proc_dir_entry *procdir;
	unsigned char number;
	unsigned char primary;
	unsigned char max_bus_speed;
	unsigned char cur_bus_speed;
	char name[48];
	short unsigned int bridge_ctl;
	pci_bus_flags_t bus_flags;
	struct device___20 *bridge;
	struct device___20 dev;
	struct bin_attribute___18 *legacy_io;
	struct bin_attribute___18 *legacy_mem;
	unsigned int is_added: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

union acpi_subtable_headers {
	struct acpi_subtable_header common;
	struct acpi_hmat_structure hmat;
	struct acpi_prmt_module_header prmt;
};

typedef int (*acpi_tbl_table_handler)(struct acpi_table_header *);

typedef int (*acpi_tbl_entry_handler)(union acpi_subtable_headers *, const long unsigned int);

struct acpi_subtable_proc {
	int id;
	acpi_tbl_entry_handler handler;
	int count;
};

typedef u32 phys_cpuid_t;

struct tty_driver___2;

struct tty_operations___2;

struct tty_ldisc___2;

struct tty_port___2;

struct tty_struct {
	int magic;
	struct kref kref;
	struct device___20 *dev;
	struct tty_driver___2 *driver;
	const struct tty_operations___2 *ops;
	int index;
	struct ld_semaphore ldisc_sem;
	struct tty_ldisc___2 *ldisc;
	struct mutex atomic_write_lock;
	struct mutex legacy_mutex;
	struct mutex throttle_mutex;
	struct rw_semaphore termios_rwsem;
	struct mutex winsize_mutex;
	struct ktermios termios;
	struct ktermios termios_locked;
	char name[64];
	long unsigned int flags;
	int count;
	struct winsize winsize;
	struct {
		spinlock_t lock;
		bool stopped;
		bool tco_stopped;
		long unsigned int unused[0];
	} flow;
	struct {
		spinlock_t lock;
		struct pid___2 *pgrp;
		struct pid___2 *session;
		unsigned char pktstatus;
		bool packet;
		long unsigned int unused[0];
	} ctrl;
	int hw_stopped;
	unsigned int receive_room;
	int flow_change;
	struct tty_struct *link;
	struct fasync_struct___18 *fasync;
	wait_queue_head_t write_wait;
	wait_queue_head_t read_wait;
	struct work_struct hangup_work;
	void *disc_data;
	void *driver_data;
	spinlock_t files_lock;
	struct list_head tty_files;
	int closing;
	unsigned char *write_buf;
	int write_cnt;
	struct work_struct SAK_work;
	struct tty_port___2 *port;
};

struct msi_desc___5 {
	struct list_head list;
	unsigned int irq;
	unsigned int nvec_used;
	struct device___20 *dev;
	struct msi_msg msg;
	struct irq_affinity_desc *affinity;
	const void *iommu_cookie;
	void (*write_msi_msg)(struct msi_desc___5 *, void *);
	void *write_msi_msg_data;
	union {
		struct {
			union {
				u32 msi_mask;
				u32 msix_ctrl;
			};
			struct {
				u8 is_msix: 1;
				u8 multiple: 3;
				u8 multi_cap: 3;
				u8 can_mask: 1;
				u8 is_64: 1;
				u8 is_virtual: 1;
				u16 entry_nr;
				unsigned int default_irq;
			} msi_attrib;
			union {
				u8 mask_pos;
				void *mask_base;
			};
		};
		struct platform_msi_desc platform;
		struct fsl_mc_msi_desc fsl_mc;
		struct ti_sci_inta_msi_desc inta;
	};
};

struct irq_chip___8 {
	struct device___20 *parent_device;
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___8 *);
	void (*irq_shutdown)(struct irq_data___8 *);
	void (*irq_enable)(struct irq_data___8 *);
	void (*irq_disable)(struct irq_data___8 *);
	void (*irq_ack)(struct irq_data___8 *);
	void (*irq_mask)(struct irq_data___8 *);
	void (*irq_mask_ack)(struct irq_data___8 *);
	void (*irq_unmask)(struct irq_data___8 *);
	void (*irq_eoi)(struct irq_data___8 *);
	int (*irq_set_affinity)(struct irq_data___8 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___8 *);
	int (*irq_set_type)(struct irq_data___8 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___8 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___8 *);
	void (*irq_bus_sync_unlock)(struct irq_data___8 *);
	void (*irq_cpu_online)(struct irq_data___8 *);
	void (*irq_cpu_offline)(struct irq_data___8 *);
	void (*irq_suspend)(struct irq_data___8 *);
	void (*irq_resume)(struct irq_data___8 *);
	void (*irq_pm_shutdown)(struct irq_data___8 *);
	void (*irq_calc_mask)(struct irq_data___8 *);
	void (*irq_print_chip)(struct irq_data___8 *, struct seq_file___16 *);
	int (*irq_request_resources)(struct irq_data___8 *);
	void (*irq_release_resources)(struct irq_data___8 *);
	void (*irq_compose_msi_msg)(struct irq_data___8 *, struct msi_msg *);
	void (*irq_write_msi_msg)(struct irq_data___8 *, struct msi_msg *);
	int (*irq_get_irqchip_state)(struct irq_data___8 *, enum irqchip_irq_state, bool *);
	int (*irq_set_irqchip_state)(struct irq_data___8 *, enum irqchip_irq_state, bool);
	int (*irq_set_vcpu_affinity)(struct irq_data___8 *, void *);
	void (*ipi_send_single)(struct irq_data___8 *, unsigned int);
	void (*ipi_send_mask)(struct irq_data___8 *, const struct cpumask *);
	int (*irq_nmi_setup)(struct irq_data___8 *);
	void (*irq_nmi_teardown)(struct irq_data___8 *);
	long unsigned int flags;
};

struct irq_alloc_info___2 {
	enum irq_alloc_type type;
	u32 flags;
	u32 devid;
	irq_hw_number_t hwirq;
	const struct cpumask *mask;
	struct msi_desc___5 *desc;
	void *data;
	union {
		struct ioapic_alloc_info ioapic;
		struct uv_alloc_info uv;
	};
};

struct irq_chip_type___7 {
	struct irq_chip___8 chip;
	struct irq_chip_regs regs;
	irq_flow_handler_t___8 handler;
	u32 type;
	u32 mask_cache_priv;
	u32 *mask_cache;
};

struct irq_chip_generic___7 {
	raw_spinlock_t lock;
	void *reg_base;
	u32 (*reg_readl)(void *);
	void (*reg_writel)(u32, void *);
	void (*suspend)(struct irq_chip_generic___7 *);
	void (*resume)(struct irq_chip_generic___7 *);
	unsigned int irq_base;
	unsigned int irq_cnt;
	u32 mask_cache;
	u32 type_cache;
	u32 polarity_cache;
	u32 wake_enabled;
	u32 wake_active;
	unsigned int num_ct;
	void *private;
	long unsigned int installed;
	long unsigned int unused;
	struct irq_domain___13 *domain;
	struct list_head list;
	struct irq_chip_type___7 chip_types[0];
};

struct pci_slot___5 {
	struct pci_bus___5 *bus;
	struct list_head list;
	struct hotplug_slot *hotplug;
	unsigned char number;
	struct kobject___18 kobj;
};

struct pci_error_handlers___5;

struct pci_driver___5 {
	struct list_head node;
	const char *name;
	const struct pci_device_id *id_table;
	int (*probe)(struct pci_dev___5 *, const struct pci_device_id *);
	void (*remove)(struct pci_dev___5 *);
	int (*suspend)(struct pci_dev___5 *, pm_message_t);
	int (*resume)(struct pci_dev___5 *);
	void (*shutdown)(struct pci_dev___5 *);
	int (*sriov_configure)(struct pci_dev___5 *, int);
	int (*sriov_set_msix_vec_count)(struct pci_dev___5 *, int);
	u32 (*sriov_get_vf_total_msix)(struct pci_dev___5 *);
	const struct pci_error_handlers___5 *err_handler;
	const struct attribute_group___18 **groups;
	const struct attribute_group___18 **dev_groups;
	struct device_driver___20 driver;
	struct pci_dynids dynids;
};

struct pci_ops___5 {
	int (*add_bus)(struct pci_bus___5 *);
	void (*remove_bus)(struct pci_bus___5 *);
	void * (*map_bus)(struct pci_bus___5 *, unsigned int, int);
	int (*read)(struct pci_bus___5 *, unsigned int, int, int, u32 *);
	int (*write)(struct pci_bus___5 *, unsigned int, int, int, u32);
};

struct pci_error_handlers___5 {
	pci_ers_result_t (*error_detected)(struct pci_dev___5 *, pci_channel_state_t);
	pci_ers_result_t (*mmio_enabled)(struct pci_dev___5 *);
	pci_ers_result_t (*slot_reset)(struct pci_dev___5 *);
	void (*reset_prepare)(struct pci_dev___5 *);
	void (*reset_done)(struct pci_dev___5 *);
	void (*resume)(struct pci_dev___5 *);
};

struct tty_driver___2 {
	int magic;
	struct kref kref;
	struct cdev___7 **cdevs;
	struct module___17 *owner;
	const char *driver_name;
	const char *name;
	int name_base;
	int major;
	int minor_start;
	unsigned int num;
	short int type;
	short int subtype;
	struct ktermios init_termios;
	long unsigned int flags;
	struct proc_dir_entry *proc_entry;
	struct tty_driver___2 *other;
	struct tty_struct **ttys;
	struct tty_port___2 **ports;
	struct ktermios **termios;
	void *driver_state;
	const struct tty_operations___2 *ops;
	struct list_head tty_drivers;
};

struct serial_icounter_struct___2;

struct serial_struct___2;

struct tty_operations___2 {
	struct tty_struct * (*lookup)(struct tty_driver___2 *, struct file___18 *, int);
	int (*install)(struct tty_driver___2 *, struct tty_struct *);
	void (*remove)(struct tty_driver___2 *, struct tty_struct *);
	int (*open)(struct tty_struct *, struct file___18 *);
	void (*close)(struct tty_struct *, struct file___18 *);
	void (*shutdown)(struct tty_struct *);
	void (*cleanup)(struct tty_struct *);
	int (*write)(struct tty_struct *, const unsigned char *, int);
	int (*put_char)(struct tty_struct *, unsigned char);
	void (*flush_chars)(struct tty_struct *);
	unsigned int (*write_room)(struct tty_struct *);
	unsigned int (*chars_in_buffer)(struct tty_struct *);
	int (*ioctl)(struct tty_struct *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct tty_struct *, unsigned int, long unsigned int);
	void (*set_termios)(struct tty_struct *, struct ktermios *);
	void (*throttle)(struct tty_struct *);
	void (*unthrottle)(struct tty_struct *);
	void (*stop)(struct tty_struct *);
	void (*start)(struct tty_struct *);
	void (*hangup)(struct tty_struct *);
	int (*break_ctl)(struct tty_struct *, int);
	void (*flush_buffer)(struct tty_struct *);
	void (*set_ldisc)(struct tty_struct *);
	void (*wait_until_sent)(struct tty_struct *, int);
	void (*send_xchar)(struct tty_struct *, char);
	int (*tiocmget)(struct tty_struct *);
	int (*tiocmset)(struct tty_struct *, unsigned int, unsigned int);
	int (*resize)(struct tty_struct *, struct winsize *);
	int (*get_icount)(struct tty_struct *, struct serial_icounter_struct___2 *);
	int (*get_serial)(struct tty_struct *, struct serial_struct___2 *);
	int (*set_serial)(struct tty_struct *, struct serial_struct___2 *);
	void (*show_fdinfo)(struct tty_struct *, struct seq_file___16 *);
	int (*poll_init)(struct tty_driver___2 *, int, char *);
	int (*poll_get_char)(struct tty_driver___2 *, int);
	void (*poll_put_char)(struct tty_driver___2 *, int, char);
	int (*proc_show)(struct seq_file___16 *, void *);
};

struct serial_icounter_struct___2 {
	int cts;
	int dsr;
	int rng;
	int dcd;
	int rx;
	int tx;
	int frame;
	int overrun;
	int parity;
	int brk;
	int buf_overrun;
	int reserved[9];
};

struct serial_struct___2 {
	int type;
	int line;
	unsigned int port;
	int irq;
	int flags;
	int xmit_fifo_size;
	int custom_divisor;
	int baud_base;
	short unsigned int close_delay;
	char io_type;
	char reserved_char[1];
	int hub6;
	short unsigned int closing_wait;
	short unsigned int closing_wait2;
	unsigned char *iomem_base;
	short unsigned int iomem_reg_shift;
	unsigned int port_high;
	long unsigned int iomap_base;
};

struct tty_port_operations___2;

struct tty_port_client_operations___2;

struct tty_port___2 {
	struct tty_bufhead buf;
	struct tty_struct *tty;
	struct tty_struct *itty;
	const struct tty_port_operations___2 *ops;
	const struct tty_port_client_operations___2 *client_ops;
	spinlock_t lock;
	int blocked_open;
	int count;
	wait_queue_head_t open_wait;
	wait_queue_head_t delta_msr_wait;
	long unsigned int flags;
	long unsigned int iflags;
	unsigned char console: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct mutex mutex;
	struct mutex buf_mutex;
	unsigned char *xmit_buf;
	unsigned int close_delay;
	unsigned int closing_wait;
	int drain_delay;
	struct kref kref;
	void *client_data;
};

struct tty_ldisc_ops___2 {
	char *name;
	int num;
	int flags;
	int (*open)(struct tty_struct *);
	void (*close)(struct tty_struct *);
	void (*flush_buffer)(struct tty_struct *);
	ssize_t (*read)(struct tty_struct *, struct file___18 *, unsigned char *, size_t, void **, long unsigned int);
	ssize_t (*write)(struct tty_struct *, struct file___18 *, const unsigned char *, size_t);
	int (*ioctl)(struct tty_struct *, struct file___18 *, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct tty_struct *, struct file___18 *, unsigned int, long unsigned int);
	void (*set_termios)(struct tty_struct *, struct ktermios *);
	__poll_t (*poll)(struct tty_struct *, struct file___18 *, struct poll_table_struct___12 *);
	int (*hangup)(struct tty_struct *);
	void (*receive_buf)(struct tty_struct *, const unsigned char *, const char *, int);
	void (*write_wakeup)(struct tty_struct *);
	void (*dcd_change)(struct tty_struct *, unsigned int);
	int (*receive_buf2)(struct tty_struct *, const unsigned char *, const char *, int);
	struct module___17 *owner;
};

struct tty_ldisc___2 {
	struct tty_ldisc_ops___2 *ops;
	struct tty_struct *tty;
};

struct tty_port_operations___2 {
	int (*carrier_raised)(struct tty_port___2 *);
	void (*dtr_rts)(struct tty_port___2 *, int);
	void (*shutdown)(struct tty_port___2 *);
	int (*activate)(struct tty_port___2 *, struct tty_struct *);
	void (*destruct)(struct tty_port___2 *);
};

struct tty_port_client_operations___2 {
	int (*receive_buf)(struct tty_port___2 *, const unsigned char *, const unsigned char *, size_t);
	void (*write_wakeup)(struct tty_port___2 *);
};

enum ioapic_domain_type {
	IOAPIC_DOMAIN_INVALID = 0,
	IOAPIC_DOMAIN_LEGACY = 1,
	IOAPIC_DOMAIN_STRICT = 2,
	IOAPIC_DOMAIN_DYNAMIC = 3,
};

struct ioapic_domain_cfg {
	enum ioapic_domain_type type;
	const struct irq_domain_ops___13 *ops;
	struct device_node___14 *dev;
};

struct legacy_pic___3 {
	int nr_legacy_irqs;
	struct irq_chip___8 *chip;
	void (*mask)(unsigned int);
	void (*unmask)(unsigned int);
	void (*mask_all)();
	void (*restore_mask)();
	void (*init)(int);
	int (*probe)();
	int (*irq_pending)(unsigned int);
	void (*make_irq)(unsigned int);
};

struct dev_pm_qos_request___3 {
	enum dev_pm_qos_req_type type;
	union {
		struct plist_node pnode;
		struct pm_qos_flags_request flr;
		struct freq_qos_request freq;
	} data;
	struct device___20 *dev;
};

struct wakeup_header {
	u16 video_mode;
	u32 pmode_entry;
	u16 pmode_cs;
	u32 pmode_cr0;
	u32 pmode_cr3;
	u32 pmode_cr4;
	u32 pmode_efer_low;
	u32 pmode_efer_high;
	u64 pmode_gdt;
	u32 pmode_misc_en_low;
	u32 pmode_misc_en_high;
	u32 pmode_behavior;
	u32 realmode_flags;
	u32 real_magic;
	u32 signature;
} __attribute__((packed));

struct acpi_hest_header {
	u16 type;
	u16 source_id;
};

struct acpi_hest_ia_error_bank {
	u8 bank_number;
	u8 clear_status_on_init;
	u8 status_format;
	u8 reserved;
	u32 control_register;
	u64 control_data;
	u32 status_register;
	u32 address_register;
	u32 misc_register;
} __attribute__((packed));

struct acpi_hest_notify {
	u8 type;
	u8 length;
	u16 config_write_enable;
	u32 poll_interval;
	u32 vector;
	u32 polling_threshold_value;
	u32 polling_threshold_window;
	u32 error_threshold_value;
	u32 error_threshold_window;
};

struct acpi_hest_ia_corrected {
	struct acpi_hest_header header;
	u16 reserved1;
	u8 flags;
	u8 enabled;
	u32 records_to_preallocate;
	u32 max_sections_per_record;
	struct acpi_hest_notify notify;
	u8 num_hardware_banks;
	u8 reserved2[3];
};

struct cpc_reg {
	u8 descriptor;
	u16 length;
	u8 space_id;
	u8 bit_width;
	u8 bit_offset;
	u8 access_width;
	u64 address;
} __attribute__((packed));

struct acpi_power_register {
	u8 descriptor;
	u16 length;
	u8 space_id;
	u8 bit_width;
	u8 bit_offset;
	u8 access_size;
	u64 address;
} __attribute__((packed));

struct acpi_processor_cx {
	u8 valid;
	u8 type;
	u32 address;
	u8 entry_method;
	u8 index;
	u32 latency;
	u8 bm_sts_skip;
	char desc[32];
};

struct acpi_processor_flags {
	u8 power: 1;
	u8 performance: 1;
	u8 throttling: 1;
	u8 limit: 1;
	u8 bm_control: 1;
	u8 bm_check: 1;
	u8 has_cst: 1;
	u8 has_lpi: 1;
	u8 power_setup_done: 1;
	u8 bm_rld_set: 1;
	u8 need_hotplug_init: 1;
	short: 15;
};

struct cstate_entry {
	struct {
		unsigned int eax;
		unsigned int ecx;
	} states[8];
};

struct pv_cpu_ops___16 {
	void (*io_delay)();
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	void (*write_cr4)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___9 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(long unsigned int);
	void (*invalidate_io_bitmap)();
	void (*update_io_bitmap)();
	void (*wbinvd)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int);
	void (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_msr_safe)(unsigned int, int *);
	int (*write_msr_safe)(unsigned int, unsigned int, unsigned int);
	u64 (*read_pmc)(int);
	void (*start_context_switch)(struct task_struct___16 *);
	void (*end_context_switch)(struct task_struct___16 *);
};

struct flush_tlb_info___7;

struct mmu_gather___3;

struct pv_mmu_ops___16 {
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_one_user)(long unsigned int);
	void (*flush_tlb_multi)(const struct cpumask *, const struct flush_tlb_info___7 *);
	void (*tlb_remove_table)(struct mmu_gather___3 *, void *);
	void (*exit_mmap)(struct mm_struct___3 *);
	struct paravirt_callee_save read_cr2;
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___3 *, struct mm_struct___3 *);
	void (*dup_mmap)(struct mm_struct___3 *, struct mm_struct___3 *);
	int (*pgd_alloc)(struct mm_struct___3 *);
	void (*pgd_free)(struct mm_struct___3 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___3 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___3 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___3 *, long unsigned int);
	void (*alloc_p4d)(struct mm_struct___3 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*release_p4d)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	pte_t (*ptep_modify_prot_start)(struct vm_area_struct___15 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct vm_area_struct___15 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_p4d)(p4d_t *, p4d_t);
	struct paravirt_callee_save p4d_val;
	struct paravirt_callee_save make_p4d;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

struct flush_tlb_info___7 {
	struct mm_struct___3 *mm;
	long unsigned int start;
	long unsigned int end;
	u64 new_tlb_gen;
	unsigned int initiating_cpu;
	u8 stride_shift;
	u8 freed_tables;
};

struct mmu_gather_batch___3 {
	struct mmu_gather_batch___3 *next;
	unsigned int nr;
	unsigned int max;
	struct page___14 *pages[0];
};

struct mmu_gather___3 {
	struct mm_struct___3 *mm;
	struct mmu_table_batch *batch;
	long unsigned int start;
	long unsigned int end;
	unsigned int fullmm: 1;
	unsigned int need_flush_all: 1;
	unsigned int freed_tables: 1;
	unsigned int cleared_ptes: 1;
	unsigned int cleared_pmds: 1;
	unsigned int cleared_puds: 1;
	unsigned int cleared_p4ds: 1;
	unsigned int vma_exec: 1;
	unsigned int vma_huge: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int batch_count;
	struct mmu_gather_batch___3 *active;
	struct mmu_gather_batch___3 local;
	struct page___14 *__pages[8];
};

struct paravirt_patch_template___16 {
	struct pv_cpu_ops___16 cpu;
	struct pv_irq_ops irq;
	struct pv_mmu_ops___16 mmu;
	struct pv_lock_ops lock;
};

struct smp_ops___5 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*crash_stop_other_cpus)();
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___16 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

enum reboot_mode {
	REBOOT_UNDEFINED = 0,
	REBOOT_COLD = 0,
	REBOOT_WARM = 1,
	REBOOT_HARD = 2,
	REBOOT_SOFT = 3,
	REBOOT_GPIO = 4,
};

enum reboot_type {
	BOOT_TRIPLE = 116,
	BOOT_KBD = 107,
	BOOT_BIOS = 98,
	BOOT_ACPI = 97,
	BOOT_EFI = 101,
	BOOT_CF9_FORCE = 112,
	BOOT_CF9_SAFE = 113,
};

typedef void (*nmi_shootdown_cb)(int, struct pt_regs *);

struct intel_early_ops {
	resource_size_t (*stolen_size)(int, int, int);
	resource_size_t (*stolen_base)(int, int, int, resource_size_t);
};

struct chipset {
	u32 vendor;
	u32 device;
	u32 class;
	u32 class_mask;
	u32 flags;
	void (*f)(int, int, int);
};

enum {
	SD_BALANCE_NEWIDLE = 1,
	SD_BALANCE_EXEC = 2,
	SD_BALANCE_FORK = 4,
	SD_BALANCE_WAKE = 8,
	SD_WAKE_AFFINE = 16,
	SD_ASYM_CPUCAPACITY = 32,
	SD_ASYM_CPUCAPACITY_FULL = 64,
	SD_SHARE_CPUCAPACITY = 128,
	SD_SHARE_PKG_RESOURCES = 256,
	SD_SERIALIZE = 512,
	SD_ASYM_PACKING = 1024,
	SD_PREFER_SIBLING = 2048,
	SD_OVERLAP = 4096,
	SD_NUMA = 8192,
};

struct sched_domain_shared {
	atomic_t ref;
	atomic_t nr_busy_cpus;
	int has_idle_cores;
};

struct sched_group;

struct sched_domain {
	struct sched_domain *parent;
	struct sched_domain *child;
	struct sched_group *groups;
	long unsigned int min_interval;
	long unsigned int max_interval;
	unsigned int busy_factor;
	unsigned int imbalance_pct;
	unsigned int cache_nice_tries;
	int nohz_idle;
	int flags;
	int level;
	long unsigned int last_balance;
	unsigned int balance_interval;
	unsigned int nr_balance_failed;
	u64 max_newidle_lb_cost;
	long unsigned int next_decay_max_lb_cost;
	u64 avg_scan_cost;
	unsigned int lb_count[3];
	unsigned int lb_failed[3];
	unsigned int lb_balanced[3];
	unsigned int lb_imbalance[3];
	unsigned int lb_gained[3];
	unsigned int lb_hot_gained[3];
	unsigned int lb_nobusyg[3];
	unsigned int lb_nobusyq[3];
	unsigned int alb_count;
	unsigned int alb_failed;
	unsigned int alb_pushed;
	unsigned int sbe_count;
	unsigned int sbe_balanced;
	unsigned int sbe_pushed;
	unsigned int sbf_count;
	unsigned int sbf_balanced;
	unsigned int sbf_pushed;
	unsigned int ttwu_wake_remote;
	unsigned int ttwu_move_affine;
	unsigned int ttwu_move_balance;
	char *name;
	union {
		void *private;
		struct callback_head rcu;
	};
	struct sched_domain_shared *shared;
	unsigned int span_weight;
	long unsigned int span[0];
};

typedef const struct cpumask * (*sched_domain_mask_f)(int);

typedef int (*sched_domain_flags_f)();

struct sched_group_capacity;

struct sd_data {
	struct sched_domain **sd;
	struct sched_domain_shared **sds;
	struct sched_group **sg;
	struct sched_group_capacity **sgc;
};

struct sched_domain_topology_level {
	sched_domain_mask_f mask;
	sched_domain_flags_f sd_flags;
	int flags;
	int numa_level;
	struct sd_data data;
	char *name;
};

enum apic_intr_mode_id {
	APIC_PIC = 0,
	APIC_VIRTUAL_WIRE = 1,
	APIC_VIRTUAL_WIRE_NO_CONFIG = 2,
	APIC_SYMMETRIC_IO = 3,
	APIC_SYMMETRIC_IO_NO_ROUTING = 4,
};

struct cppc_perf_caps {
	u32 guaranteed_perf;
	u32 highest_perf;
	u32 nominal_perf;
	u32 lowest_perf;
	u32 lowest_nonlinear_perf;
	u32 lowest_freq;
	u32 nominal_freq;
};

struct tsc_adjust {
	s64 bootval;
	s64 adjusted;
	long unsigned int nextcheck;
	bool warned;
};

typedef struct pglist_data___11 pg_data_t___3;

typedef void * (*pcpu_fc_alloc_fn_t)(unsigned int, size_t, size_t);

typedef void (*pcpu_fc_free_fn_t)(void *, size_t);

typedef void (*pcpu_fc_populate_pte_fn_t)(long unsigned int);

typedef int pcpu_fc_cpu_distance_fn_t(unsigned int, unsigned int);

enum {
	DUMP_PREFIX_NONE = 0,
	DUMP_PREFIX_ADDRESS = 1,
	DUMP_PREFIX_OFFSET = 2,
};

struct mpf_intel {
	char signature[4];
	unsigned int physptr;
	unsigned char length;
	unsigned char specification;
	unsigned char checksum;
	unsigned char feature1;
	unsigned char feature2;
	unsigned char feature3;
	unsigned char feature4;
	unsigned char feature5;
};

struct mpc_table {
	char signature[4];
	short unsigned int length;
	char spec;
	char checksum;
	char oem[8];
	char productid[12];
	unsigned int oemptr;
	short unsigned int oemsize;
	short unsigned int oemcount;
	unsigned int lapic;
	unsigned int reserved;
};

struct mpc_cpu {
	unsigned char type;
	unsigned char apicid;
	unsigned char apicver;
	unsigned char cpuflag;
	unsigned int cpufeature;
	unsigned int featureflag;
	unsigned int reserved[2];
};

struct mpc_bus {
	unsigned char type;
	unsigned char busid;
	unsigned char bustype[6];
};

struct mpc_ioapic {
	unsigned char type;
	unsigned char apicid;
	unsigned char apicver;
	unsigned char flags;
	unsigned int apicaddr;
};

struct mpc_lintsrc {
	unsigned char type;
	unsigned char irqtype;
	short unsigned int irqflag;
	unsigned char srcbusid;
	unsigned char srcbusirq;
	unsigned char destapic;
	unsigned char destapiclint;
};

struct ioapic_domain_cfg___2 {
	enum ioapic_domain_type type;
	const struct irq_domain_ops___9 *ops;
	struct device_node___10 *dev;
};

enum page_cache_mode {
	_PAGE_CACHE_MODE_WB = 0,
	_PAGE_CACHE_MODE_WC = 1,
	_PAGE_CACHE_MODE_UC_MINUS = 2,
	_PAGE_CACHE_MODE_UC = 3,
	_PAGE_CACHE_MODE_WT = 4,
	_PAGE_CACHE_MODE_WP = 5,
	_PAGE_CACHE_MODE_NUM = 8,
};

enum {
	IRQ_REMAP_XAPIC_MODE = 0,
	IRQ_REMAP_X2APIC_MODE = 1,
};

union apic_ir {
	long unsigned int map[4];
	u32 regs[8];
};

enum {
	X2APIC_OFF = 0,
	X2APIC_ON = 1,
	X2APIC_DISABLED = 2,
};

enum {
	IRQ_SET_MASK_OK = 0,
	IRQ_SET_MASK_OK_NOCOPY = 1,
	IRQ_SET_MASK_OK_DONE = 2,
};

enum {
	IRQD_TRIGGER_MASK = 15,
	IRQD_SETAFFINITY_PENDING = 256,
	IRQD_ACTIVATED = 512,
	IRQD_NO_BALANCING = 1024,
	IRQD_PER_CPU = 2048,
	IRQD_AFFINITY_SET = 4096,
	IRQD_LEVEL = 8192,
	IRQD_WAKEUP_STATE = 16384,
	IRQD_MOVE_PCNTXT = 32768,
	IRQD_IRQ_DISABLED = 65536,
	IRQD_IRQ_MASKED = 131072,
	IRQD_IRQ_INPROGRESS = 262144,
	IRQD_WAKEUP_ARMED = 524288,
	IRQD_FORWARDED_TO_VCPU = 1048576,
	IRQD_AFFINITY_MANAGED = 2097152,
	IRQD_IRQ_STARTED = 4194304,
	IRQD_MANAGED_SHUTDOWN = 8388608,
	IRQD_SINGLE_TARGET = 16777216,
	IRQD_DEFAULT_TRIGGER_SET = 33554432,
	IRQD_CAN_RESERVE = 67108864,
	IRQD_MSI_NOMASK_QUIRK = 134217728,
	IRQD_HANDLE_ENFORCE_IRQCTX = 268435456,
	IRQD_AFFINITY_ON_ACTIVATE = 536870912,
	IRQD_IRQ_ENABLED_ON_SUSPEND = 1073741824,
};

typedef struct irq_desc___7 *vector_irq_t___3[256];

enum {
	X86_IRQ_ALLOC_CONTIGUOUS_VECTORS = 1,
	X86_IRQ_ALLOC_LEGACY = 2,
};

struct apic_chip_data {
	struct irq_cfg hw_irq_cfg;
	unsigned int vector;
	unsigned int prev_vector;
	unsigned int cpu;
	unsigned int prev_cpu;
	unsigned int irq;
	struct hlist_node clist;
	unsigned int move_in_progress: 1;
	unsigned int is_managed: 1;
	unsigned int can_reserve: 1;
	unsigned int has_reserved: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irq_matrix;

enum {
	IRQ_TYPE_NONE = 0,
	IRQ_TYPE_EDGE_RISING = 1,
	IRQ_TYPE_EDGE_FALLING = 2,
	IRQ_TYPE_EDGE_BOTH = 3,
	IRQ_TYPE_LEVEL_HIGH = 4,
	IRQ_TYPE_LEVEL_LOW = 8,
	IRQ_TYPE_LEVEL_MASK = 12,
	IRQ_TYPE_SENSE_MASK = 15,
	IRQ_TYPE_DEFAULT = 15,
	IRQ_TYPE_PROBE = 16,
	IRQ_LEVEL = 256,
	IRQ_PER_CPU = 512,
	IRQ_NOPROBE = 1024,
	IRQ_NOREQUEST = 2048,
	IRQ_NOAUTOEN = 4096,
	IRQ_NO_BALANCING = 8192,
	IRQ_MOVE_PCNTXT = 16384,
	IRQ_NESTED_THREAD = 32768,
	IRQ_NOTHREAD = 65536,
	IRQ_PER_CPU_DEVID = 131072,
	IRQ_IS_POLLED = 262144,
	IRQ_DISABLE_UNLAZY = 524288,
	IRQ_HIDDEN = 1048576,
	IRQ_NO_DEBUG = 2097152,
};

struct irq_alloc_info___3 {
	enum irq_alloc_type type;
	u32 flags;
	u32 devid;
	irq_hw_number_t hwirq;
	const struct cpumask *mask;
	struct msi_desc *desc;
	void *data;
	union {
		struct ioapic_alloc_info ioapic;
		struct uv_alloc_info uv;
	};
};

struct clock_event_device___2;

union IO_APIC_reg_00 {
	u32 raw;
	struct {
		u32 __reserved_2: 14;
		u32 LTS: 1;
		u32 delivery_type: 1;
		u32 __reserved_1: 8;
		u32 ID: 8;
	} bits;
};

union IO_APIC_reg_01 {
	u32 raw;
	struct {
		u32 version: 8;
		u32 __reserved_2: 7;
		u32 PRQ: 1;
		u32 entries: 8;
		u32 __reserved_1: 8;
	} bits;
};

union IO_APIC_reg_02 {
	u32 raw;
	struct {
		u32 __reserved_2: 24;
		u32 arbitration: 4;
		u32 __reserved_1: 4;
	} bits;
};

union IO_APIC_reg_03 {
	u32 raw;
	struct {
		u32 boot_DT: 1;
		u32 __reserved_1: 31;
	} bits;
};

struct IO_APIC_route_entry {
	union {
		struct {
			u64 vector: 8;
			u64 delivery_mode: 3;
			u64 dest_mode_logical: 1;
			u64 delivery_status: 1;
			u64 active_low: 1;
			u64 irr: 1;
			u64 is_level: 1;
			u64 masked: 1;
			u64 reserved_0: 15;
			u64 reserved_1: 17;
			u64 virt_destid_8_14: 7;
			u64 destid_0_7: 8;
		};
		struct {
			u64 ir_shared_0: 8;
			u64 ir_zero: 3;
			u64 ir_index_15: 1;
			u64 ir_shared_1: 5;
			u64 ir_reserved_0: 31;
			u64 ir_format: 1;
			u64 ir_index_0_14: 15;
		};
		struct {
			u64 w1: 32;
			u64 w2: 32;
		};
	};
};

struct irq_pin_list {
	struct list_head list;
	int apic;
	int pin;
};

struct mp_chip_data {
	struct list_head irq_2_pin;
	struct IO_APIC_route_entry entry;
	bool is_level;
	bool active_low;
	bool isa_irq;
	u32 count;
};

struct mp_ioapic_gsi {
	u32 gsi_base;
	u32 gsi_end;
};

struct ioapic {
	int nr_registers;
	struct IO_APIC_route_entry *saved_registers;
	struct mpc_ioapic mp_config;
	struct mp_ioapic_gsi gsi_config;
	struct ioapic_domain_cfg___2 irqdomain_cfg;
	struct irq_domain___9 *irqdomain;
	struct resource *iomem_res;
};

struct io_apic {
	unsigned int index;
	unsigned int unused[3];
	unsigned int data;
	unsigned int unused2[11];
	unsigned int eoi;
};

enum {
	IRQ_DOMAIN_FLAG_HIERARCHY = 1,
	IRQ_DOMAIN_NAME_ALLOCATED = 2,
	IRQ_DOMAIN_FLAG_IPI_PER_CPU = 4,
	IRQ_DOMAIN_FLAG_IPI_SINGLE = 8,
	IRQ_DOMAIN_FLAG_MSI = 16,
	IRQ_DOMAIN_FLAG_MSI_REMAP = 32,
	IRQ_DOMAIN_MSI_NOMASK_QUIRK = 64,
	IRQ_DOMAIN_FLAG_NO_MAP = 128,
	IRQ_DOMAIN_FLAG_NONCORE = 65536,
};

typedef struct irq_alloc_info___3 msi_alloc_info_t___2;

struct msi_domain_info___2;

struct msi_domain_ops___2 {
	irq_hw_number_t (*get_hwirq)(struct msi_domain_info___2 *, msi_alloc_info_t___2 *);
	int (*msi_init)(struct irq_domain___9 *, struct msi_domain_info___2 *, unsigned int, irq_hw_number_t, msi_alloc_info_t___2 *);
	void (*msi_free)(struct irq_domain___9 *, struct msi_domain_info___2 *, unsigned int);
	int (*msi_check)(struct irq_domain___9 *, struct msi_domain_info___2 *, struct device___2 *);
	int (*msi_prepare)(struct irq_domain___9 *, struct device___2 *, int, msi_alloc_info_t___2 *);
	void (*msi_finish)(msi_alloc_info_t___2 *, int);
	void (*set_desc)(msi_alloc_info_t___2 *, struct msi_desc *);
	int (*handle_error)(struct irq_domain___9 *, struct msi_desc *, int);
	int (*domain_alloc_irqs)(struct irq_domain___9 *, struct device___2 *, int);
	void (*domain_free_irqs)(struct irq_domain___9 *, struct device___2 *);
};

struct msi_domain_info___2 {
	u32 flags;
	struct msi_domain_ops___2 *ops;
	struct irq_chip *chip;
	void *chip_data;
	irq_flow_handler_t handler;
	void *handler_data;
	const char *handler_name;
	void *data;
};

typedef struct pglist_data___9 pg_data_t___4;

typedef int (*arch_set_vga_state_t)(struct pci_dev___3 *, bool, unsigned int, u32);

struct acpi_device_status {
	u32 present: 1;
	u32 enabled: 1;
	u32 show_in_ui: 1;
	u32 functional: 1;
	u32 battery_present: 1;
	u32 reserved: 27;
};

struct acpi_device_flags {
	u32 dynamic_status: 1;
	u32 removable: 1;
	u32 ejectable: 1;
	u32 power_manageable: 1;
	u32 match_driver: 1;
	u32 initialized: 1;
	u32 visited: 1;
	u32 hotplug_notify: 1;
	u32 is_dock_station: 1;
	u32 of_compatible_ok: 1;
	u32 coherent_dma: 1;
	u32 cca_seen: 1;
	u32 enumeration_by_parent: 1;
	u32 reserved: 19;
};

typedef char acpi_bus_id[8];

struct acpi_pnp_type {
	u32 hardware_id: 1;
	u32 bus_address: 1;
	u32 platform_id: 1;
	u32 reserved: 29;
};

typedef u64 acpi_bus_address;

typedef char acpi_device_name[40];

typedef char acpi_device_class[20];

struct acpi_device_pnp {
	acpi_bus_id bus_id;
	int instance_no;
	struct acpi_pnp_type type;
	acpi_bus_address bus_address;
	char *unique_id;
	struct list_head ids;
	acpi_device_name device_name;
	acpi_device_class device_class;
	union acpi_object *str_obj;
};

struct acpi_device_power_flags {
	u32 explicit_get: 1;
	u32 power_resources: 1;
	u32 inrush_current: 1;
	u32 power_removed: 1;
	u32 ignore_parent: 1;
	u32 dsw_present: 1;
	u32 reserved: 26;
};

struct acpi_device_power_state {
	struct {
		u8 valid: 1;
		u8 explicit_set: 1;
		u8 reserved: 6;
	} flags;
	int power;
	int latency;
	struct list_head resources;
};

struct acpi_device_power {
	int state;
	struct acpi_device_power_flags flags;
	struct acpi_device_power_state states[5];
};

struct acpi_device_wakeup_flags {
	u8 valid: 1;
	u8 notifier_present: 1;
};

struct acpi_device_wakeup_context {
	void (*func)(struct acpi_device_wakeup_context *);
	struct device___2 *dev;
};

struct acpi_device_wakeup {
	acpi_handle gpe_device;
	u64 gpe_number;
	u64 sleep_state;
	struct list_head resources;
	struct acpi_device_wakeup_flags flags;
	struct acpi_device_wakeup_context context;
	struct wakeup_source___14 *ws;
	int prepare_count;
	int enable_count;
};

struct acpi_device_perf_flags {
	u8 reserved: 8;
};

struct acpi_device_perf_state;

struct acpi_device_perf {
	int state;
	struct acpi_device_perf_flags flags;
	int state_count;
	struct acpi_device_perf_state *states;
};

struct acpi_device_dir {
	struct proc_dir_entry *entry;
};

struct acpi_device_data {
	const union acpi_object *pointer;
	struct list_head properties;
	const union acpi_object *of_compatible;
	struct list_head subnodes;
};

struct acpi_scan_handler;

struct acpi_hotplug_context;

struct acpi_driver;

struct acpi_gpio_mapping;

struct acpi_device {
	int device_type;
	acpi_handle handle;
	struct fwnode_handle___13 fwnode;
	struct acpi_device *parent;
	struct list_head children;
	struct list_head node;
	struct list_head wakeup_list;
	struct list_head del_list;
	struct acpi_device_status status;
	struct acpi_device_flags flags;
	struct acpi_device_pnp pnp;
	struct acpi_device_power power;
	struct acpi_device_wakeup wakeup;
	struct acpi_device_perf performance;
	struct acpi_device_dir dir;
	struct acpi_device_data data;
	struct acpi_scan_handler *handler;
	struct acpi_hotplug_context *hp;
	struct acpi_driver *driver;
	const struct acpi_gpio_mapping *driver_gpios;
	void *driver_data;
	struct device___2 dev;
	unsigned int physical_node_count;
	unsigned int dep_unmet;
	struct list_head physical_node_list;
	struct mutex physical_node_lock;
	void (*remove)(struct acpi_device *);
};

struct acpi_hotplug_profile {
	struct kobject___14 kobj;
	int (*scan_dependent)(struct acpi_device *);
	void (*notify_online)(struct acpi_device *);
	bool enabled;
	bool demand_offline;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct acpi_scan_handler {
	const struct acpi_device_id *ids;
	struct list_head list_node;
	bool (*match)(const char *, const struct acpi_device_id **);
	int (*attach)(struct acpi_device *, const struct acpi_device_id *);
	void (*detach)(struct acpi_device *);
	void (*bind)(struct device___2 *);
	void (*unbind)(struct device___2 *);
	struct acpi_hotplug_profile hotplug;
};

struct acpi_hotplug_context {
	struct acpi_device *self;
	int (*notify)(struct acpi_device *, u32);
	void (*uevent)(struct acpi_device *, u32);
	void (*fixup)(struct acpi_device *);
};

typedef int (*acpi_op_add)(struct acpi_device *);

typedef int (*acpi_op_remove)(struct acpi_device *);

typedef void (*acpi_op_notify)(struct acpi_device *, u32);

struct acpi_device_ops {
	acpi_op_add add;
	acpi_op_remove remove;
	acpi_op_notify notify;
};

struct acpi_driver {
	char name[80];
	char class[80];
	const struct acpi_device_id *ids;
	unsigned int flags;
	struct acpi_device_ops ops;
	struct device_driver___14 drv;
	struct module___3 *owner;
};

struct acpi_device_perf_state {
	struct {
		u8 valid: 1;
		u8 reserved: 7;
	} flags;
	u8 power;
	u8 performance;
	int latency;
};

struct acpi_gpio_params;

struct acpi_gpio_mapping {
	const char *name;
	const struct acpi_gpio_params *data;
	unsigned int size;
	unsigned int quirks;
};

struct acpi_gpio_params {
	unsigned int crs_entry_index;
	unsigned int line_index;
	bool active_low;
};

struct uvyh_gr0_gam_gr_config_s {
	long unsigned int rsvd_0_9: 10;
	long unsigned int subspace: 1;
	long unsigned int rsvd_11_63: 53;
};

struct uv5h_gr0_gam_gr_config_s {
	long unsigned int rsvd_0_9: 10;
	long unsigned int subspace: 1;
	long unsigned int rsvd_11_63: 53;
};

struct uv4h_gr0_gam_gr_config_s {
	long unsigned int rsvd_0_9: 10;
	long unsigned int subspace: 1;
	long unsigned int rsvd_11_63: 53;
};

struct uv3h_gr0_gam_gr_config_s {
	long unsigned int m_skt: 6;
	long unsigned int undef_6_9: 4;
	long unsigned int subspace: 1;
	long unsigned int reserved: 53;
};

struct uv2h_gr0_gam_gr_config_s {
	long unsigned int n_gr: 4;
	long unsigned int reserved: 60;
};

union uvyh_gr0_gam_gr_config_u {
	long unsigned int v;
	struct uvyh_gr0_gam_gr_config_s sy;
	struct uv5h_gr0_gam_gr_config_s s5;
	struct uv4h_gr0_gam_gr_config_s s4;
	struct uv3h_gr0_gam_gr_config_s s3;
	struct uv2h_gr0_gam_gr_config_s s2;
};

struct uvh_node_id_s {
	long unsigned int force1: 1;
	long unsigned int manufacturer: 11;
	long unsigned int part_number: 16;
	long unsigned int revision: 4;
	long unsigned int rsvd_32_63: 32;
};

struct uvxh_node_id_s {
	long unsigned int force1: 1;
	long unsigned int manufacturer: 11;
	long unsigned int part_number: 16;
	long unsigned int revision: 4;
	long unsigned int node_id: 15;
	long unsigned int rsvd_47_49: 3;
	long unsigned int nodes_per_bit: 7;
	long unsigned int ni_port: 5;
	long unsigned int rsvd_62_63: 2;
};

struct uvyh_node_id_s {
	long unsigned int force1: 1;
	long unsigned int manufacturer: 11;
	long unsigned int part_number: 16;
	long unsigned int revision: 4;
	long unsigned int node_id: 7;
	long unsigned int rsvd_39_56: 18;
	long unsigned int ni_port: 6;
	long unsigned int rsvd_63: 1;
};

struct uv5h_node_id_s {
	long unsigned int force1: 1;
	long unsigned int manufacturer: 11;
	long unsigned int part_number: 16;
	long unsigned int revision: 4;
	long unsigned int node_id: 7;
	long unsigned int rsvd_39_56: 18;
	long unsigned int ni_port: 6;
	long unsigned int rsvd_63: 1;
};

struct uv4h_node_id_s {
	long unsigned int force1: 1;
	long unsigned int manufacturer: 11;
	long unsigned int part_number: 16;
	long unsigned int revision: 4;
	long unsigned int node_id: 15;
	long unsigned int rsvd_47: 1;
	long unsigned int router_select: 1;
	long unsigned int rsvd_49: 1;
	long unsigned int nodes_per_bit: 7;
	long unsigned int ni_port: 5;
	long unsigned int rsvd_62_63: 2;
};

struct uv3h_node_id_s {
	long unsigned int force1: 1;
	long unsigned int manufacturer: 11;
	long unsigned int part_number: 16;
	long unsigned int revision: 4;
	long unsigned int node_id: 15;
	long unsigned int rsvd_47: 1;
	long unsigned int router_select: 1;
	long unsigned int rsvd_49: 1;
	long unsigned int nodes_per_bit: 7;
	long unsigned int ni_port: 5;
	long unsigned int rsvd_62_63: 2;
};

struct uv2h_node_id_s {
	long unsigned int force1: 1;
	long unsigned int manufacturer: 11;
	long unsigned int part_number: 16;
	long unsigned int revision: 4;
	long unsigned int node_id: 15;
	long unsigned int rsvd_47_49: 3;
	long unsigned int nodes_per_bit: 7;
	long unsigned int ni_port: 5;
	long unsigned int rsvd_62_63: 2;
};

union uvh_node_id_u {
	long unsigned int v;
	struct uvh_node_id_s s;
	struct uvxh_node_id_s sx;
	struct uvyh_node_id_s sy;
	struct uv5h_node_id_s s5;
	struct uv4h_node_id_s s4;
	struct uv3h_node_id_s s3;
	struct uv2h_node_id_s s2;
};

struct uvh_rh10_gam_addr_map_config_s {
	long unsigned int undef_0_5: 6;
	long unsigned int n_skt: 3;
	long unsigned int undef_9_11: 3;
	long unsigned int ls_enable: 1;
	long unsigned int undef_13_15: 3;
	long unsigned int mk_tme_keyid_bits: 4;
	long unsigned int rsvd_20_63: 44;
};

struct uvyh_rh10_gam_addr_map_config_s {
	long unsigned int undef_0_5: 6;
	long unsigned int n_skt: 3;
	long unsigned int undef_9_11: 3;
	long unsigned int ls_enable: 1;
	long unsigned int undef_13_15: 3;
	long unsigned int mk_tme_keyid_bits: 4;
	long unsigned int rsvd_20_63: 44;
};

struct uv5h_rh10_gam_addr_map_config_s {
	long unsigned int undef_0_5: 6;
	long unsigned int n_skt: 3;
	long unsigned int undef_9_11: 3;
	long unsigned int ls_enable: 1;
	long unsigned int undef_13_15: 3;
	long unsigned int mk_tme_keyid_bits: 4;
};

union uvh_rh10_gam_addr_map_config_u {
	long unsigned int v;
	struct uvh_rh10_gam_addr_map_config_s s;
	struct uvyh_rh10_gam_addr_map_config_s sy;
	struct uv5h_rh10_gam_addr_map_config_s s5;
};

struct uvh_rh10_gam_mmioh_overlay_config0_s {
	long unsigned int rsvd_0_25: 26;
	long unsigned int base: 26;
	long unsigned int m_io: 6;
	long unsigned int n_io: 4;
	long unsigned int undef_62: 1;
	long unsigned int enable: 1;
};

struct uvyh_rh10_gam_mmioh_overlay_config0_s {
	long unsigned int rsvd_0_25: 26;
	long unsigned int base: 26;
	long unsigned int m_io: 6;
	long unsigned int n_io: 4;
	long unsigned int undef_62: 1;
	long unsigned int enable: 1;
};

struct uv5h_rh10_gam_mmioh_overlay_config0_s {
	long unsigned int rsvd_0_25: 26;
	long unsigned int base: 26;
	long unsigned int m_io: 6;
	long unsigned int n_io: 4;
	long unsigned int undef_62: 1;
	long unsigned int enable: 1;
};

union uvh_rh10_gam_mmioh_overlay_config0_u {
	long unsigned int v;
	struct uvh_rh10_gam_mmioh_overlay_config0_s s;
	struct uvyh_rh10_gam_mmioh_overlay_config0_s sy;
	struct uv5h_rh10_gam_mmioh_overlay_config0_s s5;
};

struct uvh_rh10_gam_mmioh_overlay_config1_s {
	long unsigned int rsvd_0_25: 26;
	long unsigned int base: 26;
	long unsigned int m_io: 6;
	long unsigned int n_io: 4;
	long unsigned int undef_62: 1;
	long unsigned int enable: 1;
};

struct uvyh_rh10_gam_mmioh_overlay_config1_s {
	long unsigned int rsvd_0_25: 26;
	long unsigned int base: 26;
	long unsigned int m_io: 6;
	long unsigned int n_io: 4;
	long unsigned int undef_62: 1;
	long unsigned int enable: 1;
};

struct uv5h_rh10_gam_mmioh_overlay_config1_s {
	long unsigned int rsvd_0_25: 26;
	long unsigned int base: 26;
	long unsigned int m_io: 6;
	long unsigned int n_io: 4;
	long unsigned int undef_62: 1;
	long unsigned int enable: 1;
};

union uvh_rh10_gam_mmioh_overlay_config1_u {
	long unsigned int v;
	struct uvh_rh10_gam_mmioh_overlay_config1_s s;
	struct uvyh_rh10_gam_mmioh_overlay_config1_s sy;
	struct uv5h_rh10_gam_mmioh_overlay_config1_s s5;
};

struct uvh_rh10_gam_mmr_overlay_config_s {
	long unsigned int undef_0_24: 25;
	long unsigned int base: 27;
	long unsigned int undef_52_62: 11;
	long unsigned int enable: 1;
};

struct uvyh_rh10_gam_mmr_overlay_config_s {
	long unsigned int undef_0_24: 25;
	long unsigned int base: 27;
	long unsigned int undef_52_62: 11;
	long unsigned int enable: 1;
};

struct uv5h_rh10_gam_mmr_overlay_config_s {
	long unsigned int undef_0_24: 25;
	long unsigned int base: 27;
	long unsigned int undef_52_62: 11;
	long unsigned int enable: 1;
};

union uvh_rh10_gam_mmr_overlay_config_u {
	long unsigned int v;
	struct uvh_rh10_gam_mmr_overlay_config_s s;
	struct uvyh_rh10_gam_mmr_overlay_config_s sy;
	struct uv5h_rh10_gam_mmr_overlay_config_s s5;
};

struct uvh_rh_gam_addr_map_config_s {
	long unsigned int rsvd_0_5: 6;
	long unsigned int n_skt: 4;
	long unsigned int rsvd_10_63: 54;
};

struct uvxh_rh_gam_addr_map_config_s {
	long unsigned int rsvd_0_5: 6;
	long unsigned int n_skt: 4;
	long unsigned int rsvd_10_63: 54;
};

struct uv4h_rh_gam_addr_map_config_s {
	long unsigned int rsvd_0_5: 6;
	long unsigned int n_skt: 4;
	long unsigned int rsvd_10_63: 54;
};

struct uv3h_rh_gam_addr_map_config_s {
	long unsigned int m_skt: 6;
	long unsigned int n_skt: 4;
	long unsigned int rsvd_10_63: 54;
};

struct uv2h_rh_gam_addr_map_config_s {
	long unsigned int m_skt: 6;
	long unsigned int n_skt: 4;
	long unsigned int rsvd_10_63: 54;
};

union uvh_rh_gam_addr_map_config_u {
	long unsigned int v;
	struct uvh_rh_gam_addr_map_config_s s;
	struct uvxh_rh_gam_addr_map_config_s sx;
	struct uv4h_rh_gam_addr_map_config_s s4;
	struct uv3h_rh_gam_addr_map_config_s s3;
	struct uv2h_rh_gam_addr_map_config_s s2;
};

struct uvh_rh_gam_alias_2_overlay_config_s {
	long unsigned int rsvd_0_23: 24;
	long unsigned int base: 8;
	long unsigned int rsvd_32_47: 16;
	long unsigned int m_alias: 5;
	long unsigned int rsvd_53_62: 10;
	long unsigned int enable: 1;
};

struct uvxh_rh_gam_alias_2_overlay_config_s {
	long unsigned int rsvd_0_23: 24;
	long unsigned int base: 8;
	long unsigned int rsvd_32_47: 16;
	long unsigned int m_alias: 5;
	long unsigned int rsvd_53_62: 10;
	long unsigned int enable: 1;
};

struct uv4h_rh_gam_alias_2_overlay_config_s {
	long unsigned int rsvd_0_23: 24;
	long unsigned int base: 8;
	long unsigned int rsvd_32_47: 16;
	long unsigned int m_alias: 5;
	long unsigned int rsvd_53_62: 10;
	long unsigned int enable: 1;
};

struct uv3h_rh_gam_alias_2_overlay_config_s {
	long unsigned int rsvd_0_23: 24;
	long unsigned int base: 8;
	long unsigned int rsvd_32_47: 16;
	long unsigned int m_alias: 5;
	long unsigned int rsvd_53_62: 10;
	long unsigned int enable: 1;
};

struct uv2h_rh_gam_alias_2_overlay_config_s {
	long unsigned int rsvd_0_23: 24;
	long unsigned int base: 8;
	long unsigned int rsvd_32_47: 16;
	long unsigned int m_alias: 5;
	long unsigned int rsvd_53_62: 10;
	long unsigned int enable: 1;
};

union uvh_rh_gam_alias_2_overlay_config_u {
	long unsigned int v;
	struct uvh_rh_gam_alias_2_overlay_config_s s;
	struct uvxh_rh_gam_alias_2_overlay_config_s sx;
	struct uv4h_rh_gam_alias_2_overlay_config_s s4;
	struct uv3h_rh_gam_alias_2_overlay_config_s s3;
	struct uv2h_rh_gam_alias_2_overlay_config_s s2;
};

struct uvh_rh_gam_alias_2_redirect_config_s {
	long unsigned int rsvd_0_23: 24;
	long unsigned int dest_base: 22;
	long unsigned int rsvd_46_63: 18;
};

struct uvxh_rh_gam_alias_2_redirect_config_s {
	long unsigned int rsvd_0_23: 24;
	long unsigned int dest_base: 22;
	long unsigned int rsvd_46_63: 18;
};

struct uv4h_rh_gam_alias_2_redirect_config_s {
	long unsigned int rsvd_0_23: 24;
	long unsigned int dest_base: 22;
	long unsigned int rsvd_46_63: 18;
};

struct uv3h_rh_gam_alias_2_redirect_config_s {
	long unsigned int rsvd_0_23: 24;
	long unsigned int dest_base: 22;
	long unsigned int rsvd_46_63: 18;
};

struct uv2h_rh_gam_alias_2_redirect_config_s {
	long unsigned int rsvd_0_23: 24;
	long unsigned int dest_base: 22;
	long unsigned int rsvd_46_63: 18;
};

union uvh_rh_gam_alias_2_redirect_config_u {
	long unsigned int v;
	struct uvh_rh_gam_alias_2_redirect_config_s s;
	struct uvxh_rh_gam_alias_2_redirect_config_s sx;
	struct uv4h_rh_gam_alias_2_redirect_config_s s4;
	struct uv3h_rh_gam_alias_2_redirect_config_s s3;
	struct uv2h_rh_gam_alias_2_redirect_config_s s2;
};

struct uvh_rh_gam_gru_overlay_config_s {
	long unsigned int rsvd_0_45: 46;
	long unsigned int rsvd_46_51: 6;
	long unsigned int n_gru: 4;
	long unsigned int rsvd_56_62: 7;
	long unsigned int enable: 1;
};

struct uvxh_rh_gam_gru_overlay_config_s {
	long unsigned int rsvd_0_45: 46;
	long unsigned int rsvd_46_51: 6;
	long unsigned int n_gru: 4;
	long unsigned int rsvd_56_62: 7;
	long unsigned int enable: 1;
};

struct uv4ah_rh_gam_gru_overlay_config_s {
	long unsigned int rsvd_0_24: 25;
	long unsigned int undef_25: 1;
	long unsigned int base: 26;
	long unsigned int n_gru: 4;
	long unsigned int rsvd_56_62: 7;
	long unsigned int enable: 1;
};

struct uv4h_rh_gam_gru_overlay_config_s {
	long unsigned int rsvd_0_24: 25;
	long unsigned int undef_25: 1;
	long unsigned int base: 20;
	long unsigned int rsvd_46_51: 6;
	long unsigned int n_gru: 4;
	long unsigned int rsvd_56_62: 7;
	long unsigned int enable: 1;
};

struct uv3h_rh_gam_gru_overlay_config_s {
	long unsigned int rsvd_0_27: 28;
	long unsigned int base: 18;
	long unsigned int rsvd_46_51: 6;
	long unsigned int n_gru: 4;
	long unsigned int rsvd_56_61: 6;
	long unsigned int mode: 1;
	long unsigned int enable: 1;
};

struct uv2h_rh_gam_gru_overlay_config_s {
	long unsigned int rsvd_0_27: 28;
	long unsigned int base: 18;
	long unsigned int rsvd_46_51: 6;
	long unsigned int n_gru: 4;
	long unsigned int rsvd_56_62: 7;
	long unsigned int enable: 1;
};

union uvh_rh_gam_gru_overlay_config_u {
	long unsigned int v;
	struct uvh_rh_gam_gru_overlay_config_s s;
	struct uvxh_rh_gam_gru_overlay_config_s sx;
	struct uv4ah_rh_gam_gru_overlay_config_s s4a;
	struct uv4h_rh_gam_gru_overlay_config_s s4;
	struct uv3h_rh_gam_gru_overlay_config_s s3;
	struct uv2h_rh_gam_gru_overlay_config_s s2;
};

struct uvh_rh_gam_mmioh_overlay_config_s {
	long unsigned int rsvd_0_26: 27;
	long unsigned int base: 19;
	long unsigned int m_io: 6;
	long unsigned int n_io: 4;
	long unsigned int rsvd_56_62: 7;
	long unsigned int enable: 1;
};

struct uvxh_rh_gam_mmioh_overlay_config_s {
	long unsigned int rsvd_0_26: 27;
	long unsigned int base: 19;
	long unsigned int m_io: 6;
	long unsigned int n_io: 4;
	long unsigned int rsvd_56_62: 7;
	long unsigned int enable: 1;
};

struct uv2h_rh_gam_mmioh_overlay_config_s {
	long unsigned int rsvd_0_26: 27;
	long unsigned int base: 19;
	long unsigned int m_io: 6;
	long unsigned int n_io: 4;
	long unsigned int rsvd_56_62: 7;
	long unsigned int enable: 1;
};

union uvh_rh_gam_mmioh_overlay_config_u {
	long unsigned int v;
	struct uvh_rh_gam_mmioh_overlay_config_s s;
	struct uvxh_rh_gam_mmioh_overlay_config_s sx;
	struct uv2h_rh_gam_mmioh_overlay_config_s s2;
};

struct uvh_rh_gam_mmioh_overlay_config0_s {
	long unsigned int rsvd_0_25: 26;
	long unsigned int base: 20;
	long unsigned int m_io: 6;
	long unsigned int n_io: 4;
	long unsigned int rsvd_56_62: 7;
	long unsigned int enable: 1;
};

struct uvxh_rh_gam_mmioh_overlay_config0_s {
	long unsigned int rsvd_0_25: 26;
	long unsigned int base: 20;
	long unsigned int m_io: 6;
	long unsigned int n_io: 4;
	long unsigned int rsvd_56_62: 7;
	long unsigned int enable: 1;
};

struct uv4ah_rh_gam_mmioh_overlay_config0_mmr_s {
	long unsigned int rsvd_0_25: 26;
	long unsigned int base: 26;
	long unsigned int m_io: 6;
	long unsigned int n_io: 4;
	long unsigned int undef_62: 1;
	long unsigned int enable: 1;
};

struct uv4h_rh_gam_mmioh_overlay_config0_s {
	long unsigned int rsvd_0_25: 26;
	long unsigned int base: 20;
	long unsigned int m_io: 6;
	long unsigned int n_io: 4;
	long unsigned int rsvd_56_62: 7;
	long unsigned int enable: 1;
};

struct uv3h_rh_gam_mmioh_overlay_config0_s {
	long unsigned int rsvd_0_25: 26;
	long unsigned int base: 20;
	long unsigned int m_io: 6;
	long unsigned int n_io: 4;
	long unsigned int rsvd_56_62: 7;
	long unsigned int enable: 1;
};

union uvh_rh_gam_mmioh_overlay_config0_u {
	long unsigned int v;
	struct uvh_rh_gam_mmioh_overlay_config0_s s;
	struct uvxh_rh_gam_mmioh_overlay_config0_s sx;
	struct uv4ah_rh_gam_mmioh_overlay_config0_mmr_s s4a;
	struct uv4h_rh_gam_mmioh_overlay_config0_s s4;
	struct uv3h_rh_gam_mmioh_overlay_config0_s s3;
};

struct uvh_rh_gam_mmioh_overlay_config1_s {
	long unsigned int rsvd_0_25: 26;
	long unsigned int base: 20;
	long unsigned int m_io: 6;
	long unsigned int n_io: 4;
	long unsigned int rsvd_56_62: 7;
	long unsigned int enable: 1;
};

struct uvxh_rh_gam_mmioh_overlay_config1_s {
	long unsigned int rsvd_0_25: 26;
	long unsigned int base: 20;
	long unsigned int m_io: 6;
	long unsigned int n_io: 4;
	long unsigned int rsvd_56_62: 7;
	long unsigned int enable: 1;
};

struct uv4ah_rh_gam_mmioh_overlay_config1_mmr_s {
	long unsigned int rsvd_0_25: 26;
	long unsigned int base: 26;
	long unsigned int m_io: 6;
	long unsigned int n_io: 4;
	long unsigned int undef_62: 1;
	long unsigned int enable: 1;
};

struct uv4h_rh_gam_mmioh_overlay_config1_s {
	long unsigned int rsvd_0_25: 26;
	long unsigned int base: 20;
	long unsigned int m_io: 6;
	long unsigned int n_io: 4;
	long unsigned int rsvd_56_62: 7;
	long unsigned int enable: 1;
};

struct uv3h_rh_gam_mmioh_overlay_config1_s {
	long unsigned int rsvd_0_25: 26;
	long unsigned int base: 20;
	long unsigned int m_io: 6;
	long unsigned int n_io: 4;
	long unsigned int rsvd_56_62: 7;
	long unsigned int enable: 1;
};

union uvh_rh_gam_mmioh_overlay_config1_u {
	long unsigned int v;
	struct uvh_rh_gam_mmioh_overlay_config1_s s;
	struct uvxh_rh_gam_mmioh_overlay_config1_s sx;
	struct uv4ah_rh_gam_mmioh_overlay_config1_mmr_s s4a;
	struct uv4h_rh_gam_mmioh_overlay_config1_s s4;
	struct uv3h_rh_gam_mmioh_overlay_config1_s s3;
};

struct uvh_rh_gam_mmr_overlay_config_s {
	long unsigned int rsvd_0_25: 26;
	long unsigned int base: 20;
	long unsigned int rsvd_46_62: 17;
	long unsigned int enable: 1;
};

struct uvxh_rh_gam_mmr_overlay_config_s {
	long unsigned int rsvd_0_25: 26;
	long unsigned int base: 20;
	long unsigned int rsvd_46_62: 17;
	long unsigned int enable: 1;
};

struct uv4h_rh_gam_mmr_overlay_config_s {
	long unsigned int rsvd_0_25: 26;
	long unsigned int base: 20;
	long unsigned int rsvd_46_62: 17;
	long unsigned int enable: 1;
};

struct uv3h_rh_gam_mmr_overlay_config_s {
	long unsigned int rsvd_0_25: 26;
	long unsigned int base: 20;
	long unsigned int rsvd_46_62: 17;
	long unsigned int enable: 1;
};

struct uv2h_rh_gam_mmr_overlay_config_s {
	long unsigned int rsvd_0_25: 26;
	long unsigned int base: 20;
	long unsigned int rsvd_46_62: 17;
	long unsigned int enable: 1;
};

union uvh_rh_gam_mmr_overlay_config_u {
	long unsigned int v;
	struct uvh_rh_gam_mmr_overlay_config_s s;
	struct uvxh_rh_gam_mmr_overlay_config_s sx;
	struct uv4h_rh_gam_mmr_overlay_config_s s4;
	struct uv3h_rh_gam_mmr_overlay_config_s s3;
	struct uv2h_rh_gam_mmr_overlay_config_s s2;
};

enum uv_system_type {
	UV_NONE = 0,
	UV_LEGACY_APIC = 1,
	UV_X2APIC = 2,
};

enum {
	BIOS_STATUS_MORE_PASSES = 1,
	BIOS_STATUS_SUCCESS = 0,
	BIOS_STATUS_UNIMPLEMENTED = 4294967258,
	BIOS_STATUS_EINVAL = 4294967274,
	BIOS_STATUS_UNAVAIL = 4294967280,
	BIOS_STATUS_ABORT = 4294967292,
};

struct uv_gam_parameters {
	u64 mmr_base;
	u64 gru_base;
	u8 mmr_shift;
	u8 gru_shift;
	u8 gpa_shift;
	u8 unused1;
};

struct uv_gam_range_entry {
	char type;
	char unused1;
	u16 nasid;
	u16 sockid;
	u16 pnode;
	u32 unused2;
	u32 limit;
};

struct uv_arch_type_entry {
	char archtype[8];
};

struct uv_systab {
	char signature[4];
	u32 revision;
	u64 function;
	u32 size;
	struct {
		u32 type: 8;
		u32 offset: 24;
	} entry[1];
};

enum {
	BIOS_FREQ_BASE_PLATFORM = 0,
	BIOS_FREQ_BASE_INTERVAL_TIMER = 1,
	BIOS_FREQ_BASE_REALTIME_CLOCK = 2,
};

struct uv_gam_range_s {
	u32 limit;
	u16 nasid;
	s8 base;
	u8 reserved;
};

struct uv_hub_info_s {
	unsigned int hub_type;
	unsigned char hub_revision;
	long unsigned int global_mmr_base;
	long unsigned int global_mmr_shift;
	long unsigned int gpa_mask;
	short unsigned int *socket_to_node;
	short unsigned int *socket_to_pnode;
	short unsigned int *pnode_to_socket;
	struct uv_gam_range_s *gr_table;
	short unsigned int min_socket;
	short unsigned int min_pnode;
	unsigned char m_val;
	unsigned char n_val;
	unsigned char gr_table_len;
	unsigned char apic_pnode_shift;
	unsigned char gpa_shift;
	unsigned char nasid_shift;
	unsigned char m_shift;
	unsigned char n_lshift;
	unsigned int gnode_extra;
	long unsigned int gnode_upper;
	long unsigned int lowmem_remap_top;
	long unsigned int lowmem_remap_base;
	long unsigned int global_gru_base;
	long unsigned int global_gru_shift;
	short unsigned int pnode;
	short unsigned int pnode_mask;
	short unsigned int coherency_domain_number;
	short unsigned int numa_blade_id;
	short unsigned int nr_possible_cpus;
	short unsigned int nr_online_cpus;
	short int memory_nid;
};

struct uv_cpu_info_s {
	void *p_uv_hub_info;
	unsigned char blade_cpu_id;
	void *reserved;
};

struct uvh_apicid_s {
	long unsigned int local_apic_mask: 24;
	long unsigned int local_apic_shift: 5;
	long unsigned int unused1: 3;
	long unsigned int pnode_mask: 24;
	long unsigned int pnode_shift: 5;
	long unsigned int unused2: 3;
};

union uvh_apicid {
	long unsigned int v;
	struct uvh_apicid_s s;
};

enum map_type {
	map_wb = 0,
	map_uc = 1,
};

enum mmioh_arch {
	UV2_MMIOH = 4294967295,
	UVY_MMIOH0 = 0,
	UVY_MMIOH1 = 1,
	UVX_MMIOH0 = 2,
	UVX_MMIOH1 = 3,
};

struct mn {
	unsigned char m_val;
	unsigned char n_val;
	unsigned char m_shift;
	unsigned char n_lshift;
};

struct cluster_mask {
	unsigned int clusterid;
	int node;
	struct cpumask mask;
};

struct dyn_arch_ftrace {};

enum {
	FTRACE_OPS_FL_ENABLED = 1,
	FTRACE_OPS_FL_DYNAMIC = 2,
	FTRACE_OPS_FL_SAVE_REGS = 4,
	FTRACE_OPS_FL_SAVE_REGS_IF_SUPPORTED = 8,
	FTRACE_OPS_FL_RECURSION = 16,
	FTRACE_OPS_FL_STUB = 32,
	FTRACE_OPS_FL_INITIALIZED = 64,
	FTRACE_OPS_FL_DELETED = 128,
	FTRACE_OPS_FL_ADDING = 256,
	FTRACE_OPS_FL_REMOVING = 512,
	FTRACE_OPS_FL_MODIFYING = 1024,
	FTRACE_OPS_FL_ALLOC_TRAMP = 2048,
	FTRACE_OPS_FL_IPMODIFY = 4096,
	FTRACE_OPS_FL_PID = 8192,
	FTRACE_OPS_FL_RCU = 16384,
	FTRACE_OPS_FL_TRACE_ARRAY = 32768,
	FTRACE_OPS_FL_PERMANENT = 65536,
	FTRACE_OPS_FL_DIRECT = 131072,
};

enum {
	FTRACE_FL_ENABLED = 2147483648,
	FTRACE_FL_REGS = 1073741824,
	FTRACE_FL_REGS_EN = 536870912,
	FTRACE_FL_TRAMP = 268435456,
	FTRACE_FL_TRAMP_EN = 134217728,
	FTRACE_FL_IPMODIFY = 67108864,
	FTRACE_FL_DISABLED = 33554432,
	FTRACE_FL_DIRECT = 16777216,
	FTRACE_FL_DIRECT_EN = 8388608,
};

struct dyn_ftrace {
	long unsigned int ip;
	long unsigned int flags;
	struct dyn_arch_ftrace arch;
};

enum {
	FTRACE_UPDATE_IGNORE = 0,
	FTRACE_UPDATE_MAKE_CALL = 1,
	FTRACE_UPDATE_MODIFY_CALL = 2,
	FTRACE_UPDATE_MAKE_NOP = 3,
};

union ftrace_op_code_union {
	char code[7];
	struct {
		char op[3];
		int offset;
	} __attribute__((packed));
};

struct ftrace_rec_iter;

typedef __s64 Elf64_Sxword;

struct elf64_rela {
	Elf64_Addr r_offset;
	Elf64_Xword r_info;
	Elf64_Sxword r_addend;
};

typedef struct elf64_rela Elf64_Rela;

struct kimage_arch {
	p4d_t *p4d;
	pud_t *pud;
	pmd_t *pmd;
	pte_t *pte;
};

typedef long unsigned int kimage_entry_t;

struct kexec_segment {
	union {
		void *buf;
		void *kbuf;
	};
	size_t bufsz;
	long unsigned int mem;
	size_t memsz;
};

struct purgatory_info {
	const Elf64_Ehdr *ehdr;
	Elf64_Shdr *sechdrs;
	void *purgatory_buf;
};

typedef int kexec_probe_t(const char *, long unsigned int);

struct kimage;

typedef void *kexec_load_t(struct kimage *, char *, long unsigned int, char *, long unsigned int, char *, long unsigned int);

struct kexec_file_ops;

struct kimage {
	kimage_entry_t head;
	kimage_entry_t *entry;
	kimage_entry_t *last_entry;
	long unsigned int start;
	struct page___19 *control_code_page;
	struct page___19 *swap_page;
	void *vmcoreinfo_data_copy;
	long unsigned int nr_segments;
	struct kexec_segment segment[16];
	struct list_head control_pages;
	struct list_head dest_pages;
	struct list_head unusable_pages;
	long unsigned int control_page;
	unsigned int type: 1;
	unsigned int preserve_context: 1;
	unsigned int file_mode: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct kimage_arch arch;
	void *kernel_buf;
	long unsigned int kernel_buf_len;
	void *initrd_buf;
	long unsigned int initrd_buf_len;
	char *cmdline_buf;
	long unsigned int cmdline_buf_len;
	const struct kexec_file_ops *fops;
	void *image_loader_data;
	struct purgatory_info purgatory_info;
	void *elf_headers;
	long unsigned int elf_headers_sz;
	long unsigned int elf_load_addr;
};

typedef int kexec_cleanup_t(void *);

typedef int kexec_verify_sig_t(const char *, long unsigned int);

struct kexec_file_ops {
	kexec_probe_t *probe;
	kexec_load_t *load;
	kexec_cleanup_t *cleanup;
	kexec_verify_sig_t *verify_sig;
};

struct x86_mapping_info {
	void * (*alloc_pgt_page)(void *);
	void *context;
	long unsigned int page_flag;
	long unsigned int offset;
	bool direct_gbpages;
	long unsigned int kernpg_flag;
};

struct init_pgtable_data {
	struct x86_mapping_info *info;
	pgd_t *level4p;
};

typedef void crash_vmclear_fn();

struct kexec_buf {
	struct kimage *image;
	void *buffer;
	long unsigned int bufsz;
	long unsigned int mem;
	long unsigned int memsz;
	long unsigned int buf_align;
	long unsigned int buf_min;
	long unsigned int buf_max;
	bool top_down;
};

struct crash_mem_range {
	u64 start;
	u64 end;
};

struct crash_mem {
	unsigned int max_nr_ranges;
	unsigned int nr_ranges;
	struct crash_mem_range ranges[0];
};

struct crash_memmap_data {
	struct boot_params *params;
	unsigned int type;
};

struct kexec_entry64_regs {
	uint64_t rax;
	uint64_t rcx;
	uint64_t rdx;
	uint64_t rbx;
	uint64_t rsp;
	uint64_t rbp;
	uint64_t rsi;
	uint64_t rdi;
	uint64_t r8;
	uint64_t r9;
	uint64_t r10;
	uint64_t r11;
	uint64_t r12;
	uint64_t r13;
	uint64_t r14;
	uint64_t r15;
	uint64_t rip;
};

enum key_being_used_for {
	VERIFYING_MODULE_SIGNATURE = 0,
	VERIFYING_FIRMWARE_SIGNATURE = 1,
	VERIFYING_KEXEC_PE_SIGNATURE = 2,
	VERIFYING_KEY_SIGNATURE = 3,
	VERIFYING_KEY_SELF_SIGNATURE = 4,
	VERIFYING_UNSPECIFIED_SIGNATURE = 5,
	NR__KEY_BEING_USED_FOR = 6,
};

struct efi_setup_data {
	u64 fw_vendor;
	u64 __unused;
	u64 tables;
	u64 smbios;
	u64 reserved[8];
};

struct bzimage64_data {
	void *bootparams_buf;
};

struct freelist_node {
	atomic_t refs;
	struct freelist_node *next;
};

struct freelist_head {
	struct freelist_node *head;
};

struct prev_kprobe {
	struct kprobe *kp;
	long unsigned int status;
	long unsigned int old_flags;
	long unsigned int saved_flags;
};

struct kprobe_ctlblk {
	long unsigned int kprobe_status;
	long unsigned int kprobe_old_flags;
	long unsigned int kprobe_saved_flags;
	struct prev_kprobe prev_kprobe;
};

struct kretprobe_instance;

typedef int (*kretprobe_handler_t)(struct kretprobe_instance *, struct pt_regs *);

struct kretprobe_holder;

struct kretprobe_instance {
	union {
		struct freelist_node freelist;
		struct callback_head rcu;
	};
	struct llist_node llist;
	struct kretprobe_holder *rph;
	kprobe_opcode_t *ret_addr;
	void *fp;
	char data[0];
};

struct kretprobe;

struct kretprobe_holder {
	struct kretprobe *rp;
	refcount_t ref;
};

struct kretprobe {
	struct kprobe kp;
	kretprobe_handler_t handler;
	kretprobe_handler_t entry_handler;
	int maxactive;
	int nmissed;
	size_t data_size;
	struct freelist_head freelist;
	struct kretprobe_holder *rph;
};

struct kretprobe_blackpoint {
	const char *name;
	void *addr;
};

struct kprobe_insn_cache {
	struct mutex mutex;
	void * (*alloc)();
	void (*free)(void *);
	const char *sym;
	struct list_head pages;
	size_t insn_size;
	int nr_garbage;
};

struct __arch_relative_insn {
	u8 op;
	s32 raddr;
} __attribute__((packed));

struct arch_optimized_insn {
	kprobe_opcode_t copied_insn[4];
	kprobe_opcode_t *insn;
	size_t size;
};

struct optimized_kprobe {
	struct kprobe kp;
	struct list_head list;
	struct arch_optimized_insn optinsn;
};

enum {
	TRACE_FTRACE_BIT = 0,
	TRACE_FTRACE_NMI_BIT = 1,
	TRACE_FTRACE_IRQ_BIT = 2,
	TRACE_FTRACE_SIRQ_BIT = 3,
	TRACE_FTRACE_TRANSITION_BIT = 4,
	TRACE_INTERNAL_BIT = 5,
	TRACE_INTERNAL_NMI_BIT = 6,
	TRACE_INTERNAL_IRQ_BIT = 7,
	TRACE_INTERNAL_SIRQ_BIT = 8,
	TRACE_INTERNAL_TRANSITION_BIT = 9,
	TRACE_BRANCH_BIT = 10,
	TRACE_IRQ_BIT = 11,
	TRACE_GRAPH_BIT = 12,
	TRACE_GRAPH_DEPTH_START_BIT = 13,
	TRACE_GRAPH_DEPTH_END_BIT = 14,
	TRACE_GRAPH_NOTRACE_BIT = 15,
	TRACE_RECORD_RECURSION_BIT = 16,
};

enum {
	TRACE_CTX_NMI = 0,
	TRACE_CTX_IRQ = 1,
	TRACE_CTX_SOFTIRQ = 2,
	TRACE_CTX_NORMAL = 3,
	TRACE_CTX_TRANSITION = 4,
};

enum regnames {
	GDB_AX = 0,
	GDB_BX = 1,
	GDB_CX = 2,
	GDB_DX = 3,
	GDB_SI = 4,
	GDB_DI = 5,
	GDB_BP = 6,
	GDB_SP = 7,
	GDB_R8 = 8,
	GDB_R9 = 9,
	GDB_R10 = 10,
	GDB_R11 = 11,
	GDB_R12 = 12,
	GDB_R13 = 13,
	GDB_R14 = 14,
	GDB_R15 = 15,
	GDB_PC = 16,
	GDB_PS = 17,
	GDB_CS = 18,
	GDB_SS = 19,
	GDB_DS = 20,
	GDB_ES = 21,
	GDB_FS = 22,
	GDB_GS = 23,
};

enum kgdb_bpstate {
	BP_UNDEFINED = 0,
	BP_REMOVED = 1,
	BP_SET = 2,
	BP_ACTIVE = 3,
};

struct kgdb_bkpt {
	long unsigned int bpt_addr;
	unsigned char saved_instr[1];
	enum kgdb_bptype type;
	enum kgdb_bpstate state;
};

struct dbg_reg_def_t {
	char *name;
	int size;
	int offset;
};

struct hw_breakpoint {
	unsigned int enabled;
	long unsigned int addr;
	int len;
	int type;
	struct perf_event___7 **pev;
};

struct console {
	char name[16];
	void (*write)(struct console *, const char *, unsigned int);
	int (*read)(struct console *, char *, unsigned int);
	struct tty_driver___2 * (*device)(struct console *, int *);
	void (*unblank)();
	int (*setup)(struct console *, char *);
	int (*exit)(struct console *);
	int (*match)(struct console *, char *, int, char *);
	short int flags;
	short int index;
	int cflag;
	uint ispeed;
	uint ospeed;
	void *data;
	struct console *next;
};

struct hpet_data {
	long unsigned int hd_phys_address;
	void *hd_address;
	short unsigned int hd_nirqs;
	unsigned int hd_state;
	unsigned int hd_irq[32];
};

typedef struct irq_alloc_info___2 msi_alloc_info_t___3;

struct msi_domain_info___3;

struct msi_domain_ops___3 {
	irq_hw_number_t (*get_hwirq)(struct msi_domain_info___3 *, msi_alloc_info_t___3 *);
	int (*msi_init)(struct irq_domain___13 *, struct msi_domain_info___3 *, unsigned int, irq_hw_number_t, msi_alloc_info_t___3 *);
	void (*msi_free)(struct irq_domain___13 *, struct msi_domain_info___3 *, unsigned int);
	int (*msi_check)(struct irq_domain___13 *, struct msi_domain_info___3 *, struct device___20 *);
	int (*msi_prepare)(struct irq_domain___13 *, struct device___20 *, int, msi_alloc_info_t___3 *);
	void (*msi_finish)(msi_alloc_info_t___3 *, int);
	void (*set_desc)(msi_alloc_info_t___3 *, struct msi_desc___5 *);
	int (*handle_error)(struct irq_domain___13 *, struct msi_desc___5 *, int);
	int (*domain_alloc_irqs)(struct irq_domain___13 *, struct device___20 *, int);
	void (*domain_free_irqs)(struct irq_domain___13 *, struct device___20 *);
};

struct msi_domain_info___3 {
	u32 flags;
	struct msi_domain_ops___3 *ops;
	struct irq_chip___8 *chip;
	void *chip_data;
	irq_flow_handler_t___8 handler;
	void *handler_data;
	const char *handler_name;
	void *data;
};

typedef irqreturn_t (*rtc_irq_handler)(int, void *);

enum hpet_mode {
	HPET_MODE_UNUSED = 0,
	HPET_MODE_LEGACY = 1,
	HPET_MODE_CLOCKEVT = 2,
	HPET_MODE_DEVICE = 3,
};

struct hpet_channel {
	struct clock_event_device evt;
	unsigned int num;
	unsigned int cpu;
	unsigned int irq;
	unsigned int in_use;
	enum hpet_mode mode;
	unsigned int boot_cfg;
	char name[10];
	long: 48;
	long: 64;
	long: 64;
	long: 64;
};

struct hpet_base {
	unsigned int nr_channels;
	unsigned int nr_clockevents;
	unsigned int boot_cfg;
	struct hpet_channel *channels;
};

union hpet_lock {
	struct {
		arch_spinlock_t lock;
		u32 value;
	};
	u64 lockval;
};

struct amd_nb_bus_dev_range {
	u8 bus;
	u8 dev_base;
	u8 dev_limit;
};

struct amd_northbridge_info {
	u16 num;
	u64 flags;
	struct amd_northbridge___2 *nb;
};

struct smp_ops___6 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*crash_stop_other_cpus)();
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___14 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct swait_queue {
	struct task_struct___14 *task;
	struct list_head task_list;
};

struct kvm_steal_time {
	__u64 steal;
	__u32 version;
	__u32 flags;
	__u8 preempted;
	__u8 u8_pad[3];
	__u32 pad[11];
};

struct kvm_vcpu_pv_apf_data {
	__u32 flags;
	__u32 token;
	__u8 pad[56];
	__u32 enabled;
};

struct kvm_task_sleep_node {
	struct hlist_node link;
	struct swait_queue_head wq;
	u32 token;
	int cpu;
};

struct kvm_task_sleep_head {
	raw_spinlock_t lock;
	struct hlist_head list;
};

typedef struct ldttss_desc ldt_desc;

struct branch {
	unsigned char opcode;
	u32 delta;
} __attribute__((packed));

typedef long unsigned int ulong;

struct platform_device_id___2;

struct platform_device___3 {
	const char *name;
	int id;
	bool id_auto;
	struct device___15 dev;
	u64 platform_dma_mask;
	struct device_dma_parameters dma_parms;
	u32 num_resources;
	struct resource *resource;
	const struct platform_device_id___2 *id_entry;
	char *driver_override;
	struct mfd_cell *mfd_cell;
	struct pdev_archdata archdata;
};

struct jailhouse_setup_data {
	struct {
		__u16 version;
		__u16 compatible_version;
	} hdr;
	struct {
		__u16 pm_timer_address;
		__u16 num_cpus;
		__u64 pci_mmconfig_base;
		__u32 tsc_khz;
		__u32 apic_khz;
		__u8 standard_ioapic;
		__u8 cpu_ids[255];
	} __attribute__((packed)) v1;
	struct {
		__u32 flags;
	} v2;
} __attribute__((packed));

struct circ_buf {
	char *buf;
	int head;
	int tail;
};

struct serial_rs485 {
	__u32 flags;
	__u32 delay_rts_before_send;
	__u32 delay_rts_after_send;
	__u32 padding[5];
};

struct serial_iso7816 {
	__u32 flags;
	__u32 tg;
	__u32 sc_fi;
	__u32 sc_di;
	__u32 clk;
	__u32 reserved[5];
};

struct uart_port;

struct uart_ops {
	unsigned int (*tx_empty)(struct uart_port *);
	void (*set_mctrl)(struct uart_port *, unsigned int);
	unsigned int (*get_mctrl)(struct uart_port *);
	void (*stop_tx)(struct uart_port *);
	void (*start_tx)(struct uart_port *);
	void (*throttle)(struct uart_port *);
	void (*unthrottle)(struct uart_port *);
	void (*send_xchar)(struct uart_port *, char);
	void (*stop_rx)(struct uart_port *);
	void (*enable_ms)(struct uart_port *);
	void (*break_ctl)(struct uart_port *, int);
	int (*startup)(struct uart_port *);
	void (*shutdown)(struct uart_port *);
	void (*flush_buffer)(struct uart_port *);
	void (*set_termios)(struct uart_port *, struct ktermios *, struct ktermios *);
	void (*set_ldisc)(struct uart_port *, struct ktermios *);
	void (*pm)(struct uart_port *, unsigned int, unsigned int);
	const char * (*type)(struct uart_port *);
	void (*release_port)(struct uart_port *);
	int (*request_port)(struct uart_port *);
	void (*config_port)(struct uart_port *, int);
	int (*verify_port)(struct uart_port *, struct serial_struct___2 *);
	int (*ioctl)(struct uart_port *, unsigned int, long unsigned int);
	int (*poll_init)(struct uart_port *);
	void (*poll_put_char)(struct uart_port *, unsigned char);
	int (*poll_get_char)(struct uart_port *);
};

struct uart_icount {
	__u32 cts;
	__u32 dsr;
	__u32 rng;
	__u32 dcd;
	__u32 rx;
	__u32 tx;
	__u32 frame;
	__u32 overrun;
	__u32 parity;
	__u32 brk;
	__u32 buf_overrun;
};

typedef unsigned int upf_t;

typedef unsigned int upstat_t;

struct gpio_desc;

struct uart_state;

struct uart_port {
	spinlock_t lock;
	long unsigned int iobase;
	unsigned char *membase;
	unsigned int (*serial_in)(struct uart_port *, int);
	void (*serial_out)(struct uart_port *, int, int);
	void (*set_termios)(struct uart_port *, struct ktermios *, struct ktermios *);
	void (*set_ldisc)(struct uart_port *, struct ktermios *);
	unsigned int (*get_mctrl)(struct uart_port *);
	void (*set_mctrl)(struct uart_port *, unsigned int);
	unsigned int (*get_divisor)(struct uart_port *, unsigned int, unsigned int *);
	void (*set_divisor)(struct uart_port *, unsigned int, unsigned int, unsigned int);
	int (*startup)(struct uart_port *);
	void (*shutdown)(struct uart_port *);
	void (*throttle)(struct uart_port *);
	void (*unthrottle)(struct uart_port *);
	int (*handle_irq)(struct uart_port *);
	void (*pm)(struct uart_port *, unsigned int, unsigned int);
	void (*handle_break)(struct uart_port *);
	int (*rs485_config)(struct uart_port *, struct serial_rs485 *);
	int (*iso7816_config)(struct uart_port *, struct serial_iso7816 *);
	unsigned int irq;
	long unsigned int irqflags;
	unsigned int uartclk;
	unsigned int fifosize;
	unsigned char x_char;
	unsigned char regshift;
	unsigned char iotype;
	unsigned char quirks;
	unsigned int read_status_mask;
	unsigned int ignore_status_mask;
	struct uart_state *state;
	struct uart_icount icount;
	struct console *cons;
	upf_t flags;
	upstat_t status;
	int hw_stopped;
	unsigned int mctrl;
	unsigned int timeout;
	unsigned int type;
	const struct uart_ops *ops;
	unsigned int custom_divisor;
	unsigned int line;
	unsigned int minor;
	resource_size_t mapbase;
	resource_size_t mapsize;
	struct device___20 *dev;
	long unsigned int sysrq;
	unsigned int sysrq_ch;
	unsigned char has_sysrq;
	unsigned char sysrq_seq;
	unsigned char hub6;
	unsigned char suspended;
	unsigned char console_reinit;
	const char *name;
	struct attribute_group___18 *attr_group;
	const struct attribute_group___18 **tty_groups;
	struct serial_rs485 rs485;
	struct gpio_desc *rs485_term_gpio;
	struct serial_iso7816 iso7816;
	void *private_data;
};

enum uart_pm_state {
	UART_PM_STATE_ON = 0,
	UART_PM_STATE_OFF = 3,
	UART_PM_STATE_UNDEFINED = 4,
};

struct uart_state {
	struct tty_port___2 port;
	enum uart_pm_state pm_state;
	struct circ_buf xmit;
	atomic_t refcount;
	wait_queue_head_t remove_wait;
	struct uart_port *uart_port;
};

struct pci_mmcfg_region {
	struct list_head list;
	struct resource res;
	u64 address;
	char *virt;
	u16 segment;
	u8 start_bus;
	u8 end_bus;
	char name[30];
};

struct platform_device_info___2 {
	struct device___15 *parent;
	struct fwnode_handle___5 *fwnode;
	bool of_node_reused;
	const char *name;
	int id;
	const struct resource *res;
	unsigned int num_res;
	const void *data;
	size_t size_data;
	u64 dma_mask;
	const struct property_entry *properties;
};

struct scan_area {
	u64 addr;
	u64 size;
};

struct uprobe_xol_ops;

struct arch_uprobe {
	union {
		u8 insn[16];
		u8 ixol[16];
	};
	const struct uprobe_xol_ops *ops;
	union {
		struct {
			s32 offs;
			u8 ilen;
			u8 opc1;
		} branch;
		struct {
			u8 fixups;
			u8 ilen;
		} defparam;
		struct {
			u8 reg_offset;
			u8 ilen;
		} push;
	};
};

struct uprobe_xol_ops {
	bool (*emulate)(struct arch_uprobe *, struct pt_regs *);
	int (*pre_xol)(struct arch_uprobe *, struct pt_regs *);
	int (*post_xol)(struct arch_uprobe *, struct pt_regs *);
	void (*abort)(struct arch_uprobe *, struct pt_regs *);
};

enum rp_check {
	RP_CHECK_CALL = 0,
	RP_CHECK_CHAIN_CALL = 1,
	RP_CHECK_RET = 2,
};

enum perf_sample_regs_abi {
	PERF_SAMPLE_REGS_ABI_NONE = 0,
	PERF_SAMPLE_REGS_ABI_32 = 1,
	PERF_SAMPLE_REGS_ABI_64 = 2,
};

struct mutex___2 {
	atomic_long_t owner;
	raw_spinlock_t___2 wait_lock;
	struct optimistic_spin_queue osq;
	struct list_head wait_list;
};

struct va_format {
	const char *fmt;
	va_list *va;
};

enum es_result {
	ES_OK = 0,
	ES_UNSUPPORTED = 1,
	ES_VMM_ERROR = 2,
	ES_DECODE_FAILED = 3,
	ES_EXCEPTION = 4,
	ES_RETRY = 5,
};

struct es_fault_info {
	long unsigned int vector;
	long unsigned int error_code;
	long unsigned int cr2;
};

struct es_em_ctxt {
	struct pt_regs *regs;
	struct insn insn;
	struct es_fault_info fi;
};

struct sev_es_runtime_data {
	struct ghcb ghcb_page;
	struct ghcb backup_ghcb;
	bool ghcb_active;
	bool backup_ghcb_active;
	long unsigned int dr7;
};

struct ghcb_state {
	struct ghcb *ghcb;
};

enum cc_attr {
	CC_ATTR_MEM_ENCRYPT = 0,
	CC_ATTR_HOST_MEM_ENCRYPT = 1,
	CC_ATTR_GUEST_MEM_ENCRYPT = 2,
	CC_ATTR_GUEST_STATE_ENCRYPT = 3,
};

enum chipset_type {
	NOT_SUPPORTED = 0,
	SUPPORTED = 1,
};

struct agp_version {
	u16 major;
	u16 minor;
};

struct agp_kern_info {
	struct agp_version version;
	struct pci_dev___3 *device;
	enum chipset_type chipset;
	long unsigned int mode;
	long unsigned int aper_base;
	size_t aper_size;
	int max_memory;
	int current_memory;
	bool cant_use_aperture;
	long unsigned int page_mask;
	const struct vm_operations_struct___13 *vm_ops;
};

struct agp_bridge_data;

struct pci_hostbridge_probe {
	u32 bus;
	u32 slot;
	u32 vendor;
	u32 device;
};

struct mmu_gather___4;

struct pv_mmu_ops___17 {
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_one_user)(long unsigned int);
	void (*flush_tlb_multi)(const struct cpumask *, const struct flush_tlb_info___2 *);
	void (*tlb_remove_table)(struct mmu_gather___4 *, void *);
	void (*exit_mmap)(struct mm_struct___20 *);
	struct paravirt_callee_save read_cr2;
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___20 *, struct mm_struct___20 *);
	void (*dup_mmap)(struct mm_struct___20 *, struct mm_struct___20 *);
	int (*pgd_alloc)(struct mm_struct___20 *);
	void (*pgd_free)(struct mm_struct___20 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___20 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___20 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___20 *, long unsigned int);
	void (*alloc_p4d)(struct mm_struct___20 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*release_p4d)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	pte_t (*ptep_modify_prot_start)(struct vm_area_struct___20 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct vm_area_struct___20 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_p4d)(p4d_t *, p4d_t);
	struct paravirt_callee_save p4d_val;
	struct paravirt_callee_save make_p4d;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

struct mmu_gather_batch___4 {
	struct mmu_gather_batch___4 *next;
	unsigned int nr;
	unsigned int max;
	struct page___19 *pages[0];
};

struct mmu_gather___4 {
	struct mm_struct___20 *mm;
	struct mmu_table_batch *batch;
	long unsigned int start;
	long unsigned int end;
	unsigned int fullmm: 1;
	unsigned int need_flush_all: 1;
	unsigned int freed_tables: 1;
	unsigned int cleared_ptes: 1;
	unsigned int cleared_pmds: 1;
	unsigned int cleared_puds: 1;
	unsigned int cleared_p4ds: 1;
	unsigned int vma_exec: 1;
	unsigned int vma_huge: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int batch_count;
	struct mmu_gather_batch___4 *active;
	struct mmu_gather_batch___4 local;
	struct page___19 *__pages[8];
};

struct paravirt_patch_template___17 {
	struct pv_cpu_ops___15 cpu;
	struct pv_irq_ops irq;
	struct pv_mmu_ops___17 mmu;
	struct pv_lock_ops lock;
};

struct trace_print_flags {
	long unsigned int mask;
	const char *name;
};

enum tlb_flush_reason {
	TLB_FLUSH_ON_TASK_SWITCH = 0,
	TLB_REMOTE_SHOOTDOWN = 1,
	TLB_LOCAL_SHOOTDOWN = 2,
	TLB_LOCAL_MM_SHOOTDOWN = 3,
	TLB_REMOTE_SEND_IPI = 4,
	NR_TLB_FLUSH_REASONS = 5,
};

enum {
	REGION_INTERSECTS = 0,
	REGION_DISJOINT = 1,
	REGION_MIXED = 2,
};

struct tlb_state___6 {
	struct mm_struct___20 *loaded_mm;
	union {
		struct mm_struct___20 *last_user_mm;
		long unsigned int last_user_mm_spec;
	};
	u16 loaded_mm_asid;
	u16 next_asid;
	bool invalidate_other;
	short unsigned int user_pcid_flush_mask;
	long unsigned int cr4;
	struct tlb_context ctxs[6];
};

struct trace_event_raw_tlb_flush {
	struct trace_entry ent;
	int reason;
	long unsigned int pages;
	char __data[0];
};

struct trace_event_data_offsets_tlb_flush {};

typedef void (*btf_trace_tlb_flush)(void *, int, long unsigned int);

struct map_range {
	long unsigned int start;
	long unsigned int end;
	unsigned int page_size_mask;
};

struct mhp_params {
	struct vmem_altmap *altmap;
	pgprot_t pgprot;
};

struct mem_section_usage {
	long unsigned int subsection_map[1];
	long unsigned int pageblock_flags[0];
};

struct mem_section {
	long unsigned int section_mem_map;
	struct mem_section_usage *usage;
};

enum kcore_type {
	KCORE_TEXT = 0,
	KCORE_VMALLOC = 1,
	KCORE_RAM = 2,
	KCORE_VMEMMAP = 3,
	KCORE_USER = 4,
};

struct kcore_list {
	struct list_head list;
	long unsigned int addr;
	size_t size;
	int type;
};

enum {
	MEMORY_HOTPLUG_MIN_BOOTMEM_TYPE = 12,
	SECTION_INFO = 12,
	MIX_SECTION_INFO = 13,
	NODE_INFO = 14,
	MEMORY_HOTPLUG_MAX_BOOTMEM_TYPE = 14,
};

struct dentry___19;

struct super_block___19;

struct module___18;

struct file_system_type___19 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___19 * (*mount)(struct file_system_type___19 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___19 *);
	struct module___18 *owner;
	struct file_system_type___19 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___19;

struct kiocb___19;

struct iov_iter___15;

struct poll_table_struct___13;

struct vm_area_struct___21;

struct inode___19;

struct file_lock___19;

struct page___20;

struct seq_file___17;

struct file_operations___19 {
	struct module___18 *owner;
	loff_t (*llseek)(struct file___19 *, loff_t, int);
	ssize_t (*read)(struct file___19 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___19 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___19 *, struct iov_iter___15 *);
	ssize_t (*write_iter)(struct kiocb___19 *, struct iov_iter___15 *);
	int (*iopoll)(struct kiocb___19 *, bool);
	int (*iterate)(struct file___19 *, struct dir_context *);
	int (*iterate_shared)(struct file___19 *, struct dir_context *);
	__poll_t (*poll)(struct file___19 *, struct poll_table_struct___13 *);
	long int (*unlocked_ioctl)(struct file___19 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___19 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___19 *, struct vm_area_struct___21 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___19 *, struct file___19 *);
	int (*flush)(struct file___19 *, fl_owner_t);
	int (*release)(struct inode___19 *, struct file___19 *);
	int (*fsync)(struct file___19 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___19 *, int);
	int (*lock)(struct file___19 *, int, struct file_lock___19 *);
	ssize_t (*sendpage)(struct file___19 *, struct page___20 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___19 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___19 *, long unsigned int);
	int (*flock)(struct file___19 *, int, struct file_lock___19 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___19 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___19 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___19 *, long int, struct file_lock___19 **, void **);
	long int (*fallocate)(struct file___19 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___17 *, struct file___19 *);
	ssize_t (*copy_file_range)(struct file___19 *, loff_t, struct file___19 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___19 *, loff_t, struct file___19 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___19 *, loff_t, loff_t, int);
};

struct static_call_mod___13 {
	struct static_call_mod___13 *next;
	struct module___18 *mod;
	struct static_call_site *sites;
};

struct static_call_key___13 {
	void *func;
	union {
		long unsigned int type;
		struct static_call_mod___13 *mods;
		struct static_call_site *sites;
	};
};

struct vmacache___20 {
	u64 seqnum;
	struct vm_area_struct___21 *vmas[4];
};

struct page_frag___20 {
	struct page___20 *page;
	__u32 offset;
	__u32 size;
};

struct perf_event___11;

struct thread_struct___12 {
	struct desc_struct tls_array[3];
	long unsigned int sp;
	short unsigned int es;
	short unsigned int ds;
	short unsigned int fsindex;
	short unsigned int gsindex;
	long unsigned int fsbase;
	long unsigned int gsbase;
	struct perf_event___11 *ptrace_bps[4];
	long unsigned int virtual_dr6;
	long unsigned int ptrace_dr7;
	long unsigned int cr2;
	long unsigned int trap_nr;
	long unsigned int error_code;
	struct io_bitmap *io_bitmap;
	long unsigned int iopl_emul;
	unsigned int iopl_warn: 1;
	unsigned int sig_on_uaccess_err: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u32 pkru;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct fpu fpu;
};

struct mm_struct___21;

struct pid___17;

struct nsproxy___18;

struct signal_struct___20;

struct bio_list___12;

struct backing_dev_info___11;

struct io_context___13;

struct css_set___14;

struct perf_event_context___11;

struct mem_cgroup___11;

struct request_queue___12;

struct vm_struct___17;

struct task_struct___22 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___22 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___21 *mm;
	struct mm_struct___21 *active_mm;
	struct vmacache___20 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int restore_sigmask: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___22 *real_parent;
	struct task_struct___22 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___22 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___17 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	struct posix_cputimers_work posix_cputimers_work;
	const struct cred *ptracer_cred;
	const struct cred *real_cred;
	const struct cred *cred;
	struct key *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___18 *nsproxy;
	struct signal_struct___20 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___22 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___12 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___11 *backing_dev_info;
	struct io_context___13 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___14 *cgroups;
	struct list_head cg_list;
	u32 closid;
	u32 rmid;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___11 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	long: 64;
	long: 64;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___20 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___11 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___11 *active_memcg;
	struct request_queue___12 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___22 *oom_reaper_list;
	struct vm_struct___17 *stack_vm_area;
	refcount_t stack_refcount;
	int patch_state;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	void *mce_vaddr;
	__u64 mce_kflags;
	u64 mce_addr;
	__u64 mce_ripv: 1;
	__u64 mce_whole_page: 1;
	__u64 __mce_reserved: 62;
	long: 2;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct callback_head mce_kill_me;
	int mce_count;
	struct llist_head kretprobe_instances;
	struct callback_head l1d_flush_kill;
	long: 64;
	struct thread_struct___12 thread;
};

typedef struct page___20 *pgtable_t___20;

struct address_space___19;

struct dev_pagemap___19;

struct page___20 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___19 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___4 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___20 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___20 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___21 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___19 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct pv_cpu_ops___17 {
	void (*io_delay)();
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	void (*write_cr4)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___12 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(long unsigned int);
	void (*invalidate_io_bitmap)();
	void (*update_io_bitmap)();
	void (*wbinvd)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int);
	void (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_msr_safe)(unsigned int, int *);
	int (*write_msr_safe)(unsigned int, unsigned int, unsigned int);
	u64 (*read_pmc)(int);
	void (*start_context_switch)(struct task_struct___22 *);
	void (*end_context_switch)(struct task_struct___22 *);
};

struct flush_tlb_info___8;

struct mmu_gather___5;

struct pv_mmu_ops___18 {
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_one_user)(long unsigned int);
	void (*flush_tlb_multi)(const struct cpumask *, const struct flush_tlb_info___8 *);
	void (*tlb_remove_table)(struct mmu_gather___5 *, void *);
	void (*exit_mmap)(struct mm_struct___21 *);
	struct paravirt_callee_save read_cr2;
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___21 *, struct mm_struct___21 *);
	void (*dup_mmap)(struct mm_struct___21 *, struct mm_struct___21 *);
	int (*pgd_alloc)(struct mm_struct___21 *);
	void (*pgd_free)(struct mm_struct___21 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___21 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___21 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___21 *, long unsigned int);
	void (*alloc_p4d)(struct mm_struct___21 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*release_p4d)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	pte_t (*ptep_modify_prot_start)(struct vm_area_struct___21 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct vm_area_struct___21 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_p4d)(p4d_t *, p4d_t);
	struct paravirt_callee_save p4d_val;
	struct paravirt_callee_save make_p4d;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

struct flush_tlb_info___8 {
	struct mm_struct___21 *mm;
	long unsigned int start;
	long unsigned int end;
	u64 new_tlb_gen;
	unsigned int initiating_cpu;
	u8 stride_shift;
	u8 freed_tables;
};

struct mmu_gather_batch___5 {
	struct mmu_gather_batch___5 *next;
	unsigned int nr;
	unsigned int max;
	struct page___20 *pages[0];
};

struct mmu_gather___5 {
	struct mm_struct___21 *mm;
	struct mmu_table_batch *batch;
	long unsigned int start;
	long unsigned int end;
	unsigned int fullmm: 1;
	unsigned int need_flush_all: 1;
	unsigned int freed_tables: 1;
	unsigned int cleared_ptes: 1;
	unsigned int cleared_pmds: 1;
	unsigned int cleared_puds: 1;
	unsigned int cleared_p4ds: 1;
	unsigned int vma_exec: 1;
	unsigned int vma_huge: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int batch_count;
	struct mmu_gather_batch___5 *active;
	struct mmu_gather_batch___5 local;
	struct page___20 *__pages[8];
};

struct core_state___20;

struct mm_struct___21 {
	struct {
		struct vm_area_struct___21 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___19 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int mmap_compat_base;
		long unsigned int mmap_compat_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[48];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___20 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___22 *owner;
		struct user_namespace *user_ns;
		struct file___19 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		bool tlb_flush_batched;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct vm_operations_struct___19;

struct vm_area_struct___21 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___21 *vm_next;
	struct vm_area_struct___21 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___21 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___19 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___19 *vm_file;
	struct file___19 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct paravirt_patch_template___18 {
	struct pv_cpu_ops___17 cpu;
	struct pv_irq_ops irq;
	struct pv_mmu_ops___18 mmu;
	struct pv_lock_ops lock;
};

struct tracepoint___13 {
	const char *name;
	struct static_key key;
	struct static_call_key___13 *static_call_key;
	void *static_call_tramp;
	void *iterator;
	int (*regfunc)();
	void (*unregfunc)();
	struct tracepoint_func *funcs;
};

struct bpf_raw_event_map___13 {
	struct tracepoint___13 *tp;
	void *bpf_func;
	u32 num_args;
	u32 writable_size;
	long: 64;
};

struct seq_operations___17 {
	void * (*start)(struct seq_file___17 *, loff_t *);
	void (*stop)(struct seq_file___17 *, void *);
	void * (*next)(struct seq_file___17 *, void *, loff_t *);
	int (*show)(struct seq_file___17 *, void *);
};

struct hw_perf_event___11 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___22 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	union {
		struct {
			u64 last_period;
			local64_t period_left;
		};
		struct {
			u64 saved_metric;
			u64 saved_slots;
		};
	};
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___11)(struct perf_event___11 *, struct perf_sample_data *, struct pt_regs *);

struct pmu___11;

struct fasync_struct___19;

struct pid_namespace___17;

struct trace_event_call___11;

struct perf_cgroup___11;

struct perf_event___11 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___11 *group_leader;
	struct pmu___11 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___11 hw;
	struct perf_event_context___11 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___11 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___22 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct perf_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___19 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	long unsigned int pending_addr;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	struct perf_addr_filter_range *addr_filter_ranges;
	long unsigned int addr_filters_gen;
	struct perf_event___11 *aux_event;
	void (*destroy)(struct perf_event___11 *);
	struct callback_head callback_head;
	struct pid_namespace___17 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___11 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___11 orig_overflow_handler;
	struct bpf_prog *prog;
	u64 bpf_cookie;
	struct trace_event_call___11 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___11 *cgrp;
	void *security;
	struct list_head sb_list;
};

struct upid___17 {
	int nr;
	struct pid_namespace___17 *ns;
};

struct pid_namespace___17 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___22 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___17 *parent;
	struct fs_pin *bacct;
	struct user_namespace *user_ns;
	struct ucounts *ucounts;
	int reboot;
	struct ns_common ns;
};

struct pid___17 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___17 numbers[1];
};

struct signal_struct___20 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___22 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___22 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper;
	unsigned int has_child_subreaper;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___17 *pids[4];
	struct pid___17 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___21 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct cgroup_namespace___14;

struct nsproxy___18 {
	atomic_t count;
	struct uts_namespace *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___17 *pid_ns_for_children;
	struct net *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___14 *cgroup_ns;
};

struct bio___12;

struct bio_list___12 {
	struct bio___12 *head;
	struct bio___12 *tail;
};

struct cgroup_subsys_state___14;

struct bdi_writeback___11 {
	struct backing_dev_info___11 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	atomic_t writeback_inodes;
	struct percpu_counter stat[4];
	long unsigned int congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	struct delayed_work bw_dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___14 *memcg_css;
	struct cgroup_subsys_state___14 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	struct list_head b_attached;
	struct list_head offline_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
};

struct device___21;

struct backing_dev_info___11 {
	u64 id;
	struct rb_node rb_node;
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___11 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct mutex cgwb_release_mutex;
	struct rw_semaphore wb_switch_rwsem;
	wait_queue_head_t wb_waitq;
	struct device___21 *dev;
	char dev_name[64];
	struct device___21 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___19 *debug_dir;
};

struct io_cq___12;

struct io_context___13 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	struct xarray icq_tree;
	struct io_cq___12 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct cgroup___14;

struct css_set___14 {
	struct cgroup_subsys_state___14 *subsys[14];
	refcount_t refcount;
	struct css_set___14 *dom_cset;
	struct cgroup___14 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___14 *mg_src_cgrp;
	struct cgroup___14 *mg_dst_cgrp;
	struct css_set___14 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___11 {
	struct pmu___11 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	int rotate_necessary;
	refcount_t refcount;
	struct task_struct___22 *task;
	u64 time;
	u64 timestamp;
	u64 timeoffset;
	struct perf_event_context___11 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

struct cgroup_subsys___14;

struct cgroup_subsys_state___14 {
	struct cgroup___14 *cgroup;
	struct cgroup_subsys___14 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___14 *parent;
};

struct kernfs_node___19;

struct cgroup_file___14 {
	struct kernfs_node___19 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct obj_cgroup___11;

struct mem_cgroup_per_node___11;

struct mem_cgroup___11 {
	struct cgroup_subsys_state___14 css;
	struct mem_cgroup_id id;
	struct page_counter memory;
	union {
		struct page_counter swap;
		struct page_counter memsw;
	};
	struct page_counter kmem;
	struct page_counter tcpmem;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool oom_group;
	bool oom_lock;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___14 events_file;
	struct cgroup_file___14 events_local_file;
	struct cgroup_file___14 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	struct memcg_vmstats vmstats;
	atomic_long_t memory_events[8];
	atomic_long_t memory_events_local[8];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct obj_cgroup___11 *objcg;
	struct list_head objcg_list;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad2_;
	atomic_t moving_account;
	struct task_struct___22 *move_lock_task;
	struct memcg_vmstats_percpu *vmstats_percpu;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct memcg_cgwb_frn cgwb_frn[4];
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct deferred_split deferred_split_queue;
	struct mem_cgroup_per_node___11 *nodeinfo[0];
	long: 64;
};

struct kset___18;

struct kobj_type___18;

struct kobject___19 {
	const char *name;
	struct list_head entry;
	struct kobject___19 *parent;
	struct kset___18 *kset;
	struct kobj_type___18 *ktype;
	struct kernfs_node___19 *sd;
	struct kref kref;
	unsigned int state_initialized;
	unsigned int state_in_sysfs;
	unsigned int state_add_uevent_sent;
	unsigned int state_remove_uevent_sent;
	unsigned int uevent_suppress;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct blk_integrity_profile___12;

struct blk_integrity___12 {
	const struct blk_integrity_profile___12 *profile;
	unsigned char flags;
	unsigned char tuple_size;
	unsigned char interval_exp;
	unsigned char tag_size;
};

struct bio_set___12 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	struct bio_alloc_cache *cache;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	unsigned int back_pad;
	spinlock_t rescue_lock;
	struct bio_list___12 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	struct hlist_node cpuhp_dead;
};

struct request___12;

struct elevator_queue___12;

struct gendisk___12;

struct blkcg_gq___11;

struct request_queue___12 {
	struct request___12 *last_merge;
	struct elevator_queue___12 *elevator;
	struct percpu_ref q_usage_counter;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	const struct blk_mq_ops *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx **queue_hw_ctx;
	unsigned int nr_hw_queues;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	spinlock_t queue_lock;
	struct gendisk___12 *disk;
	struct kobject___19 kobj;
	struct kobject___19 *mq_kobj;
	struct blk_integrity___12 integrity;
	struct device___21 *dev;
	enum rpm_status rpm_status;
	long unsigned int nr_requests;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_keyslot_manager *ksm;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	atomic_t nr_active_requests_shared_sbitmap;
	struct sbitmap_queue sched_bitmap_tags;
	struct sbitmap_queue sched_breserved_tags;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___11 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int required_elevator_features;
	unsigned int nr_zones;
	long unsigned int *conv_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int max_open_zones;
	unsigned int max_active_zones;
	int node;
	struct mutex debugfs_mutex;
	struct blk_trace *blk_trace;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	struct mutex sysfs_dir_lock;
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	int mq_freeze_depth;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct mutex mq_freeze_lock;
	struct blk_mq_tag_set *tag_set;
	struct list_head tag_set_list;
	struct bio_set___12 bio_split;
	struct dentry___19 *debugfs_dir;
	struct dentry___19 *sched_debugfs_dir;
	struct dentry___19 *rqos_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	u64 write_hints[5];
};

struct vm_struct___17 {
	struct vm_struct___17 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___20 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct address_space_operations___19;

struct address_space___19 {
	struct inode___19 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___19 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct dev_pagemap_ops___19;

struct dev_pagemap___19 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___19 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vfsmount___19;

struct path___19 {
	struct vfsmount___19 *mnt;
	struct dentry___19 *dentry;
};

struct fown_struct___17 {
	rwlock_t lock;
	struct pid___17 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___19 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	long: 64;
	long: 64;
	struct path___19 f_path;
	struct inode___19 *f_inode;
	const struct file_operations___19 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___17 f_owner;
	const struct cred *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___19 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___19;

struct vm_operations_struct___19 {
	void (*open)(struct vm_area_struct___21 *);
	void (*close)(struct vm_area_struct___21 *);
	int (*may_split)(struct vm_area_struct___21 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___21 *);
	int (*mprotect)(struct vm_area_struct___21 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___19 *);
	vm_fault_t (*huge_fault)(struct vm_fault___19 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___19 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___21 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___19 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___19 *);
	int (*access)(struct vm_area_struct___21 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___21 *);
	int (*set_policy)(struct vm_area_struct___21 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___21 *, long unsigned int);
	struct page___20 * (*find_special_page)(struct vm_area_struct___21 *, long unsigned int);
};

struct core_thread___20 {
	struct task_struct___22 *task;
	struct core_thread___20 *next;
};

struct core_state___20 {
	atomic_t nr_threads;
	struct core_thread___20 dumper;
	struct completion startup;
};

struct vm_fault___19 {
	const struct {
		struct vm_area_struct___21 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___20 *cow_page;
	struct page___20 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___20 prealloc_pte;
};

struct pglist_data___12;

struct lruvec___12 {
	struct list_head lists[5];
	spinlock_t lru_lock;
	long unsigned int anon_cost;
	long unsigned int file_cost;
	atomic_long_t nonresident_age;
	long unsigned int refaults[2];
	long unsigned int flags;
	struct pglist_data___12 *pgdat;
};

struct zone___12 {
	long unsigned int _watermark[3];
	long unsigned int watermark_boost;
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[5];
	int node;
	struct pglist_data___12 *zone_pgdat;
	struct per_cpu_pages *per_cpu_pageset;
	struct per_cpu_zonestat *per_cpu_zonestats;
	int pageset_high;
	int pageset_batch;
	long unsigned int zone_start_pfn;
	atomic_long_t managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int present_early_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	seqlock_t span_seqlock;
	int initialized;
	int: 32;
	struct zone_padding _pad1_;
	struct free_area free_area[11];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	long unsigned int compact_init_migrate_pfn;
	long unsigned int compact_init_free_pfn;
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	short: 16;
	struct zone_padding _pad3_;
	atomic_long_t vm_stat[11];
	atomic_long_t vm_numa_event[6];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___12 {
	struct zone___12 *zone;
	int zone_idx;
};

struct zonelist___12 {
	struct zoneref___12 _zonerefs[5121];
};

struct pglist_data___12 {
	struct zone___12 node_zones[5];
	struct zonelist___12 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___22 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_highest_zoneidx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_highest_zoneidx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___22 *kcompactd;
	bool proactive_compact_trigger;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct deferred_split deferred_split_queue;
	struct lruvec___12 __lruvec;
	long unsigned int flags;
	long: 64;
	struct zone_padding _pad2_;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[39];
};

struct shrink_control___11 {
	gfp_t gfp_mask;
	int nid;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	struct mem_cgroup___11 *memcg;
};

struct shrinker___11 {
	long unsigned int (*count_objects)(struct shrinker___11 *, struct shrink_control___11 *);
	long unsigned int (*scan_objects)(struct shrinker___11 *, struct shrink_control___11 *);
	long int batch;
	int seeks;
	unsigned int flags;
	struct list_head list;
	int id;
	atomic_long_t *nr_deferred;
};

struct dev_pagemap_ops___19 {
	void (*page_free)(struct page___20 *);
	void (*kill)(struct dev_pagemap___19 *);
	void (*cleanup)(struct dev_pagemap___19 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___19 *);
};

struct dentry_operations___19;

struct dentry___19 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___19 *d_parent;
	struct qstr d_name;
	struct inode___19 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___19 *d_op;
	struct super_block___19 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___19;

struct cdev___8;

struct inode___19 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___19 *i_op;
	struct super_block___19 *i_sb;
	struct address_space___19 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___11 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	long: 64;
	long: 64;
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___19 *i_fop;
		void (*free_inode)(struct inode___19 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___19 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct cdev___8 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___19 {
	int (*d_revalidate)(struct dentry___19 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___19 *, unsigned int);
	int (*d_hash)(const struct dentry___19 *, struct qstr *);
	int (*d_compare)(const struct dentry___19 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___19 *);
	int (*d_init)(struct dentry___19 *);
	void (*d_release)(struct dentry___19 *);
	void (*d_prune)(struct dentry___19 *);
	void (*d_iput)(struct dentry___19 *, struct inode___19 *);
	char * (*d_dname)(struct dentry___19 *, char *, int);
	struct vfsmount___19 * (*d_automount)(struct path___19 *);
	int (*d_manage)(const struct path___19 *, bool);
	struct dentry___19 * (*d_real)(struct dentry___19 *, const struct inode___19 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___19;

struct mem_dqinfo___19 {
	struct quota_format_type___19 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___19;

struct quota_info___19 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___19 *files[3];
	struct mem_dqinfo___19 info[3];
	const struct quota_format_ops___19 *ops[3];
};

struct rcuwait___19 {
	struct task_struct___22 *task;
};

struct percpu_rw_semaphore___19 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___19 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___19 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___19 rw_sem[3];
};

struct super_operations___19;

struct dquot_operations___19;

struct quotactl_ops___19;

struct block_device___12;

struct super_block___19 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___19 *s_type;
	const struct super_operations___19 *s_op;
	const struct dquot_operations___19 *dq_op;
	const struct quotactl_ops___19 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___19 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___12 *s_bdev;
	struct backing_dev_info___11 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___19 s_dquot;
	struct sb_writers___19 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___19 *s_d_op;
	int cleancache_poolid;
	struct shrinker___11 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___19 {
	struct dentry___19 *mnt_root;
	struct super_block___19 *mnt_sb;
	int mnt_flags;
	struct user_namespace *mnt_userns;
};

struct psi_group___14 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___22 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___14;

struct cgroup_rstat_cpu___14;

struct cgroup___14 {
	struct cgroup_subsys_state___14 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___19 *kn;
	struct cgroup_file___14 procs_file;
	struct cgroup_file___14 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___14 *subsys[14];
	struct cgroup_root___14 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___14 *dom_cgrp;
	struct cgroup___14 *old_dom_cgrp;
	struct cgroup_rstat_cpu___14 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___14 psi;
	struct cgroup_bpf bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct io_cq___12 {
	struct request_queue___12 *q;
	struct io_context___13 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct wait_page_queue___10;

struct kiocb___19 {
	struct file___19 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___19 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___10 *ki_waitq;
	};
};

struct iattr___19 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___19 *ia_file;
};

struct dquot___19 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___19 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___19 {
	int qf_fmt_id;
	const struct quota_format_ops___19 *qf_ops;
	struct module___18 *qf_owner;
	struct quota_format_type___19 *qf_next;
};

struct quota_format_ops___19 {
	int (*check_quota_file)(struct super_block___19 *, int);
	int (*read_file_info)(struct super_block___19 *, int);
	int (*write_file_info)(struct super_block___19 *, int);
	int (*free_file_info)(struct super_block___19 *, int);
	int (*read_dqblk)(struct dquot___19 *);
	int (*commit_dqblk)(struct dquot___19 *);
	int (*release_dqblk)(struct dquot___19 *);
	int (*get_next_id)(struct super_block___19 *, struct kqid *);
};

struct dquot_operations___19 {
	int (*write_dquot)(struct dquot___19 *);
	struct dquot___19 * (*alloc_dquot)(struct super_block___19 *, int);
	void (*destroy_dquot)(struct dquot___19 *);
	int (*acquire_dquot)(struct dquot___19 *);
	int (*release_dquot)(struct dquot___19 *);
	int (*mark_dirty)(struct dquot___19 *);
	int (*write_info)(struct super_block___19 *, int);
	qsize_t * (*get_reserved_space)(struct inode___19 *);
	int (*get_projid)(struct inode___19 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___19 *, qsize_t *);
	int (*get_next_id)(struct super_block___19 *, struct kqid *);
};

struct quotactl_ops___19 {
	int (*quota_on)(struct super_block___19 *, int, int, const struct path___19 *);
	int (*quota_off)(struct super_block___19 *, int);
	int (*quota_enable)(struct super_block___19 *, unsigned int);
	int (*quota_disable)(struct super_block___19 *, unsigned int);
	int (*quota_sync)(struct super_block___19 *, int);
	int (*set_info)(struct super_block___19 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___19 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___19 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___19 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___19 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___19 *, unsigned int);
};

struct module_kobject___18 {
	struct kobject___19 kobj;
	struct module___18 *mod;
	struct kobject___19 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___18 {
	struct module___18 *mod;
	struct latch_tree_node node;
};

struct module_layout___18 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___18 mtn;
};

struct module_attribute___18;

struct kernel_param___18;

struct module___18 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___18 mkobj;
	struct module_attribute___18 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___19 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___18 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___18 core_layout;
	struct module_layout___18 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map___13 *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___11 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	int num_static_call_sites;
	struct static_call_site *static_call_sites;
	bool klp;
	bool klp_alive;
	struct klp_modinfo *klp_info;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct wait_page_queue___10 {
	struct page___20 *page;
	int bit_nr;
	wait_queue_entry_t wait;
};

struct writeback_control___11;

struct readahead_control___10;

struct swap_info_struct___7;

struct address_space_operations___19 {
	int (*writepage)(struct page___20 *, struct writeback_control___11 *);
	int (*readpage)(struct file___19 *, struct page___20 *);
	int (*writepages)(struct address_space___19 *, struct writeback_control___11 *);
	int (*set_page_dirty)(struct page___20 *);
	int (*readpages)(struct file___19 *, struct address_space___19 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___10 *);
	int (*write_begin)(struct file___19 *, struct address_space___19 *, loff_t, unsigned int, unsigned int, struct page___20 **, void **);
	int (*write_end)(struct file___19 *, struct address_space___19 *, loff_t, unsigned int, unsigned int, struct page___20 *, void *);
	sector_t (*bmap)(struct address_space___19 *, sector_t);
	void (*invalidatepage)(struct page___20 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___20 *, gfp_t);
	void (*freepage)(struct page___20 *);
	ssize_t (*direct_IO)(struct kiocb___19 *, struct iov_iter___15 *);
	int (*migratepage)(struct address_space___19 *, struct page___20 *, struct page___20 *, enum migrate_mode);
	bool (*isolate_page)(struct page___20 *, isolate_mode_t);
	void (*putback_page)(struct page___20 *);
	int (*launder_page)(struct page___20 *);
	int (*is_partially_uptodate)(struct page___20 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___20 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___19 *, struct page___20 *);
	int (*swap_activate)(struct swap_info_struct___7 *, struct file___19 *, sector_t *);
	void (*swap_deactivate)(struct file___19 *);
};

struct writeback_control___11 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate;
	unsigned int for_background;
	unsigned int tagged_writepages;
	unsigned int for_reclaim;
	unsigned int range_cyclic;
	unsigned int for_sync;
	unsigned int no_cgroup_owner;
	unsigned int punt_to_cgroup;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bdi_writeback___11 *wb;
	struct inode___19 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
};

struct readahead_control___10 {
	struct file___19 *file;
	struct address_space___19 *mapping;
	struct file_ra_state *ra;
	long unsigned int _index;
	unsigned int _nr_pages;
	unsigned int _batch_count;
};

struct bio_vec___15;

struct iov_iter___15 {
	u8 iter_type;
	bool data_source;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___15 *bvec;
		struct xarray *xarray;
		struct pipe_inode_info *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			unsigned int head;
			unsigned int start_head;
		};
		loff_t xarray_start;
	};
};

struct swap_info_struct___7 {
	struct percpu_ref users;
	long unsigned int flags;
	short int prio;
	struct plist_node list;
	signed char type;
	unsigned int max;
	unsigned char *swap_map;
	struct swap_cluster_info *cluster_info;
	struct swap_cluster_list free_clusters;
	unsigned int lowest_bit;
	unsigned int highest_bit;
	unsigned int pages;
	unsigned int inuse_pages;
	unsigned int cluster_next;
	unsigned int cluster_nr;
	unsigned int *cluster_next_cpu;
	struct percpu_cluster *percpu_cluster;
	struct rb_root swap_extent_root;
	struct block_device___12 *bdev;
	struct file___19 *swap_file;
	unsigned int old_block_size;
	struct completion comp;
	long unsigned int *frontswap_map;
	atomic_t frontswap_pages;
	spinlock_t lock;
	spinlock_t cont_lock;
	struct work_struct discard_work;
	struct swap_cluster_list discard_clusters;
	struct plist_node avail_lists[0];
};

struct cdev___8 {
	struct kobject___19 kobj;
	struct module___18 *owner;
	const struct file_operations___19 *ops;
	struct list_head list;
	dev_t dev;
	unsigned int count;
};

struct inode_operations___19 {
	struct dentry___19 * (*lookup)(struct inode___19 *, struct dentry___19 *, unsigned int);
	const char * (*get_link)(struct dentry___19 *, struct inode___19 *, struct delayed_call *);
	int (*permission)(struct user_namespace *, struct inode___19 *, int);
	struct posix_acl * (*get_acl)(struct inode___19 *, int, bool);
	int (*readlink)(struct dentry___19 *, char *, int);
	int (*create)(struct user_namespace *, struct inode___19 *, struct dentry___19 *, umode_t, bool);
	int (*link)(struct dentry___19 *, struct inode___19 *, struct dentry___19 *);
	int (*unlink)(struct inode___19 *, struct dentry___19 *);
	int (*symlink)(struct user_namespace *, struct inode___19 *, struct dentry___19 *, const char *);
	int (*mkdir)(struct user_namespace *, struct inode___19 *, struct dentry___19 *, umode_t);
	int (*rmdir)(struct inode___19 *, struct dentry___19 *);
	int (*mknod)(struct user_namespace *, struct inode___19 *, struct dentry___19 *, umode_t, dev_t);
	int (*rename)(struct user_namespace *, struct inode___19 *, struct dentry___19 *, struct inode___19 *, struct dentry___19 *, unsigned int);
	int (*setattr)(struct user_namespace *, struct dentry___19 *, struct iattr___19 *);
	int (*getattr)(struct user_namespace *, const struct path___19 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___19 *, char *, size_t);
	int (*fiemap)(struct inode___19 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___19 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___19 *, struct dentry___19 *, struct file___19 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace *, struct inode___19 *, struct dentry___19 *, umode_t);
	int (*set_acl)(struct user_namespace *, struct inode___19 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace *, struct dentry___19 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___19 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___19 {
	void (*fl_copy_lock)(struct file_lock___19 *, struct file_lock___19 *);
	void (*fl_release_private)(struct file_lock___19 *);
};

struct lock_manager_operations___19;

struct file_lock___19 {
	struct file_lock___19 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___19 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___19 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___19 *fl_ops;
	const struct lock_manager_operations___19 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___19 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___19 *);
	int (*lm_grant)(struct file_lock___19 *, int);
	bool (*lm_break)(struct file_lock___19 *);
	int (*lm_change)(struct file_lock___19 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___19 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___19 *);
};

struct fasync_struct___19 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___19 *fa_next;
	struct file___19 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___19 {
	struct inode___19 * (*alloc_inode)(struct super_block___19 *);
	void (*destroy_inode)(struct inode___19 *);
	void (*free_inode)(struct inode___19 *);
	void (*dirty_inode)(struct inode___19 *, int);
	int (*write_inode)(struct inode___19 *, struct writeback_control___11 *);
	int (*drop_inode)(struct inode___19 *);
	void (*evict_inode)(struct inode___19 *);
	void (*put_super)(struct super_block___19 *);
	int (*sync_fs)(struct super_block___19 *, int);
	int (*freeze_super)(struct super_block___19 *);
	int (*freeze_fs)(struct super_block___19 *);
	int (*thaw_super)(struct super_block___19 *);
	int (*unfreeze_fs)(struct super_block___19 *);
	int (*statfs)(struct dentry___19 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___19 *, int *, char *);
	void (*umount_begin)(struct super_block___19 *);
	int (*show_options)(struct seq_file___17 *, struct dentry___19 *);
	int (*show_devname)(struct seq_file___17 *, struct dentry___19 *);
	int (*show_path)(struct seq_file___17 *, struct dentry___19 *);
	int (*show_stats)(struct seq_file___17 *, struct dentry___19 *);
	ssize_t (*quota_read)(struct super_block___19 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___19 *, int, const char *, size_t, loff_t);
	struct dquot___19 ** (*get_dquots)(struct inode___19 *);
	long int (*nr_cached_objects)(struct super_block___19 *, struct shrink_control___11 *);
	long int (*free_cached_objects)(struct super_block___19 *, struct shrink_control___11 *);
	struct file___19 * (*real_loop)(struct file___19 *);
};

struct wakeup_source___21;

struct dev_pm_info___21 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___21 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___21 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___21;

struct bus_type___21;

struct device_driver___21;

struct dev_pm_domain___21;

struct fwnode_handle___19;

struct class___21;

struct attribute_group___19;

struct device___21 {
	struct kobject___19 kobj;
	struct device___21 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___21 *type;
	struct bus_type___21 *bus;
	struct device_driver___21 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___21 power;
	struct dev_pm_domain___21 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node *of_node;
	struct fwnode_handle___19 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___21 *class;
	const struct attribute_group___19 **groups;
	void (*release)(struct device___21 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct block_device___12 {
	sector_t bd_start_sect;
	struct disk_stats *bd_stats;
	long unsigned int bd_stamp;
	bool bd_read_only;
	dev_t bd_dev;
	int bd_openers;
	struct inode___19 *bd_inode;
	struct super_block___19 *bd_super;
	void *bd_claiming;
	struct device___21 bd_device;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct kobject___19 *bd_holder_dir;
	u8 bd_partno;
	spinlock_t bd_size_lock;
	struct gendisk___12 *bd_disk;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	struct super_block___19 *bd_fsfreeze_sb;
	struct partition_meta_info *bd_meta_info;
};

typedef void (*poll_queue_proc___13)(struct file___19 *, wait_queue_head_t *, struct poll_table_struct___13 *);

struct poll_table_struct___13 {
	poll_queue_proc___13 _qproc;
	__poll_t _key;
};

struct seq_file___17 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___17 *op;
	int poll_event;
	const struct file___19 *file;
	void *private;
};

typedef void bio_end_io_t___12(struct bio___12 *);

struct bio_vec___15 {
	struct page___20 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___12;

struct bio___12 {
	struct bio___12 *bi_next;
	struct block_device___12 *bi_bdev;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	atomic_t __bi_remaining;
	struct bvec_iter bi_iter;
	bio_end_io_t___12 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___11 *bi_blkg;
	struct bio_issue bi_issue;
	u64 bi_iocost_cost;
	struct bio_crypt_ctx *bi_crypt_context;
	union {
		struct bio_integrity_payload___12 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___15 *bi_io_vec;
	struct bio_set___12 *bi_pool;
	struct bio_vec___15 bi_inline_vecs[0];
};

struct fwnode_operations___19;

struct fwnode_handle___19 {
	struct fwnode_handle___19 *secondary;
	const struct fwnode_operations___19 *ops;
	struct device___21 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct fwnode_reference_args___19;

struct fwnode_endpoint___19;

struct fwnode_operations___19 {
	struct fwnode_handle___19 * (*get)(struct fwnode_handle___19 *);
	void (*put)(struct fwnode_handle___19 *);
	bool (*device_is_available)(const struct fwnode_handle___19 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___19 *, const struct device___21 *);
	bool (*property_present)(const struct fwnode_handle___19 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___19 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___19 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___19 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___19 *);
	struct fwnode_handle___19 * (*get_parent)(const struct fwnode_handle___19 *);
	struct fwnode_handle___19 * (*get_next_child_node)(const struct fwnode_handle___19 *, struct fwnode_handle___19 *);
	struct fwnode_handle___19 * (*get_named_child_node)(const struct fwnode_handle___19 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___19 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___19 *);
	struct fwnode_handle___19 * (*graph_get_next_endpoint)(const struct fwnode_handle___19 *, struct fwnode_handle___19 *);
	struct fwnode_handle___19 * (*graph_get_remote_endpoint)(const struct fwnode_handle___19 *);
	struct fwnode_handle___19 * (*graph_get_port_parent)(struct fwnode_handle___19 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___19 *, struct fwnode_endpoint___19 *);
	int (*add_links)(struct fwnode_handle___19 *);
};

struct fwnode_endpoint___19 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___19 *local_fwnode;
};

struct fwnode_reference_args___19 {
	struct fwnode_handle___19 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct kernfs_root___19;

struct kernfs_elem_dir___19 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___19 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___19;

struct kernfs_root___19 {
	struct kernfs_node___19 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___19 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___19 {
	struct kernfs_node___19 *target_kn;
};

struct kernfs_ops___19;

struct kernfs_elem_attr___19 {
	const struct kernfs_ops___19 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___19 *notify_next;
};

struct kernfs_node___19 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___19 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___19 dir;
		struct kernfs_elem_symlink___19 symlink;
		struct kernfs_elem_attr___19 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___19;

struct kernfs_ops___19 {
	int (*open)(struct kernfs_open_file___19 *);
	void (*release)(struct kernfs_open_file___19 *);
	int (*seq_show)(struct seq_file___17 *, void *);
	void * (*seq_start)(struct seq_file___17 *, loff_t *);
	void * (*seq_next)(struct seq_file___17 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___17 *, void *);
	ssize_t (*read)(struct kernfs_open_file___19 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___19 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___19 *, struct poll_table_struct___13 *);
	int (*mmap)(struct kernfs_open_file___19 *, struct vm_area_struct___21 *);
};

struct kernfs_syscall_ops___19 {
	int (*show_options)(struct seq_file___17 *, struct kernfs_root___19 *);
	int (*mkdir)(struct kernfs_node___19 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___19 *);
	int (*rename)(struct kernfs_node___19 *, struct kernfs_node___19 *, const char *);
	int (*show_path)(struct seq_file___17 *, struct kernfs_node___19 *, struct kernfs_root___19 *);
};

struct kernfs_open_file___19 {
	struct kernfs_node___19 *kn;
	struct file___19 *file;
	struct seq_file___17 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped;
	bool released;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___19 *vm_ops;
};

struct bin_attribute___19;

struct attribute_group___19 {
	const char *name;
	umode_t (*is_visible)(struct kobject___19 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___19 *, struct bin_attribute___19 *, int);
	struct attribute **attrs;
	struct bin_attribute___19 **bin_attrs;
};

struct bin_attribute___19 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___19 * (*f_mapping)();
	ssize_t (*read)(struct file___19 *, struct kobject___19 *, struct bin_attribute___19 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___19 *, struct kobject___19 *, struct bin_attribute___19 *, char *, loff_t, size_t);
	int (*mmap)(struct file___19 *, struct kobject___19 *, struct bin_attribute___19 *, struct vm_area_struct___21 *);
};

struct sysfs_ops___18 {
	ssize_t (*show)(struct kobject___19 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___19 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___18;

struct kset___18 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___19 kobj;
	const struct kset_uevent_ops___18 *uevent_ops;
};

struct kobj_type___18 {
	void (*release)(struct kobject___19 *);
	const struct sysfs_ops___18 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___19 **default_groups;
	const struct kobj_ns_type_operations * (*child_ns_type)(struct kobject___19 *);
	const void * (*namespace)(struct kobject___19 *);
	void (*get_ownership)(struct kobject___19 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___18 {
	int (* const filter)(struct kset___18 *, struct kobject___19 *);
	const char * (* const name)(struct kset___18 *, struct kobject___19 *);
	int (* const uevent)(struct kset___18 *, struct kobject___19 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___18 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___18 *);
	int (*get)(char *, const struct kernel_param___18 *);
	void (*free)(void *);
};

struct kparam_array___18;

struct kernel_param___18 {
	const char *name;
	struct module___18 *mod;
	const struct kernel_param_ops___18 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___18 *arr;
	};
};

struct kparam_array___18 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___18 *ops;
	void *elem;
};

struct module_attribute___18 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___18 *, struct module_kobject___18 *, char *);
	ssize_t (*store)(struct module_attribute___18 *, struct module_kobject___18 *, const char *, size_t);
	void (*setup)(struct module___18 *, const char *);
	int (*test)(struct module___18 *);
	void (*free)(struct module___18 *);
};

struct trace_event_class___11;

struct trace_event_call___11 {
	struct list_head list;
	struct trace_event_class___11 *class;
	union {
		char *name;
		struct tracepoint___13 *tp;
	};
	struct trace_event event;
	char *print_fmt;
	struct event_filter *filter;
	union {
		void *module;
		atomic_t refcnt;
	};
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
	struct bpf_prog_array *prog_array;
	int (*perf_perm)(struct trace_event_call___11 *, struct perf_event___11 *);
};

struct cgroup_namespace___14 {
	struct ns_common ns;
	struct user_namespace *user_ns;
	struct ucounts *ucounts;
	struct css_set___14 *root_cset;
};

struct perf_cpu_context___11;

struct perf_output_handle___11;

struct pmu___11 {
	struct list_head entry;
	struct module___18 *module;
	struct device___21 *dev;
	const struct attribute_group___19 **attr_groups;
	const struct attribute_group___19 **attr_update;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___11 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___11 *);
	void (*pmu_disable)(struct pmu___11 *);
	int (*event_init)(struct perf_event___11 *);
	void (*event_mapped)(struct perf_event___11 *, struct mm_struct___21 *);
	void (*event_unmapped)(struct perf_event___11 *, struct mm_struct___21 *);
	int (*add)(struct perf_event___11 *, int);
	void (*del)(struct perf_event___11 *, int);
	void (*start)(struct perf_event___11 *, int);
	void (*stop)(struct perf_event___11 *, int);
	void (*read)(struct perf_event___11 *);
	void (*start_txn)(struct pmu___11 *, unsigned int);
	int (*commit_txn)(struct pmu___11 *);
	void (*cancel_txn)(struct pmu___11 *);
	int (*event_idx)(struct perf_event___11 *);
	void (*sched_task)(struct perf_event_context___11 *, bool);
	struct kmem_cache *task_ctx_cache;
	void (*swap_task_ctx)(struct perf_event_context___11 *, struct perf_event_context___11 *);
	void * (*setup_aux)(struct perf_event___11 *, void **, int, bool);
	void (*free_aux)(void *);
	long int (*snapshot_aux)(struct perf_event___11 *, struct perf_output_handle___11 *, long unsigned int);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___11 *);
	int (*aux_output_match)(struct perf_event___11 *);
	int (*filter_match)(struct perf_event___11 *);
	int (*check_period)(struct perf_event___11 *, u64);
};

struct dev_pm_ops___21 {
	int (*prepare)(struct device___21 *);
	void (*complete)(struct device___21 *);
	int (*suspend)(struct device___21 *);
	int (*resume)(struct device___21 *);
	int (*freeze)(struct device___21 *);
	int (*thaw)(struct device___21 *);
	int (*poweroff)(struct device___21 *);
	int (*restore)(struct device___21 *);
	int (*suspend_late)(struct device___21 *);
	int (*resume_early)(struct device___21 *);
	int (*freeze_late)(struct device___21 *);
	int (*thaw_early)(struct device___21 *);
	int (*poweroff_late)(struct device___21 *);
	int (*restore_early)(struct device___21 *);
	int (*suspend_noirq)(struct device___21 *);
	int (*resume_noirq)(struct device___21 *);
	int (*freeze_noirq)(struct device___21 *);
	int (*thaw_noirq)(struct device___21 *);
	int (*poweroff_noirq)(struct device___21 *);
	int (*restore_noirq)(struct device___21 *);
	int (*runtime_suspend)(struct device___21 *);
	int (*runtime_resume)(struct device___21 *);
	int (*runtime_idle)(struct device___21 *);
};

struct wakeup_source___21 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___21 *dev;
	bool active;
	bool autosleep_enabled;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___21 {
	struct dev_pm_ops___21 ops;
	int (*start)(struct device___21 *);
	void (*detach)(struct device___21 *, bool);
	int (*activate)(struct device___21 *);
	void (*sync)(struct device___21 *);
	void (*dismiss)(struct device___21 *);
};

struct bus_type___21 {
	const char *name;
	const char *dev_name;
	struct device___21 *dev_root;
	const struct attribute_group___19 **bus_groups;
	const struct attribute_group___19 **dev_groups;
	const struct attribute_group___19 **drv_groups;
	int (*match)(struct device___21 *, struct device_driver___21 *);
	int (*uevent)(struct device___21 *, struct kobj_uevent_env *);
	int (*probe)(struct device___21 *);
	void (*sync_state)(struct device___21 *);
	void (*remove)(struct device___21 *);
	void (*shutdown)(struct device___21 *);
	int (*online)(struct device___21 *);
	int (*offline)(struct device___21 *);
	int (*suspend)(struct device___21 *, pm_message_t);
	int (*resume)(struct device___21 *);
	int (*num_vf)(struct device___21 *);
	int (*dma_configure)(struct device___21 *);
	const struct dev_pm_ops___21 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___21 {
	const char *name;
	struct bus_type___21 *bus;
	struct module___18 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___21 *);
	void (*sync_state)(struct device___21 *);
	int (*remove)(struct device___21 *);
	void (*shutdown)(struct device___21 *);
	int (*suspend)(struct device___21 *, pm_message_t);
	int (*resume)(struct device___21 *);
	const struct attribute_group___19 **groups;
	const struct attribute_group___19 **dev_groups;
	const struct dev_pm_ops___21 *pm;
	void (*coredump)(struct device___21 *);
	struct driver_private *p;
};

struct device_type___21 {
	const char *name;
	const struct attribute_group___19 **groups;
	int (*uevent)(struct device___21 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___21 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___21 *);
	const struct dev_pm_ops___21 *pm;
};

struct class___21 {
	const char *name;
	struct module___18 *owner;
	const struct attribute_group___19 **class_groups;
	const struct attribute_group___19 **dev_groups;
	struct kobject___19 *dev_kobj;
	int (*dev_uevent)(struct device___21 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___21 *, umode_t *);
	void (*class_release)(struct class___21 *);
	void (*dev_release)(struct device___21 *);
	int (*shutdown_pre)(struct device___21 *);
	const struct kobj_ns_type_operations *ns_type;
	const void * (*namespace)(struct device___21 *);
	void (*get_ownership)(struct device___21 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___21 *pm;
	struct subsys_private *p;
};

struct cftype___14;

struct cgroup_subsys___14 {
	struct cgroup_subsys_state___14 * (*css_alloc)(struct cgroup_subsys_state___14 *);
	int (*css_online)(struct cgroup_subsys_state___14 *);
	void (*css_offline)(struct cgroup_subsys_state___14 *);
	void (*css_released)(struct cgroup_subsys_state___14 *);
	void (*css_free)(struct cgroup_subsys_state___14 *);
	void (*css_reset)(struct cgroup_subsys_state___14 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___14 *, int);
	int (*css_extra_stat_show)(struct seq_file___17 *, struct cgroup_subsys_state___14 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___22 *, struct css_set___14 *);
	void (*cancel_fork)(struct task_struct___22 *, struct css_set___14 *);
	void (*fork)(struct task_struct___22 *);
	void (*exit)(struct task_struct___22 *);
	void (*release)(struct task_struct___22 *);
	void (*bind)(struct cgroup_subsys_state___14 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___14 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___14 *dfl_cftypes;
	struct cftype___14 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___14 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___14 *updated_children;
	struct cgroup___14 *updated_next;
};

struct cgroup_root___14 {
	struct kernfs_root___19 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___14 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___14 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___14 *ss;
	struct list_head node;
	struct kernfs_ops___19 *kf_ops;
	int (*open)(struct kernfs_open_file___19 *);
	void (*release)(struct kernfs_open_file___19 *);
	u64 (*read_u64)(struct cgroup_subsys_state___14 *, struct cftype___14 *);
	s64 (*read_s64)(struct cgroup_subsys_state___14 *, struct cftype___14 *);
	int (*seq_show)(struct seq_file___17 *, void *);
	void * (*seq_start)(struct seq_file___17 *, loff_t *);
	void * (*seq_next)(struct seq_file___17 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___17 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___14 *, struct cftype___14 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___14 *, struct cftype___14 *, s64);
	ssize_t (*write)(struct kernfs_open_file___19 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___19 *, struct poll_table_struct___13 *);
};

struct perf_cpu_context___11 {
	struct perf_event_context___11 ctx;
	struct perf_event_context___11 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___11 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
	int heap_size;
	struct perf_event___11 **heap;
	struct perf_event___11 *heap_default[2];
};

struct perf_output_handle___11 {
	struct perf_event___11 *event;
	struct perf_buffer *rb;
	long unsigned int wakeup;
	long unsigned int size;
	u64 aux_flags;
	union {
		void *addr;
		long unsigned int head;
	};
	int page;
};

struct perf_cgroup___11 {
	struct cgroup_subsys_state___14 css;
	struct perf_cgroup_info *info;
};

struct hstate {
	struct mutex resize_lock;
	int next_nid_to_alloc;
	int next_nid_to_free;
	unsigned int order;
	long unsigned int mask;
	long unsigned int max_huge_pages;
	long unsigned int nr_huge_pages;
	long unsigned int free_huge_pages;
	long unsigned int resv_huge_pages;
	long unsigned int surplus_huge_pages;
	long unsigned int nr_overcommit_huge_pages;
	struct list_head hugepage_activelist;
	struct list_head hugepage_freelists[1024];
	unsigned int nr_huge_pages_node[1024];
	unsigned int free_huge_pages_node[1024];
	unsigned int surplus_huge_pages_node[1024];
	unsigned int nr_free_vmemmap_pages;
	struct cftype___14 cgroup_files_dfl[7];
	struct cftype___14 cgroup_files_legacy[9];
	char name[32];
};

struct block_device_operations___12;

struct gendisk___12 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	short unsigned int events;
	short unsigned int event_flags;
	struct xarray part_tbl;
	struct block_device___12 *part0;
	const struct block_device_operations___12 *fops;
	struct request_queue___12 *queue;
	void *private_data;
	int flags;
	long unsigned int state;
	struct mutex open_mutex;
	unsigned int open_partitions;
	struct backing_dev_info___11 *bdi;
	struct kobject___19 *slave_dir;
	struct list_head slave_bdevs;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___19 integrity_kobj;
	struct cdrom_device_info *cdi;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	u64 diskseq;
};

struct bio_integrity_payload___12 {
	struct bio___12 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___15 *bip_vec;
	struct bio_vec___15 bip_inline_vecs[0];
};

struct blkcg___11;

struct blkg_policy_data___11;

struct blkcg_gq___11 {
	struct request_queue___12 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___11 *blkcg;
	struct blkcg_gq___11 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_iostat_set *iostat_cpu;
	struct blkg_iostat_set iostat;
	struct blkg_policy_data___11 *pd[6];
	spinlock_t async_bio_lock;
	struct bio_list___12 async_bios;
	struct work_struct async_bio_work;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
	struct callback_head callback_head;
};

typedef void integrity_prepare_fn___12(struct request___12 *);

typedef void integrity_complete_fn___12(struct request___12 *, unsigned int);

struct blk_integrity_profile___12 {
	integrity_processing_fn *generate_fn;
	integrity_processing_fn *verify_fn;
	integrity_prepare_fn___12 *prepare_fn;
	integrity_complete_fn___12 *complete_fn;
	const char *name;
};

struct block_device_operations___12 {
	blk_qc_t (*submit_bio)(struct bio___12 *);
	int (*open)(struct block_device___12 *, fmode_t);
	void (*release)(struct gendisk___12 *, fmode_t);
	int (*rw_page)(struct block_device___12 *, sector_t, struct page___20 *, unsigned int);
	int (*ioctl)(struct block_device___12 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___12 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___12 *, unsigned int);
	void (*unlock_native_capacity)(struct gendisk___12 *);
	int (*getgeo)(struct block_device___12 *, struct hd_geometry *);
	int (*set_read_only)(struct block_device___12 *, bool);
	void (*swap_slot_free_notify)(struct block_device___12 *, long unsigned int);
	int (*report_zones)(struct gendisk___12 *, sector_t, unsigned int, report_zones_cb, void *);
	char * (*devnode)(struct gendisk___12 *, umode_t *);
	struct module___18 *owner;
	const struct pr_ops *pr_ops;
	int (*alternative_gpt_sector)(struct gendisk___12 *, sector_t *);
};

typedef void rq_end_io_fn___12(struct request___12 *, blk_status_t);

struct request___12 {
	struct request_queue___12 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int tag;
	int internal_tag;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___12 *bio;
	struct bio___12 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct llist_node ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___15 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___12 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___12 *saved_end_io;
		} flush;
	};
	struct gendisk___12 *rq_disk;
	struct block_device___12 *part;
	u64 alloc_time_ns;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int stats_sectors;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	struct bio_crypt_ctx *crypt_ctx;
	struct blk_ksm_keyslot *crypt_keyslot;
	short unsigned int write_hint;
	short unsigned int ioprio;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___12 *end_io;
	void *end_io_data;
};

struct elevator_type___12;

struct elevator_mq_ops___12 {
	int (*init_sched)(struct request_queue___12 *, struct elevator_type___12 *);
	void (*exit_sched)(struct elevator_queue___12 *);
	int (*init_hctx)(struct blk_mq_hw_ctx *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx *, unsigned int);
	void (*depth_updated)(struct blk_mq_hw_ctx *);
	bool (*allow_merge)(struct request_queue___12 *, struct request___12 *, struct bio___12 *);
	bool (*bio_merge)(struct request_queue___12 *, struct bio___12 *, unsigned int);
	int (*request_merge)(struct request_queue___12 *, struct request___12 **, struct bio___12 *);
	void (*request_merged)(struct request_queue___12 *, struct request___12 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___12 *, struct request___12 *, struct request___12 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___12 *);
	void (*finish_request)(struct request___12 *);
	void (*insert_requests)(struct blk_mq_hw_ctx *, struct list_head *, bool);
	struct request___12 * (*dispatch_request)(struct blk_mq_hw_ctx *);
	bool (*has_work)(struct blk_mq_hw_ctx *);
	void (*completed_request)(struct request___12 *, u64);
	void (*requeue_request)(struct request___12 *);
	struct request___12 * (*former_request)(struct request_queue___12 *, struct request___12 *);
	struct request___12 * (*next_request)(struct request_queue___12 *, struct request___12 *);
	void (*init_icq)(struct io_cq___12 *);
	void (*exit_icq)(struct io_cq___12 *);
};

struct elv_fs_entry___12;

struct elevator_type___12 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___12 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___12 *elevator_attrs;
	const char *elevator_name;
	const char *elevator_alias;
	const unsigned int elevator_features;
	struct module___18 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
};

struct elevator_queue___12 {
	struct elevator_type___12 *type;
	void *elevator_data;
	struct kobject___19 kobj;
	struct mutex sysfs_lock;
	unsigned int registered;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hlist_head hash[64];
};

struct elv_fs_entry___12 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___12 *, char *);
	ssize_t (*store)(struct elevator_queue___12 *, const char *, size_t);
};

struct blkcg_policy_data___11;

struct blkcg___11 {
	struct cgroup_subsys_state___14 css;
	spinlock_t lock;
	refcount_t online_pin;
	struct xarray blkg_tree;
	struct blkcg_gq___11 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___11 *cpd[6];
	struct list_head all_blkcgs_node;
	char fc_app_id[129];
	struct list_head cgwb_list;
};

struct blkcg_policy_data___11 {
	struct blkcg___11 *blkcg;
	int plid;
};

struct blkg_policy_data___11 {
	struct blkcg_gq___11 *blkg;
	int plid;
};

struct mem_cgroup_reclaim_iter___11 {
	struct mem_cgroup___11 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___11 {
	struct lruvec___12 lruvec;
	struct lruvec_stats_percpu *lruvec_stats_percpu;
	struct lruvec_stats lruvec_stats;
	long unsigned int lru_zone_size[25];
	struct mem_cgroup_reclaim_iter___11 iter;
	struct shrinker_info *shrinker_info;
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	struct mem_cgroup___11 *memcg;
};

struct obj_cgroup___11 {
	struct percpu_ref refcnt;
	struct mem_cgroup___11 *memcg;
	atomic_t nr_charged_bytes;
	union {
		struct list_head list;
		struct callback_head rcu;
	};
};

struct trace_event_fields___11 {
	const char *type;
	union {
		struct {
			const char *name;
			const int size;
			const int align;
			const int is_signed;
			const int filter_type;
		};
		int (*define_fields)(struct trace_event_call___11 *);
	};
};

struct trace_event_class___11 {
	const char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct trace_event_call___11 *, enum trace_reg, void *);
	struct trace_event_fields___11 *fields_array;
	struct list_head * (*get_fields)(struct trace_event_call___11 *);
	struct list_head fields;
	int (*raw_init)(struct trace_event_call___11 *);
};

struct trace_event_file___7;

struct trace_event_buffer___7 {
	struct trace_buffer *buffer;
	struct ring_buffer_event *event;
	struct trace_event_file___7 *trace_file;
	void *entry;
	unsigned int trace_ctx;
	struct pt_regs *regs;
};

struct trace_event_file___7 {
	struct list_head list;
	struct trace_event_call___11 *event_call;
	struct event_filter *filter;
	struct dentry___19 *dir;
	struct trace_array *tr;
	struct trace_subsystem_dir *system;
	struct list_head triggers;
	long unsigned int flags;
	atomic_t sm_ref;
	atomic_t tm_ref;
};

struct trace_event_raw_x86_exceptions {
	struct trace_entry ent;
	long unsigned int address;
	long unsigned int ip;
	long unsigned int error_code;
	char __data[0];
};

struct trace_event_data_offsets_x86_exceptions {};

typedef void (*btf_trace_page_fault_user)(void *, long unsigned int, struct pt_regs *, long unsigned int);

typedef void (*btf_trace_page_fault_kernel)(void *, long unsigned int, struct pt_regs *, long unsigned int);

enum {
	IORES_MAP_SYSTEM_RAM = 1,
	IORES_MAP_ENCRYPTED = 2,
};

struct ioremap_desc {
	unsigned int flags;
};

struct hugepage_subpool {
	spinlock_t lock;
	long int count;
	long int max_hpages;
	long int used_hpages;
	struct hstate *hstate;
	long int min_hpages;
	long int rsv_hpages;
};

struct hugetlbfs_sb_info {
	long int max_inodes;
	long int free_inodes;
	spinlock_t stat_lock;
	struct hstate *hstate;
	struct hugepage_subpool *spool;
	kuid_t uid;
	kgid_t gid;
	umode_t mode;
};

struct exception_stacks {
	char DF_stack_guard[0];
	char DF_stack[8192];
	char NMI_stack_guard[0];
	char NMI_stack[8192];
	char DB_stack_guard[0];
	char DB_stack[8192];
	char MCE_stack_guard[0];
	char MCE_stack[8192];
	char VC_stack_guard[0];
	char VC_stack[8192];
	char VC2_stack_guard[0];
	char VC2_stack[8192];
	char IST_top_guard[0];
};

struct vm_event_state {
	long unsigned int event[100];
};

struct cpa_data {
	long unsigned int *vaddr;
	pgd_t *pgd;
	pgprot_t mask_set;
	pgprot_t mask_clr;
	long unsigned int numpages;
	long unsigned int curpage;
	long unsigned int pfn;
	unsigned int flags;
	unsigned int force_split;
	unsigned int force_static_prot;
	unsigned int force_flush_all;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct page___8 **pages;
};

enum cpa_warn {
	CPA_CONFLICT = 0,
	CPA_PROTECT = 1,
	CPA_DETECT = 2,
};

typedef struct {
	u64 val;
} pfn_t;

struct memtype {
	u64 start;
	u64 end;
	u64 subtree_max_end;
	enum page_cache_mode type;
	struct rb_node rb;
};

enum {
	PAT_UC = 0,
	PAT_WC = 1,
	PAT_WT = 4,
	PAT_WP = 5,
	PAT_WB = 6,
	PAT_UC_MINUS = 7,
};

struct pagerange_state {
	long unsigned int cur_pfn;
	int ram;
	int not_ram;
};

struct rb_augment_callbacks {
	void (*propagate)(struct rb_node *, struct rb_node *);
	void (*copy)(struct rb_node *, struct rb_node *);
	void (*rotate)(struct rb_node *, struct rb_node *);
};

enum {
	MEMTYPE_EXACT_MATCH = 0,
	MEMTYPE_END_MATCH = 1,
};

struct ptdump_range {
	long unsigned int start;
	long unsigned int end;
};

struct ptdump_state {
	void (*note_page)(struct ptdump_state *, long unsigned int, int, u64);
	void (*effective_prot)(struct ptdump_state *, int, u64);
	const struct ptdump_range *range;
};

struct addr_marker;

struct pg_state {
	struct ptdump_state ptdump;
	int level;
	pgprotval_t current_prot;
	pgprotval_t effective_prot;
	pgprotval_t prot_levels[5];
	long unsigned int start_address;
	const struct addr_marker *marker;
	long unsigned int lines;
	bool to_dmesg;
	bool check_wx;
	long unsigned int wx_pages;
	struct seq_file___6 *seq;
};

struct addr_marker {
	long unsigned int start_address;
	const char *name;
	long unsigned int max_lines;
};

enum address_markers_idx {
	USER_SPACE_NR = 0,
	KERNEL_SPACE_NR = 1,
	LDT_NR = 2,
	LOW_KERNEL_NR = 3,
	VMALLOC_START_NR = 4,
	VMEMMAP_START_NR = 5,
	CPU_ENTRY_AREA_NR = 6,
	ESPFIX_START_NR = 7,
	EFI_END_NR = 8,
	HIGH_KERNEL_NR = 9,
	MODULES_VADDR_NR = 10,
	MODULES_END_NR = 11,
	FIXADDR_START_NR = 12,
	END_OF_SPACE_NR = 13,
};

typedef void (*rcu_callback_t)(struct callback_head *);

struct kmmio_probe;

typedef void (*kmmio_pre_handler_t)(struct kmmio_probe *, struct pt_regs *, long unsigned int);

typedef void (*kmmio_post_handler_t)(struct kmmio_probe *, long unsigned int, struct pt_regs *);

struct kmmio_probe {
	struct list_head list;
	long unsigned int addr;
	long unsigned int len;
	kmmio_pre_handler_t pre_handler;
	kmmio_post_handler_t post_handler;
	void *private;
};

struct kmmio_fault_page {
	struct list_head list;
	struct kmmio_fault_page *release_next;
	long unsigned int addr;
	pteval_t old_presence;
	bool armed;
	int count;
	bool scheduled_for_release;
};

struct kmmio_delayed_release {
	struct callback_head rcu;
	struct kmmio_fault_page *release_list;
};

struct kmmio_context {
	struct kmmio_fault_page *fpage;
	struct kmmio_probe *probe;
	long unsigned int saved_flags;
	long unsigned int addr;
	int active;
};

enum reason_type {
	NOT_ME = 0,
	NOTHING = 1,
	REG_READ = 2,
	REG_WRITE = 3,
	IMM_WRITE = 4,
	OTHERS = 5,
};

struct prefix_bits {
	unsigned int shorted;
	unsigned int enlarged;
	unsigned int rexr;
	unsigned int rex: 1;
};

enum {
	arg_AL = 0,
	arg_CL = 1,
	arg_DL = 2,
	arg_BL = 3,
	arg_AH = 4,
	arg_CH = 5,
	arg_DH = 6,
	arg_BH = 7,
	arg_AX = 0,
	arg_CX = 1,
	arg_DX = 2,
	arg_BX = 3,
	arg_SP = 4,
	arg_BP = 5,
	arg_SI = 6,
	arg_DI = 7,
	arg_R8 = 8,
	arg_R9 = 9,
	arg_R10 = 10,
	arg_R11 = 11,
	arg_R12 = 12,
	arg_R13 = 13,
	arg_R14 = 14,
	arg_R15 = 15,
};

enum mm_io_opcode {
	MMIO_READ = 1,
	MMIO_WRITE = 2,
	MMIO_PROBE = 3,
	MMIO_UNPROBE = 4,
	MMIO_UNKNOWN_OP = 5,
};

struct mmiotrace_rw {
	resource_size_t phys;
	long unsigned int value;
	long unsigned int pc;
	int map_id;
	unsigned char opcode;
	unsigned char width;
};

struct mmiotrace_map {
	resource_size_t phys;
	long unsigned int virt;
	long unsigned int len;
	int map_id;
	unsigned char opcode;
};

struct trap_reason {
	long unsigned int addr;
	long unsigned int ip;
	enum reason_type type;
	int active_traces;
};

struct remap_trace {
	struct list_head list;
	struct kmmio_probe probe;
	resource_size_t phys;
	long unsigned int id;
};

struct numa_memblk {
	u64 start;
	u64 end;
	int nid;
};

struct numa_meminfo {
	int nr_blks;
	struct numa_memblk blk[2048];
};

struct acpi_srat_cpu_affinity {
	struct acpi_subtable_header header;
	u8 proximity_domain_lo;
	u8 apic_id;
	u32 flags;
	u8 local_sapic_eid;
	u8 proximity_domain_hi[3];
	u32 clock_domain;
};

struct acpi_srat_x2apic_cpu_affinity {
	struct acpi_subtable_header header;
	u16 reserved;
	u32 proximity_domain;
	u32 apic_id;
	u32 flags;
	u32 clock_domain;
	u32 reserved2;
};

struct rnd_state {
	__u32 s1;
	__u32 s2;
	__u32 s3;
	__u32 s4;
};

struct kaslr_memory_region {
	long unsigned int *base;
	long unsigned int size_tb;
};

enum pti_mode {
	PTI_AUTO = 0,
	PTI_FORCE_OFF = 1,
	PTI_FORCE_ON = 2,
};

enum pti_clone_level {
	PTI_CLONE_PMD = 0,
	PTI_CLONE_PTE = 1,
};

struct sme_populate_pgd_data {
	void *pgtable_area;
	pgd_t___2 *pgd;
	pmdval_t pmd_flags;
	pteval_t pte_flags;
	long unsigned int paddr;
	long unsigned int vaddr;
	long unsigned int vaddr_end;
};

struct crypto_alg___2;

struct crypto_tfm___2 {
	u32 crt_flags;
	int node;
	void (*exit)(struct crypto_tfm___2 *);
	struct crypto_alg___2 *__crt_alg;
	void *__crt_ctx[0];
};

struct cipher_alg___2 {
	unsigned int cia_min_keysize;
	unsigned int cia_max_keysize;
	int (*cia_setkey)(struct crypto_tfm___2 *, const u8 *, unsigned int);
	void (*cia_encrypt)(struct crypto_tfm___2 *, u8 *, const u8 *);
	void (*cia_decrypt)(struct crypto_tfm___2 *, u8 *, const u8 *);
};

struct compress_alg___2 {
	int (*coa_compress)(struct crypto_tfm___2 *, const u8 *, unsigned int, u8 *, unsigned int *);
	int (*coa_decompress)(struct crypto_tfm___2 *, const u8 *, unsigned int, u8 *, unsigned int *);
};

struct crypto_type___2;

struct crypto_alg___2 {
	struct list_head cra_list;
	struct list_head cra_users;
	u32 cra_flags;
	unsigned int cra_blocksize;
	unsigned int cra_ctxsize;
	unsigned int cra_alignmask;
	int cra_priority;
	refcount_t cra_refcnt;
	char cra_name[128];
	char cra_driver_name[128];
	const struct crypto_type___2 *cra_type;
	union {
		struct cipher_alg___2 cipher;
		struct compress_alg___2 compress;
	} cra_u;
	int (*cra_init)(struct crypto_tfm___2 *);
	void (*cra_exit)(struct crypto_tfm___2 *);
	void (*cra_destroy)(struct crypto_alg___2 *);
	struct module___7 *cra_module;
	union {
		struct crypto_istat_aead aead;
		struct crypto_istat_akcipher akcipher;
		struct crypto_istat_cipher cipher;
		struct crypto_istat_compress compress;
		struct crypto_istat_hash hash;
		struct crypto_istat_rng rng;
		struct crypto_istat_kpp kpp;
	} stats;
};

struct sk_buff___2;

struct crypto_instance;

struct crypto_type___2 {
	unsigned int (*ctxsize)(struct crypto_alg___2 *, u32, u32);
	unsigned int (*extsize)(struct crypto_alg___2 *);
	int (*init)(struct crypto_tfm___2 *, u32, u32);
	int (*init_tfm)(struct crypto_tfm___2 *);
	void (*show)(struct seq_file *, struct crypto_alg___2 *);
	int (*report)(struct sk_buff___2 *, struct crypto_alg___2 *);
	void (*free)(struct crypto_instance *);
	unsigned int type;
	unsigned int maskclear;
	unsigned int maskset;
	unsigned int tfmsize;
};

struct crypto_template;

struct crypto_spawn;

struct crypto_instance {
	struct crypto_alg___2 alg;
	struct crypto_template *tmpl;
	union {
		struct hlist_node list;
		struct crypto_spawn *spawns;
	};
	void *__ctx[0];
};

struct crypto_spawn {
	struct list_head list;
	struct crypto_alg___2 *alg;
	union {
		struct crypto_instance *inst;
		struct crypto_spawn *next;
	};
	const struct crypto_type___2 *frontend;
	u32 mask;
	bool dead;
	bool registered;
};

struct rtattr;

struct crypto_template {
	struct list_head list;
	struct hlist_head instances;
	struct module___7 *module;
	int (*create)(struct crypto_template *, struct rtattr **);
	char name[128];
};

struct crypto_shash___2;

struct shash_desc___2 {
	struct crypto_shash___2 *tfm;
	void *__ctx[0];
};

struct crypto_shash___2 {
	unsigned int descsize;
	struct crypto_tfm___2 base;
};

struct shash_alg {
	int (*init)(struct shash_desc___2 *);
	int (*update)(struct shash_desc___2 *, const u8 *, unsigned int);
	int (*final)(struct shash_desc___2 *, u8 *);
	int (*finup)(struct shash_desc___2 *, const u8 *, unsigned int, u8 *);
	int (*digest)(struct shash_desc___2 *, const u8 *, unsigned int, u8 *);
	int (*export)(struct shash_desc___2 *, void *);
	int (*import)(struct shash_desc___2 *, const void *);
	int (*setkey)(struct crypto_shash___2 *, const u8 *, unsigned int);
	int (*init_tfm)(struct crypto_shash___2 *);
	void (*exit_tfm)(struct crypto_shash___2 *);
	unsigned int descsize;
	int: 32;
	unsigned int digestsize;
	unsigned int statesize;
	struct crypto_alg___2 base;
};

struct dentry___20;

struct super_block___20;

struct module___19;

struct file_system_type___20 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___20 * (*mount)(struct file_system_type___20 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___20 *);
	struct module___19 *owner;
	struct file_system_type___20 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___20;

struct kiocb___20;

struct poll_table_struct___14;

struct vm_area_struct___22;

struct inode___20;

struct file_lock___20;

struct page___21;

struct seq_file___18;

struct file_operations___20 {
	struct module___19 *owner;
	loff_t (*llseek)(struct file___20 *, loff_t, int);
	ssize_t (*read)(struct file___20 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___20 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___20 *, struct iov_iter___6 *);
	ssize_t (*write_iter)(struct kiocb___20 *, struct iov_iter___6 *);
	int (*iopoll)(struct kiocb___20 *, bool);
	int (*iterate)(struct file___20 *, struct dir_context *);
	int (*iterate_shared)(struct file___20 *, struct dir_context *);
	__poll_t (*poll)(struct file___20 *, struct poll_table_struct___14 *);
	long int (*unlocked_ioctl)(struct file___20 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___20 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___20 *, struct vm_area_struct___22 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___20 *, struct file___20 *);
	int (*flush)(struct file___20 *, fl_owner_t);
	int (*release)(struct inode___20 *, struct file___20 *);
	int (*fsync)(struct file___20 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___20 *, int);
	int (*lock)(struct file___20 *, int, struct file_lock___20 *);
	ssize_t (*sendpage)(struct file___20 *, struct page___21 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___20 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___20 *, long unsigned int);
	int (*flock)(struct file___20 *, int, struct file_lock___20 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___20 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___20 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___20 *, long int, struct file_lock___20 **, void **);
	long int (*fallocate)(struct file___20 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___18 *, struct file___20 *);
	ssize_t (*copy_file_range)(struct file___20 *, loff_t, struct file___20 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___20 *, loff_t, struct file___20 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___20 *, loff_t, loff_t, int);
};

struct static_call_mod___14 {
	struct static_call_mod___14 *next;
	struct module___19 *mod;
	struct static_call_site *sites;
};

struct static_call_key___14 {
	void *func;
	union {
		long unsigned int type;
		struct static_call_mod___14 *mods;
		struct static_call_site *sites;
	};
};

struct vmacache___21 {
	u64 seqnum;
	struct vm_area_struct___22 *vmas[4];
};

struct page_frag___21 {
	struct page___21 *page;
	__u32 offset;
	__u32 size;
};

struct perf_event___12;

struct thread_struct___13 {
	struct desc_struct tls_array[3];
	long unsigned int sp;
	short unsigned int es;
	short unsigned int ds;
	short unsigned int fsindex;
	short unsigned int gsindex;
	long unsigned int fsbase;
	long unsigned int gsbase;
	struct perf_event___12 *ptrace_bps[4];
	long unsigned int virtual_dr6;
	long unsigned int ptrace_dr7;
	long unsigned int cr2;
	long unsigned int trap_nr;
	long unsigned int error_code;
	struct io_bitmap *io_bitmap;
	long unsigned int iopl_emul;
	unsigned int iopl_warn: 1;
	unsigned int sig_on_uaccess_err: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u32 pkru;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct fpu fpu;
};

struct mm_struct___22;

struct pid___18;

struct nsproxy___19;

struct signal_struct___21;

struct css_set___15;

struct perf_event_context___12;

struct task_struct___23 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___23 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___22 *mm;
	struct mm_struct___22 *active_mm;
	struct vmacache___21 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int restore_sigmask: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___23 *real_parent;
	struct task_struct___23 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___23 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___18 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	struct posix_cputimers_work posix_cputimers_work;
	const struct cred *ptracer_cred;
	const struct cred *real_cred;
	const struct cred *cred;
	struct key *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___19 *nsproxy;
	struct signal_struct___21 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___23 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context___6 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___15 *cgroups;
	struct list_head cg_list;
	u32 closid;
	u32 rmid;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___12 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	long: 64;
	long: 64;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___21 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup *active_memcg;
	struct request_queue *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___23 *oom_reaper_list;
	struct vm_struct___3 *stack_vm_area;
	refcount_t stack_refcount;
	int patch_state;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	void *mce_vaddr;
	__u64 mce_kflags;
	u64 mce_addr;
	__u64 mce_ripv: 1;
	__u64 mce_whole_page: 1;
	__u64 __mce_reserved: 62;
	long: 2;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct callback_head mce_kill_me;
	int mce_count;
	struct llist_head kretprobe_instances;
	struct callback_head l1d_flush_kill;
	long: 64;
	struct thread_struct___13 thread;
};

typedef struct page___21 *pgtable_t___21;

struct address_space___20;

struct dev_pagemap___20;

struct page___21 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___20 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___2 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___21 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___21 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___22 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___20 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct pv_cpu_ops___18 {
	void (*io_delay)();
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	void (*write_cr4)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___13 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(long unsigned int);
	void (*invalidate_io_bitmap)();
	void (*update_io_bitmap)();
	void (*wbinvd)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int);
	void (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_msr_safe)(unsigned int, int *);
	int (*write_msr_safe)(unsigned int, unsigned int, unsigned int);
	u64 (*read_pmc)(int);
	void (*start_context_switch)(struct task_struct___23 *);
	void (*end_context_switch)(struct task_struct___23 *);
};

struct pv_mmu_ops___19 {
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_one_user)(long unsigned int);
	void (*flush_tlb_multi)(const struct cpumask *, const struct flush_tlb_info___3 *);
	void (*tlb_remove_table)(struct mmu_gather *, void *);
	void (*exit_mmap)(struct mm_struct___22 *);
	struct paravirt_callee_save read_cr2;
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___22 *, struct mm_struct___22 *);
	void (*dup_mmap)(struct mm_struct___22 *, struct mm_struct___22 *);
	int (*pgd_alloc)(struct mm_struct___22 *);
	void (*pgd_free)(struct mm_struct___22 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___22 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___22 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___22 *, long unsigned int);
	void (*alloc_p4d)(struct mm_struct___22 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*release_p4d)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	pte_t (*ptep_modify_prot_start)(struct vm_area_struct___22 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct vm_area_struct___22 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_p4d)(p4d_t *, p4d_t);
	struct paravirt_callee_save p4d_val;
	struct paravirt_callee_save make_p4d;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

struct linux_binfmt___2;

struct core_state___21;

struct mm_struct___22 {
	struct {
		struct vm_area_struct___22 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___20 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int mmap_compat_base;
		long unsigned int mmap_compat_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[48];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___21 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___23 *owner;
		struct user_namespace *user_ns;
		struct file___20 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		bool tlb_flush_batched;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct vm_operations_struct___20;

struct vm_area_struct___22 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___22 *vm_next;
	struct vm_area_struct___22 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___22 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___20 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___20 *vm_file;
	struct file___20 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct paravirt_patch_template___19 {
	struct pv_cpu_ops___18 cpu;
	struct pv_irq_ops irq;
	struct pv_mmu_ops___19 mmu;
	struct pv_lock_ops lock;
};

struct sigcontext_32 {
	__u16 gs;
	__u16 __gsh;
	__u16 fs;
	__u16 __fsh;
	__u16 es;
	__u16 __esh;
	__u16 ds;
	__u16 __dsh;
	__u32 di;
	__u32 si;
	__u32 bp;
	__u32 sp;
	__u32 bx;
	__u32 dx;
	__u32 cx;
	__u32 ax;
	__u32 trapno;
	__u32 err;
	__u32 ip;
	__u16 cs;
	__u16 __csh;
	__u32 flags;
	__u32 sp_at_signal;
	__u16 ss;
	__u16 __ssh;
	__u32 fpstate;
	__u32 oldmask;
	__u32 cr2;
};

struct tracepoint___14 {
	const char *name;
	struct static_key key;
	struct static_call_key___14 *static_call_key;
	void *static_call_tramp;
	void *iterator;
	int (*regfunc)();
	void (*unregfunc)();
	struct tracepoint_func *funcs;
};

struct bpf_raw_event_map___14 {
	struct tracepoint___14 *tp;
	void *bpf_func;
	u32 num_args;
	u32 writable_size;
	long: 64;
};

struct seq_operations___18 {
	void * (*start)(struct seq_file___18 *, loff_t *);
	void (*stop)(struct seq_file___18 *, void *);
	void * (*next)(struct seq_file___18 *, void *, loff_t *);
	int (*show)(struct seq_file___18 *, void *);
};

struct hw_perf_event___12 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___23 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	union {
		struct {
			u64 last_period;
			local64_t period_left;
		};
		struct {
			u64 saved_metric;
			u64 saved_slots;
		};
	};
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___12)(struct perf_event___12 *, struct perf_sample_data *, struct pt_regs *);

struct pmu___12;

struct fasync_struct___20;

struct pid_namespace___18;

struct trace_event_call___12;

struct perf_cgroup___12;

struct perf_event___12 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___12 *group_leader;
	struct pmu___12 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___12 hw;
	struct perf_event_context___12 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___12 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___23 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct perf_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___20 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	long unsigned int pending_addr;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	struct perf_addr_filter_range *addr_filter_ranges;
	long unsigned int addr_filters_gen;
	struct perf_event___12 *aux_event;
	void (*destroy)(struct perf_event___12 *);
	struct callback_head callback_head;
	struct pid_namespace___18 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___12 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___12 orig_overflow_handler;
	struct bpf_prog *prog;
	u64 bpf_cookie;
	struct trace_event_call___12 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___12 *cgrp;
	void *security;
	struct list_head sb_list;
};

struct upid___18 {
	int nr;
	struct pid_namespace___18 *ns;
};

struct pid_namespace___18 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___23 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___18 *parent;
	struct fs_pin *bacct;
	struct user_namespace *user_ns;
	struct ucounts *ucounts;
	int reboot;
	struct ns_common ns;
};

struct pid___18 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___18 numbers[1];
};

struct signal_struct___21 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___23 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___23 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper;
	unsigned int has_child_subreaper;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___18 *pids[4];
	struct pid___18 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___22 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct cgroup_namespace___15;

struct nsproxy___19 {
	atomic_t count;
	struct uts_namespace *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___18 *pid_ns_for_children;
	struct net *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___15 *cgroup_ns;
};

struct cgroup_subsys_state___15;

struct cgroup___15;

struct css_set___15 {
	struct cgroup_subsys_state___15 *subsys[14];
	refcount_t refcount;
	struct css_set___15 *dom_cset;
	struct cgroup___15 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___15 *mg_src_cgrp;
	struct cgroup___15 *mg_dst_cgrp;
	struct css_set___15 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___12 {
	struct pmu___12 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	int rotate_necessary;
	refcount_t refcount;
	struct task_struct___23 *task;
	u64 time;
	u64 timestamp;
	u64 timeoffset;
	struct perf_event_context___12 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

struct address_space_operations___20;

struct address_space___20 {
	struct inode___20 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___20 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct dev_pagemap_ops___20;

struct dev_pagemap___20 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___20 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vfsmount___20;

struct path___20 {
	struct vfsmount___20 *mnt;
	struct dentry___20 *dentry;
};

struct fown_struct___18 {
	rwlock_t lock;
	struct pid___18 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___20 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	long: 64;
	long: 64;
	struct path___20 f_path;
	struct inode___20 *f_inode;
	const struct file_operations___20 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___18 f_owner;
	const struct cred *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___20 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___20;

struct vm_operations_struct___20 {
	void (*open)(struct vm_area_struct___22 *);
	void (*close)(struct vm_area_struct___22 *);
	int (*may_split)(struct vm_area_struct___22 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___22 *);
	int (*mprotect)(struct vm_area_struct___22 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___20 *);
	vm_fault_t (*huge_fault)(struct vm_fault___20 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___20 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___22 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___20 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___20 *);
	int (*access)(struct vm_area_struct___22 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___22 *);
	int (*set_policy)(struct vm_area_struct___22 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___22 *, long unsigned int);
	struct page___21 * (*find_special_page)(struct vm_area_struct___22 *, long unsigned int);
};

struct core_thread___21 {
	struct task_struct___23 *task;
	struct core_thread___21 *next;
};

struct core_state___21 {
	atomic_t nr_threads;
	struct core_thread___21 dumper;
	struct completion startup;
};

struct linux_binprm___3;

struct coredump_params___2;

struct linux_binfmt___2 {
	struct list_head lh;
	struct module___19 *module;
	int (*load_binary)(struct linux_binprm___3 *);
	int (*load_shlib)(struct file___20 *);
	int (*core_dump)(struct coredump_params___2 *);
	long unsigned int min_coredump;
};

struct vm_fault___20 {
	const struct {
		struct vm_area_struct___22 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___21 *cow_page;
	struct page___21 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___21 prealloc_pte;
};

struct dev_pagemap_ops___20 {
	void (*page_free)(struct page___21 *);
	void (*kill)(struct dev_pagemap___20 *);
	void (*cleanup)(struct dev_pagemap___20 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___20 *);
};

struct dentry_operations___20;

struct dentry___20 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___20 *d_parent;
	struct qstr d_name;
	struct inode___20 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___20 *d_op;
	struct super_block___20 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___20;

struct inode___20 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___20 *i_op;
	struct super_block___20 *i_sb;
	struct address_space___20 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	long: 64;
	long: 64;
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___20 *i_fop;
		void (*free_inode)(struct inode___20 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___20 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___20 {
	int (*d_revalidate)(struct dentry___20 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___20 *, unsigned int);
	int (*d_hash)(const struct dentry___20 *, struct qstr *);
	int (*d_compare)(const struct dentry___20 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___20 *);
	int (*d_init)(struct dentry___20 *);
	void (*d_release)(struct dentry___20 *);
	void (*d_prune)(struct dentry___20 *);
	void (*d_iput)(struct dentry___20 *, struct inode___20 *);
	char * (*d_dname)(struct dentry___20 *, char *, int);
	struct vfsmount___20 * (*d_automount)(struct path___20 *);
	int (*d_manage)(const struct path___20 *, bool);
	struct dentry___20 * (*d_real)(struct dentry___20 *, const struct inode___20 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___20;

struct mem_dqinfo___20 {
	struct quota_format_type___20 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___20;

struct quota_info___20 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___20 *files[3];
	struct mem_dqinfo___20 info[3];
	const struct quota_format_ops___20 *ops[3];
};

struct rcuwait___20 {
	struct task_struct___23 *task;
};

struct percpu_rw_semaphore___20 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___20 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___20 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___20 rw_sem[3];
};

struct super_operations___20;

struct dquot_operations___20;

struct quotactl_ops___20;

struct super_block___20 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___20 *s_type;
	const struct super_operations___20 *s_op;
	const struct dquot_operations___20 *dq_op;
	const struct quotactl_ops___20 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___20 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device *s_bdev;
	struct backing_dev_info *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___20 s_dquot;
	struct sb_writers___20 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___20 *s_d_op;
	int cleancache_poolid;
	struct shrinker___4 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___20 {
	struct dentry___20 *mnt_root;
	struct super_block___20 *mnt_sb;
	int mnt_flags;
	struct user_namespace *mnt_userns;
};

struct cgroup_subsys___15;

struct cgroup_subsys_state___15 {
	struct cgroup___15 *cgroup;
	struct cgroup_subsys___15 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___15 *parent;
};

struct kernfs_node___20;

struct cgroup_file___15 {
	struct kernfs_node___20 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct psi_group___15 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___23 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___15;

struct cgroup_rstat_cpu___15;

struct cgroup___15 {
	struct cgroup_subsys_state___15 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___20 *kn;
	struct cgroup_file___15 procs_file;
	struct cgroup_file___15 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___15 *subsys[14];
	struct cgroup_root___15 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___15 *dom_cgrp;
	struct cgroup___15 *old_dom_cgrp;
	struct cgroup_rstat_cpu___15 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___15 psi;
	struct cgroup_bpf bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct kiocb___20 {
	struct file___20 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___20 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___3 *ki_waitq;
	};
};

struct iattr___20 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___20 *ia_file;
};

struct dquot___20 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___20 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___20 {
	int qf_fmt_id;
	const struct quota_format_ops___20 *qf_ops;
	struct module___19 *qf_owner;
	struct quota_format_type___20 *qf_next;
};

struct quota_format_ops___20 {
	int (*check_quota_file)(struct super_block___20 *, int);
	int (*read_file_info)(struct super_block___20 *, int);
	int (*write_file_info)(struct super_block___20 *, int);
	int (*free_file_info)(struct super_block___20 *, int);
	int (*read_dqblk)(struct dquot___20 *);
	int (*commit_dqblk)(struct dquot___20 *);
	int (*release_dqblk)(struct dquot___20 *);
	int (*get_next_id)(struct super_block___20 *, struct kqid *);
};

struct dquot_operations___20 {
	int (*write_dquot)(struct dquot___20 *);
	struct dquot___20 * (*alloc_dquot)(struct super_block___20 *, int);
	void (*destroy_dquot)(struct dquot___20 *);
	int (*acquire_dquot)(struct dquot___20 *);
	int (*release_dquot)(struct dquot___20 *);
	int (*mark_dirty)(struct dquot___20 *);
	int (*write_info)(struct super_block___20 *, int);
	qsize_t * (*get_reserved_space)(struct inode___20 *);
	int (*get_projid)(struct inode___20 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___20 *, qsize_t *);
	int (*get_next_id)(struct super_block___20 *, struct kqid *);
};

struct quotactl_ops___20 {
	int (*quota_on)(struct super_block___20 *, int, int, const struct path___20 *);
	int (*quota_off)(struct super_block___20 *, int);
	int (*quota_enable)(struct super_block___20 *, unsigned int);
	int (*quota_disable)(struct super_block___20 *, unsigned int);
	int (*quota_sync)(struct super_block___20 *, int);
	int (*set_info)(struct super_block___20 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___20 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___20 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___20 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___20 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___20 *, unsigned int);
};

struct kset___19;

struct kobj_type___19;

struct kobject___20 {
	const char *name;
	struct list_head entry;
	struct kobject___20 *parent;
	struct kset___19 *kset;
	struct kobj_type___19 *ktype;
	struct kernfs_node___20 *sd;
	struct kref kref;
	unsigned int state_initialized;
	unsigned int state_in_sysfs;
	unsigned int state_add_uevent_sent;
	unsigned int state_remove_uevent_sent;
	unsigned int uevent_suppress;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___19 {
	struct kobject___20 kobj;
	struct module___19 *mod;
	struct kobject___20 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___19 {
	struct module___19 *mod;
	struct latch_tree_node node;
};

struct module_layout___19 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___19 mtn;
};

struct module_attribute___19;

struct kernel_param___19;

struct module___19 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___19 mkobj;
	struct module_attribute___19 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___20 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___19 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___19 core_layout;
	struct module_layout___19 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map___14 *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___12 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	int num_static_call_sites;
	struct static_call_site *static_call_sites;
	bool klp;
	bool klp_alive;
	struct klp_modinfo *klp_info;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct address_space_operations___20 {
	int (*writepage)(struct page___21 *, struct writeback_control *);
	int (*readpage)(struct file___20 *, struct page___21 *);
	int (*writepages)(struct address_space___20 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___21 *);
	int (*readpages)(struct file___20 *, struct address_space___20 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control *);
	int (*write_begin)(struct file___20 *, struct address_space___20 *, loff_t, unsigned int, unsigned int, struct page___21 **, void **);
	int (*write_end)(struct file___20 *, struct address_space___20 *, loff_t, unsigned int, unsigned int, struct page___21 *, void *);
	sector_t (*bmap)(struct address_space___20 *, sector_t);
	void (*invalidatepage)(struct page___21 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___21 *, gfp_t);
	void (*freepage)(struct page___21 *);
	ssize_t (*direct_IO)(struct kiocb___20 *, struct iov_iter___6 *);
	int (*migratepage)(struct address_space___20 *, struct page___21 *, struct page___21 *, enum migrate_mode);
	bool (*isolate_page)(struct page___21 *, isolate_mode_t);
	void (*putback_page)(struct page___21 *);
	int (*launder_page)(struct page___21 *);
	int (*is_partially_uptodate)(struct page___21 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___21 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___20 *, struct page___21 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___20 *, sector_t *);
	void (*swap_deactivate)(struct file___20 *);
};

struct inode_operations___20 {
	struct dentry___20 * (*lookup)(struct inode___20 *, struct dentry___20 *, unsigned int);
	const char * (*get_link)(struct dentry___20 *, struct inode___20 *, struct delayed_call *);
	int (*permission)(struct user_namespace *, struct inode___20 *, int);
	struct posix_acl * (*get_acl)(struct inode___20 *, int, bool);
	int (*readlink)(struct dentry___20 *, char *, int);
	int (*create)(struct user_namespace *, struct inode___20 *, struct dentry___20 *, umode_t, bool);
	int (*link)(struct dentry___20 *, struct inode___20 *, struct dentry___20 *);
	int (*unlink)(struct inode___20 *, struct dentry___20 *);
	int (*symlink)(struct user_namespace *, struct inode___20 *, struct dentry___20 *, const char *);
	int (*mkdir)(struct user_namespace *, struct inode___20 *, struct dentry___20 *, umode_t);
	int (*rmdir)(struct inode___20 *, struct dentry___20 *);
	int (*mknod)(struct user_namespace *, struct inode___20 *, struct dentry___20 *, umode_t, dev_t);
	int (*rename)(struct user_namespace *, struct inode___20 *, struct dentry___20 *, struct inode___20 *, struct dentry___20 *, unsigned int);
	int (*setattr)(struct user_namespace *, struct dentry___20 *, struct iattr___20 *);
	int (*getattr)(struct user_namespace *, const struct path___20 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___20 *, char *, size_t);
	int (*fiemap)(struct inode___20 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___20 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___20 *, struct dentry___20 *, struct file___20 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace *, struct inode___20 *, struct dentry___20 *, umode_t);
	int (*set_acl)(struct user_namespace *, struct inode___20 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace *, struct dentry___20 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___20 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___20 {
	void (*fl_copy_lock)(struct file_lock___20 *, struct file_lock___20 *);
	void (*fl_release_private)(struct file_lock___20 *);
};

struct lock_manager_operations___20;

struct file_lock___20 {
	struct file_lock___20 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___20 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___20 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___20 *fl_ops;
	const struct lock_manager_operations___20 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___20 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___20 *);
	int (*lm_grant)(struct file_lock___20 *, int);
	bool (*lm_break)(struct file_lock___20 *);
	int (*lm_change)(struct file_lock___20 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___20 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___20 *);
};

struct fasync_struct___20 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___20 *fa_next;
	struct file___20 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___20 {
	struct inode___20 * (*alloc_inode)(struct super_block___20 *);
	void (*destroy_inode)(struct inode___20 *);
	void (*free_inode)(struct inode___20 *);
	void (*dirty_inode)(struct inode___20 *, int);
	int (*write_inode)(struct inode___20 *, struct writeback_control *);
	int (*drop_inode)(struct inode___20 *);
	void (*evict_inode)(struct inode___20 *);
	void (*put_super)(struct super_block___20 *);
	int (*sync_fs)(struct super_block___20 *, int);
	int (*freeze_super)(struct super_block___20 *);
	int (*freeze_fs)(struct super_block___20 *);
	int (*thaw_super)(struct super_block___20 *);
	int (*unfreeze_fs)(struct super_block___20 *);
	int (*statfs)(struct dentry___20 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___20 *, int *, char *);
	void (*umount_begin)(struct super_block___20 *);
	int (*show_options)(struct seq_file___18 *, struct dentry___20 *);
	int (*show_devname)(struct seq_file___18 *, struct dentry___20 *);
	int (*show_path)(struct seq_file___18 *, struct dentry___20 *);
	int (*show_stats)(struct seq_file___18 *, struct dentry___20 *);
	ssize_t (*quota_read)(struct super_block___20 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___20 *, int, const char *, size_t, loff_t);
	struct dquot___20 ** (*get_dquots)(struct inode___20 *);
	long int (*nr_cached_objects)(struct super_block___20 *, struct shrink_control___4 *);
	long int (*free_cached_objects)(struct super_block___20 *, struct shrink_control___4 *);
	struct file___20 * (*real_loop)(struct file___20 *);
};

typedef void (*poll_queue_proc___14)(struct file___20 *, wait_queue_head_t *, struct poll_table_struct___14 *);

struct poll_table_struct___14 {
	poll_queue_proc___14 _qproc;
	__poll_t _key;
};

struct seq_file___18 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___18 *op;
	int poll_event;
	const struct file___20 *file;
	void *private;
};

struct linux_binprm___3 {
	struct vm_area_struct___22 *vma;
	long unsigned int vma_pages;
	struct mm_struct___22 *mm;
	long unsigned int p;
	long unsigned int argmin;
	unsigned int have_execfd;
	unsigned int execfd_creds;
	unsigned int secureexec;
	unsigned int point_of_no_return;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct file___20 *executable;
	struct file___20 *interpreter;
	struct file___20 *file;
	struct cred *cred;
	int unsafe;
	unsigned int per_clear;
	int argc;
	int envc;
	const char *filename;
	const char *interp;
	const char *fdpath;
	unsigned int interp_flags;
	int execfd;
	long unsigned int loader;
	long unsigned int exec;
	struct rlimit rlim_stack;
	char buf[256];
};

struct coredump_params___2 {
	const kernel_siginfo_t *siginfo;
	struct pt_regs *regs;
	struct file___20 *file;
	long unsigned int limit;
	long unsigned int mm_flags;
	loff_t written;
	loff_t pos;
	loff_t to_skip;
};

struct kernfs_root___20;

struct kernfs_elem_dir___20 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___20 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___20;

struct kernfs_root___20 {
	struct kernfs_node___20 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___20 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___20 {
	struct kernfs_node___20 *target_kn;
};

struct kernfs_ops___20;

struct kernfs_elem_attr___20 {
	const struct kernfs_ops___20 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___20 *notify_next;
};

struct kernfs_node___20 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___20 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___20 dir;
		struct kernfs_elem_symlink___20 symlink;
		struct kernfs_elem_attr___20 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___20;

struct kernfs_ops___20 {
	int (*open)(struct kernfs_open_file___20 *);
	void (*release)(struct kernfs_open_file___20 *);
	int (*seq_show)(struct seq_file___18 *, void *);
	void * (*seq_start)(struct seq_file___18 *, loff_t *);
	void * (*seq_next)(struct seq_file___18 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___18 *, void *);
	ssize_t (*read)(struct kernfs_open_file___20 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___20 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___20 *, struct poll_table_struct___14 *);
	int (*mmap)(struct kernfs_open_file___20 *, struct vm_area_struct___22 *);
};

struct kernfs_syscall_ops___20 {
	int (*show_options)(struct seq_file___18 *, struct kernfs_root___20 *);
	int (*mkdir)(struct kernfs_node___20 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___20 *);
	int (*rename)(struct kernfs_node___20 *, struct kernfs_node___20 *, const char *);
	int (*show_path)(struct seq_file___18 *, struct kernfs_node___20 *, struct kernfs_root___20 *);
};

struct kernfs_open_file___20 {
	struct kernfs_node___20 *kn;
	struct file___20 *file;
	struct seq_file___18 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped;
	bool released;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___20 *vm_ops;
};

struct bin_attribute___20;

struct attribute_group___20 {
	const char *name;
	umode_t (*is_visible)(struct kobject___20 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___20 *, struct bin_attribute___20 *, int);
	struct attribute **attrs;
	struct bin_attribute___20 **bin_attrs;
};

struct bin_attribute___20 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___20 * (*f_mapping)();
	ssize_t (*read)(struct file___20 *, struct kobject___20 *, struct bin_attribute___20 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___20 *, struct kobject___20 *, struct bin_attribute___20 *, char *, loff_t, size_t);
	int (*mmap)(struct file___20 *, struct kobject___20 *, struct bin_attribute___20 *, struct vm_area_struct___22 *);
};

struct sysfs_ops___19 {
	ssize_t (*show)(struct kobject___20 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___20 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___19;

struct kset___19 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___20 kobj;
	const struct kset_uevent_ops___19 *uevent_ops;
};

struct kobj_type___19 {
	void (*release)(struct kobject___20 *);
	const struct sysfs_ops___19 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___20 **default_groups;
	const struct kobj_ns_type_operations * (*child_ns_type)(struct kobject___20 *);
	const void * (*namespace)(struct kobject___20 *);
	void (*get_ownership)(struct kobject___20 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___19 {
	int (* const filter)(struct kset___19 *, struct kobject___20 *);
	const char * (* const name)(struct kset___19 *, struct kobject___20 *);
	int (* const uevent)(struct kset___19 *, struct kobject___20 *, struct kobj_uevent_env *);
};

struct wakeup_source___22;

struct device___22;

struct dev_pm_info___22 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___22 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___22 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___22;

struct bus_type___22;

struct device_driver___22;

struct dev_pm_domain___22;

struct class___22;

struct device___22 {
	struct kobject___20 kobj;
	struct device___22 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___22 *type;
	struct bus_type___22 *bus;
	struct device_driver___22 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___22 power;
	struct dev_pm_domain___22 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node *of_node;
	struct fwnode_handle___5 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___22 *class;
	const struct attribute_group___20 **groups;
	void (*release)(struct device___22 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_ops___22 {
	int (*prepare)(struct device___22 *);
	void (*complete)(struct device___22 *);
	int (*suspend)(struct device___22 *);
	int (*resume)(struct device___22 *);
	int (*freeze)(struct device___22 *);
	int (*thaw)(struct device___22 *);
	int (*poweroff)(struct device___22 *);
	int (*restore)(struct device___22 *);
	int (*suspend_late)(struct device___22 *);
	int (*resume_early)(struct device___22 *);
	int (*freeze_late)(struct device___22 *);
	int (*thaw_early)(struct device___22 *);
	int (*poweroff_late)(struct device___22 *);
	int (*restore_early)(struct device___22 *);
	int (*suspend_noirq)(struct device___22 *);
	int (*resume_noirq)(struct device___22 *);
	int (*freeze_noirq)(struct device___22 *);
	int (*thaw_noirq)(struct device___22 *);
	int (*poweroff_noirq)(struct device___22 *);
	int (*restore_noirq)(struct device___22 *);
	int (*runtime_suspend)(struct device___22 *);
	int (*runtime_resume)(struct device___22 *);
	int (*runtime_idle)(struct device___22 *);
};

struct wakeup_source___22 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___22 *dev;
	bool active;
	bool autosleep_enabled;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___22 {
	struct dev_pm_ops___22 ops;
	int (*start)(struct device___22 *);
	void (*detach)(struct device___22 *, bool);
	int (*activate)(struct device___22 *);
	void (*sync)(struct device___22 *);
	void (*dismiss)(struct device___22 *);
};

struct bus_type___22 {
	const char *name;
	const char *dev_name;
	struct device___22 *dev_root;
	const struct attribute_group___20 **bus_groups;
	const struct attribute_group___20 **dev_groups;
	const struct attribute_group___20 **drv_groups;
	int (*match)(struct device___22 *, struct device_driver___22 *);
	int (*uevent)(struct device___22 *, struct kobj_uevent_env *);
	int (*probe)(struct device___22 *);
	void (*sync_state)(struct device___22 *);
	void (*remove)(struct device___22 *);
	void (*shutdown)(struct device___22 *);
	int (*online)(struct device___22 *);
	int (*offline)(struct device___22 *);
	int (*suspend)(struct device___22 *, pm_message_t);
	int (*resume)(struct device___22 *);
	int (*num_vf)(struct device___22 *);
	int (*dma_configure)(struct device___22 *);
	const struct dev_pm_ops___22 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___22 {
	const char *name;
	struct bus_type___22 *bus;
	struct module___19 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___22 *);
	void (*sync_state)(struct device___22 *);
	int (*remove)(struct device___22 *);
	void (*shutdown)(struct device___22 *);
	int (*suspend)(struct device___22 *, pm_message_t);
	int (*resume)(struct device___22 *);
	const struct attribute_group___20 **groups;
	const struct attribute_group___20 **dev_groups;
	const struct dev_pm_ops___22 *pm;
	void (*coredump)(struct device___22 *);
	struct driver_private *p;
};

struct device_type___22 {
	const char *name;
	const struct attribute_group___20 **groups;
	int (*uevent)(struct device___22 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___22 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___22 *);
	const struct dev_pm_ops___22 *pm;
};

struct class___22 {
	const char *name;
	struct module___19 *owner;
	const struct attribute_group___20 **class_groups;
	const struct attribute_group___20 **dev_groups;
	struct kobject___20 *dev_kobj;
	int (*dev_uevent)(struct device___22 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___22 *, umode_t *);
	void (*class_release)(struct class___22 *);
	void (*dev_release)(struct device___22 *);
	int (*shutdown_pre)(struct device___22 *);
	const struct kobj_ns_type_operations *ns_type;
	const void * (*namespace)(struct device___22 *);
	void (*get_ownership)(struct device___22 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___22 *pm;
	struct subsys_private *p;
};

struct cgroup_namespace___15 {
	struct ns_common ns;
	struct user_namespace *user_ns;
	struct ucounts *ucounts;
	struct css_set___15 *root_cset;
};

struct perf_cpu_context___12;

struct perf_output_handle___12;

struct pmu___12 {
	struct list_head entry;
	struct module___19 *module;
	struct device___22 *dev;
	const struct attribute_group___20 **attr_groups;
	const struct attribute_group___20 **attr_update;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___12 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___12 *);
	void (*pmu_disable)(struct pmu___12 *);
	int (*event_init)(struct perf_event___12 *);
	void (*event_mapped)(struct perf_event___12 *, struct mm_struct___22 *);
	void (*event_unmapped)(struct perf_event___12 *, struct mm_struct___22 *);
	int (*add)(struct perf_event___12 *, int);
	void (*del)(struct perf_event___12 *, int);
	void (*start)(struct perf_event___12 *, int);
	void (*stop)(struct perf_event___12 *, int);
	void (*read)(struct perf_event___12 *);
	void (*start_txn)(struct pmu___12 *, unsigned int);
	int (*commit_txn)(struct pmu___12 *);
	void (*cancel_txn)(struct pmu___12 *);
	int (*event_idx)(struct perf_event___12 *);
	void (*sched_task)(struct perf_event_context___12 *, bool);
	struct kmem_cache *task_ctx_cache;
	void (*swap_task_ctx)(struct perf_event_context___12 *, struct perf_event_context___12 *);
	void * (*setup_aux)(struct perf_event___12 *, void **, int, bool);
	void (*free_aux)(void *);
	long int (*snapshot_aux)(struct perf_event___12 *, struct perf_output_handle___12 *, long unsigned int);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___12 *);
	int (*aux_output_match)(struct perf_event___12 *);
	int (*filter_match)(struct perf_event___12 *);
	int (*check_period)(struct perf_event___12 *, u64);
};

struct kernel_param_ops___19 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___19 *);
	int (*get)(char *, const struct kernel_param___19 *);
	void (*free)(void *);
};

struct kparam_array___19;

struct kernel_param___19 {
	const char *name;
	struct module___19 *mod;
	const struct kernel_param_ops___19 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___19 *arr;
	};
};

struct kparam_array___19 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___19 *ops;
	void *elem;
};

struct module_attribute___19 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___19 *, struct module_kobject___19 *, char *);
	ssize_t (*store)(struct module_attribute___19 *, struct module_kobject___19 *, const char *, size_t);
	void (*setup)(struct module___19 *, const char *);
	int (*test)(struct module___19 *);
	void (*free)(struct module___19 *);
};

struct trace_event_class___12;

struct trace_event_call___12 {
	struct list_head list;
	struct trace_event_class___12 *class;
	union {
		char *name;
		struct tracepoint___14 *tp;
	};
	struct trace_event event;
	char *print_fmt;
	struct event_filter *filter;
	union {
		void *module;
		atomic_t refcnt;
	};
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
	struct bpf_prog_array *prog_array;
	int (*perf_perm)(struct trace_event_call___12 *, struct perf_event___12 *);
};

struct cftype___15;

struct cgroup_subsys___15 {
	struct cgroup_subsys_state___15 * (*css_alloc)(struct cgroup_subsys_state___15 *);
	int (*css_online)(struct cgroup_subsys_state___15 *);
	void (*css_offline)(struct cgroup_subsys_state___15 *);
	void (*css_released)(struct cgroup_subsys_state___15 *);
	void (*css_free)(struct cgroup_subsys_state___15 *);
	void (*css_reset)(struct cgroup_subsys_state___15 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___15 *, int);
	int (*css_extra_stat_show)(struct seq_file___18 *, struct cgroup_subsys_state___15 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___23 *, struct css_set___15 *);
	void (*cancel_fork)(struct task_struct___23 *, struct css_set___15 *);
	void (*fork)(struct task_struct___23 *);
	void (*exit)(struct task_struct___23 *);
	void (*release)(struct task_struct___23 *);
	void (*bind)(struct cgroup_subsys_state___15 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___15 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___15 *dfl_cftypes;
	struct cftype___15 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___15 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___15 *updated_children;
	struct cgroup___15 *updated_next;
};

struct cgroup_root___15 {
	struct kernfs_root___20 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___15 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___15 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___15 *ss;
	struct list_head node;
	struct kernfs_ops___20 *kf_ops;
	int (*open)(struct kernfs_open_file___20 *);
	void (*release)(struct kernfs_open_file___20 *);
	u64 (*read_u64)(struct cgroup_subsys_state___15 *, struct cftype___15 *);
	s64 (*read_s64)(struct cgroup_subsys_state___15 *, struct cftype___15 *);
	int (*seq_show)(struct seq_file___18 *, void *);
	void * (*seq_start)(struct seq_file___18 *, loff_t *);
	void * (*seq_next)(struct seq_file___18 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___18 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___15 *, struct cftype___15 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___15 *, struct cftype___15 *, s64);
	ssize_t (*write)(struct kernfs_open_file___20 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___20 *, struct poll_table_struct___14 *);
};

struct perf_cpu_context___12 {
	struct perf_event_context___12 ctx;
	struct perf_event_context___12 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___12 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
	int heap_size;
	struct perf_event___12 **heap;
	struct perf_event___12 *heap_default[2];
};

struct perf_output_handle___12 {
	struct perf_event___12 *event;
	struct perf_buffer *rb;
	long unsigned int wakeup;
	long unsigned int size;
	u64 aux_flags;
	union {
		void *addr;
		long unsigned int head;
	};
	int page;
};

struct perf_cgroup___12 {
	struct cgroup_subsys_state___15 css;
	struct perf_cgroup_info *info;
};

struct trace_event_fields___12 {
	const char *type;
	union {
		struct {
			const char *name;
			const int size;
			const int align;
			const int is_signed;
			const int filter_type;
		};
		int (*define_fields)(struct trace_event_call___12 *);
	};
};

struct trace_event_class___12 {
	const char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct trace_event_call___12 *, enum trace_reg, void *);
	struct trace_event_fields___12 *fields_array;
	struct list_head * (*get_fields)(struct trace_event_call___12 *);
	struct list_head fields;
	int (*raw_init)(struct trace_event_call___12 *);
};

struct ucontext_ia32 {
	unsigned int uc_flags;
	unsigned int uc_link;
	compat_stack_t uc_stack;
	struct sigcontext_32 uc_mcontext;
	compat_sigset_t uc_sigmask;
};

struct sigframe_ia32 {
	u32 pretcode;
	int sig;
	struct sigcontext_32 sc;
	struct _fpstate_32 fpstate_unused;
	unsigned int extramask[1];
	char retcode[8];
};

struct rt_sigframe_ia32 {
	u32 pretcode;
	int sig;
	u32 pinfo;
	u32 puc;
	compat_siginfo_t info;
	struct ucontext_ia32 uc;
	char retcode[8];
} __attribute__((packed));

typedef struct {
	efi_guid_t guid;
	u64 table;
} efi_config_table_64_t;

struct efi_memory_map_data {
	phys_addr_t phys_map;
	long unsigned int size;
	long unsigned int desc_version;
	long unsigned int desc_size;
	long unsigned int flags;
};

struct efi_mem_range {
	struct range range;
	u64 attribute;
};

enum efi_rts_ids {
	EFI_NONE = 0,
	EFI_GET_TIME = 1,
	EFI_SET_TIME = 2,
	EFI_GET_WAKEUP_TIME = 3,
	EFI_SET_WAKEUP_TIME = 4,
	EFI_GET_VARIABLE = 5,
	EFI_GET_NEXT_VARIABLE = 6,
	EFI_SET_VARIABLE = 7,
	EFI_QUERY_VARIABLE_INFO = 8,
	EFI_GET_NEXT_HIGH_MONO_COUNT = 9,
	EFI_RESET_SYSTEM = 10,
	EFI_UPDATE_CAPSULE = 11,
	EFI_QUERY_CAPSULE_CAPS = 12,
};

struct efi_runtime_work {
	void *arg1;
	void *arg2;
	void *arg3;
	void *arg4;
	void *arg5;
	efi_status_t status;
	struct work_struct work;
	enum efi_rts_ids efi_rts_id;
	struct completion efi_rts_comp;
};

struct dentry___21;

struct super_block___21;

struct module___20;

struct file_system_type___21 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___21 * (*mount)(struct file_system_type___21 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___21 *);
	struct module___20 *owner;
	struct file_system_type___21 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___21;

struct kiocb___21;

struct iov_iter___16;

struct poll_table_struct___15;

struct vm_area_struct___23;

struct inode___21;

struct file_lock___21;

struct page___22;

struct seq_file___19;

struct file_operations___21 {
	struct module___20 *owner;
	loff_t (*llseek)(struct file___21 *, loff_t, int);
	ssize_t (*read)(struct file___21 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___21 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___21 *, struct iov_iter___16 *);
	ssize_t (*write_iter)(struct kiocb___21 *, struct iov_iter___16 *);
	int (*iopoll)(struct kiocb___21 *, bool);
	int (*iterate)(struct file___21 *, struct dir_context *);
	int (*iterate_shared)(struct file___21 *, struct dir_context *);
	__poll_t (*poll)(struct file___21 *, struct poll_table_struct___15 *);
	long int (*unlocked_ioctl)(struct file___21 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___21 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___21 *, struct vm_area_struct___23 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___21 *, struct file___21 *);
	int (*flush)(struct file___21 *, fl_owner_t);
	int (*release)(struct inode___21 *, struct file___21 *);
	int (*fsync)(struct file___21 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___21 *, int);
	int (*lock)(struct file___21 *, int, struct file_lock___21 *);
	ssize_t (*sendpage)(struct file___21 *, struct page___22 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___21 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___21 *, long unsigned int);
	int (*flock)(struct file___21 *, int, struct file_lock___21 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___21 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___21 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___21 *, long int, struct file_lock___21 **, void **);
	long int (*fallocate)(struct file___21 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___19 *, struct file___21 *);
	ssize_t (*copy_file_range)(struct file___21 *, loff_t, struct file___21 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___21 *, loff_t, struct file___21 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___21 *, loff_t, loff_t, int);
};

struct static_call_mod___15 {
	struct static_call_mod___15 *next;
	struct module___20 *mod;
	struct static_call_site *sites;
};

struct static_call_key___15 {
	void *func;
	union {
		long unsigned int type;
		struct static_call_mod___15 *mods;
		struct static_call_site *sites;
	};
};

typedef struct page___22 *pgtable_t___22;

struct address_space___21;

struct mm_struct___23;

struct dev_pagemap___21;

struct page___22 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___21 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___2 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___22 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___22 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___23 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___21 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vmacache___22 {
	u64 seqnum;
	struct vm_area_struct___23 *vmas[4];
};

struct page_frag___22 {
	struct page___22 *page;
	__u32 offset;
	__u32 size;
};

struct nsproxy___20;

struct signal_struct___22;

struct bio_list___13;

struct backing_dev_info___12;

struct io_context___14;

struct css_set___16;

struct mem_cgroup___12;

struct request_queue___13;

struct vm_struct___18;

struct task_struct___24 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___24 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___23 *mm;
	struct mm_struct___23 *active_mm;
	struct vmacache___22 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int restore_sigmask: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___24 *real_parent;
	struct task_struct___24 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___24 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___18 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	struct posix_cputimers_work posix_cputimers_work;
	const struct cred *ptracer_cred;
	const struct cred *real_cred;
	const struct cred *cred;
	struct key *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___20 *nsproxy;
	struct signal_struct___22 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___24 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___13 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___12 *backing_dev_info;
	struct io_context___14 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___16 *cgroups;
	struct list_head cg_list;
	u32 closid;
	u32 rmid;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	struct pipe_inode_info *splice_pipe;
	struct page_frag___22 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___12 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___12 *active_memcg;
	struct request_queue___13 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___24 *oom_reaper_list;
	struct vm_struct___18 *stack_vm_area;
	refcount_t stack_refcount;
	int patch_state;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	void *mce_vaddr;
	__u64 mce_kflags;
	u64 mce_addr;
	__u64 mce_ripv: 1;
	__u64 mce_whole_page: 1;
	__u64 __mce_reserved: 62;
	long: 2;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct callback_head mce_kill_me;
	int mce_count;
	struct llist_head kretprobe_instances;
	struct callback_head l1d_flush_kill;
	long: 64;
	struct thread_struct___13 thread;
};

struct core_state___22;

struct mm_struct___23 {
	struct {
		struct vm_area_struct___23 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___21 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int mmap_compat_base;
		long unsigned int mmap_compat_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[48];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___22 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___24 *owner;
		struct user_namespace *user_ns;
		struct file___21 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		bool tlb_flush_batched;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct vm_operations_struct___21;

struct vm_area_struct___23 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___23 *vm_next;
	struct vm_area_struct___23 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___23 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___21 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___21 *vm_file;
	struct file___21 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct tracepoint___15 {
	const char *name;
	struct static_key key;
	struct static_call_key___15 *static_call_key;
	void *static_call_tramp;
	void *iterator;
	int (*regfunc)();
	void (*unregfunc)();
	struct tracepoint_func *funcs;
};

struct bpf_raw_event_map___15 {
	struct tracepoint___15 *tp;
	void *bpf_func;
	u32 num_args;
	u32 writable_size;
	long: 64;
};

struct seq_operations___19 {
	void * (*start)(struct seq_file___19 *, loff_t *);
	void (*stop)(struct seq_file___19 *, void *);
	void * (*next)(struct seq_file___19 *, void *, loff_t *);
	int (*show)(struct seq_file___19 *, void *);
};

struct dentry_operations___21;

struct dentry___21 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___21 *d_parent;
	struct qstr d_name;
	struct inode___21 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___21 *d_op;
	struct super_block___21 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct address_space_operations___21;

struct address_space___21 {
	struct inode___21 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___21 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct inode_operations___21;

struct bdi_writeback___12;

struct cdev___9;

struct inode___21 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___21 *i_op;
	struct super_block___21 *i_sb;
	struct address_space___21 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___12 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___21 *i_fop;
		void (*free_inode)(struct inode___21 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___21 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct cdev___9 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct vfsmount___21;

struct path___21;

struct dentry_operations___21 {
	int (*d_revalidate)(struct dentry___21 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___21 *, unsigned int);
	int (*d_hash)(const struct dentry___21 *, struct qstr *);
	int (*d_compare)(const struct dentry___21 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___21 *);
	int (*d_init)(struct dentry___21 *);
	void (*d_release)(struct dentry___21 *);
	void (*d_prune)(struct dentry___21 *);
	void (*d_iput)(struct dentry___21 *, struct inode___21 *);
	char * (*d_dname)(struct dentry___21 *, char *, int);
	struct vfsmount___21 * (*d_automount)(struct path___21 *);
	int (*d_manage)(const struct path___21 *, bool);
	struct dentry___21 * (*d_real)(struct dentry___21 *, const struct inode___21 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___21;

struct mem_dqinfo___21 {
	struct quota_format_type___21 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___21;

struct quota_info___21 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___21 *files[3];
	struct mem_dqinfo___21 info[3];
	const struct quota_format_ops___21 *ops[3];
};

struct rcuwait___21 {
	struct task_struct___24 *task;
};

struct percpu_rw_semaphore___21 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___21 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___21 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___21 rw_sem[3];
};

struct shrink_control___12;

struct shrinker___12 {
	long unsigned int (*count_objects)(struct shrinker___12 *, struct shrink_control___12 *);
	long unsigned int (*scan_objects)(struct shrinker___12 *, struct shrink_control___12 *);
	long int batch;
	int seeks;
	unsigned int flags;
	struct list_head list;
	int id;
	atomic_long_t *nr_deferred;
};

struct super_operations___21;

struct dquot_operations___21;

struct quotactl_ops___21;

struct block_device___13;

struct super_block___21 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___21 *s_type;
	const struct super_operations___21 *s_op;
	const struct dquot_operations___21 *dq_op;
	const struct quotactl_ops___21 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___21 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___13 *s_bdev;
	struct backing_dev_info___12 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___21 s_dquot;
	struct sb_writers___21 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___21 *s_d_op;
	int cleancache_poolid;
	struct shrinker___12 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___21 {
	struct dentry___21 *mnt_root;
	struct super_block___21 *mnt_sb;
	int mnt_flags;
	struct user_namespace *mnt_userns;
};

struct path___21 {
	struct vfsmount___21 *mnt;
	struct dentry___21 *dentry;
};

struct shrink_control___12 {
	gfp_t gfp_mask;
	int nid;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	struct mem_cgroup___12 *memcg;
};

struct cgroup___16;

struct cgroup_subsys___16;

struct cgroup_subsys_state___16 {
	struct cgroup___16 *cgroup;
	struct cgroup_subsys___16 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___16 *parent;
};

struct kernfs_node___21;

struct cgroup_file___16 {
	struct kernfs_node___21 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct obj_cgroup___12;

struct mem_cgroup_per_node___12;

struct mem_cgroup___12 {
	struct cgroup_subsys_state___16 css;
	struct mem_cgroup_id id;
	struct page_counter memory;
	union {
		struct page_counter swap;
		struct page_counter memsw;
	};
	struct page_counter kmem;
	struct page_counter tcpmem;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool oom_group;
	bool oom_lock;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___16 events_file;
	struct cgroup_file___16 events_local_file;
	struct cgroup_file___16 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	struct memcg_vmstats vmstats;
	atomic_long_t memory_events[8];
	atomic_long_t memory_events_local[8];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct obj_cgroup___12 *objcg;
	struct list_head objcg_list;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad2_;
	atomic_t moving_account;
	struct task_struct___24 *move_lock_task;
	struct memcg_vmstats_percpu *vmstats_percpu;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct memcg_cgwb_frn cgwb_frn[4];
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct deferred_split deferred_split_queue;
	struct mem_cgroup_per_node___12 *nodeinfo[0];
	long: 64;
};

struct dev_pagemap_ops___21;

struct dev_pagemap___21 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___21 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct file___21 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___21 f_path;
	struct inode___21 *f_inode;
	const struct file_operations___21 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___18 f_owner;
	const struct cred *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___21 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___21;

struct vm_operations_struct___21 {
	void (*open)(struct vm_area_struct___23 *);
	void (*close)(struct vm_area_struct___23 *);
	int (*may_split)(struct vm_area_struct___23 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___23 *);
	int (*mprotect)(struct vm_area_struct___23 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___21 *);
	vm_fault_t (*huge_fault)(struct vm_fault___21 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___21 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___23 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___21 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___21 *);
	int (*access)(struct vm_area_struct___23 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___23 *);
	int (*set_policy)(struct vm_area_struct___23 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___23 *, long unsigned int);
	struct page___22 * (*find_special_page)(struct vm_area_struct___23 *, long unsigned int);
};

struct core_thread___22 {
	struct task_struct___24 *task;
	struct core_thread___22 *next;
};

struct core_state___22 {
	atomic_t nr_threads;
	struct core_thread___22 dumper;
	struct completion startup;
};

struct vm_fault___21 {
	const struct {
		struct vm_area_struct___23 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___22 *cow_page;
	struct page___22 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___22 prealloc_pte;
};

struct pglist_data___13;

struct lruvec___13 {
	struct list_head lists[5];
	spinlock_t lru_lock;
	long unsigned int anon_cost;
	long unsigned int file_cost;
	atomic_long_t nonresident_age;
	long unsigned int refaults[2];
	long unsigned int flags;
	struct pglist_data___13 *pgdat;
};

struct zone___13 {
	long unsigned int _watermark[3];
	long unsigned int watermark_boost;
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[5];
	int node;
	struct pglist_data___13 *zone_pgdat;
	struct per_cpu_pages *per_cpu_pageset;
	struct per_cpu_zonestat *per_cpu_zonestats;
	int pageset_high;
	int pageset_batch;
	long unsigned int zone_start_pfn;
	atomic_long_t managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int present_early_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	seqlock_t span_seqlock;
	int initialized;
	int: 32;
	struct zone_padding _pad1_;
	struct free_area free_area[11];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	long unsigned int compact_init_migrate_pfn;
	long unsigned int compact_init_free_pfn;
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	short: 16;
	struct zone_padding _pad3_;
	atomic_long_t vm_stat[11];
	atomic_long_t vm_numa_event[6];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___13 {
	struct zone___13 *zone;
	int zone_idx;
};

struct zonelist___13 {
	struct zoneref___13 _zonerefs[5121];
};

struct pglist_data___13 {
	struct zone___13 node_zones[5];
	struct zonelist___13 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___24 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_highest_zoneidx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_highest_zoneidx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___24 *kcompactd;
	bool proactive_compact_trigger;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct deferred_split deferred_split_queue;
	struct lruvec___13 __lruvec;
	long unsigned int flags;
	long: 64;
	struct zone_padding _pad2_;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[39];
};

struct irq_domain_ops___14;

struct fwnode_handle___20;

struct irq_domain___14 {
	struct list_head link;
	const char *name;
	const struct irq_domain_ops___14 *ops;
	void *host_data;
	unsigned int flags;
	unsigned int mapcount;
	struct fwnode_handle___20 *fwnode;
	enum irq_domain_bus_token bus_token;
	struct irq_domain_chip_generic *gc;
	struct irq_domain___14 *parent;
	irq_hw_number_t hwirq_max;
	unsigned int revmap_size;
	struct xarray revmap_tree;
	struct mutex revmap_mutex;
	struct irq_data *revmap[0];
};

struct signal_struct___22 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___24 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___24 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper;
	unsigned int has_child_subreaper;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___18 *pids[4];
	struct pid___18 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___23 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct cgroup_namespace___16;

struct nsproxy___20 {
	atomic_t count;
	struct uts_namespace *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace *pid_ns_for_children;
	struct net *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___16 *cgroup_ns;
};

struct bio___13;

struct bio_list___13 {
	struct bio___13 *head;
	struct bio___13 *tail;
};

struct bdi_writeback___12 {
	struct backing_dev_info___12 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	atomic_t writeback_inodes;
	struct percpu_counter stat[4];
	long unsigned int congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	struct delayed_work bw_dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___16 *memcg_css;
	struct cgroup_subsys_state___16 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	struct list_head b_attached;
	struct list_head offline_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
};

struct device___23;

struct backing_dev_info___12 {
	u64 id;
	struct rb_node rb_node;
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___12 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct mutex cgwb_release_mutex;
	struct rw_semaphore wb_switch_rwsem;
	wait_queue_head_t wb_waitq;
	struct device___23 *dev;
	char dev_name[64];
	struct device___23 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___21 *debug_dir;
};

struct io_cq___13;

struct io_context___14 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	struct xarray icq_tree;
	struct io_cq___13 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct css_set___16 {
	struct cgroup_subsys_state___16 *subsys[14];
	refcount_t refcount;
	struct css_set___16 *dom_cset;
	struct cgroup___16 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___16 *mg_src_cgrp;
	struct cgroup___16 *mg_dst_cgrp;
	struct css_set___16 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct kset___20;

struct kobj_type___20;

struct kobject___21 {
	const char *name;
	struct list_head entry;
	struct kobject___21 *parent;
	struct kset___20 *kset;
	struct kobj_type___20 *ktype;
	struct kernfs_node___21 *sd;
	struct kref kref;
	unsigned int state_initialized;
	unsigned int state_in_sysfs;
	unsigned int state_add_uevent_sent;
	unsigned int state_remove_uevent_sent;
	unsigned int uevent_suppress;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct blk_integrity_profile___13;

struct blk_integrity___13 {
	const struct blk_integrity_profile___13 *profile;
	unsigned char flags;
	unsigned char tuple_size;
	unsigned char interval_exp;
	unsigned char tag_size;
};

struct bio_set___13 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	struct bio_alloc_cache *cache;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	unsigned int back_pad;
	spinlock_t rescue_lock;
	struct bio_list___13 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	struct hlist_node cpuhp_dead;
};

struct request___13;

struct elevator_queue___13;

struct gendisk___13;

struct blkcg_gq___12;

struct request_queue___13 {
	struct request___13 *last_merge;
	struct elevator_queue___13 *elevator;
	struct percpu_ref q_usage_counter;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	const struct blk_mq_ops *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx **queue_hw_ctx;
	unsigned int nr_hw_queues;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	spinlock_t queue_lock;
	struct gendisk___13 *disk;
	struct kobject___21 kobj;
	struct kobject___21 *mq_kobj;
	struct blk_integrity___13 integrity;
	struct device___23 *dev;
	enum rpm_status rpm_status;
	long unsigned int nr_requests;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_keyslot_manager *ksm;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	atomic_t nr_active_requests_shared_sbitmap;
	struct sbitmap_queue sched_bitmap_tags;
	struct sbitmap_queue sched_breserved_tags;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___12 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int required_elevator_features;
	unsigned int nr_zones;
	long unsigned int *conv_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int max_open_zones;
	unsigned int max_active_zones;
	int node;
	struct mutex debugfs_mutex;
	struct blk_trace *blk_trace;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	struct mutex sysfs_dir_lock;
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	int mq_freeze_depth;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct mutex mq_freeze_lock;
	struct blk_mq_tag_set *tag_set;
	struct list_head tag_set_list;
	struct bio_set___13 bio_split;
	struct dentry___21 *debugfs_dir;
	struct dentry___21 *sched_debugfs_dir;
	struct dentry___21 *rqos_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	u64 write_hints[5];
};

struct vm_struct___18 {
	struct vm_struct___18 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___22 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct psi_group___16 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___24 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___16;

struct cgroup_rstat_cpu___16;

struct cgroup___16 {
	struct cgroup_subsys_state___16 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___21 *kn;
	struct cgroup_file___16 procs_file;
	struct cgroup_file___16 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___16 *subsys[14];
	struct cgroup_root___16 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___16 *dom_cgrp;
	struct cgroup___16 *old_dom_cgrp;
	struct cgroup_rstat_cpu___16 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___16 psi;
	struct cgroup_bpf bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct io_cq___13 {
	struct request_queue___13 *q;
	struct io_context___14 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct wait_page_queue___11;

struct kiocb___21 {
	struct file___21 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___21 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___11 *ki_waitq;
	};
};

struct iattr___21 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___21 *ia_file;
};

struct dquot___21 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___21 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___21 {
	int qf_fmt_id;
	const struct quota_format_ops___21 *qf_ops;
	struct module___20 *qf_owner;
	struct quota_format_type___21 *qf_next;
};

struct quota_format_ops___21 {
	int (*check_quota_file)(struct super_block___21 *, int);
	int (*read_file_info)(struct super_block___21 *, int);
	int (*write_file_info)(struct super_block___21 *, int);
	int (*free_file_info)(struct super_block___21 *, int);
	int (*read_dqblk)(struct dquot___21 *);
	int (*commit_dqblk)(struct dquot___21 *);
	int (*release_dqblk)(struct dquot___21 *);
	int (*get_next_id)(struct super_block___21 *, struct kqid *);
};

struct dquot_operations___21 {
	int (*write_dquot)(struct dquot___21 *);
	struct dquot___21 * (*alloc_dquot)(struct super_block___21 *, int);
	void (*destroy_dquot)(struct dquot___21 *);
	int (*acquire_dquot)(struct dquot___21 *);
	int (*release_dquot)(struct dquot___21 *);
	int (*mark_dirty)(struct dquot___21 *);
	int (*write_info)(struct super_block___21 *, int);
	qsize_t * (*get_reserved_space)(struct inode___21 *);
	int (*get_projid)(struct inode___21 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___21 *, qsize_t *);
	int (*get_next_id)(struct super_block___21 *, struct kqid *);
};

struct quotactl_ops___21 {
	int (*quota_on)(struct super_block___21 *, int, int, const struct path___21 *);
	int (*quota_off)(struct super_block___21 *, int);
	int (*quota_enable)(struct super_block___21 *, unsigned int);
	int (*quota_disable)(struct super_block___21 *, unsigned int);
	int (*quota_sync)(struct super_block___21 *, int);
	int (*set_info)(struct super_block___21 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___21 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___21 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___21 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___21 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___21 *, unsigned int);
};

struct module_kobject___20 {
	struct kobject___21 kobj;
	struct module___20 *mod;
	struct kobject___21 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___20 {
	struct module___20 *mod;
	struct latch_tree_node node;
};

struct module_layout___20 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___20 mtn;
};

struct module_attribute___20;

struct kernel_param___20;

struct module___20 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___20 mkobj;
	struct module_attribute___20 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___21 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___20 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___20 core_layout;
	struct module_layout___20 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map___15 *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___4 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	int num_static_call_sites;
	struct static_call_site *static_call_sites;
	bool klp;
	bool klp_alive;
	struct klp_modinfo *klp_info;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct wait_page_queue___11 {
	struct page___22 *page;
	int bit_nr;
	wait_queue_entry_t wait;
};

struct writeback_control___12;

struct readahead_control___11;

struct swap_info_struct___8;

struct address_space_operations___21 {
	int (*writepage)(struct page___22 *, struct writeback_control___12 *);
	int (*readpage)(struct file___21 *, struct page___22 *);
	int (*writepages)(struct address_space___21 *, struct writeback_control___12 *);
	int (*set_page_dirty)(struct page___22 *);
	int (*readpages)(struct file___21 *, struct address_space___21 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___11 *);
	int (*write_begin)(struct file___21 *, struct address_space___21 *, loff_t, unsigned int, unsigned int, struct page___22 **, void **);
	int (*write_end)(struct file___21 *, struct address_space___21 *, loff_t, unsigned int, unsigned int, struct page___22 *, void *);
	sector_t (*bmap)(struct address_space___21 *, sector_t);
	void (*invalidatepage)(struct page___22 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___22 *, gfp_t);
	void (*freepage)(struct page___22 *);
	ssize_t (*direct_IO)(struct kiocb___21 *, struct iov_iter___16 *);
	int (*migratepage)(struct address_space___21 *, struct page___22 *, struct page___22 *, enum migrate_mode);
	bool (*isolate_page)(struct page___22 *, isolate_mode_t);
	void (*putback_page)(struct page___22 *);
	int (*launder_page)(struct page___22 *);
	int (*is_partially_uptodate)(struct page___22 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___22 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___21 *, struct page___22 *);
	int (*swap_activate)(struct swap_info_struct___8 *, struct file___21 *, sector_t *);
	void (*swap_deactivate)(struct file___21 *);
};

struct writeback_control___12 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate;
	unsigned int for_background;
	unsigned int tagged_writepages;
	unsigned int for_reclaim;
	unsigned int range_cyclic;
	unsigned int for_sync;
	unsigned int no_cgroup_owner;
	unsigned int punt_to_cgroup;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bdi_writeback___12 *wb;
	struct inode___21 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
};

struct readahead_control___11 {
	struct file___21 *file;
	struct address_space___21 *mapping;
	struct file_ra_state *ra;
	long unsigned int _index;
	unsigned int _nr_pages;
	unsigned int _batch_count;
};

struct bio_vec___16;

struct iov_iter___16 {
	u8 iter_type;
	bool data_source;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___16 *bvec;
		struct xarray *xarray;
		struct pipe_inode_info *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			unsigned int head;
			unsigned int start_head;
		};
		loff_t xarray_start;
	};
};

struct swap_info_struct___8 {
	struct percpu_ref users;
	long unsigned int flags;
	short int prio;
	struct plist_node list;
	signed char type;
	unsigned int max;
	unsigned char *swap_map;
	struct swap_cluster_info *cluster_info;
	struct swap_cluster_list free_clusters;
	unsigned int lowest_bit;
	unsigned int highest_bit;
	unsigned int pages;
	unsigned int inuse_pages;
	unsigned int cluster_next;
	unsigned int cluster_nr;
	unsigned int *cluster_next_cpu;
	struct percpu_cluster *percpu_cluster;
	struct rb_root swap_extent_root;
	struct block_device___13 *bdev;
	struct file___21 *swap_file;
	unsigned int old_block_size;
	struct completion comp;
	long unsigned int *frontswap_map;
	atomic_t frontswap_pages;
	spinlock_t lock;
	spinlock_t cont_lock;
	struct work_struct discard_work;
	struct swap_cluster_list discard_clusters;
	struct plist_node avail_lists[0];
};

struct cdev___9 {
	struct kobject___21 kobj;
	struct module___20 *owner;
	const struct file_operations___21 *ops;
	struct list_head list;
	dev_t dev;
	unsigned int count;
};

struct inode_operations___21 {
	struct dentry___21 * (*lookup)(struct inode___21 *, struct dentry___21 *, unsigned int);
	const char * (*get_link)(struct dentry___21 *, struct inode___21 *, struct delayed_call *);
	int (*permission)(struct user_namespace *, struct inode___21 *, int);
	struct posix_acl * (*get_acl)(struct inode___21 *, int, bool);
	int (*readlink)(struct dentry___21 *, char *, int);
	int (*create)(struct user_namespace *, struct inode___21 *, struct dentry___21 *, umode_t, bool);
	int (*link)(struct dentry___21 *, struct inode___21 *, struct dentry___21 *);
	int (*unlink)(struct inode___21 *, struct dentry___21 *);
	int (*symlink)(struct user_namespace *, struct inode___21 *, struct dentry___21 *, const char *);
	int (*mkdir)(struct user_namespace *, struct inode___21 *, struct dentry___21 *, umode_t);
	int (*rmdir)(struct inode___21 *, struct dentry___21 *);
	int (*mknod)(struct user_namespace *, struct inode___21 *, struct dentry___21 *, umode_t, dev_t);
	int (*rename)(struct user_namespace *, struct inode___21 *, struct dentry___21 *, struct inode___21 *, struct dentry___21 *, unsigned int);
	int (*setattr)(struct user_namespace *, struct dentry___21 *, struct iattr___21 *);
	int (*getattr)(struct user_namespace *, const struct path___21 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___21 *, char *, size_t);
	int (*fiemap)(struct inode___21 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___21 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___21 *, struct dentry___21 *, struct file___21 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace *, struct inode___21 *, struct dentry___21 *, umode_t);
	int (*set_acl)(struct user_namespace *, struct inode___21 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace *, struct dentry___21 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___21 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___21 {
	void (*fl_copy_lock)(struct file_lock___21 *, struct file_lock___21 *);
	void (*fl_release_private)(struct file_lock___21 *);
};

struct fasync_struct___21;

struct lock_manager_operations___21;

struct file_lock___21 {
	struct file_lock___21 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___21 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___21 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___21 *fl_ops;
	const struct lock_manager_operations___21 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___21 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___21 *);
	int (*lm_grant)(struct file_lock___21 *, int);
	bool (*lm_break)(struct file_lock___21 *);
	int (*lm_change)(struct file_lock___21 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___21 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___21 *);
};

struct fasync_struct___21 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___21 *fa_next;
	struct file___21 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___21 {
	struct inode___21 * (*alloc_inode)(struct super_block___21 *);
	void (*destroy_inode)(struct inode___21 *);
	void (*free_inode)(struct inode___21 *);
	void (*dirty_inode)(struct inode___21 *, int);
	int (*write_inode)(struct inode___21 *, struct writeback_control___12 *);
	int (*drop_inode)(struct inode___21 *);
	void (*evict_inode)(struct inode___21 *);
	void (*put_super)(struct super_block___21 *);
	int (*sync_fs)(struct super_block___21 *, int);
	int (*freeze_super)(struct super_block___21 *);
	int (*freeze_fs)(struct super_block___21 *);
	int (*thaw_super)(struct super_block___21 *);
	int (*unfreeze_fs)(struct super_block___21 *);
	int (*statfs)(struct dentry___21 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___21 *, int *, char *);
	void (*umount_begin)(struct super_block___21 *);
	int (*show_options)(struct seq_file___19 *, struct dentry___21 *);
	int (*show_devname)(struct seq_file___19 *, struct dentry___21 *);
	int (*show_path)(struct seq_file___19 *, struct dentry___21 *);
	int (*show_stats)(struct seq_file___19 *, struct dentry___21 *);
	ssize_t (*quota_read)(struct super_block___21 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___21 *, int, const char *, size_t, loff_t);
	struct dquot___21 ** (*get_dquots)(struct inode___21 *);
	long int (*nr_cached_objects)(struct super_block___21 *, struct shrink_control___12 *);
	long int (*free_cached_objects)(struct super_block___21 *, struct shrink_control___12 *);
	struct file___21 * (*real_loop)(struct file___21 *);
};

struct wakeup_source___23;

struct dev_pm_info___23 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___23 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___23 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___23;

struct bus_type___23;

struct device_driver___23;

struct dev_pm_domain___23;

struct device_node___15;

struct class___23;

struct attribute_group___21;

struct device___23 {
	struct kobject___21 kobj;
	struct device___23 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___23 *type;
	struct bus_type___23 *bus;
	struct device_driver___23 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___23 power;
	struct dev_pm_domain___23 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___14 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___15 *of_node;
	struct fwnode_handle___20 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___23 *class;
	const struct attribute_group___21 **groups;
	void (*release)(struct device___23 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct block_device___13 {
	sector_t bd_start_sect;
	struct disk_stats *bd_stats;
	long unsigned int bd_stamp;
	bool bd_read_only;
	dev_t bd_dev;
	int bd_openers;
	struct inode___21 *bd_inode;
	struct super_block___21 *bd_super;
	void *bd_claiming;
	struct device___23 bd_device;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct kobject___21 *bd_holder_dir;
	u8 bd_partno;
	spinlock_t bd_size_lock;
	struct gendisk___13 *bd_disk;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	struct super_block___21 *bd_fsfreeze_sb;
	struct partition_meta_info *bd_meta_info;
};

typedef void (*poll_queue_proc___15)(struct file___21 *, wait_queue_head_t *, struct poll_table_struct___15 *);

struct poll_table_struct___15 {
	poll_queue_proc___15 _qproc;
	__poll_t _key;
};

struct seq_file___19 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___19 *op;
	int poll_event;
	const struct file___21 *file;
	void *private;
};

typedef void bio_end_io_t___13(struct bio___13 *);

struct bio_vec___16 {
	struct page___22 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___13;

struct bio___13 {
	struct bio___13 *bi_next;
	struct block_device___13 *bi_bdev;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	atomic_t __bi_remaining;
	struct bvec_iter bi_iter;
	bio_end_io_t___13 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___12 *bi_blkg;
	struct bio_issue bi_issue;
	u64 bi_iocost_cost;
	struct bio_crypt_ctx *bi_crypt_context;
	union {
		struct bio_integrity_payload___13 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___16 *bi_io_vec;
	struct bio_set___13 *bi_pool;
	struct bio_vec___16 bi_inline_vecs[0];
};

struct fwnode_operations___20;

struct fwnode_handle___20 {
	struct fwnode_handle___20 *secondary;
	const struct fwnode_operations___20 *ops;
	struct device___23 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct device_node___15 {
	const char *name;
	phandle phandle;
	const char *full_name;
	struct fwnode_handle___20 fwnode;
	struct property *properties;
	struct property *deadprops;
	struct device_node___15 *parent;
	struct device_node___15 *child;
	struct device_node___15 *sibling;
	long unsigned int _flags;
	void *data;
};

struct kernfs_root___21;

struct kernfs_elem_dir___21 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___21 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___21;

struct kernfs_root___21 {
	struct kernfs_node___21 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___21 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___21 {
	struct kernfs_node___21 *target_kn;
};

struct kernfs_ops___21;

struct kernfs_elem_attr___21 {
	const struct kernfs_ops___21 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___21 *notify_next;
};

struct kernfs_node___21 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___21 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___21 dir;
		struct kernfs_elem_symlink___21 symlink;
		struct kernfs_elem_attr___21 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___21;

struct kernfs_ops___21 {
	int (*open)(struct kernfs_open_file___21 *);
	void (*release)(struct kernfs_open_file___21 *);
	int (*seq_show)(struct seq_file___19 *, void *);
	void * (*seq_start)(struct seq_file___19 *, loff_t *);
	void * (*seq_next)(struct seq_file___19 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___19 *, void *);
	ssize_t (*read)(struct kernfs_open_file___21 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___21 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___21 *, struct poll_table_struct___15 *);
	int (*mmap)(struct kernfs_open_file___21 *, struct vm_area_struct___23 *);
};

struct kernfs_syscall_ops___21 {
	int (*show_options)(struct seq_file___19 *, struct kernfs_root___21 *);
	int (*mkdir)(struct kernfs_node___21 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___21 *);
	int (*rename)(struct kernfs_node___21 *, struct kernfs_node___21 *, const char *);
	int (*show_path)(struct seq_file___19 *, struct kernfs_node___21 *, struct kernfs_root___21 *);
};

struct kernfs_open_file___21 {
	struct kernfs_node___21 *kn;
	struct file___21 *file;
	struct seq_file___19 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped;
	bool released;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___21 *vm_ops;
};

struct bin_attribute___21;

struct attribute_group___21 {
	const char *name;
	umode_t (*is_visible)(struct kobject___21 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___21 *, struct bin_attribute___21 *, int);
	struct attribute **attrs;
	struct bin_attribute___21 **bin_attrs;
};

struct bin_attribute___21 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___21 * (*f_mapping)();
	ssize_t (*read)(struct file___21 *, struct kobject___21 *, struct bin_attribute___21 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___21 *, struct kobject___21 *, struct bin_attribute___21 *, char *, loff_t, size_t);
	int (*mmap)(struct file___21 *, struct kobject___21 *, struct bin_attribute___21 *, struct vm_area_struct___23 *);
};

struct sysfs_ops___20 {
	ssize_t (*show)(struct kobject___21 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___21 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___20;

struct kset___20 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___21 kobj;
	const struct kset_uevent_ops___20 *uevent_ops;
};

struct kobj_type___20 {
	void (*release)(struct kobject___21 *);
	const struct sysfs_ops___20 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___21 **default_groups;
	const struct kobj_ns_type_operations * (*child_ns_type)(struct kobject___21 *);
	const void * (*namespace)(struct kobject___21 *);
	void (*get_ownership)(struct kobject___21 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___20 {
	int (* const filter)(struct kset___20 *, struct kobject___21 *);
	const char * (* const name)(struct kset___20 *, struct kobject___21 *);
	int (* const uevent)(struct kset___20 *, struct kobject___21 *, struct kobj_uevent_env *);
};

struct kobj_attribute___2 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___21 *, struct kobj_attribute___2 *, char *);
	ssize_t (*store)(struct kobject___21 *, struct kobj_attribute___2 *, const char *, size_t);
};

struct dev_pm_ops___23 {
	int (*prepare)(struct device___23 *);
	void (*complete)(struct device___23 *);
	int (*suspend)(struct device___23 *);
	int (*resume)(struct device___23 *);
	int (*freeze)(struct device___23 *);
	int (*thaw)(struct device___23 *);
	int (*poweroff)(struct device___23 *);
	int (*restore)(struct device___23 *);
	int (*suspend_late)(struct device___23 *);
	int (*resume_early)(struct device___23 *);
	int (*freeze_late)(struct device___23 *);
	int (*thaw_early)(struct device___23 *);
	int (*poweroff_late)(struct device___23 *);
	int (*restore_early)(struct device___23 *);
	int (*suspend_noirq)(struct device___23 *);
	int (*resume_noirq)(struct device___23 *);
	int (*freeze_noirq)(struct device___23 *);
	int (*thaw_noirq)(struct device___23 *);
	int (*poweroff_noirq)(struct device___23 *);
	int (*restore_noirq)(struct device___23 *);
	int (*runtime_suspend)(struct device___23 *);
	int (*runtime_resume)(struct device___23 *);
	int (*runtime_idle)(struct device___23 *);
};

struct wakeup_source___23 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___23 *dev;
	bool active;
	bool autosleep_enabled;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___23 {
	struct dev_pm_ops___23 ops;
	int (*start)(struct device___23 *);
	void (*detach)(struct device___23 *, bool);
	int (*activate)(struct device___23 *);
	void (*sync)(struct device___23 *);
	void (*dismiss)(struct device___23 *);
};

struct bus_type___23 {
	const char *name;
	const char *dev_name;
	struct device___23 *dev_root;
	const struct attribute_group___21 **bus_groups;
	const struct attribute_group___21 **dev_groups;
	const struct attribute_group___21 **drv_groups;
	int (*match)(struct device___23 *, struct device_driver___23 *);
	int (*uevent)(struct device___23 *, struct kobj_uevent_env *);
	int (*probe)(struct device___23 *);
	void (*sync_state)(struct device___23 *);
	void (*remove)(struct device___23 *);
	void (*shutdown)(struct device___23 *);
	int (*online)(struct device___23 *);
	int (*offline)(struct device___23 *);
	int (*suspend)(struct device___23 *, pm_message_t);
	int (*resume)(struct device___23 *);
	int (*num_vf)(struct device___23 *);
	int (*dma_configure)(struct device___23 *);
	const struct dev_pm_ops___23 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___23 {
	const char *name;
	struct bus_type___23 *bus;
	struct module___20 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___23 *);
	void (*sync_state)(struct device___23 *);
	int (*remove)(struct device___23 *);
	void (*shutdown)(struct device___23 *);
	int (*suspend)(struct device___23 *, pm_message_t);
	int (*resume)(struct device___23 *);
	const struct attribute_group___21 **groups;
	const struct attribute_group___21 **dev_groups;
	const struct dev_pm_ops___23 *pm;
	void (*coredump)(struct device___23 *);
	struct driver_private *p;
};

struct device_type___23 {
	const char *name;
	const struct attribute_group___21 **groups;
	int (*uevent)(struct device___23 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___23 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___23 *);
	const struct dev_pm_ops___23 *pm;
};

struct class___23 {
	const char *name;
	struct module___20 *owner;
	const struct attribute_group___21 **class_groups;
	const struct attribute_group___21 **dev_groups;
	struct kobject___21 *dev_kobj;
	int (*dev_uevent)(struct device___23 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___23 *, umode_t *);
	void (*class_release)(struct class___23 *);
	void (*dev_release)(struct device___23 *);
	int (*shutdown_pre)(struct device___23 *);
	const struct kobj_ns_type_operations *ns_type;
	const void * (*namespace)(struct device___23 *);
	void (*get_ownership)(struct device___23 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___23 *pm;
	struct subsys_private *p;
};

typedef struct {
	efi_guid_t guid;
	u32 table;
} efi_config_table_32_t;

typedef union {
	struct {
		efi_guid_t guid;
		void *table;
	};
	efi_config_table_32_t mixed_mode;
} efi_config_table_t;

typedef struct {
	efi_guid_t guid;
	long unsigned int *ptr;
	const char name[16];
} efi_config_table_type_t;

typedef struct {
	efi_table_hdr_t hdr;
	u64 fw_vendor;
	u32 fw_revision;
	u32 __pad1;
	u64 con_in_handle;
	u64 con_in;
	u64 con_out_handle;
	u64 con_out;
	u64 stderr_handle;
	u64 stderr;
	u64 runtime;
	u64 boottime;
	u32 nr_tables;
	u32 __pad2;
	u64 tables;
} efi_system_table_64_t;

typedef struct {
	u32 version;
	u32 length;
	u64 memory_protection_attribute;
} efi_properties_table_t;

struct fwnode_reference_args___20;

struct fwnode_endpoint___20;

struct fwnode_operations___20 {
	struct fwnode_handle___20 * (*get)(struct fwnode_handle___20 *);
	void (*put)(struct fwnode_handle___20 *);
	bool (*device_is_available)(const struct fwnode_handle___20 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___20 *, const struct device___23 *);
	bool (*property_present)(const struct fwnode_handle___20 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___20 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___20 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___20 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___20 *);
	struct fwnode_handle___20 * (*get_parent)(const struct fwnode_handle___20 *);
	struct fwnode_handle___20 * (*get_next_child_node)(const struct fwnode_handle___20 *, struct fwnode_handle___20 *);
	struct fwnode_handle___20 * (*get_named_child_node)(const struct fwnode_handle___20 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___20 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___20 *);
	struct fwnode_handle___20 * (*graph_get_next_endpoint)(const struct fwnode_handle___20 *, struct fwnode_handle___20 *);
	struct fwnode_handle___20 * (*graph_get_remote_endpoint)(const struct fwnode_handle___20 *);
	struct fwnode_handle___20 * (*graph_get_port_parent)(struct fwnode_handle___20 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___20 *, struct fwnode_endpoint___20 *);
	int (*add_links)(struct fwnode_handle___20 *);
};

struct fwnode_endpoint___20 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___20 *local_fwnode;
};

struct fwnode_reference_args___20 {
	struct fwnode_handle___20 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct irq_fwspec___13 {
	struct fwnode_handle___20 *fwnode;
	int param_count;
	u32 param[16];
};

struct irq_domain_ops___14 {
	int (*match)(struct irq_domain___14 *, struct device_node___15 *, enum irq_domain_bus_token);
	int (*select)(struct irq_domain___14 *, struct irq_fwspec___13 *, enum irq_domain_bus_token);
	int (*map)(struct irq_domain___14 *, unsigned int, irq_hw_number_t);
	void (*unmap)(struct irq_domain___14 *, unsigned int);
	int (*xlate)(struct irq_domain___14 *, struct device_node___15 *, const u32 *, unsigned int, long unsigned int *, unsigned int *);
	int (*alloc)(struct irq_domain___14 *, unsigned int, unsigned int, void *);
	void (*free)(struct irq_domain___14 *, unsigned int, unsigned int);
	int (*activate)(struct irq_domain___14 *, struct irq_data *, bool);
	void (*deactivate)(struct irq_domain___14 *, struct irq_data *);
	int (*translate)(struct irq_domain___14 *, struct irq_fwspec___13 *, long unsigned int *, unsigned int *);
};

struct kernel_param_ops___20 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___20 *);
	int (*get)(char *, const struct kernel_param___20 *);
	void (*free)(void *);
};

struct kparam_array___20;

struct kernel_param___20 {
	const char *name;
	struct module___20 *mod;
	const struct kernel_param_ops___20 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___20 *arr;
	};
};

struct kparam_array___20 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___20 *ops;
	void *elem;
};

struct module_attribute___20 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___20 *, struct module_kobject___20 *, char *);
	ssize_t (*store)(struct module_attribute___20 *, struct module_kobject___20 *, const char *, size_t);
	void (*setup)(struct module___20 *, const char *);
	int (*test)(struct module___20 *);
	void (*free)(struct module___20 *);
};

struct dev_pagemap_ops___21 {
	void (*page_free)(struct page___22 *);
	void (*kill)(struct dev_pagemap___21 *);
	void (*cleanup)(struct dev_pagemap___21 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___21 *);
};

struct cgroup_namespace___16 {
	struct ns_common ns;
	struct user_namespace *user_ns;
	struct ucounts *ucounts;
	struct css_set___16 *root_cset;
};

struct cftype___16;

struct cgroup_subsys___16 {
	struct cgroup_subsys_state___16 * (*css_alloc)(struct cgroup_subsys_state___16 *);
	int (*css_online)(struct cgroup_subsys_state___16 *);
	void (*css_offline)(struct cgroup_subsys_state___16 *);
	void (*css_released)(struct cgroup_subsys_state___16 *);
	void (*css_free)(struct cgroup_subsys_state___16 *);
	void (*css_reset)(struct cgroup_subsys_state___16 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___16 *, int);
	int (*css_extra_stat_show)(struct seq_file___19 *, struct cgroup_subsys_state___16 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___24 *, struct css_set___16 *);
	void (*cancel_fork)(struct task_struct___24 *, struct css_set___16 *);
	void (*fork)(struct task_struct___24 *);
	void (*exit)(struct task_struct___24 *);
	void (*release)(struct task_struct___24 *);
	void (*bind)(struct cgroup_subsys_state___16 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___16 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___16 *dfl_cftypes;
	struct cftype___16 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___16 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___16 *updated_children;
	struct cgroup___16 *updated_next;
};

struct cgroup_root___16 {
	struct kernfs_root___21 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___16 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___16 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___16 *ss;
	struct list_head node;
	struct kernfs_ops___21 *kf_ops;
	int (*open)(struct kernfs_open_file___21 *);
	void (*release)(struct kernfs_open_file___21 *);
	u64 (*read_u64)(struct cgroup_subsys_state___16 *, struct cftype___16 *);
	s64 (*read_s64)(struct cgroup_subsys_state___16 *, struct cftype___16 *);
	int (*seq_show)(struct seq_file___19 *, void *);
	void * (*seq_start)(struct seq_file___19 *, loff_t *);
	void * (*seq_next)(struct seq_file___19 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___19 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___16 *, struct cftype___16 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___16 *, struct cftype___16 *, s64);
	ssize_t (*write)(struct kernfs_open_file___21 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___21 *, struct poll_table_struct___15 *);
};

struct block_device_operations___13;

struct gendisk___13 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	short unsigned int events;
	short unsigned int event_flags;
	struct xarray part_tbl;
	struct block_device___13 *part0;
	const struct block_device_operations___13 *fops;
	struct request_queue___13 *queue;
	void *private_data;
	int flags;
	long unsigned int state;
	struct mutex open_mutex;
	unsigned int open_partitions;
	struct backing_dev_info___12 *bdi;
	struct kobject___21 *slave_dir;
	struct list_head slave_bdevs;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___21 integrity_kobj;
	struct cdrom_device_info *cdi;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	u64 diskseq;
};

struct bio_integrity_payload___13 {
	struct bio___13 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___16 *bip_vec;
	struct bio_vec___16 bip_inline_vecs[0];
};

struct blkcg___12;

struct blkg_policy_data___12;

struct blkcg_gq___12 {
	struct request_queue___13 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___12 *blkcg;
	struct blkcg_gq___12 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_iostat_set *iostat_cpu;
	struct blkg_iostat_set iostat;
	struct blkg_policy_data___12 *pd[6];
	spinlock_t async_bio_lock;
	struct bio_list___13 async_bios;
	struct work_struct async_bio_work;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
	struct callback_head callback_head;
};

typedef void integrity_prepare_fn___13(struct request___13 *);

typedef void integrity_complete_fn___13(struct request___13 *, unsigned int);

struct blk_integrity_profile___13 {
	integrity_processing_fn *generate_fn;
	integrity_processing_fn *verify_fn;
	integrity_prepare_fn___13 *prepare_fn;
	integrity_complete_fn___13 *complete_fn;
	const char *name;
};

struct block_device_operations___13 {
	blk_qc_t (*submit_bio)(struct bio___13 *);
	int (*open)(struct block_device___13 *, fmode_t);
	void (*release)(struct gendisk___13 *, fmode_t);
	int (*rw_page)(struct block_device___13 *, sector_t, struct page___22 *, unsigned int);
	int (*ioctl)(struct block_device___13 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___13 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___13 *, unsigned int);
	void (*unlock_native_capacity)(struct gendisk___13 *);
	int (*getgeo)(struct block_device___13 *, struct hd_geometry *);
	int (*set_read_only)(struct block_device___13 *, bool);
	void (*swap_slot_free_notify)(struct block_device___13 *, long unsigned int);
	int (*report_zones)(struct gendisk___13 *, sector_t, unsigned int, report_zones_cb, void *);
	char * (*devnode)(struct gendisk___13 *, umode_t *);
	struct module___20 *owner;
	const struct pr_ops *pr_ops;
	int (*alternative_gpt_sector)(struct gendisk___13 *, sector_t *);
};

typedef void rq_end_io_fn___13(struct request___13 *, blk_status_t);

struct request___13 {
	struct request_queue___13 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int tag;
	int internal_tag;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___13 *bio;
	struct bio___13 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct llist_node ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___16 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___13 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___13 *saved_end_io;
		} flush;
	};
	struct gendisk___13 *rq_disk;
	struct block_device___13 *part;
	u64 alloc_time_ns;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int stats_sectors;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	struct bio_crypt_ctx *crypt_ctx;
	struct blk_ksm_keyslot *crypt_keyslot;
	short unsigned int write_hint;
	short unsigned int ioprio;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___13 *end_io;
	void *end_io_data;
};

struct elevator_type___13;

struct elevator_mq_ops___13 {
	int (*init_sched)(struct request_queue___13 *, struct elevator_type___13 *);
	void (*exit_sched)(struct elevator_queue___13 *);
	int (*init_hctx)(struct blk_mq_hw_ctx *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx *, unsigned int);
	void (*depth_updated)(struct blk_mq_hw_ctx *);
	bool (*allow_merge)(struct request_queue___13 *, struct request___13 *, struct bio___13 *);
	bool (*bio_merge)(struct request_queue___13 *, struct bio___13 *, unsigned int);
	int (*request_merge)(struct request_queue___13 *, struct request___13 **, struct bio___13 *);
	void (*request_merged)(struct request_queue___13 *, struct request___13 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___13 *, struct request___13 *, struct request___13 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___13 *);
	void (*finish_request)(struct request___13 *);
	void (*insert_requests)(struct blk_mq_hw_ctx *, struct list_head *, bool);
	struct request___13 * (*dispatch_request)(struct blk_mq_hw_ctx *);
	bool (*has_work)(struct blk_mq_hw_ctx *);
	void (*completed_request)(struct request___13 *, u64);
	void (*requeue_request)(struct request___13 *);
	struct request___13 * (*former_request)(struct request_queue___13 *, struct request___13 *);
	struct request___13 * (*next_request)(struct request_queue___13 *, struct request___13 *);
	void (*init_icq)(struct io_cq___13 *);
	void (*exit_icq)(struct io_cq___13 *);
};

struct elv_fs_entry___13;

struct elevator_type___13 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___13 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___13 *elevator_attrs;
	const char *elevator_name;
	const char *elevator_alias;
	const unsigned int elevator_features;
	struct module___20 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
};

struct elevator_queue___13 {
	struct elevator_type___13 *type;
	void *elevator_data;
	struct kobject___21 kobj;
	struct mutex sysfs_lock;
	unsigned int registered;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hlist_head hash[64];
};

struct elv_fs_entry___13 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___13 *, char *);
	ssize_t (*store)(struct elevator_queue___13 *, const char *, size_t);
};

struct blkcg_policy_data___12;

struct blkcg___12 {
	struct cgroup_subsys_state___16 css;
	spinlock_t lock;
	refcount_t online_pin;
	struct xarray blkg_tree;
	struct blkcg_gq___12 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___12 *cpd[6];
	struct list_head all_blkcgs_node;
	char fc_app_id[129];
	struct list_head cgwb_list;
};

struct blkcg_policy_data___12 {
	struct blkcg___12 *blkcg;
	int plid;
};

struct blkg_policy_data___12 {
	struct blkcg_gq___12 *blkg;
	int plid;
};

struct mem_cgroup_reclaim_iter___12 {
	struct mem_cgroup___12 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___12 {
	struct lruvec___13 lruvec;
	struct lruvec_stats_percpu *lruvec_stats_percpu;
	struct lruvec_stats lruvec_stats;
	long unsigned int lru_zone_size[25];
	struct mem_cgroup_reclaim_iter___12 iter;
	struct shrinker_info *shrinker_info;
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	struct mem_cgroup___12 *memcg;
};

struct obj_cgroup___12 {
	struct percpu_ref refcnt;
	struct mem_cgroup___12 *memcg;
	atomic_t nr_charged_bytes;
	union {
		struct list_head list;
		struct callback_head rcu;
	};
};

typedef int (*efi_memattr_perm_setter)(struct mm_struct___3 *, efi_memory_desc_t *);

typedef u16 ucs2_char_t;

struct pm_qos_request {
	struct plist_node node;
	struct pm_qos_constraints *qos;
};

struct semaphore {
	raw_spinlock_t lock;
	unsigned int count;
	struct list_head wait_list;
};

enum uv_bios_cmd {
	UV_BIOS_COMMON = 0,
	UV_BIOS_GET_SN_INFO = 1,
	UV_BIOS_FREQ_BASE = 2,
	UV_BIOS_WATCHLIST_ALLOC = 3,
	UV_BIOS_WATCHLIST_FREE = 4,
	UV_BIOS_MEMPROTECT = 5,
	UV_BIOS_GET_PARTITION_ADDR = 6,
	UV_BIOS_SET_LEGACY_VGA_TARGET = 7,
};

union partition_info_u {
	u64 val;
	struct {
		u64 hub_version: 8;
		u64 partition_id: 16;
		u64 coherence_id: 16;
		u64 region_size: 24;
	};
};

enum uv_memprotect {
	UV_MEMPROT_RESTRICT_ACCESS = 0,
	UV_MEMPROT_ALLOW_AMO = 1,
	UV_MEMPROT_ALLOW_RW = 2,
};

struct uv_IO_APIC_route_entry {
	__u64 vector: 8;
	__u64 delivery_mode: 3;
	__u64 dest_mode: 1;
	__u64 delivery_status: 1;
	__u64 polarity: 1;
	__u64 __reserved_1: 1;
	__u64 trigger: 1;
	__u64 mask: 1;
	__u64 __reserved_2: 15;
	__u64 dest: 32;
};

enum {
	UV_AFFINITY_ALL = 0,
	UV_AFFINITY_NODE = 1,
	UV_AFFINITY_CPU = 2,
};

struct uv_irq_2_mmr_pnode {
	long unsigned int offset;
	int pnode;
};

struct uv_rtc_timer_head {
	spinlock_t___2 lock;
	int next_cpu;
	int ncpus;
	struct {
		int lcpu;
		u64 expires;
	} cpu[0];
};

enum {
	KDB_REASON_ENTER = 1,
	KDB_REASON_ENTER_SLAVE = 2,
	KDB_REASON_BREAK = 3,
	KDB_REASON_DEBUG = 4,
	KDB_REASON_OOPS = 5,
	KDB_REASON_SWITCH = 6,
	KDB_REASON_KEYBOARD = 7,
	KDB_REASON_NMI = 8,
	KDB_REASON_RECURSE = 9,
	KDB_REASON_SSTEP = 10,
	KDB_REASON_SYSTEM_NMI = 11,
};

struct kimage___2;

typedef void *kexec_load_t___2(struct kimage___2 *, char *, long unsigned int, char *, long unsigned int, char *, long unsigned int);

struct kexec_file_ops___2;

struct kimage___2 {
	kimage_entry_t head;
	kimage_entry_t *entry;
	kimage_entry_t *last_entry;
	long unsigned int start;
	struct page___7 *control_code_page;
	struct page___7 *swap_page;
	void *vmcoreinfo_data_copy;
	long unsigned int nr_segments;
	struct kexec_segment segment[16];
	struct list_head control_pages;
	struct list_head dest_pages;
	struct list_head unusable_pages;
	long unsigned int control_page;
	unsigned int type: 1;
	unsigned int preserve_context: 1;
	unsigned int file_mode: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct kimage_arch arch;
	void *kernel_buf;
	long unsigned int kernel_buf_len;
	void *initrd_buf;
	long unsigned int initrd_buf_len;
	char *cmdline_buf;
	long unsigned int cmdline_buf_len;
	const struct kexec_file_ops___2 *fops;
	void *image_loader_data;
	struct purgatory_info purgatory_info;
	void *elf_headers;
	long unsigned int elf_headers_sz;
	long unsigned int elf_load_addr;
};

struct kexec_file_ops___2 {
	kexec_probe_t *probe;
	kexec_load_t___2 *load;
	kexec_cleanup_t *cleanup;
	kexec_verify_sig_t *verify_sig;
};

struct uv_hub_nmi_s {
	raw_spinlock_t nmi_lock;
	atomic_t in_nmi;
	atomic_t cpu_owner;
	atomic_t read_mmr_count;
	atomic_t nmi_count;
	long unsigned int nmi_value;
	bool hub_present;
	bool pch_owner;
};

struct uv_cpu_nmi_s {
	struct uv_hub_nmi_s *hub;
	int state;
	int pinging;
	int queries;
	int pings;
};

struct nmi_action {
	char *action;
	char *desc;
};

typedef char action_t[16];

struct init_nmi {
	unsigned int offset;
	unsigned int mask;
	unsigned int data;
};

struct dentry___22;

struct super_block___22;

struct module___21;

struct file_system_type___22 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___22 * (*mount)(struct file_system_type___22 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___22 *);
	struct module___21 *owner;
	struct file_system_type___22 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___22;

struct kiocb___22;

struct iov_iter___17;

struct vm_area_struct___24;

struct inode___22;

struct file_lock___22;

struct page___23;

struct pipe_inode_info___5;

struct seq_file___20;

struct file_operations___22 {
	struct module___21 *owner;
	loff_t (*llseek)(struct file___22 *, loff_t, int);
	ssize_t (*read)(struct file___22 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___22 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___22 *, struct iov_iter___17 *);
	ssize_t (*write_iter)(struct kiocb___22 *, struct iov_iter___17 *);
	int (*iopoll)(struct kiocb___22 *, bool);
	int (*iterate)(struct file___22 *, struct dir_context *);
	int (*iterate_shared)(struct file___22 *, struct dir_context *);
	__poll_t (*poll)(struct file___22 *, struct poll_table_struct *);
	long int (*unlocked_ioctl)(struct file___22 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___22 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___22 *, struct vm_area_struct___24 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___22 *, struct file___22 *);
	int (*flush)(struct file___22 *, fl_owner_t);
	int (*release)(struct inode___22 *, struct file___22 *);
	int (*fsync)(struct file___22 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___22 *, int);
	int (*lock)(struct file___22 *, int, struct file_lock___22 *);
	ssize_t (*sendpage)(struct file___22 *, struct page___23 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___22 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___22 *, long unsigned int);
	int (*flock)(struct file___22 *, int, struct file_lock___22 *);
	ssize_t (*splice_write)(struct pipe_inode_info___5 *, struct file___22 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___22 *, loff_t *, struct pipe_inode_info___5 *, size_t, unsigned int);
	int (*setlease)(struct file___22 *, long int, struct file_lock___22 **, void **);
	long int (*fallocate)(struct file___22 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___20 *, struct file___22 *);
	ssize_t (*copy_file_range)(struct file___22 *, loff_t, struct file___22 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___22 *, loff_t, struct file___22 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___22 *, loff_t, loff_t, int);
};

typedef struct page___23 *pgtable_t___23;

struct address_space___22;

struct page_pool___5;

struct mm_struct___24;

struct dev_pagemap___22;

struct page___23 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___22 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___5 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___23 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___23 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___24 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___22 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vmacache___23 {
	u64 seqnum;
	struct vm_area_struct___24 *vmas[4];
};

struct page_frag___23 {
	struct page___23 *page;
	__u32 offset;
	__u32 size;
};

struct nsproxy___21;

struct signal_struct___23;

struct css_set___17;

struct vm_struct___19;

struct task_struct___25 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___25 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___24 *mm;
	struct mm_struct___24 *active_mm;
	struct vmacache___23 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int restore_sigmask: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___25 *real_parent;
	struct task_struct___25 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___25 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___18 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	struct posix_cputimers_work posix_cputimers_work;
	const struct cred *ptracer_cred;
	const struct cred *real_cred;
	const struct cred *cred;
	struct key *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___21 *nsproxy;
	struct signal_struct___23 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___25 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context___14 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___17 *cgroups;
	struct list_head cg_list;
	u32 closid;
	u32 rmid;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	struct pipe_inode_info___5 *splice_pipe;
	struct page_frag___23 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup *active_memcg;
	struct request_queue *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___25 *oom_reaper_list;
	struct vm_struct___19 *stack_vm_area;
	refcount_t stack_refcount;
	int patch_state;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	void *mce_vaddr;
	__u64 mce_kflags;
	u64 mce_addr;
	__u64 mce_ripv: 1;
	__u64 mce_whole_page: 1;
	__u64 __mce_reserved: 62;
	long: 2;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct callback_head mce_kill_me;
	int mce_count;
	struct llist_head kretprobe_instances;
	struct callback_head l1d_flush_kill;
	long: 64;
	struct thread_struct___13 thread;
};

struct core_state___23;

struct mm_struct___24 {
	struct {
		struct vm_area_struct___24 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___22 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int mmap_compat_base;
		long unsigned int mmap_compat_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[48];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___23 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___25 *owner;
		struct user_namespace *user_ns;
		struct file___22 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		bool tlb_flush_batched;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct vm_operations_struct___22;

struct vm_area_struct___24 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___24 *vm_next;
	struct vm_area_struct___24 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___24 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___22 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___22 *vm_file;
	struct file___22 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct seq_operations___20 {
	void * (*start)(struct seq_file___20 *, loff_t *);
	void (*stop)(struct seq_file___20 *, void *);
	void * (*next)(struct seq_file___20 *, void *, loff_t *);
	int (*show)(struct seq_file___20 *, void *);
};

struct signal_struct___23 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___25 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___25 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper;
	unsigned int has_child_subreaper;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___18 *pids[4];
	struct pid___18 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___24 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct net___3;

struct cgroup_namespace___17;

struct nsproxy___21 {
	atomic_t count;
	struct uts_namespace *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace *pid_ns_for_children;
	struct net___3 *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___17 *cgroup_ns;
};

struct cgroup_subsys_state___17;

struct cgroup___17;

struct css_set___17 {
	struct cgroup_subsys_state___17 *subsys[14];
	refcount_t refcount;
	struct css_set___17 *dom_cset;
	struct cgroup___17 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___17 *mg_src_cgrp;
	struct cgroup___17 *mg_dst_cgrp;
	struct css_set___17 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct fasync_struct___22;

struct pipe_buffer___5;

struct pipe_inode_info___5 {
	struct mutex mutex;
	wait_queue_head_t rd_wait;
	wait_queue_head_t wr_wait;
	unsigned int head;
	unsigned int tail;
	unsigned int max_usage;
	unsigned int ring_size;
	bool note_loss;
	unsigned int nr_accounted;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int r_counter;
	unsigned int w_counter;
	unsigned int poll_usage;
	struct page___23 *tmp_page;
	struct fasync_struct___22 *fasync_readers;
	struct fasync_struct___22 *fasync_writers;
	struct pipe_buffer___5 *bufs;
	struct user_struct *user;
	struct watch_queue *watch_queue;
};

struct vm_struct___19 {
	struct vm_struct___19 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___23 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct bio_vec___17 {
	struct page___23 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct iov_iter___17 {
	u8 iter_type;
	bool data_source;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___17 *bvec;
		struct xarray *xarray;
		struct pipe_inode_info___5 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			unsigned int head;
			unsigned int start_head;
		};
		loff_t xarray_start;
	};
};

struct kiocb___22 {
	struct file___22 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___22 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___11 *ki_waitq;
	};
};

struct net_device___2;

struct sk_buff___3 {
	union {
		struct {
			struct sk_buff___3 *next;
			struct sk_buff___3 *prev;
			union {
				struct net_device___2 *dev;
				long unsigned int dev_scratch;
			};
		};
		struct rb_node rbnode;
		struct list_head list;
	};
	union {
		struct sock *sk;
		int ip_defrag_offset;
	};
	union {
		ktime_t tstamp;
		u64 skb_mstamp_ns;
	};
	char cb[48];
	union {
		struct {
			long unsigned int _skb_refdst;
			void (*destructor)(struct sk_buff___3 *);
		};
		struct list_head tcp_tsorted_anchor;
		long unsigned int _sk_redir;
	};
	long unsigned int _nfct;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	__u16 queue_mapping;
	__u8 __cloned_offset[0];
	__u8 cloned: 1;
	__u8 nohdr: 1;
	__u8 fclone: 2;
	__u8 peeked: 1;
	__u8 head_frag: 1;
	__u8 pfmemalloc: 1;
	__u8 pp_recycle: 1;
	long: 55;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 active_extensions;
	__u32 headers_start[0];
	__u8 __pkt_type_offset[0];
	__u8 pkt_type: 3;
	__u8 ignore_df: 1;
	__u8 nf_trace: 1;
	__u8 ip_summed: 2;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 sw_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	long: 15;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 __pkt_vlan_present_offset[0];
	__u8 vlan_present: 1;
	__u8 csum_complete_sw: 1;
	__u8 csum_level: 2;
	__u8 csum_not_inet: 1;
	__u8 dst_pending_confirm: 1;
	__u8 ndisc_nodetype: 2;
	__u8 ipvs_property: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	__u8 offload_fwd_mark: 1;
	__u8 offload_l3_fwd_mark: 1;
	__u8 tc_skip_classify: 1;
	__u8 tc_at_ingress: 1;
	__u8 redirected: 1;
	__u8 from_ingress: 1;
	__u8 decrypted: 1;
	__u8 slow_gro: 1;
	long: 47;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u16 tc_index;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	int skb_iif;
	__u32 hash;
	__be16 vlan_proto;
	__u16 vlan_tci;
	union {
		unsigned int napi_id;
		unsigned int sender_cpu;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__be16 protocol;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	__u32 headers_end[0];
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	refcount_t users;
	struct skb_ext *extensions;
};

struct inet_frags___2;

struct fqdir___2 {
	long int high_thresh;
	long int low_thresh;
	int timeout;
	int max_dist;
	struct inet_frags___2 *f;
	struct net___3 *net;
	bool dead;
	long: 56;
	long: 64;
	long: 64;
	struct rhashtable rhashtable;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	atomic_long_t mem;
	struct work_struct destroy_work;
	struct llist_node free_list;
	long: 64;
	long: 64;
};

struct inet_frag_queue___2;

struct inet_frags___2 {
	unsigned int qsize;
	void (*constructor)(struct inet_frag_queue___2 *, const void *);
	void (*destructor)(struct inet_frag_queue___2 *);
	void (*frag_expire)(struct timer_list *);
	struct kmem_cache *frags_cachep;
	const char *frags_cache_name;
	struct rhashtable_params rhash_params;
	refcount_t refcnt;
	struct completion completion;
};

struct netns_ipv4___2 {
	struct inet_timewait_death_row tcp_death_row;
	struct ctl_table_header *forw_hdr;
	struct ctl_table_header *frags_hdr;
	struct ctl_table_header *ipv4_hdr;
	struct ctl_table_header *route_hdr;
	struct ctl_table_header *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct ip_ra_chain *ra_chain;
	struct mutex ra_mutex;
	struct fib_rules_ops *rules_ops;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	unsigned int fib_rules_require_fldissect;
	bool fib_has_custom_rules;
	bool fib_has_custom_local_routes;
	bool fib_offload_disabled;
	atomic_t fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	struct sock *fibnl;
	struct sock **icmp_sk;
	struct sock *mc_autojoin_sk;
	struct inet_peer_base *peers;
	struct sock **tcp_sk;
	struct fqdir___2 *fqdir;
	u8 sysctl_icmp_echo_ignore_all;
	u8 sysctl_icmp_echo_enable_probe;
	u8 sysctl_icmp_echo_ignore_broadcasts;
	u8 sysctl_icmp_ignore_bogus_error_responses;
	u8 sysctl_icmp_errors_use_inbound_ifaddr;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	struct local_ports ip_local_ports;
	u8 sysctl_tcp_ecn;
	u8 sysctl_tcp_ecn_fallback;
	u8 sysctl_ip_default_ttl;
	u8 sysctl_ip_no_pmtu_disc;
	u8 sysctl_ip_fwd_use_pmtu;
	u8 sysctl_ip_fwd_update_priority;
	u8 sysctl_ip_nonlocal_bind;
	u8 sysctl_ip_autobind_reuse;
	u8 sysctl_ip_dynaddr;
	u8 sysctl_ip_early_demux;
	u8 sysctl_raw_l3mdev_accept;
	u8 sysctl_tcp_early_demux;
	u8 sysctl_udp_early_demux;
	u8 sysctl_nexthop_compat_mode;
	u8 sysctl_fwmark_reflect;
	u8 sysctl_tcp_fwmark_accept;
	u8 sysctl_tcp_l3mdev_accept;
	u8 sysctl_tcp_mtu_probing;
	int sysctl_tcp_mtu_probe_floor;
	int sysctl_tcp_base_mss;
	int sysctl_tcp_min_snd_mss;
	int sysctl_tcp_probe_threshold;
	u32 sysctl_tcp_probe_interval;
	int sysctl_tcp_keepalive_time;
	int sysctl_tcp_keepalive_intvl;
	u8 sysctl_tcp_keepalive_probes;
	u8 sysctl_tcp_syn_retries;
	u8 sysctl_tcp_synack_retries;
	u8 sysctl_tcp_syncookies;
	u8 sysctl_tcp_migrate_req;
	int sysctl_tcp_reordering;
	u8 sysctl_tcp_retries1;
	u8 sysctl_tcp_retries2;
	u8 sysctl_tcp_orphan_retries;
	u8 sysctl_tcp_tw_reuse;
	int sysctl_tcp_fin_timeout;
	unsigned int sysctl_tcp_notsent_lowat;
	u8 sysctl_tcp_sack;
	u8 sysctl_tcp_window_scaling;
	u8 sysctl_tcp_timestamps;
	u8 sysctl_tcp_early_retrans;
	u8 sysctl_tcp_recovery;
	u8 sysctl_tcp_thin_linear_timeouts;
	u8 sysctl_tcp_slow_start_after_idle;
	u8 sysctl_tcp_retrans_collapse;
	u8 sysctl_tcp_stdurg;
	u8 sysctl_tcp_rfc1337;
	u8 sysctl_tcp_abort_on_overflow;
	u8 sysctl_tcp_fack;
	int sysctl_tcp_max_reordering;
	int sysctl_tcp_adv_win_scale;
	u8 sysctl_tcp_dsack;
	u8 sysctl_tcp_app_win;
	u8 sysctl_tcp_frto;
	u8 sysctl_tcp_nometrics_save;
	u8 sysctl_tcp_no_ssthresh_metrics_save;
	u8 sysctl_tcp_moderate_rcvbuf;
	u8 sysctl_tcp_tso_win_divisor;
	u8 sysctl_tcp_workaround_signed_windows;
	int sysctl_tcp_limit_output_bytes;
	int sysctl_tcp_challenge_ack_limit;
	int sysctl_tcp_min_rtt_wlen;
	u8 sysctl_tcp_min_tso_segs;
	u8 sysctl_tcp_autocorking;
	u8 sysctl_tcp_reflect_tos;
	u8 sysctl_tcp_comp_sack_nr;
	int sysctl_tcp_invalid_ratelimit;
	int sysctl_tcp_pacing_ss_ratio;
	int sysctl_tcp_pacing_ca_ratio;
	int sysctl_tcp_wmem[3];
	int sysctl_tcp_rmem[3];
	long unsigned int sysctl_tcp_comp_sack_delay_ns;
	long unsigned int sysctl_tcp_comp_sack_slack_ns;
	int sysctl_max_syn_backlog;
	int sysctl_tcp_fastopen;
	const struct tcp_congestion_ops *tcp_congestion_control;
	struct tcp_fastopen_context *tcp_fastopen_ctx;
	unsigned int sysctl_tcp_fastopen_blackhole_timeout;
	atomic_t tfo_active_disable_times;
	long unsigned int tfo_active_disable_stamp;
	int sysctl_udp_wmem_min;
	int sysctl_udp_rmem_min;
	u8 sysctl_fib_notify_on_flag_change;
	u8 sysctl_udp_l3mdev_accept;
	u8 sysctl_igmp_llm_reports;
	int sysctl_igmp_max_memberships;
	int sysctl_igmp_max_msf;
	int sysctl_igmp_qrv;
	struct ping_group_range ping_group_range;
	atomic_t dev_addr_genid;
	long unsigned int *sysctl_local_reserved_ports;
	int sysctl_ip_prot_sock;
	struct list_head mr_tables;
	struct fib_rules_ops *mr_rules_ops;
	u32 sysctl_fib_multipath_hash_fields;
	u8 sysctl_fib_multipath_use_neigh;
	u8 sysctl_fib_multipath_hash_policy;
	struct fib_notifier_ops *notifier_ops;
	unsigned int fib_seq;
	struct fib_notifier_ops *ipmr_notifier_ops;
	unsigned int ipmr_seq;
	atomic_t rt_genid;
	siphash_key_t ip_id_key;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dst_ops___2 {
	short unsigned int family;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___2 *);
	struct dst_entry * (*check)(struct dst_entry *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry *);
	unsigned int (*mtu)(const struct dst_entry *);
	u32 * (*cow_metrics)(struct dst_entry *, long unsigned int);
	void (*destroy)(struct dst_entry *);
	void (*ifdown)(struct dst_entry *, struct net_device___2 *, int);
	struct dst_entry * (*negative_advice)(struct dst_entry *);
	void (*link_failure)(struct sk_buff___3 *);
	void (*update_pmtu)(struct dst_entry *, struct sock *, struct sk_buff___3 *, u32, bool);
	void (*redirect)(struct dst_entry *, struct sock *, struct sk_buff___3 *);
	int (*local_out)(struct net___3 *, struct sock *, struct sk_buff___3 *);
	struct neighbour * (*neigh_lookup)(const struct dst_entry *, struct sk_buff___3 *, const void *);
	void (*confirm_neigh)(const struct dst_entry *, const void *);
	struct kmem_cache *kmem_cachep;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv6___2 {
	struct dst_ops___2 ip6_dst_ops;
	struct netns_sysctl_ipv6 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	struct fqdir___2 *fqdir;
	struct fib6_info *fib6_null_entry;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	struct list_head fib6_walkers;
	rwlock_t fib6_walker_lock;
	spinlock_t fib6_gc_lock;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	unsigned char flowlabel_has_excl;
	bool fib6_has_custom_rules;
	unsigned int fib6_rules_require_fldissect;
	unsigned int fib6_routes_require_src;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops *fib6_rules_ops;
	struct sock **icmp_sk;
	struct sock *ndisc_sk;
	struct sock *tcp_sk;
	struct sock *igmp_sk;
	struct sock *mc_autojoin_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops *mr6_rules_ops;
	atomic_t dev_addr_genid;
	atomic_t fib6_sernum;
	struct seg6_pernet_data *seg6_data;
	struct fib_notifier_ops *notifier_ops;
	struct fib_notifier_ops *ip6mr_notifier_ops;
	unsigned int ipmr_seq;
	struct {
		struct hlist_head head;
		spinlock_t lock;
		u32 seq;
	} ip6addrlbl_table;
	struct ioam6_pernet_data *ioam6_data;
};

struct netns_ieee802154_lowpan___2 {
	struct netns_sysctl_lowpan sysctl;
	struct fqdir___2 *fqdir;
};

struct sk_buff_head___2 {
	struct sk_buff___3 *next;
	struct sk_buff___3 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct bpf_prog_array___2;

struct bpf_prog___2;

struct netns_bpf___2 {
	struct bpf_prog_array___2 *run_array[2];
	struct bpf_prog___2 *progs[2];
	struct list_head links[2];
};

struct netns_xfrm___2 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	struct hlist_head *state_byseq;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[3];
	struct xfrm_policy_hash policy_bydst[3];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct xfrm_policy_hthresh policy_hthresh;
	struct list_head inexact_bins;
	struct sock *nlsk;
	struct sock *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	u8 policy_default;
	struct ctl_table_header *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___2 xfrm4_dst_ops;
	struct dst_ops___2 xfrm6_dst_ops;
	spinlock_t xfrm_state_lock;
	seqcount_spinlock_t xfrm_state_hash_generation;
	seqcount_spinlock_t xfrm_policy_hash_generation;
	spinlock_t xfrm_policy_lock;
	struct mutex xfrm_cfg_mutex;
	long: 64;
	long: 64;
};

struct net___3 {
	refcount_t passive;
	spinlock_t rules_mod_lock;
	unsigned int dev_unreg_count;
	unsigned int dev_base_seq;
	int ifindex;
	spinlock_t nsid_lock;
	atomic_t fnhe_genid;
	struct list_head list;
	struct list_head exit_list;
	struct llist_node cleanup_list;
	struct key_tag *key_domain;
	struct user_namespace *user_ns;
	struct ucounts *ucounts;
	struct idr netns_ids;
	struct ns_common ns;
	struct list_head dev_base_head;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set sysctls;
	struct sock *rtnl;
	struct sock *genl_sock;
	struct uevent_sock *uevent_sock;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	struct raw_notifier_head netdev_chain;
	u32 hash_mix;
	struct net_device___2 *loopback_dev;
	struct list_head rules_ops;
	struct netns_core core;
	struct netns_mib mib;
	struct netns_packet packet;
	struct netns_unix unx;
	struct netns_nexthop nexthop;
	struct netns_ipv4___2 ipv4;
	struct netns_ipv6___2 ipv6;
	struct netns_ieee802154_lowpan___2 ieee802154_lowpan;
	struct netns_sctp sctp;
	struct netns_nf nf;
	struct netns_ct ct;
	struct netns_nftables nft;
	struct sk_buff_head___2 wext_nlevents;
	struct net_generic *gen;
	struct netns_bpf___2 bpf;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_xfrm___2 xfrm;
	u64 net_cookie;
	struct netns_ipvs *ipvs;
	struct netns_mpls mpls;
	struct netns_can can;
	struct netns_xdp xdp;
	struct netns_mctp mctp;
	struct sock *crypto_nlsk;
	struct sock *diag_nlsk;
	struct netns_smc smc;
	long: 64;
};

struct inet_frag_queue___2 {
	struct rhash_head node;
	union {
		struct frag_v4_compare_key v4;
		struct frag_v6_compare_key v6;
	} key;
	struct timer_list timer;
	spinlock_t lock;
	refcount_t refcnt;
	struct rb_root rb_fragments;
	struct sk_buff___3 *fragments_tail;
	struct sk_buff___3 *last_run_head;
	ktime_t stamp;
	int len;
	int meat;
	__u8 flags;
	u16 max_size;
	struct fqdir___2 *fqdir;
	struct callback_head rcu;
};

struct address_space_operations___22;

struct address_space___22 {
	struct inode___22 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___22 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct device___24;

struct page_pool_params___5 {
	unsigned int flags;
	unsigned int order;
	unsigned int pool_size;
	int nid;
	struct device___24 *dev;
	enum dma_data_direction dma_dir;
	unsigned int max_len;
	unsigned int offset;
};

struct pp_alloc_cache___5 {
	u32 count;
	struct page___23 *cache[128];
};

struct page_pool___5 {
	struct page_pool_params___5 p;
	struct delayed_work release_dw;
	void (*disconnect)(void *);
	long unsigned int defer_start;
	long unsigned int defer_warn;
	u32 pages_state_hold_cnt;
	unsigned int frag_offset;
	struct page___23 *frag_page;
	long int frag_users;
	long: 64;
	long: 64;
	struct pp_alloc_cache___5 alloc;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct ptr_ring ring;
	atomic_t pages_state_release_cnt;
	refcount_t user_cnt;
	u64 destroy_cnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pagemap_ops___22;

struct dev_pagemap___22 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___22 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vfsmount___22;

struct path___22 {
	struct vfsmount___22 *mnt;
	struct dentry___22 *dentry;
};

struct file___22 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___22 f_path;
	struct inode___22 *f_inode;
	const struct file_operations___22 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___18 f_owner;
	const struct cred *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___22 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___22;

struct vm_operations_struct___22 {
	void (*open)(struct vm_area_struct___24 *);
	void (*close)(struct vm_area_struct___24 *);
	int (*may_split)(struct vm_area_struct___24 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___24 *);
	int (*mprotect)(struct vm_area_struct___24 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___22 *);
	vm_fault_t (*huge_fault)(struct vm_fault___22 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___22 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___24 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___22 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___22 *);
	int (*access)(struct vm_area_struct___24 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___24 *);
	int (*set_policy)(struct vm_area_struct___24 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___24 *, long unsigned int);
	struct page___23 * (*find_special_page)(struct vm_area_struct___24 *, long unsigned int);
};

struct core_thread___23 {
	struct task_struct___25 *task;
	struct core_thread___23 *next;
};

struct core_state___23 {
	atomic_t nr_threads;
	struct core_thread___23 dumper;
	struct completion startup;
};

struct vm_fault___22 {
	const struct {
		struct vm_area_struct___24 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___23 *cow_page;
	struct page___23 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___23 prealloc_pte;
};

struct l3mdev_ops___2;

struct ndisc_ops___2;

struct inet6_dev___2;

typedef rx_handler_result_t rx_handler_func_t___2(struct sk_buff___3 **);

typedef struct {
	struct net___3 *net;
} possible_net_t___2;

struct kset___21;

struct kobj_type___21;

struct kernfs_node___22;

struct kobject___22 {
	const char *name;
	struct list_head entry;
	struct kobject___22 *parent;
	struct kset___21 *kset;
	struct kobj_type___21 *ktype;
	struct kernfs_node___22 *sd;
	struct kref kref;
	unsigned int state_initialized;
	unsigned int state_in_sysfs;
	unsigned int state_add_uevent_sent;
	unsigned int state_remove_uevent_sent;
	unsigned int uevent_suppress;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct wakeup_source___24;

struct dev_pm_info___24 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___24 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___24 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___24;

struct bus_type___24;

struct device_driver___24;

struct dev_pm_domain___24;

struct fwnode_handle___21;

struct class___24;

struct attribute_group___22;

struct device___24 {
	struct kobject___22 kobj;
	struct device___24 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___24 *type;
	struct bus_type___24 *bus;
	struct device_driver___24 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___24 power;
	struct dev_pm_domain___24 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node *of_node;
	struct fwnode_handle___21 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___24 *class;
	const struct attribute_group___22 **groups;
	void (*release)(struct device___24 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_xdp_entity___2 {
	struct bpf_prog___2 *prog;
	struct bpf_xdp_link *link;
};

struct netdev_name_node___2;

struct net_device_ops___2;

struct xfrmdev_ops___2;

struct header_ops___2;

struct netdev_rx_queue___2;

struct mini_Qdisc___2;

struct netdev_queue___2;

struct Qdisc___2;

struct rtnl_link_ops___2;

struct dcbnl_rtnl_ops___2;

struct net_device___2 {
	char name[16];
	struct netdev_name_node___2 *name_node;
	struct dev_ifalias *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head close_list;
	struct list_head ptype_all;
	struct list_head ptype_specific;
	struct {
		struct list_head upper;
		struct list_head lower;
	} adj_list;
	unsigned int flags;
	unsigned int priv_flags;
	const struct net_device_ops___2 *netdev_ops;
	int ifindex;
	short unsigned int gflags;
	short unsigned int hard_header_len;
	unsigned int mtu;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	netdev_features_t gso_partial_features;
	unsigned int min_mtu;
	unsigned int max_mtu;
	short unsigned int type;
	unsigned char min_header_len;
	unsigned char name_assign_type;
	int group;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	atomic_long_t tx_dropped;
	atomic_long_t rx_nohandler;
	atomic_t carrier_up_count;
	atomic_t carrier_down_count;
	const struct iw_handler_def *wireless_handlers;
	struct iw_public_data *wireless_data;
	const struct ethtool_ops *ethtool_ops;
	const struct l3mdev_ops___2 *l3mdev_ops;
	const struct ndisc_ops___2 *ndisc_ops;
	const struct xfrmdev_ops___2 *xfrmdev_ops;
	const struct tlsdev_ops *tlsdev_ops;
	const struct header_ops___2 *header_ops;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	unsigned char upper_level;
	unsigned char lower_level;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	short unsigned int padded;
	spinlock_t addr_list_lock;
	int irq;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___21 *queues_kset;
	unsigned int promiscuity;
	unsigned int allmulti;
	bool uc_promisc;
	struct vlan_info *vlan_info;
	struct dsa_port *dsa_ptr;
	struct tipc_bearer *tipc_ptr;
	void *atalk_ptr;
	struct in_device *ip_ptr;
	struct dn_dev *dn_ptr;
	struct inet6_dev___2 *ip6_ptr;
	void *ax25_ptr;
	struct wireless_dev *ieee80211_ptr;
	struct wpan_dev *ieee802154_ptr;
	struct mpls_dev *mpls_ptr;
	struct mctp_dev *mctp_ptr;
	unsigned char *dev_addr;
	struct netdev_rx_queue___2 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	struct bpf_prog___2 *xdp_prog;
	long unsigned int gro_flush_timeout;
	int napi_defer_hard_irqs;
	rx_handler_func_t___2 *rx_handler;
	void *rx_handler_data;
	struct mini_Qdisc___2 *miniq_ingress;
	struct netdev_queue___2 *ingress_queue;
	struct nf_hook_entries *nf_hooks_ingress;
	unsigned char broadcast[32];
	struct cpu_rmap *rx_cpu_rmap;
	struct hlist_node index_hlist;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___2 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc___2 *qdisc;
	unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	struct xdp_dev_bulk_queue *xdp_bulkq;
	struct xps_dev_maps *xps_maps[2];
	struct mini_Qdisc___2 *miniq_egress;
	struct hlist_head qdisc_hash[16];
	struct timer_list watchdog_timer;
	int watchdog_timeo;
	u32 proto_down_reason;
	struct list_head todo_list;
	int *pcpu_refcnt;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___2 = 0,
		NETREG_REGISTERED___2 = 1,
		NETREG_UNREGISTERING___2 = 2,
		NETREG_UNREGISTERED___2 = 3,
		NETREG_RELEASED___2 = 4,
		NETREG_DUMMY___2 = 5,
	} reg_state: 8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___2 = 0,
		RTNL_LINK_INITIALIZING___2 = 1,
	} rtnl_link_state: 16;
	long: 16;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	bool needs_free_netdev;
	void (*priv_destructor)(struct net_device___2 *);
	struct netpoll_info *npinfo;
	possible_net_t___2 nd_net;
	void *ml_priv;
	enum netdev_ml_priv_type ml_priv_type;
	union {
		struct pcpu_lstats *lstats;
		struct pcpu_sw_netstats *tstats;
		struct pcpu_dstats *dstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___24 dev;
	const struct attribute_group___22 *sysfs_groups[4];
	const struct attribute_group___22 *sysfs_rx_queue_group;
	const struct rtnl_link_ops___2 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___2 *dcbnl_ops;
	s16 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	unsigned int fcoe_ddp_xid;
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct sfp_bus *sfp_bus;
	struct lock_class_key *qdisc_tx_busylock;
	struct lock_class_key *qdisc_running_key;
	bool proto_down;
	unsigned int wol_enabled: 1;
	unsigned int threaded: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct list_head net_notifier_list;
	const struct macsec_ops *macsec_ops;
	const struct udp_tunnel_nic_info *udp_tunnel_nic_info;
	struct udp_tunnel_nic *udp_tunnel_nic;
	struct bpf_xdp_entity___2 xdp_state[3];
	long: 64;
	long: 64;
	long: 64;
};

enum {
	BPF_REG_0 = 0,
	BPF_REG_1 = 1,
	BPF_REG_2 = 2,
	BPF_REG_3 = 3,
	BPF_REG_4 = 4,
	BPF_REG_5 = 5,
	BPF_REG_6 = 6,
	BPF_REG_7 = 7,
	BPF_REG_8 = 8,
	BPF_REG_9 = 9,
	BPF_REG_10 = 10,
	__MAX_BPF_REG = 11,
};

struct bpf_prog_array_item___2 {
	struct bpf_prog___2 *prog;
	union {
		struct bpf_cgroup_storage *cgroup_storage[2];
		u64 bpf_cookie;
	};
};

struct bpf_prog_array___2 {
	struct callback_head rcu;
	struct bpf_prog_array_item___2 items[0];
};

struct bpf_prog_aux___2;

struct bpf_prog___2 {
	u16 pages;
	u16 jited: 1;
	u16 jit_requested: 1;
	u16 gpl_compatible: 1;
	u16 cb_access: 1;
	u16 dst_needed: 1;
	u16 blinded: 1;
	u16 is_func: 1;
	u16 kprobe_override: 1;
	u16 has_callchain_buf: 1;
	u16 enforce_expected_attach_type: 1;
	u16 call_get_stack: 1;
	u16 call_get_func_ip: 1;
	enum bpf_prog_type type;
	enum bpf_attach_type expected_attach_type;
	u32 len;
	u32 jited_len;
	u8 tag[8];
	struct bpf_prog_stats *stats;
	int *active;
	unsigned int (*bpf_func)(const void *, const struct bpf_insn *);
	struct bpf_prog_aux___2 *aux;
	struct sock_fprog_kern *orig_prog;
	struct sock_filter insns[0];
	struct bpf_insn insnsi[0];
};

struct dentry_operations___22;

struct dentry___22 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___22 *d_parent;
	struct qstr d_name;
	struct inode___22 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___22 *d_op;
	struct super_block___22 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___22;

struct inode___22 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___22 *i_op;
	struct super_block___22 *i_sb;
	struct address_space___22 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___22 *i_fop;
		void (*free_inode)(struct inode___22 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___22 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___5 *i_pipe;
		struct cdev *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___22 {
	int (*d_revalidate)(struct dentry___22 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___22 *, unsigned int);
	int (*d_hash)(const struct dentry___22 *, struct qstr *);
	int (*d_compare)(const struct dentry___22 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___22 *);
	int (*d_init)(struct dentry___22 *);
	void (*d_release)(struct dentry___22 *);
	void (*d_prune)(struct dentry___22 *);
	void (*d_iput)(struct dentry___22 *, struct inode___22 *);
	char * (*d_dname)(struct dentry___22 *, char *, int);
	struct vfsmount___22 * (*d_automount)(struct path___22 *);
	int (*d_manage)(const struct path___22 *, bool);
	struct dentry___22 * (*d_real)(struct dentry___22 *, const struct inode___22 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___22;

struct mem_dqinfo___22 {
	struct quota_format_type___22 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___22;

struct quota_info___22 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___22 *files[3];
	struct mem_dqinfo___22 info[3];
	const struct quota_format_ops___22 *ops[3];
};

struct rcuwait___22 {
	struct task_struct___25 *task;
};

struct percpu_rw_semaphore___22 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___22 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___22 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___22 rw_sem[3];
};

struct super_operations___22;

struct dquot_operations___22;

struct quotactl_ops___22;

struct super_block___22 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___22 *s_type;
	const struct super_operations___22 *s_op;
	const struct dquot_operations___22 *dq_op;
	const struct quotactl_ops___22 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___22 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device *s_bdev;
	struct backing_dev_info *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___22 s_dquot;
	struct sb_writers___22 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___22 *s_d_op;
	int cleancache_poolid;
	struct shrinker___12 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___22 {
	struct dentry___22 *mnt_root;
	struct super_block___22 *mnt_sb;
	int mnt_flags;
	struct user_namespace *mnt_userns;
};

struct cgroup_subsys___17;

struct cgroup_subsys_state___17 {
	struct cgroup___17 *cgroup;
	struct cgroup_subsys___17 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___17 *parent;
};

struct cgroup_file___17 {
	struct kernfs_node___22 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct psi_group___17 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___25 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_bpf___2 {
	struct bpf_prog_array___2 *effective[23];
	struct list_head progs[23];
	u32 flags[23];
	struct list_head storages;
	struct bpf_prog_array___2 *inactive;
	struct percpu_ref refcnt;
	struct work_struct release_work;
};

struct cgroup_root___17;

struct cgroup_rstat_cpu___17;

struct cgroup___17 {
	struct cgroup_subsys_state___17 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___22 *kn;
	struct cgroup_file___17 procs_file;
	struct cgroup_file___17 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___17 *subsys[14];
	struct cgroup_root___17 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___17 *dom_cgrp;
	struct cgroup___17 *old_dom_cgrp;
	struct cgroup_rstat_cpu___17 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___17 psi;
	struct cgroup_bpf___2 bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct iattr___22 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___22 *ia_file;
};

struct dquot___22 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___22 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___22 {
	int qf_fmt_id;
	const struct quota_format_ops___22 *qf_ops;
	struct module___21 *qf_owner;
	struct quota_format_type___22 *qf_next;
};

struct quota_format_ops___22 {
	int (*check_quota_file)(struct super_block___22 *, int);
	int (*read_file_info)(struct super_block___22 *, int);
	int (*write_file_info)(struct super_block___22 *, int);
	int (*free_file_info)(struct super_block___22 *, int);
	int (*read_dqblk)(struct dquot___22 *);
	int (*commit_dqblk)(struct dquot___22 *);
	int (*release_dqblk)(struct dquot___22 *);
	int (*get_next_id)(struct super_block___22 *, struct kqid *);
};

struct dquot_operations___22 {
	int (*write_dquot)(struct dquot___22 *);
	struct dquot___22 * (*alloc_dquot)(struct super_block___22 *, int);
	void (*destroy_dquot)(struct dquot___22 *);
	int (*acquire_dquot)(struct dquot___22 *);
	int (*release_dquot)(struct dquot___22 *);
	int (*mark_dirty)(struct dquot___22 *);
	int (*write_info)(struct super_block___22 *, int);
	qsize_t * (*get_reserved_space)(struct inode___22 *);
	int (*get_projid)(struct inode___22 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___22 *, qsize_t *);
	int (*get_next_id)(struct super_block___22 *, struct kqid *);
};

struct quotactl_ops___22 {
	int (*quota_on)(struct super_block___22 *, int, int, const struct path___22 *);
	int (*quota_off)(struct super_block___22 *, int);
	int (*quota_enable)(struct super_block___22 *, unsigned int);
	int (*quota_disable)(struct super_block___22 *, unsigned int);
	int (*quota_sync)(struct super_block___22 *, int);
	int (*set_info)(struct super_block___22 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___22 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___22 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___22 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___22 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___22 *, unsigned int);
};

struct module_kobject___21 {
	struct kobject___22 kobj;
	struct module___21 *mod;
	struct kobject___22 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___21 {
	struct module___21 *mod;
	struct latch_tree_node node;
};

struct module_layout___21 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___21 mtn;
};

struct module_attribute___21;

struct kernel_param___21;

struct module___21 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___21 mkobj;
	struct module_attribute___21 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___22 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___21 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___21 core_layout;
	struct module_layout___21 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map___15 *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___4 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	int num_static_call_sites;
	struct static_call_site *static_call_sites;
	bool klp;
	bool klp_alive;
	struct klp_modinfo *klp_info;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct address_space_operations___22 {
	int (*writepage)(struct page___23 *, struct writeback_control *);
	int (*readpage)(struct file___22 *, struct page___23 *);
	int (*writepages)(struct address_space___22 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___23 *);
	int (*readpages)(struct file___22 *, struct address_space___22 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control *);
	int (*write_begin)(struct file___22 *, struct address_space___22 *, loff_t, unsigned int, unsigned int, struct page___23 **, void **);
	int (*write_end)(struct file___22 *, struct address_space___22 *, loff_t, unsigned int, unsigned int, struct page___23 *, void *);
	sector_t (*bmap)(struct address_space___22 *, sector_t);
	void (*invalidatepage)(struct page___23 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___23 *, gfp_t);
	void (*freepage)(struct page___23 *);
	ssize_t (*direct_IO)(struct kiocb___22 *, struct iov_iter___17 *);
	int (*migratepage)(struct address_space___22 *, struct page___23 *, struct page___23 *, enum migrate_mode);
	bool (*isolate_page)(struct page___23 *, isolate_mode_t);
	void (*putback_page)(struct page___23 *);
	int (*launder_page)(struct page___23 *);
	int (*is_partially_uptodate)(struct page___23 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___23 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___22 *, struct page___23 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___22 *, sector_t *);
	void (*swap_deactivate)(struct file___22 *);
};

struct inode_operations___22 {
	struct dentry___22 * (*lookup)(struct inode___22 *, struct dentry___22 *, unsigned int);
	const char * (*get_link)(struct dentry___22 *, struct inode___22 *, struct delayed_call *);
	int (*permission)(struct user_namespace *, struct inode___22 *, int);
	struct posix_acl * (*get_acl)(struct inode___22 *, int, bool);
	int (*readlink)(struct dentry___22 *, char *, int);
	int (*create)(struct user_namespace *, struct inode___22 *, struct dentry___22 *, umode_t, bool);
	int (*link)(struct dentry___22 *, struct inode___22 *, struct dentry___22 *);
	int (*unlink)(struct inode___22 *, struct dentry___22 *);
	int (*symlink)(struct user_namespace *, struct inode___22 *, struct dentry___22 *, const char *);
	int (*mkdir)(struct user_namespace *, struct inode___22 *, struct dentry___22 *, umode_t);
	int (*rmdir)(struct inode___22 *, struct dentry___22 *);
	int (*mknod)(struct user_namespace *, struct inode___22 *, struct dentry___22 *, umode_t, dev_t);
	int (*rename)(struct user_namespace *, struct inode___22 *, struct dentry___22 *, struct inode___22 *, struct dentry___22 *, unsigned int);
	int (*setattr)(struct user_namespace *, struct dentry___22 *, struct iattr___22 *);
	int (*getattr)(struct user_namespace *, const struct path___22 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___22 *, char *, size_t);
	int (*fiemap)(struct inode___22 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___22 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___22 *, struct dentry___22 *, struct file___22 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace *, struct inode___22 *, struct dentry___22 *, umode_t);
	int (*set_acl)(struct user_namespace *, struct inode___22 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace *, struct dentry___22 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___22 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___22 {
	void (*fl_copy_lock)(struct file_lock___22 *, struct file_lock___22 *);
	void (*fl_release_private)(struct file_lock___22 *);
};

struct lock_manager_operations___22;

struct file_lock___22 {
	struct file_lock___22 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___22 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___22 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___22 *fl_ops;
	const struct lock_manager_operations___22 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___22 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___22 *);
	int (*lm_grant)(struct file_lock___22 *, int);
	bool (*lm_break)(struct file_lock___22 *);
	int (*lm_change)(struct file_lock___22 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___22 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___22 *);
};

struct fasync_struct___22 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___22 *fa_next;
	struct file___22 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___22 {
	struct inode___22 * (*alloc_inode)(struct super_block___22 *);
	void (*destroy_inode)(struct inode___22 *);
	void (*free_inode)(struct inode___22 *);
	void (*dirty_inode)(struct inode___22 *, int);
	int (*write_inode)(struct inode___22 *, struct writeback_control *);
	int (*drop_inode)(struct inode___22 *);
	void (*evict_inode)(struct inode___22 *);
	void (*put_super)(struct super_block___22 *);
	int (*sync_fs)(struct super_block___22 *, int);
	int (*freeze_super)(struct super_block___22 *);
	int (*freeze_fs)(struct super_block___22 *);
	int (*thaw_super)(struct super_block___22 *);
	int (*unfreeze_fs)(struct super_block___22 *);
	int (*statfs)(struct dentry___22 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___22 *, int *, char *);
	void (*umount_begin)(struct super_block___22 *);
	int (*show_options)(struct seq_file___20 *, struct dentry___22 *);
	int (*show_devname)(struct seq_file___20 *, struct dentry___22 *);
	int (*show_path)(struct seq_file___20 *, struct dentry___22 *);
	int (*show_stats)(struct seq_file___20 *, struct dentry___22 *);
	ssize_t (*quota_read)(struct super_block___22 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___22 *, int, const char *, size_t, loff_t);
	struct dquot___22 ** (*get_dquots)(struct inode___22 *);
	long int (*nr_cached_objects)(struct super_block___22 *, struct shrink_control___12 *);
	long int (*free_cached_objects)(struct super_block___22 *, struct shrink_control___12 *);
	struct file___22 * (*real_loop)(struct file___22 *);
};

struct seq_file___20 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___20 *op;
	int poll_event;
	const struct file___22 *file;
	void *private;
};

struct dev_pagemap_ops___22 {
	void (*page_free)(struct page___23 *);
	void (*kill)(struct dev_pagemap___22 *);
	void (*cleanup)(struct dev_pagemap___22 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___22 *);
};

struct kernfs_root___22;

struct kernfs_elem_dir___22 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___22 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___22;

struct kernfs_root___22 {
	struct kernfs_node___22 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___22 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___22 {
	struct kernfs_node___22 *target_kn;
};

struct kernfs_ops___22;

struct kernfs_elem_attr___22 {
	const struct kernfs_ops___22 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___22 *notify_next;
};

struct kernfs_node___22 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___22 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___22 dir;
		struct kernfs_elem_symlink___22 symlink;
		struct kernfs_elem_attr___22 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___22;

struct kernfs_ops___22 {
	int (*open)(struct kernfs_open_file___22 *);
	void (*release)(struct kernfs_open_file___22 *);
	int (*seq_show)(struct seq_file___20 *, void *);
	void * (*seq_start)(struct seq_file___20 *, loff_t *);
	void * (*seq_next)(struct seq_file___20 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___20 *, void *);
	ssize_t (*read)(struct kernfs_open_file___22 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___22 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___22 *, struct poll_table_struct *);
	int (*mmap)(struct kernfs_open_file___22 *, struct vm_area_struct___24 *);
};

struct kernfs_syscall_ops___22 {
	int (*show_options)(struct seq_file___20 *, struct kernfs_root___22 *);
	int (*mkdir)(struct kernfs_node___22 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___22 *);
	int (*rename)(struct kernfs_node___22 *, struct kernfs_node___22 *, const char *);
	int (*show_path)(struct seq_file___20 *, struct kernfs_node___22 *, struct kernfs_root___22 *);
};

struct kernfs_open_file___22 {
	struct kernfs_node___22 *kn;
	struct file___22 *file;
	struct seq_file___20 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped;
	bool released;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___22 *vm_ops;
};

struct bin_attribute___22;

struct attribute_group___22 {
	const char *name;
	umode_t (*is_visible)(struct kobject___22 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___22 *, struct bin_attribute___22 *, int);
	struct attribute **attrs;
	struct bin_attribute___22 **bin_attrs;
};

struct bin_attribute___22 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___22 * (*f_mapping)();
	ssize_t (*read)(struct file___22 *, struct kobject___22 *, struct bin_attribute___22 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___22 *, struct kobject___22 *, struct bin_attribute___22 *, char *, loff_t, size_t);
	int (*mmap)(struct file___22 *, struct kobject___22 *, struct bin_attribute___22 *, struct vm_area_struct___24 *);
};

struct sysfs_ops___21 {
	ssize_t (*show)(struct kobject___22 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___22 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___21;

struct kset___21 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___22 kobj;
	const struct kset_uevent_ops___21 *uevent_ops;
};

struct kobj_type___21 {
	void (*release)(struct kobject___22 *);
	const struct sysfs_ops___21 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___22 **default_groups;
	const struct kobj_ns_type_operations * (*child_ns_type)(struct kobject___22 *);
	const void * (*namespace)(struct kobject___22 *);
	void (*get_ownership)(struct kobject___22 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___21 {
	int (* const filter)(struct kset___21 *, struct kobject___22 *);
	const char * (* const name)(struct kset___21 *, struct kobject___22 *);
	int (* const uevent)(struct kset___21 *, struct kobject___22 *, struct kobj_uevent_env *);
};

struct dev_pm_ops___24 {
	int (*prepare)(struct device___24 *);
	void (*complete)(struct device___24 *);
	int (*suspend)(struct device___24 *);
	int (*resume)(struct device___24 *);
	int (*freeze)(struct device___24 *);
	int (*thaw)(struct device___24 *);
	int (*poweroff)(struct device___24 *);
	int (*restore)(struct device___24 *);
	int (*suspend_late)(struct device___24 *);
	int (*resume_early)(struct device___24 *);
	int (*freeze_late)(struct device___24 *);
	int (*thaw_early)(struct device___24 *);
	int (*poweroff_late)(struct device___24 *);
	int (*restore_early)(struct device___24 *);
	int (*suspend_noirq)(struct device___24 *);
	int (*resume_noirq)(struct device___24 *);
	int (*freeze_noirq)(struct device___24 *);
	int (*thaw_noirq)(struct device___24 *);
	int (*poweroff_noirq)(struct device___24 *);
	int (*restore_noirq)(struct device___24 *);
	int (*runtime_suspend)(struct device___24 *);
	int (*runtime_resume)(struct device___24 *);
	int (*runtime_idle)(struct device___24 *);
};

struct wakeup_source___24 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___24 *dev;
	bool active;
	bool autosleep_enabled;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___24 {
	struct dev_pm_ops___24 ops;
	int (*start)(struct device___24 *);
	void (*detach)(struct device___24 *, bool);
	int (*activate)(struct device___24 *);
	void (*sync)(struct device___24 *);
	void (*dismiss)(struct device___24 *);
};

struct bus_type___24 {
	const char *name;
	const char *dev_name;
	struct device___24 *dev_root;
	const struct attribute_group___22 **bus_groups;
	const struct attribute_group___22 **dev_groups;
	const struct attribute_group___22 **drv_groups;
	int (*match)(struct device___24 *, struct device_driver___24 *);
	int (*uevent)(struct device___24 *, struct kobj_uevent_env *);
	int (*probe)(struct device___24 *);
	void (*sync_state)(struct device___24 *);
	void (*remove)(struct device___24 *);
	void (*shutdown)(struct device___24 *);
	int (*online)(struct device___24 *);
	int (*offline)(struct device___24 *);
	int (*suspend)(struct device___24 *, pm_message_t);
	int (*resume)(struct device___24 *);
	int (*num_vf)(struct device___24 *);
	int (*dma_configure)(struct device___24 *);
	const struct dev_pm_ops___24 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___24 {
	const char *name;
	struct bus_type___24 *bus;
	struct module___21 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___24 *);
	void (*sync_state)(struct device___24 *);
	int (*remove)(struct device___24 *);
	void (*shutdown)(struct device___24 *);
	int (*suspend)(struct device___24 *, pm_message_t);
	int (*resume)(struct device___24 *);
	const struct attribute_group___22 **groups;
	const struct attribute_group___22 **dev_groups;
	const struct dev_pm_ops___24 *pm;
	void (*coredump)(struct device___24 *);
	struct driver_private *p;
};

struct device_type___24 {
	const char *name;
	const struct attribute_group___22 **groups;
	int (*uevent)(struct device___24 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___24 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___24 *);
	const struct dev_pm_ops___24 *pm;
};

struct class___24 {
	const char *name;
	struct module___21 *owner;
	const struct attribute_group___22 **class_groups;
	const struct attribute_group___22 **dev_groups;
	struct kobject___22 *dev_kobj;
	int (*dev_uevent)(struct device___24 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___24 *, umode_t *);
	void (*class_release)(struct class___24 *);
	void (*dev_release)(struct device___24 *);
	int (*shutdown_pre)(struct device___24 *);
	const struct kobj_ns_type_operations *ns_type;
	const void * (*namespace)(struct device___24 *);
	void (*get_ownership)(struct device___24 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___24 *pm;
	struct subsys_private *p;
};

struct fwnode_operations___21;

struct fwnode_handle___21 {
	struct fwnode_handle___21 *secondary;
	const struct fwnode_operations___21 *ops;
	struct device___24 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct fwnode_reference_args___21;

struct fwnode_endpoint___21;

struct fwnode_operations___21 {
	struct fwnode_handle___21 * (*get)(struct fwnode_handle___21 *);
	void (*put)(struct fwnode_handle___21 *);
	bool (*device_is_available)(const struct fwnode_handle___21 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___21 *, const struct device___24 *);
	bool (*property_present)(const struct fwnode_handle___21 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___21 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___21 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___21 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___21 *);
	struct fwnode_handle___21 * (*get_parent)(const struct fwnode_handle___21 *);
	struct fwnode_handle___21 * (*get_next_child_node)(const struct fwnode_handle___21 *, struct fwnode_handle___21 *);
	struct fwnode_handle___21 * (*get_named_child_node)(const struct fwnode_handle___21 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___21 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___21 *);
	struct fwnode_handle___21 * (*graph_get_next_endpoint)(const struct fwnode_handle___21 *, struct fwnode_handle___21 *);
	struct fwnode_handle___21 * (*graph_get_remote_endpoint)(const struct fwnode_handle___21 *);
	struct fwnode_handle___21 * (*graph_get_port_parent)(struct fwnode_handle___21 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___21 *, struct fwnode_endpoint___21 *);
	int (*add_links)(struct fwnode_handle___21 *);
};

struct fwnode_endpoint___21 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___21 *local_fwnode;
};

struct fwnode_reference_args___21 {
	struct fwnode_handle___21 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct pipe_buf_operations___5;

struct pipe_buffer___5 {
	struct page___23 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___5 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___5 {
	int (*confirm)(struct pipe_inode_info___5 *, struct pipe_buffer___5 *);
	void (*release)(struct pipe_inode_info___5 *, struct pipe_buffer___5 *);
	bool (*try_steal)(struct pipe_inode_info___5 *, struct pipe_buffer___5 *);
	bool (*get)(struct pipe_inode_info___5 *, struct pipe_buffer___5 *);
};

struct dcbnl_rtnl_ops___2 {
	int (*ieee_getets)(struct net_device___2 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___2 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___2 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___2 *, struct ieee_maxrate *);
	int (*ieee_getqcn)(struct net_device___2 *, struct ieee_qcn *);
	int (*ieee_setqcn)(struct net_device___2 *, struct ieee_qcn *);
	int (*ieee_getqcnstats)(struct net_device___2 *, struct ieee_qcn_stats *);
	int (*ieee_getpfc)(struct net_device___2 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___2 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___2 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___2 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___2 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___2 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___2 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___2 *);
	u8 (*setstate)(struct net_device___2 *, u8);
	void (*getpermhwaddr)(struct net_device___2 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___2 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___2 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___2 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___2 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___2 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___2 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___2 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___2 *, int, u8 *);
	void (*setpfccfg)(struct net_device___2 *, int, u8);
	void (*getpfccfg)(struct net_device___2 *, int, u8 *);
	u8 (*setall)(struct net_device___2 *);
	u8 (*getcap)(struct net_device___2 *, int, u8 *);
	int (*getnumtcs)(struct net_device___2 *, int, u8 *);
	int (*setnumtcs)(struct net_device___2 *, int, u8);
	u8 (*getpfcstate)(struct net_device___2 *);
	void (*setpfcstate)(struct net_device___2 *, u8);
	void (*getbcncfg)(struct net_device___2 *, int, u32 *);
	void (*setbcncfg)(struct net_device___2 *, int, u32);
	void (*getbcnrp)(struct net_device___2 *, int, u8 *);
	void (*setbcnrp)(struct net_device___2 *, int, u8);
	int (*setapp)(struct net_device___2 *, u8, u16, u8);
	int (*getapp)(struct net_device___2 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___2 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___2 *, int, u8);
	u8 (*getdcbx)(struct net_device___2 *);
	u8 (*setdcbx)(struct net_device___2 *, u8);
	int (*peer_getappinfo)(struct net_device___2 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___2 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___2 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___2 *, struct cee_pfc *);
	int (*dcbnl_getbuffer)(struct net_device___2 *, struct dcbnl_buffer *);
	int (*dcbnl_setbuffer)(struct net_device___2 *, struct dcbnl_buffer *);
};

struct cgroup_namespace___17 {
	struct ns_common ns;
	struct user_namespace *user_ns;
	struct ucounts *ucounts;
	struct css_set___17 *root_cset;
};

struct kernel_param_ops___21 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___21 *);
	int (*get)(char *, const struct kernel_param___21 *);
	void (*free)(void *);
};

struct kparam_array___21;

struct kernel_param___21 {
	const char *name;
	struct module___21 *mod;
	const struct kernel_param_ops___21 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___21 *arr;
	};
};

struct kparam_array___21 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___21 *ops;
	void *elem;
};

struct module_attribute___21 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___21 *, struct module_kobject___21 *, char *);
	ssize_t (*store)(struct module_attribute___21 *, struct module_kobject___21 *, const char *, size_t);
	void (*setup)(struct module___21 *, const char *);
	int (*test)(struct module___21 *);
	void (*free)(struct module___21 *);
};

struct bpf_iter_aux_info___2;

typedef int (*bpf_iter_init_seq_priv_t___2)(void *, struct bpf_iter_aux_info___2 *);

struct bpf_map___2;

struct bpf_iter_aux_info___2 {
	struct bpf_map___2 *map;
};

struct bpf_iter_seq_info___2 {
	const struct seq_operations___20 *seq_ops;
	bpf_iter_init_seq_priv_t___2 init_seq_private;
	bpf_iter_fini_seq_priv_t fini_seq_private;
	u32 seq_priv_size;
};

struct bpf_map_ops___2 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___2 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___2 *, struct file___22 *);
	void (*map_free)(struct bpf_map___2 *);
	int (*map_get_next_key)(struct bpf_map___2 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___2 *);
	void * (*map_lookup_elem_sys_only)(struct bpf_map___2 *, void *);
	int (*map_lookup_batch)(struct bpf_map___2 *, const union bpf_attr *, union bpf_attr *);
	int (*map_lookup_and_delete_elem)(struct bpf_map___2 *, void *, void *, u64);
	int (*map_lookup_and_delete_batch)(struct bpf_map___2 *, const union bpf_attr *, union bpf_attr *);
	int (*map_update_batch)(struct bpf_map___2 *, const union bpf_attr *, union bpf_attr *);
	int (*map_delete_batch)(struct bpf_map___2 *, const union bpf_attr *, union bpf_attr *);
	void * (*map_lookup_elem)(struct bpf_map___2 *, void *);
	int (*map_update_elem)(struct bpf_map___2 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___2 *, void *);
	int (*map_push_elem)(struct bpf_map___2 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___2 *, void *);
	int (*map_peek_elem)(struct bpf_map___2 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___2 *, struct file___22 *, int);
	void (*map_fd_put_ptr)(void *);
	int (*map_gen_lookup)(struct bpf_map___2 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___2 *, void *, struct seq_file___20 *);
	int (*map_check_btf)(const struct bpf_map___2 *, const struct btf *, const struct btf_type *, const struct btf_type *);
	int (*map_poke_track)(struct bpf_map___2 *, struct bpf_prog_aux___2 *);
	void (*map_poke_untrack)(struct bpf_map___2 *, struct bpf_prog_aux___2 *);
	void (*map_poke_run)(struct bpf_map___2 *, u32, struct bpf_prog___2 *, struct bpf_prog___2 *);
	int (*map_direct_value_addr)(const struct bpf_map___2 *, u64 *, u32);
	int (*map_direct_value_meta)(const struct bpf_map___2 *, u64, u32 *);
	int (*map_mmap)(struct bpf_map___2 *, struct vm_area_struct___24 *);
	__poll_t (*map_poll)(struct bpf_map___2 *, struct file___22 *, struct poll_table_struct *);
	int (*map_local_storage_charge)(struct bpf_local_storage_map *, void *, u32);
	void (*map_local_storage_uncharge)(struct bpf_local_storage_map *, void *, u32);
	struct bpf_local_storage ** (*map_owner_storage_ptr)(void *);
	int (*map_redirect)(struct bpf_map___2 *, u32, u64);
	bool (*map_meta_equal)(const struct bpf_map___2 *, const struct bpf_map___2 *);
	int (*map_set_for_each_callback_args)(struct bpf_verifier_env *, struct bpf_func_state *, struct bpf_func_state *);
	int (*map_for_each_callback)(struct bpf_map___2 *, void *, void *, u64);
	const char * const map_btf_name;
	int *map_btf_id;
	const struct bpf_iter_seq_info___2 *iter_seq_info;
};

struct bpf_map___2 {
	const struct bpf_map_ops___2 *ops;
	struct bpf_map___2 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	int spin_lock_off;
	int timer_off;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	struct mem_cgroup *memcg;
	char name[16];
	u32 btf_vmlinux_value_type_id;
	bool bypass_spec_v1;
	bool frozen;
	long: 16;
	long: 64;
	long: 64;
	atomic64_t refcnt;
	atomic64_t usercnt;
	struct work_struct work;
	struct mutex freeze_mutex;
	atomic64_t writecnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_trampoline___2;

struct bpf_jit_poke_descriptor___2;

struct bpf_prog_ops___2;

struct btf_mod_pair___2;

struct bpf_prog_offload___2;

struct bpf_prog_aux___2 {
	atomic64_t refcnt;
	u32 used_map_cnt;
	u32 used_btf_cnt;
	u32 max_ctx_offset;
	u32 max_pkt_offset;
	u32 max_tp_access;
	u32 stack_depth;
	u32 id;
	u32 func_cnt;
	u32 func_idx;
	u32 attach_btf_id;
	u32 ctx_arg_info_size;
	u32 max_rdonly_access;
	u32 max_rdwr_access;
	struct btf *attach_btf;
	const struct bpf_ctx_arg_aux *ctx_arg_info;
	struct mutex dst_mutex;
	struct bpf_prog___2 *dst_prog;
	struct bpf_trampoline___2 *dst_trampoline;
	enum bpf_prog_type saved_dst_prog_type;
	enum bpf_attach_type saved_dst_attach_type;
	bool verifier_zext;
	bool offload_requested;
	bool attach_btf_trace;
	bool func_proto_unreliable;
	bool sleepable;
	bool tail_call_reachable;
	struct hlist_node tramp_hlist;
	const struct btf_type *attach_func_proto;
	const char *attach_func_name;
	struct bpf_prog___2 **func;
	void *jit_data;
	struct bpf_jit_poke_descriptor___2 *poke_tab;
	struct bpf_kfunc_desc_tab *kfunc_tab;
	u32 size_poke_tab;
	struct bpf_ksym ksym;
	const struct bpf_prog_ops___2 *ops;
	struct bpf_map___2 **used_maps;
	struct mutex used_maps_mutex;
	struct btf_mod_pair___2 *used_btfs;
	struct bpf_prog___2 *prog;
	struct user_struct *user;
	u64 load_time;
	struct bpf_map___2 *cgroup_storage[2];
	char name[16];
	void *security;
	struct bpf_prog_offload___2 *offload;
	struct btf *btf;
	struct bpf_func_info *func_info;
	struct bpf_func_info_aux *func_info_aux;
	struct bpf_line_info *linfo;
	void **jited_linfo;
	u32 func_info_cnt;
	u32 nr_linfo;
	u32 linfo_idx;
	u32 num_exentries;
	struct exception_table_entry *extable;
	union {
		struct work_struct work;
		struct callback_head rcu;
	};
};

struct bpf_offloaded_map___2;

struct bpf_map_dev_ops___2 {
	int (*map_get_next_key)(struct bpf_offloaded_map___2 *, void *, void *);
	int (*map_lookup_elem)(struct bpf_offloaded_map___2 *, void *, void *);
	int (*map_update_elem)(struct bpf_offloaded_map___2 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_offloaded_map___2 *, void *);
};

struct bpf_offloaded_map___2 {
	struct bpf_map___2 map;
	struct net_device___2 *netdev;
	const struct bpf_map_dev_ops___2 *dev_ops;
	void *dev_priv;
	struct list_head offloads;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_prog_ops___2 {
	int (*test_run)(struct bpf_prog___2 *, const union bpf_attr *, union bpf_attr *);
};

struct bpf_prog_offload___2 {
	struct bpf_prog___2 *prog;
	struct net_device___2 *netdev;
	struct bpf_offload_dev *offdev;
	void *dev_priv;
	struct list_head offloads;
	bool dev_state;
	bool opt_failed;
	void *jited_image;
	u32 jited_len;
};

struct bpf_tramp_progs {
	struct bpf_prog___2 *progs[38];
	int nr_progs;
};

struct bpf_trampoline___2 {
	struct hlist_node hlist;
	struct mutex mutex;
	refcount_t refcnt;
	u64 key;
	struct {
		struct btf_func_model model;
		void *addr;
		bool ftrace_managed;
	} func;
	struct bpf_prog___2 *extension_prog;
	struct hlist_head progs_hlist[3];
	int progs_cnt[3];
	struct bpf_tramp_image *cur_image;
	u64 selector;
	struct module___21 *mod;
};

enum bpf_jit_poke_reason {
	BPF_POKE_REASON_TAIL_CALL = 0,
};

struct bpf_jit_poke_descriptor___2 {
	void *tailcall_target;
	void *tailcall_bypass;
	void *bypass_addr;
	void *aux;
	union {
		struct {
			struct bpf_map___2 *map;
			u32 key;
		} tail_call;
	};
	bool tailcall_target_stable;
	u8 adj_off;
	u16 reason;
	u32 insn_idx;
};

struct btf_mod_pair___2 {
	struct btf *btf;
	struct module___21 *module;
};

struct bpf_array_aux {
	struct {
		spinlock_t lock;
		enum bpf_prog_type type;
		bool jited;
	} owner;
	struct list_head poke_progs;
	struct bpf_map___2 *map;
	struct mutex poke_mutex;
	struct work_struct work;
};

struct bpf_array {
	struct bpf_map___2 map;
	u32 elem_size;
	u32 index_mask;
	struct bpf_array_aux *aux;
	union {
		char value[0];
		void *ptrs[0];
		void *pptrs[0];
	};
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

enum bpf_text_poke_type {
	BPF_MOD_CALL = 0,
	BPF_MOD_JUMP = 1,
};

struct cftype___17;

struct cgroup_subsys___17 {
	struct cgroup_subsys_state___17 * (*css_alloc)(struct cgroup_subsys_state___17 *);
	int (*css_online)(struct cgroup_subsys_state___17 *);
	void (*css_offline)(struct cgroup_subsys_state___17 *);
	void (*css_released)(struct cgroup_subsys_state___17 *);
	void (*css_free)(struct cgroup_subsys_state___17 *);
	void (*css_reset)(struct cgroup_subsys_state___17 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___17 *, int);
	int (*css_extra_stat_show)(struct seq_file___20 *, struct cgroup_subsys_state___17 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___25 *, struct css_set___17 *);
	void (*cancel_fork)(struct task_struct___25 *, struct css_set___17 *);
	void (*fork)(struct task_struct___25 *);
	void (*exit)(struct task_struct___25 *);
	void (*release)(struct task_struct___25 *);
	void (*bind)(struct cgroup_subsys_state___17 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___17 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___17 *dfl_cftypes;
	struct cftype___17 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___17 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___17 *updated_children;
	struct cgroup___17 *updated_next;
};

struct cgroup_root___17 {
	struct kernfs_root___22 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___17 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___17 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___17 *ss;
	struct list_head node;
	struct kernfs_ops___22 *kf_ops;
	int (*open)(struct kernfs_open_file___22 *);
	void (*release)(struct kernfs_open_file___22 *);
	u64 (*read_u64)(struct cgroup_subsys_state___17 *, struct cftype___17 *);
	s64 (*read_s64)(struct cgroup_subsys_state___17 *, struct cftype___17 *);
	int (*seq_show)(struct seq_file___20 *, void *);
	void * (*seq_start)(struct seq_file___20 *, loff_t *);
	void * (*seq_next)(struct seq_file___20 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___20 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___17 *, struct cftype___17 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___17 *, struct cftype___17 *, s64);
	ssize_t (*write)(struct kernfs_open_file___22 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___22 *, struct poll_table_struct *);
};

struct xdp_rxq_info___2 {
	struct net_device___2 *dev;
	u32 queue_index;
	u32 reg_state;
	struct xdp_mem_info mem;
	unsigned int napi_id;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct xdp_txq_info___2 {
	struct net_device___2 *dev;
};

struct xdp_buff___2 {
	void *data;
	void *data_end;
	void *data_meta;
	void *data_hard_start;
	struct xdp_rxq_info___2 *rxq;
	struct xdp_txq_info___2 *txq;
	u32 frame_sz;
};

struct xdp_frame___2 {
	void *data;
	u16 len;
	u16 headroom;
	u32 metasize: 8;
	u32 frame_sz: 24;
	long: 40;
	long: 64;
	struct xdp_mem_info mem;
	struct net_device___2 *dev_rx;
};

struct netlink_callback___2 {
	struct sk_buff___3 *skb;
	const struct nlmsghdr *nlh;
	int (*dump)(struct sk_buff___3 *, struct netlink_callback___2 *);
	int (*done)(struct netlink_callback___2 *);
	void *data;
	struct module___21 *module;
	struct netlink_ext_ack *extack;
	u16 family;
	u16 answer_flags;
	u32 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	bool strict_check;
	union {
		u8 ctx[48];
		long int args[6];
	};
};

struct header_ops___2 {
	int (*create)(struct sk_buff___3 *, struct net_device___2 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___3 *, unsigned char *);
	int (*cache)(const struct neighbour *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___2 *, const unsigned char *);
	bool (*validate)(const char *, unsigned int);
	__be16 (*parse_protocol)(const struct sk_buff___3 *);
};

struct netdev_queue___2 {
	struct net_device___2 *dev;
	struct Qdisc___2 *qdisc;
	struct Qdisc___2 *qdisc_sleeping;
	struct kobject___22 kobj;
	int numa_node;
	long unsigned int tx_maxrate;
	long unsigned int trans_timeout;
	struct net_device___2 *sb_dev;
	struct xsk_buff_pool *pool;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
};

struct qdisc_skb_head___2 {
	struct sk_buff___3 *head;
	struct sk_buff___3 *tail;
	__u32 qlen;
	spinlock_t lock;
};

struct Qdisc_ops___2;

struct Qdisc___2 {
	int (*enqueue)(struct sk_buff___3 *, struct Qdisc___2 *, struct sk_buff___3 **);
	struct sk_buff___3 * (*dequeue)(struct Qdisc___2 *);
	unsigned int flags;
	u32 limit;
	const struct Qdisc_ops___2 *ops;
	struct qdisc_size_table *stab;
	struct hlist_node hash;
	u32 handle;
	u32 parent;
	struct netdev_queue___2 *dev_queue;
	struct net_rate_estimator *rate_est;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	int pad;
	refcount_t refcnt;
	long: 64;
	long: 64;
	long: 64;
	struct sk_buff_head___2 gso_skb;
	struct qdisc_skb_head___2 q;
	struct gnet_stats_basic_packed bstats;
	seqcount_t running;
	struct gnet_stats_queue qstats;
	long unsigned int state;
	struct Qdisc___2 *next_sched;
	struct sk_buff_head___2 skb_bad_txq;
	spinlock_t busylock;
	spinlock_t seqlock;
	struct callback_head rcu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long int privdata[0];
};

struct netdev_rx_queue___2 {
	struct xdp_rxq_info___2 xdp_rxq;
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___22 kobj;
	struct net_device___2 *dev;
	struct xsk_buff_pool *pool;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct net_device_path___2 {
	enum net_device_path_type type;
	const struct net_device___2 *dev;
	union {
		struct {
			u16 id;
			__be16 proto;
			u8 h_dest[6];
		} encap;
		struct {
			enum {
				DEV_PATH_BR_VLAN_KEEP___2 = 0,
				DEV_PATH_BR_VLAN_TAG___2 = 1,
				DEV_PATH_BR_VLAN_UNTAG___2 = 2,
				DEV_PATH_BR_VLAN_UNTAG_HW___2 = 3,
			} vlan_mode;
			u16 vlan_id;
			__be16 vlan_proto;
		} bridge;
		struct {
			int port;
			u16 proto;
		} dsa;
	};
};

struct net_device_path_ctx___2 {
	const struct net_device___2 *dev;
	const u8 *daddr;
	int num_vlans;
	struct {
		u16 id;
		__be16 proto;
	} vlan[2];
};

struct netdev_bpf___2 {
	enum bpf_netdev_command command;
	union {
		struct {
			u32 flags;
			struct bpf_prog___2 *prog;
			struct netlink_ext_ack *extack;
		};
		struct {
			struct bpf_offloaded_map___2 *offmap;
		};
		struct {
			struct xsk_buff_pool *pool;
			u16 queue_id;
		} xsk;
	};
};

struct xfrmdev_ops___2 {
	int (*xdo_dev_state_add)(struct xfrm_state *);
	void (*xdo_dev_state_delete)(struct xfrm_state *);
	void (*xdo_dev_state_free)(struct xfrm_state *);
	bool (*xdo_dev_offload_ok)(struct sk_buff___3 *, struct xfrm_state *);
	void (*xdo_dev_state_advance_esn)(struct xfrm_state *);
};

struct netdev_name_node___2 {
	struct hlist_node hlist;
	struct list_head list;
	struct net_device___2 *dev;
	const char *name;
};

struct neigh_parms___2;

struct net_device_ops___2 {
	int (*ndo_init)(struct net_device___2 *);
	void (*ndo_uninit)(struct net_device___2 *);
	int (*ndo_open)(struct net_device___2 *);
	int (*ndo_stop)(struct net_device___2 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___3 *, struct net_device___2 *);
	netdev_features_t (*ndo_features_check)(struct sk_buff___3 *, struct net_device___2 *, netdev_features_t);
	u16 (*ndo_select_queue)(struct net_device___2 *, struct sk_buff___3 *, struct net_device___2 *);
	void (*ndo_change_rx_flags)(struct net_device___2 *, int);
	void (*ndo_set_rx_mode)(struct net_device___2 *);
	int (*ndo_set_mac_address)(struct net_device___2 *, void *);
	int (*ndo_validate_addr)(struct net_device___2 *);
	int (*ndo_do_ioctl)(struct net_device___2 *, struct ifreq *, int);
	int (*ndo_eth_ioctl)(struct net_device___2 *, struct ifreq *, int);
	int (*ndo_siocbond)(struct net_device___2 *, struct ifreq *, int);
	int (*ndo_siocwandev)(struct net_device___2 *, struct if_settings *);
	int (*ndo_siocdevprivate)(struct net_device___2 *, struct ifreq *, void *, int);
	int (*ndo_set_config)(struct net_device___2 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___2 *, int);
	int (*ndo_neigh_setup)(struct net_device___2 *, struct neigh_parms___2 *);
	void (*ndo_tx_timeout)(struct net_device___2 *, unsigned int);
	void (*ndo_get_stats64)(struct net_device___2 *, struct rtnl_link_stats64 *);
	bool (*ndo_has_offload_stats)(const struct net_device___2 *, int);
	int (*ndo_get_offload_stats)(int, const struct net_device___2 *, void *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___2 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___2 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___2 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___2 *);
	int (*ndo_netpoll_setup)(struct net_device___2 *, struct netpoll_info *);
	void (*ndo_netpoll_cleanup)(struct net_device___2 *);
	int (*ndo_set_vf_mac)(struct net_device___2 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___2 *, int, u16, u8, __be16);
	int (*ndo_set_vf_rate)(struct net_device___2 *, int, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___2 *, int, bool);
	int (*ndo_set_vf_trust)(struct net_device___2 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___2 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___2 *, int, int);
	int (*ndo_get_vf_stats)(struct net_device___2 *, int, struct ifla_vf_stats *);
	int (*ndo_set_vf_port)(struct net_device___2 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___2 *, int, struct sk_buff___3 *);
	int (*ndo_get_vf_guid)(struct net_device___2 *, int, struct ifla_vf_guid *, struct ifla_vf_guid *);
	int (*ndo_set_vf_guid)(struct net_device___2 *, int, u64, int);
	int (*ndo_set_vf_rss_query_en)(struct net_device___2 *, int, bool);
	int (*ndo_setup_tc)(struct net_device___2 *, enum tc_setup_type, void *);
	int (*ndo_fcoe_enable)(struct net_device___2 *);
	int (*ndo_fcoe_disable)(struct net_device___2 *);
	int (*ndo_fcoe_ddp_setup)(struct net_device___2 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_ddp_done)(struct net_device___2 *, u16);
	int (*ndo_fcoe_ddp_target)(struct net_device___2 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_get_hbainfo)(struct net_device___2 *, struct netdev_fcoe_hbainfo *);
	int (*ndo_fcoe_get_wwn)(struct net_device___2 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___2 *, const struct sk_buff___3 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___2 *, struct net_device___2 *, struct netlink_ext_ack *);
	int (*ndo_del_slave)(struct net_device___2 *, struct net_device___2 *);
	struct net_device___2 * (*ndo_get_xmit_slave)(struct net_device___2 *, struct sk_buff___3 *, bool);
	struct net_device___2 * (*ndo_sk_get_lower_dev)(struct net_device___2 *, struct sock *);
	netdev_features_t (*ndo_fix_features)(struct net_device___2 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___2 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct net_device___2 *, struct neighbour *);
	void (*ndo_neigh_destroy)(struct net_device___2 *, struct neighbour *);
	int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___2 *, const unsigned char *, u16, u16, struct netlink_ext_ack *);
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___2 *, const unsigned char *, u16);
	int (*ndo_fdb_dump)(struct sk_buff___3 *, struct netlink_callback___2 *, struct net_device___2 *, struct net_device___2 *, int *);
	int (*ndo_fdb_get)(struct sk_buff___3 *, struct nlattr **, struct net_device___2 *, const unsigned char *, u16, u32, u32, struct netlink_ext_ack *);
	int (*ndo_bridge_setlink)(struct net_device___2 *, struct nlmsghdr *, u16, struct netlink_ext_ack *);
	int (*ndo_bridge_getlink)(struct sk_buff___3 *, u32, u32, struct net_device___2 *, u32, int);
	int (*ndo_bridge_dellink)(struct net_device___2 *, struct nlmsghdr *, u16);
	int (*ndo_change_carrier)(struct net_device___2 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___2 *, struct netdev_phys_item_id *);
	int (*ndo_get_port_parent_id)(struct net_device___2 *, struct netdev_phys_item_id *);
	int (*ndo_get_phys_port_name)(struct net_device___2 *, char *, size_t);
	void * (*ndo_dfwd_add_station)(struct net_device___2 *, struct net_device___2 *);
	void (*ndo_dfwd_del_station)(struct net_device___2 *, void *);
	int (*ndo_set_tx_maxrate)(struct net_device___2 *, int, u32);
	int (*ndo_get_iflink)(const struct net_device___2 *);
	int (*ndo_change_proto_down)(struct net_device___2 *, bool);
	int (*ndo_fill_metadata_dst)(struct net_device___2 *, struct sk_buff___3 *);
	void (*ndo_set_rx_headroom)(struct net_device___2 *, int);
	int (*ndo_bpf)(struct net_device___2 *, struct netdev_bpf___2 *);
	int (*ndo_xdp_xmit)(struct net_device___2 *, int, struct xdp_frame___2 **, u32);
	struct net_device___2 * (*ndo_xdp_get_xmit_slave)(struct net_device___2 *, struct xdp_buff___2 *);
	int (*ndo_xsk_wakeup)(struct net_device___2 *, u32, u32);
	struct devlink_port * (*ndo_get_devlink_port)(struct net_device___2 *);
	int (*ndo_tunnel_ctl)(struct net_device___2 *, struct ip_tunnel_parm *, int);
	struct net_device___2 * (*ndo_get_peer_dev)(struct net_device___2 *);
	int (*ndo_fill_forward_path)(struct net_device_path_ctx___2 *, struct net_device_path___2 *);
};

struct tcf_proto___2;

struct tcf_block___2;

struct mini_Qdisc___2 {
	struct tcf_proto___2 *filter_list;
	struct tcf_block___2 *block;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	struct callback_head rcu;
};

struct rtnl_link_ops___2 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	struct net_device___2 * (*alloc)(struct nlattr **, const char *, unsigned char, unsigned int, unsigned int);
	void (*setup)(struct net_device___2 *);
	bool netns_refund;
	unsigned int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*newlink)(struct net___3 *, struct net_device___2 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*changelink)(struct net_device___2 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	void (*dellink)(struct net_device___2 *, struct list_head *);
	size_t (*get_size)(const struct net_device___2 *);
	int (*fill_info)(struct sk_buff___3 *, const struct net_device___2 *);
	size_t (*get_xstats_size)(const struct net_device___2 *);
	int (*fill_xstats)(struct sk_buff___3 *, const struct net_device___2 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	unsigned int slave_maxtype;
	const struct nla_policy *slave_policy;
	int (*slave_changelink)(struct net_device___2 *, struct net_device___2 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	size_t (*get_slave_size)(const struct net_device___2 *, const struct net_device___2 *);
	int (*fill_slave_info)(struct sk_buff___3 *, const struct net_device___2 *, const struct net_device___2 *);
	struct net___3 * (*get_link_net)(const struct net_device___2 *);
	size_t (*get_linkxstats_size)(const struct net_device___2 *, int);
	int (*fill_linkxstats)(struct sk_buff___3 *, const struct net_device___2 *, int *, int);
};

struct gnet_dump___2 {
	spinlock_t *lock;
	struct sk_buff___3 *skb;
	struct nlattr *tail;
	int compat_tc_stats;
	int compat_xstats;
	int padattr;
	void *xstats;
	int xstats_len;
	struct tc_stats tc_stats;
};

struct Qdisc_class_ops___2;

struct Qdisc_ops___2 {
	struct Qdisc_ops___2 *next;
	const struct Qdisc_class_ops___2 *cl_ops;
	char id[16];
	int priv_size;
	unsigned int static_flags;
	int (*enqueue)(struct sk_buff___3 *, struct Qdisc___2 *, struct sk_buff___3 **);
	struct sk_buff___3 * (*dequeue)(struct Qdisc___2 *);
	struct sk_buff___3 * (*peek)(struct Qdisc___2 *);
	int (*init)(struct Qdisc___2 *, struct nlattr *, struct netlink_ext_ack *);
	void (*reset)(struct Qdisc___2 *);
	void (*destroy)(struct Qdisc___2 *);
	int (*change)(struct Qdisc___2 *, struct nlattr *, struct netlink_ext_ack *);
	void (*attach)(struct Qdisc___2 *);
	int (*change_tx_queue_len)(struct Qdisc___2 *, unsigned int);
	void (*change_real_num_tx)(struct Qdisc___2 *, unsigned int);
	int (*dump)(struct Qdisc___2 *, struct sk_buff___3 *);
	int (*dump_stats)(struct Qdisc___2 *, struct gnet_dump___2 *);
	void (*ingress_block_set)(struct Qdisc___2 *, u32);
	void (*egress_block_set)(struct Qdisc___2 *, u32);
	u32 (*ingress_block_get)(struct Qdisc___2 *);
	u32 (*egress_block_get)(struct Qdisc___2 *);
	struct module___21 *owner;
};

struct Qdisc_class_ops___2 {
	unsigned int flags;
	struct netdev_queue___2 * (*select_queue)(struct Qdisc___2 *, struct tcmsg *);
	int (*graft)(struct Qdisc___2 *, long unsigned int, struct Qdisc___2 *, struct Qdisc___2 **, struct netlink_ext_ack *);
	struct Qdisc___2 * (*leaf)(struct Qdisc___2 *, long unsigned int);
	void (*qlen_notify)(struct Qdisc___2 *, long unsigned int);
	long unsigned int (*find)(struct Qdisc___2 *, u32);
	int (*change)(struct Qdisc___2 *, u32, u32, struct nlattr **, long unsigned int *, struct netlink_ext_ack *);
	int (*delete)(struct Qdisc___2 *, long unsigned int, struct netlink_ext_ack *);
	void (*walk)(struct Qdisc___2 *, struct qdisc_walker *);
	struct tcf_block___2 * (*tcf_block)(struct Qdisc___2 *, long unsigned int, struct netlink_ext_ack *);
	long unsigned int (*bind_tcf)(struct Qdisc___2 *, long unsigned int, u32);
	void (*unbind_tcf)(struct Qdisc___2 *, long unsigned int);
	int (*dump)(struct Qdisc___2 *, long unsigned int, struct sk_buff___3 *, struct tcmsg *);
	int (*dump_stats)(struct Qdisc___2 *, long unsigned int, struct gnet_dump___2 *);
};

struct tcf_chain___2;

struct tcf_block___2 {
	struct mutex lock;
	struct list_head chain_list;
	u32 index;
	u32 classid;
	refcount_t refcnt;
	struct net___3 *net;
	struct Qdisc___2 *q;
	struct rw_semaphore cb_lock;
	struct flow_block flow_block;
	struct list_head owner_list;
	bool keep_dst;
	atomic_t offloadcnt;
	unsigned int nooffloaddevcnt;
	unsigned int lockeddevcnt;
	struct {
		struct tcf_chain___2 *chain;
		struct list_head filter_chain_list;
	} chain0;
	struct callback_head rcu;
	struct hlist_head proto_destroy_ht[128];
	struct mutex proto_destroy_lock;
};

struct tcf_result___2;

struct tcf_proto_ops___2;

struct tcf_proto___2 {
	struct tcf_proto___2 *next;
	void *root;
	int (*classify)(struct sk_buff___3 *, const struct tcf_proto___2 *, struct tcf_result___2 *);
	__be16 protocol;
	u32 prio;
	void *data;
	const struct tcf_proto_ops___2 *ops;
	struct tcf_chain___2 *chain;
	spinlock_t lock;
	bool deleting;
	refcount_t refcnt;
	struct callback_head rcu;
	struct hlist_node destroy_ht_node;
};

struct tcf_result___2 {
	union {
		struct {
			long unsigned int class;
			u32 classid;
		};
		const struct tcf_proto___2 *goto_tp;
		struct {
			bool ingress;
			struct gnet_stats_queue *qstats;
		};
	};
};

struct tcf_proto_ops___2 {
	struct list_head head;
	char kind[16];
	int (*classify)(struct sk_buff___3 *, const struct tcf_proto___2 *, struct tcf_result___2 *);
	int (*init)(struct tcf_proto___2 *);
	void (*destroy)(struct tcf_proto___2 *, bool, struct netlink_ext_ack *);
	void * (*get)(struct tcf_proto___2 *, u32);
	void (*put)(struct tcf_proto___2 *, void *);
	int (*change)(struct net___3 *, struct sk_buff___3 *, struct tcf_proto___2 *, long unsigned int, u32, struct nlattr **, void **, u32, struct netlink_ext_ack *);
	int (*delete)(struct tcf_proto___2 *, void *, bool *, bool, struct netlink_ext_ack *);
	bool (*delete_empty)(struct tcf_proto___2 *);
	void (*walk)(struct tcf_proto___2 *, struct tcf_walker *, bool);
	int (*reoffload)(struct tcf_proto___2 *, bool, flow_setup_cb_t *, void *, struct netlink_ext_ack *);
	void (*hw_add)(struct tcf_proto___2 *, void *);
	void (*hw_del)(struct tcf_proto___2 *, void *);
	void (*bind_class)(void *, u32, long unsigned int, void *, long unsigned int);
	void * (*tmplt_create)(struct net___3 *, struct tcf_chain___2 *, struct nlattr **, struct netlink_ext_ack *);
	void (*tmplt_destroy)(void *);
	int (*dump)(struct net___3 *, struct tcf_proto___2 *, void *, struct sk_buff___3 *, struct tcmsg *, bool);
	int (*terse_dump)(struct net___3 *, struct tcf_proto___2 *, void *, struct sk_buff___3 *, struct tcmsg *, bool);
	int (*tmplt_dump)(struct sk_buff___3 *, struct net___3 *, void *);
	struct module___21 *owner;
	int flags;
};

struct tcf_chain___2 {
	struct mutex filter_chain_lock;
	struct tcf_proto___2 *filter_chain;
	struct list_head list;
	struct tcf_block___2 *block;
	u32 index;
	unsigned int refcnt;
	unsigned int action_refcnt;
	bool explicitly_created;
	bool flushing;
	const struct tcf_proto_ops___2 *tmplt_ops;
	void *tmplt_priv;
	struct callback_head rcu;
};

struct bpf_binary_header {
	u32 pages;
	int: 32;
	u8 image[0];
};

typedef void (*bpf_jit_fill_hole_t)(void *, unsigned int);

struct jit_context {
	int cleanup_addr;
	int tail_call_direct_label;
	int tail_call_indirect_label;
};

struct x64_jit_data {
	struct bpf_binary_header *header;
	int *addrs;
	u8 *image;
	int proglen;
	struct jit_context ctx;
};

struct fs_context___5;

struct fs_parameter_spec___3;

struct dentry___23;

struct super_block___23;

struct module___22;

struct file_system_type___23 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context___5 *);
	const struct fs_parameter_spec___3 *parameters;
	struct dentry___23 * (*mount)(struct file_system_type___23 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___23 *);
	struct module___22 *owner;
	struct file_system_type___23 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___23;

struct kiocb___23;

struct iov_iter___18;

struct poll_table_struct___16;

struct vm_area_struct___25;

struct inode___23;

struct file_lock___23;

struct page___24;

struct pipe_inode_info___6;

struct seq_file___21;

struct file_operations___23 {
	struct module___22 *owner;
	loff_t (*llseek)(struct file___23 *, loff_t, int);
	ssize_t (*read)(struct file___23 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___23 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___23 *, struct iov_iter___18 *);
	ssize_t (*write_iter)(struct kiocb___23 *, struct iov_iter___18 *);
	int (*iopoll)(struct kiocb___23 *, bool);
	int (*iterate)(struct file___23 *, struct dir_context *);
	int (*iterate_shared)(struct file___23 *, struct dir_context *);
	__poll_t (*poll)(struct file___23 *, struct poll_table_struct___16 *);
	long int (*unlocked_ioctl)(struct file___23 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___23 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___23 *, struct vm_area_struct___25 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___23 *, struct file___23 *);
	int (*flush)(struct file___23 *, fl_owner_t);
	int (*release)(struct inode___23 *, struct file___23 *);
	int (*fsync)(struct file___23 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___23 *, int);
	int (*lock)(struct file___23 *, int, struct file_lock___23 *);
	ssize_t (*sendpage)(struct file___23 *, struct page___24 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___23 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___23 *, long unsigned int);
	int (*flock)(struct file___23 *, int, struct file_lock___23 *);
	ssize_t (*splice_write)(struct pipe_inode_info___6 *, struct file___23 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___23 *, loff_t *, struct pipe_inode_info___6 *, size_t, unsigned int);
	int (*setlease)(struct file___23 *, long int, struct file_lock___23 **, void **);
	long int (*fallocate)(struct file___23 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___21 *, struct file___23 *);
	ssize_t (*copy_file_range)(struct file___23 *, loff_t, struct file___23 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___23 *, loff_t, struct file___23 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___23 *, loff_t, loff_t, int);
};

struct static_call_mod___16 {
	struct static_call_mod___16 *next;
	struct module___22 *mod;
	struct static_call_site *sites;
};

struct static_call_key___16 {
	void *func;
	union {
		long unsigned int type;
		struct static_call_mod___16 *mods;
		struct static_call_site *sites;
	};
};

struct vmacache___24 {
	u64 seqnum;
	struct vm_area_struct___25 *vmas[4];
};

struct page_frag___24 {
	struct page___24 *page;
	__u32 offset;
	__u32 size;
};

struct perf_event___13;

struct thread_struct___14 {
	struct desc_struct tls_array[3];
	long unsigned int sp;
	short unsigned int es;
	short unsigned int ds;
	short unsigned int fsindex;
	short unsigned int gsindex;
	long unsigned int fsbase;
	long unsigned int gsbase;
	struct perf_event___13 *ptrace_bps[4];
	long unsigned int virtual_dr6;
	long unsigned int ptrace_dr7;
	long unsigned int cr2;
	long unsigned int trap_nr;
	long unsigned int error_code;
	struct io_bitmap *io_bitmap;
	long unsigned int iopl_emul;
	unsigned int iopl_warn: 1;
	unsigned int sig_on_uaccess_err: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u32 pkru;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct fpu fpu;
};

struct mm_struct___25;

struct pid___19;

struct fs_struct___3;

struct files_struct___2;

struct nsproxy___22;

struct signal_struct___24;

struct bio_list___14;

struct backing_dev_info___13;

struct io_context___15;

struct css_set___18;

struct robust_list_head___2;

struct perf_event_context___13;

struct mem_cgroup___13;

struct request_queue___14;

struct vm_struct___20;

struct task_struct___26 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___26 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___25 *mm;
	struct mm_struct___25 *active_mm;
	struct vmacache___24 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int restore_sigmask: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___26 *real_parent;
	struct task_struct___26 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___26 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___19 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	struct posix_cputimers_work posix_cputimers_work;
	const struct cred *ptracer_cred;
	const struct cred *real_cred;
	const struct cred *cred;
	struct key *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct___3 *fs;
	struct files_struct___2 *files;
	struct io_uring_task *io_uring;
	struct nsproxy___22 *nsproxy;
	struct signal_struct___24 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___26 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___14 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___13 *backing_dev_info;
	struct io_context___15 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___18 *cgroups;
	struct list_head cg_list;
	u32 closid;
	u32 rmid;
	struct robust_list_head___2 *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___13 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	long: 64;
	long: 64;
	struct pipe_inode_info___6 *splice_pipe;
	struct page_frag___24 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___13 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___13 *active_memcg;
	struct request_queue___14 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___26 *oom_reaper_list;
	struct vm_struct___20 *stack_vm_area;
	refcount_t stack_refcount;
	int patch_state;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	void *mce_vaddr;
	__u64 mce_kflags;
	u64 mce_addr;
	__u64 mce_ripv: 1;
	__u64 mce_whole_page: 1;
	__u64 __mce_reserved: 62;
	long: 2;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct callback_head mce_kill_me;
	int mce_count;
	struct llist_head kretprobe_instances;
	struct callback_head l1d_flush_kill;
	long: 64;
	struct thread_struct___14 thread;
};

typedef struct page___24 *pgtable_t___24;

struct address_space___23;

struct page_pool___6;

struct dev_pagemap___23;

struct page___24 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___23 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___6 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___24 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___24 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___25 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___23 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct pv_cpu_ops___19 {
	void (*io_delay)();
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	void (*write_cr4)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___14 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(long unsigned int);
	void (*invalidate_io_bitmap)();
	void (*update_io_bitmap)();
	void (*wbinvd)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int);
	void (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_msr_safe)(unsigned int, int *);
	int (*write_msr_safe)(unsigned int, unsigned int, unsigned int);
	u64 (*read_pmc)(int);
	void (*start_context_switch)(struct task_struct___26 *);
	void (*end_context_switch)(struct task_struct___26 *);
};

struct flush_tlb_info___9;

struct pv_mmu_ops___20 {
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_one_user)(long unsigned int);
	void (*flush_tlb_multi)(const struct cpumask *, const struct flush_tlb_info___9 *);
	void (*tlb_remove_table)(struct mmu_gather *, void *);
	void (*exit_mmap)(struct mm_struct___25 *);
	struct paravirt_callee_save read_cr2;
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___25 *, struct mm_struct___25 *);
	void (*dup_mmap)(struct mm_struct___25 *, struct mm_struct___25 *);
	int (*pgd_alloc)(struct mm_struct___25 *);
	void (*pgd_free)(struct mm_struct___25 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___25 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___25 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___25 *, long unsigned int);
	void (*alloc_p4d)(struct mm_struct___25 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*release_p4d)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	pte_t (*ptep_modify_prot_start)(struct vm_area_struct___25 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct vm_area_struct___25 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_p4d)(p4d_t *, p4d_t);
	struct paravirt_callee_save p4d_val;
	struct paravirt_callee_save make_p4d;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

struct flush_tlb_info___9 {
	struct mm_struct___25 *mm;
	long unsigned int start;
	long unsigned int end;
	u64 new_tlb_gen;
	unsigned int initiating_cpu;
	u8 stride_shift;
	u8 freed_tables;
};

struct linux_binfmt___3;

struct core_state___24;

struct mm_struct___25 {
	struct {
		struct vm_area_struct___25 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___23 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int mmap_compat_base;
		long unsigned int mmap_compat_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[48];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___3 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___24 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___26 *owner;
		struct user_namespace *user_ns;
		struct file___23 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		bool tlb_flush_batched;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct vm_operations_struct___23;

struct vm_area_struct___25 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___25 *vm_next;
	struct vm_area_struct___25 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___25 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___23 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___23 *vm_file;
	struct file___23 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct paravirt_patch_template___20 {
	struct pv_cpu_ops___19 cpu;
	struct pv_irq_ops irq;
	struct pv_mmu_ops___20 mmu;
	struct pv_lock_ops lock;
};

struct tracepoint___16 {
	const char *name;
	struct static_key key;
	struct static_call_key___16 *static_call_key;
	void *static_call_tramp;
	void *iterator;
	int (*regfunc)();
	void (*unregfunc)();
	struct tracepoint_func *funcs;
};

struct bpf_raw_event_map___16 {
	struct tracepoint___16 *tp;
	void *bpf_func;
	u32 num_args;
	u32 writable_size;
	long: 64;
};

struct seq_operations___21 {
	void * (*start)(struct seq_file___21 *, loff_t *);
	void (*stop)(struct seq_file___21 *, void *);
	void * (*next)(struct seq_file___21 *, void *, loff_t *);
	int (*show)(struct seq_file___21 *, void *);
};

struct hw_perf_event___13 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___26 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	union {
		struct {
			u64 last_period;
			local64_t period_left;
		};
		struct {
			u64 saved_metric;
			u64 saved_slots;
		};
	};
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___13)(struct perf_event___13 *, struct perf_sample_data___2 *, struct pt_regs *);

struct pmu___13;

struct fasync_struct___23;

struct pid_namespace___19;

struct trace_event_call___13;

struct perf_cgroup___13;

struct perf_event___13 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___13 *group_leader;
	struct pmu___13 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___13 hw;
	struct perf_event_context___13 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___13 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___26 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct perf_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___23 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	long unsigned int pending_addr;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	struct perf_addr_filter_range *addr_filter_ranges;
	long unsigned int addr_filters_gen;
	struct perf_event___13 *aux_event;
	void (*destroy)(struct perf_event___13 *);
	struct callback_head callback_head;
	struct pid_namespace___19 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___13 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___13 orig_overflow_handler;
	struct bpf_prog *prog;
	u64 bpf_cookie;
	struct trace_event_call___13 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___13 *cgrp;
	void *security;
	struct list_head sb_list;
};

enum tk_offsets {
	TK_OFFS_REAL = 0,
	TK_OFFS_BOOT = 1,
	TK_OFFS_TAI = 2,
	TK_OFFS_MAX = 3,
};

struct address_space_operations___23;

struct address_space___23 {
	struct inode___23 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___23 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct device___25;

struct page_pool_params___6 {
	unsigned int flags;
	unsigned int order;
	unsigned int pool_size;
	int nid;
	struct device___25 *dev;
	enum dma_data_direction dma_dir;
	unsigned int max_len;
	unsigned int offset;
};

struct pp_alloc_cache___6 {
	u32 count;
	struct page___24 *cache[128];
};

struct page_pool___6 {
	struct page_pool_params___6 p;
	struct delayed_work release_dw;
	void (*disconnect)(void *);
	long unsigned int defer_start;
	long unsigned int defer_warn;
	u32 pages_state_hold_cnt;
	unsigned int frag_offset;
	struct page___24 *frag_page;
	long int frag_users;
	long: 64;
	long: 64;
	struct pp_alloc_cache___6 alloc;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct ptr_ring ring;
	atomic_t pages_state_release_cnt;
	refcount_t user_cnt;
	u64 destroy_cnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pagemap_ops___23;

struct dev_pagemap___23 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___23 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

typedef long unsigned int vm_flags_t;

struct vfsmount___23;

struct path___23 {
	struct vfsmount___23 *mnt;
	struct dentry___23 *dentry;
};

struct fown_struct___19 {
	rwlock_t lock;
	struct pid___19 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___23 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	long: 64;
	long: 64;
	struct path___23 f_path;
	struct inode___23 *f_inode;
	const struct file_operations___23 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___19 f_owner;
	const struct cred *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___23 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___23;

struct vm_operations_struct___23 {
	void (*open)(struct vm_area_struct___25 *);
	void (*close)(struct vm_area_struct___25 *);
	int (*may_split)(struct vm_area_struct___25 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___25 *);
	int (*mprotect)(struct vm_area_struct___25 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___23 *);
	vm_fault_t (*huge_fault)(struct vm_fault___23 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___23 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___25 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___23 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___23 *);
	int (*access)(struct vm_area_struct___25 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___25 *);
	int (*set_policy)(struct vm_area_struct___25 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___25 *, long unsigned int);
	struct page___24 * (*find_special_page)(struct vm_area_struct___25 *, long unsigned int);
};

struct core_thread___24 {
	struct task_struct___26 *task;
	struct core_thread___24 *next;
};

struct core_state___24 {
	atomic_t nr_threads;
	struct core_thread___24 dumper;
	struct completion startup;
};

struct linux_binprm___4;

struct coredump_params___3;

struct linux_binfmt___3 {
	struct list_head lh;
	struct module___22 *module;
	int (*load_binary)(struct linux_binprm___4 *);
	int (*load_shlib)(struct file___23 *);
	int (*core_dump)(struct coredump_params___3 *);
	long unsigned int min_coredump;
};

struct vm_fault___23 {
	const struct {
		struct vm_area_struct___25 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___24 *cow_page;
	struct page___24 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___24 prealloc_pte;
};

struct pglist_data___14;

struct lruvec___14 {
	struct list_head lists[5];
	spinlock_t lru_lock;
	long unsigned int anon_cost;
	long unsigned int file_cost;
	atomic_long_t nonresident_age;
	long unsigned int refaults[2];
	long unsigned int flags;
	struct pglist_data___14 *pgdat;
};

struct zone___14 {
	long unsigned int _watermark[3];
	long unsigned int watermark_boost;
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[5];
	int node;
	struct pglist_data___14 *zone_pgdat;
	struct per_cpu_pages *per_cpu_pageset;
	struct per_cpu_zonestat *per_cpu_zonestats;
	int pageset_high;
	int pageset_batch;
	long unsigned int zone_start_pfn;
	atomic_long_t managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int present_early_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	seqlock_t span_seqlock;
	int initialized;
	int: 32;
	struct zone_padding _pad1_;
	struct free_area free_area[11];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	long unsigned int compact_init_migrate_pfn;
	long unsigned int compact_init_free_pfn;
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	short: 16;
	struct zone_padding _pad3_;
	atomic_long_t vm_stat[11];
	atomic_long_t vm_numa_event[6];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___14 {
	struct zone___14 *zone;
	int zone_idx;
};

struct zonelist___14 {
	struct zoneref___14 _zonerefs[5121];
};

struct pglist_data___14 {
	struct zone___14 node_zones[5];
	struct zonelist___14 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___26 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_highest_zoneidx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_highest_zoneidx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___26 *kcompactd;
	bool proactive_compact_trigger;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct deferred_split deferred_split_queue;
	struct lruvec___14 __lruvec;
	long unsigned int flags;
	long: 64;
	struct zone_padding _pad2_;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[39];
};

struct clone_args {
	__u64 flags;
	__u64 pidfd;
	__u64 child_tid;
	__u64 parent_tid;
	__u64 exit_signal;
	__u64 stack;
	__u64 stack_size;
	__u64 tls;
	__u64 set_tid;
	__u64 set_tid_size;
	__u64 cgroup;
};

struct upid___19 {
	int nr;
	struct pid_namespace___19 *ns;
};

struct pid_namespace___19 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___26 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___19 *parent;
	struct fs_pin *bacct;
	struct user_namespace *user_ns;
	struct ucounts *ucounts;
	int reboot;
	struct ns_common ns;
};

struct pid___19 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___19 numbers[1];
};

struct tty_struct___3;

struct signal_struct___24 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___26 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___26 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___19 *pids[4];
	struct pid___19 *tty_old_pgrp;
	int leader;
	struct tty_struct___3 *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___25 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct fs_struct___3 {
	int users;
	spinlock_t lock;
	seqcount_spinlock_t seq;
	int umask;
	int in_exec;
	struct path___23 root;
	struct path___23 pwd;
};

struct fdtable {
	unsigned int max_fds;
	struct file___23 **fd;
	long unsigned int *close_on_exec;
	long unsigned int *open_fds;
	long unsigned int *full_fds_bits;
	struct callback_head rcu;
};

struct files_struct___2 {
	atomic_t count;
	bool resize_in_progress;
	wait_queue_head_t resize_wait;
	struct fdtable *fdt;
	struct fdtable fdtab;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t file_lock;
	unsigned int next_fd;
	long unsigned int close_on_exec_init[1];
	long unsigned int open_fds_init[1];
	long unsigned int full_fds_bits_init[1];
	struct file___23 *fd_array[64];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct cgroup_namespace___18;

struct nsproxy___22 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___19 *pid_ns_for_children;
	struct net___3 *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___18 *cgroup_ns;
};

struct bio___14;

struct bio_list___14 {
	struct bio___14 *head;
	struct bio___14 *tail;
};

struct cgroup_subsys_state___18;

struct bdi_writeback___13 {
	struct backing_dev_info___13 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	atomic_t writeback_inodes;
	struct percpu_counter stat[4];
	long unsigned int congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	struct delayed_work bw_dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___18 *memcg_css;
	struct cgroup_subsys_state___18 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	struct list_head b_attached;
	struct list_head offline_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
};

struct backing_dev_info___13 {
	u64 id;
	struct rb_node rb_node;
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___13 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct mutex cgwb_release_mutex;
	struct rw_semaphore wb_switch_rwsem;
	wait_queue_head_t wb_waitq;
	struct device___25 *dev;
	char dev_name[64];
	struct device___25 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___23 *debug_dir;
};

struct io_cq___14;

struct io_context___15 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	struct xarray icq_tree;
	struct io_cq___14 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct cgroup___18;

struct css_set___18 {
	struct cgroup_subsys_state___18 *subsys[14];
	refcount_t refcount;
	struct css_set___18 *dom_cset;
	struct cgroup___18 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___18 *mg_src_cgrp;
	struct cgroup___18 *mg_dst_cgrp;
	struct css_set___18 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct robust_list {
	struct robust_list *next;
};

struct robust_list_head___2 {
	struct robust_list list;
	long int futex_offset;
	struct robust_list *list_op_pending;
};

struct perf_event_context___13 {
	struct pmu___13 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	int rotate_necessary;
	refcount_t refcount;
	struct task_struct___26 *task;
	u64 time;
	u64 timestamp;
	u64 timeoffset;
	struct perf_event_context___13 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

struct pipe_buffer___6;

struct pipe_inode_info___6 {
	struct mutex mutex;
	wait_queue_head_t rd_wait;
	wait_queue_head_t wr_wait;
	unsigned int head;
	unsigned int tail;
	unsigned int max_usage;
	unsigned int ring_size;
	bool note_loss;
	unsigned int nr_accounted;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int r_counter;
	unsigned int w_counter;
	unsigned int poll_usage;
	struct page___24 *tmp_page;
	struct fasync_struct___23 *fasync_readers;
	struct fasync_struct___23 *fasync_writers;
	struct pipe_buffer___6 *bufs;
	struct user_struct *user;
	struct watch_queue *watch_queue;
};

struct cgroup_subsys___18;

struct cgroup_subsys_state___18 {
	struct cgroup___18 *cgroup;
	struct cgroup_subsys___18 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___18 *parent;
};

struct kernfs_node___23;

struct cgroup_file___18 {
	struct kernfs_node___23 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct obj_cgroup___13;

struct mem_cgroup_per_node___13;

struct mem_cgroup___13 {
	struct cgroup_subsys_state___18 css;
	struct mem_cgroup_id id;
	struct page_counter memory;
	union {
		struct page_counter swap;
		struct page_counter memsw;
	};
	struct page_counter kmem;
	struct page_counter tcpmem;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool oom_group;
	bool oom_lock;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___18 events_file;
	struct cgroup_file___18 events_local_file;
	struct cgroup_file___18 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	struct memcg_vmstats vmstats;
	atomic_long_t memory_events[8];
	atomic_long_t memory_events_local[8];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct obj_cgroup___13 *objcg;
	struct list_head objcg_list;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad2_;
	atomic_t moving_account;
	struct task_struct___26 *move_lock_task;
	struct memcg_vmstats_percpu *vmstats_percpu;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct memcg_cgwb_frn cgwb_frn[4];
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct deferred_split deferred_split_queue;
	struct mem_cgroup_per_node___13 *nodeinfo[0];
	long: 64;
};

struct kset___22;

struct kobj_type___22;

struct kobject___23 {
	const char *name;
	struct list_head entry;
	struct kobject___23 *parent;
	struct kset___22 *kset;
	struct kobj_type___22 *ktype;
	struct kernfs_node___23 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct blk_integrity_profile___14;

struct blk_integrity___14 {
	const struct blk_integrity_profile___14 *profile;
	unsigned char flags;
	unsigned char tuple_size;
	unsigned char interval_exp;
	unsigned char tag_size;
};

struct bio_set___14 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	struct bio_alloc_cache *cache;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	unsigned int back_pad;
	spinlock_t rescue_lock;
	struct bio_list___14 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	struct hlist_node cpuhp_dead;
};

struct request___14;

struct elevator_queue___14;

struct gendisk___14;

struct blkcg_gq___13;

struct request_queue___14 {
	struct request___14 *last_merge;
	struct elevator_queue___14 *elevator;
	struct percpu_ref q_usage_counter;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	const struct blk_mq_ops *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx **queue_hw_ctx;
	unsigned int nr_hw_queues;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	spinlock_t queue_lock;
	struct gendisk___14 *disk;
	struct kobject___23 kobj;
	struct kobject___23 *mq_kobj;
	struct blk_integrity___14 integrity;
	struct device___25 *dev;
	enum rpm_status rpm_status;
	long unsigned int nr_requests;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_keyslot_manager *ksm;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	atomic_t nr_active_requests_shared_sbitmap;
	struct sbitmap_queue sched_bitmap_tags;
	struct sbitmap_queue sched_breserved_tags;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___13 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int required_elevator_features;
	unsigned int nr_zones;
	long unsigned int *conv_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int max_open_zones;
	unsigned int max_active_zones;
	int node;
	struct mutex debugfs_mutex;
	struct blk_trace *blk_trace;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	struct mutex sysfs_dir_lock;
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	int mq_freeze_depth;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct mutex mq_freeze_lock;
	struct blk_mq_tag_set *tag_set;
	struct list_head tag_set_list;
	struct bio_set___14 bio_split;
	struct dentry___23 *debugfs_dir;
	struct dentry___23 *sched_debugfs_dir;
	struct dentry___23 *rqos_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	u64 write_hints[5];
};

struct vm_struct___20 {
	struct vm_struct___20 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___24 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct kernel_clone_args___2 {
	u64 flags;
	int *pidfd;
	int *child_tid;
	int *parent_tid;
	int exit_signal;
	long unsigned int stack;
	long unsigned int stack_size;
	long unsigned int tls;
	pid_t *set_tid;
	size_t set_tid_size;
	int cgroup;
	int io_thread;
	struct cgroup___18 *cgrp;
	struct css_set___18 *cset;
};

struct psi_group___18 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___26 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___18;

struct cgroup_rstat_cpu___18;

struct cgroup___18 {
	struct cgroup_subsys_state___18 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___23 *kn;
	struct cgroup_file___18 procs_file;
	struct cgroup_file___18 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___18 *subsys[14];
	struct cgroup_root___18 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___18 *dom_cgrp;
	struct cgroup___18 *old_dom_cgrp;
	struct cgroup_rstat_cpu___18 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___18 psi;
	struct cgroup_bpf___2 bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct multiprocess_signals {
	sigset_t signal;
	struct hlist_node node;
};

struct tty_driver___3;

struct tty_operations___3;

struct tty_ldisc___3;

struct tty_port___3;

struct tty_struct___3 {
	int magic;
	struct kref kref;
	struct device___25 *dev;
	struct tty_driver___3 *driver;
	const struct tty_operations___3 *ops;
	int index;
	struct ld_semaphore ldisc_sem;
	struct tty_ldisc___3 *ldisc;
	struct mutex atomic_write_lock;
	struct mutex legacy_mutex;
	struct mutex throttle_mutex;
	struct rw_semaphore termios_rwsem;
	struct mutex winsize_mutex;
	struct ktermios termios;
	struct ktermios termios_locked;
	char name[64];
	long unsigned int flags;
	int count;
	struct winsize winsize;
	struct {
		spinlock_t lock;
		bool stopped;
		bool tco_stopped;
		long unsigned int unused[0];
	} flow;
	struct {
		spinlock_t lock;
		struct pid___19 *pgrp;
		struct pid___19 *session;
		unsigned char pktstatus;
		bool packet;
		long unsigned int unused[0];
	} ctrl;
	int hw_stopped;
	unsigned int receive_room;
	int flow_change;
	struct tty_struct___3 *link;
	struct fasync_struct___23 *fasync;
	wait_queue_head_t write_wait;
	wait_queue_head_t read_wait;
	struct work_struct hangup_work;
	void *disc_data;
	void *driver_data;
	spinlock_t files_lock;
	struct list_head tty_files;
	int closing;
	unsigned char *write_buf;
	int write_cnt;
	struct work_struct SAK_work;
	struct tty_port___3 *port;
};

typedef int (*proc_visitor)(struct task_struct___26 *, void *);

struct dentry_operations___23;

struct dentry___23 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___23 *d_parent;
	struct qstr d_name;
	struct inode___23 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___23 *d_op;
	struct super_block___23 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___23;

struct cdev___10;

struct inode___23 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___23 *i_op;
	struct super_block___23 *i_sb;
	struct address_space___23 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___13 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	long: 64;
	long: 64;
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___23 *i_fop;
		void (*free_inode)(struct inode___23 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___23 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___6 *i_pipe;
		struct cdev___10 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___23 {
	int (*d_revalidate)(struct dentry___23 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___23 *, unsigned int);
	int (*d_hash)(const struct dentry___23 *, struct qstr *);
	int (*d_compare)(const struct dentry___23 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___23 *);
	int (*d_init)(struct dentry___23 *);
	void (*d_release)(struct dentry___23 *);
	void (*d_prune)(struct dentry___23 *);
	void (*d_iput)(struct dentry___23 *, struct inode___23 *);
	char * (*d_dname)(struct dentry___23 *, char *, int);
	struct vfsmount___23 * (*d_automount)(struct path___23 *);
	int (*d_manage)(const struct path___23 *, bool);
	struct dentry___23 * (*d_real)(struct dentry___23 *, const struct inode___23 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___23;

struct mem_dqinfo___23 {
	struct quota_format_type___23 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___23;

struct quota_info___23 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___23 *files[3];
	struct mem_dqinfo___23 info[3];
	const struct quota_format_ops___23 *ops[3];
};

struct rcuwait___23 {
	struct task_struct___26 *task;
};

struct percpu_rw_semaphore___23 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___23 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___23 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___23 rw_sem[3];
};

struct shrink_control___13;

struct shrinker___13 {
	long unsigned int (*count_objects)(struct shrinker___13 *, struct shrink_control___13 *);
	long unsigned int (*scan_objects)(struct shrinker___13 *, struct shrink_control___13 *);
	long int batch;
	int seeks;
	unsigned int flags;
	struct list_head list;
	int id;
	atomic_long_t *nr_deferred;
};

struct super_operations___23;

struct dquot_operations___23;

struct quotactl_ops___23;

struct xattr_handler___3;

struct block_device___14;

struct super_block___23 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___23 *s_type;
	const struct super_operations___23 *s_op;
	const struct dquot_operations___23 *dq_op;
	const struct quotactl_ops___23 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___23 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___14 *s_bdev;
	struct backing_dev_info___13 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___23 s_dquot;
	struct sb_writers___23 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___23 *s_d_op;
	int cleancache_poolid;
	struct shrinker___13 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___23 {
	struct dentry___23 *mnt_root;
	struct super_block___23 *mnt_sb;
	int mnt_flags;
	struct user_namespace *mnt_userns;
};

struct shrink_control___13 {
	gfp_t gfp_mask;
	int nid;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	struct mem_cgroup___13 *memcg;
};

struct io_cq___14 {
	struct request_queue___14 *q;
	struct io_context___15 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

enum {
	IOPRIO_CLASS_NONE = 0,
	IOPRIO_CLASS_RT = 1,
	IOPRIO_CLASS_BE = 2,
	IOPRIO_CLASS_IDLE = 3,
};

struct wait_page_queue___12;

struct kiocb___23 {
	struct file___23 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___23 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___12 *ki_waitq;
	};
};

struct iattr___23 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___23 *ia_file;
};

struct dquot___23 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___23 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___23 {
	int qf_fmt_id;
	const struct quota_format_ops___23 *qf_ops;
	struct module___22 *qf_owner;
	struct quota_format_type___23 *qf_next;
};

struct quota_format_ops___23 {
	int (*check_quota_file)(struct super_block___23 *, int);
	int (*read_file_info)(struct super_block___23 *, int);
	int (*write_file_info)(struct super_block___23 *, int);
	int (*free_file_info)(struct super_block___23 *, int);
	int (*read_dqblk)(struct dquot___23 *);
	int (*commit_dqblk)(struct dquot___23 *);
	int (*release_dqblk)(struct dquot___23 *);
	int (*get_next_id)(struct super_block___23 *, struct kqid *);
};

struct dquot_operations___23 {
	int (*write_dquot)(struct dquot___23 *);
	struct dquot___23 * (*alloc_dquot)(struct super_block___23 *, int);
	void (*destroy_dquot)(struct dquot___23 *);
	int (*acquire_dquot)(struct dquot___23 *);
	int (*release_dquot)(struct dquot___23 *);
	int (*mark_dirty)(struct dquot___23 *);
	int (*write_info)(struct super_block___23 *, int);
	qsize_t * (*get_reserved_space)(struct inode___23 *);
	int (*get_projid)(struct inode___23 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___23 *, qsize_t *);
	int (*get_next_id)(struct super_block___23 *, struct kqid *);
};

struct quotactl_ops___23 {
	int (*quota_on)(struct super_block___23 *, int, int, const struct path___23 *);
	int (*quota_off)(struct super_block___23 *, int);
	int (*quota_enable)(struct super_block___23 *, unsigned int);
	int (*quota_disable)(struct super_block___23 *, unsigned int);
	int (*quota_sync)(struct super_block___23 *, int);
	int (*set_info)(struct super_block___23 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___23 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___23 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___23 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___23 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___23 *, unsigned int);
};

struct module_kobject___22 {
	struct kobject___23 kobj;
	struct module___22 *mod;
	struct kobject___23 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___22 {
	struct module___22 *mod;
	struct latch_tree_node node;
};

struct module_layout___22 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___22 mtn;
};

struct module_attribute___22;

struct kernel_param___22;

struct module___22 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___22 mkobj;
	struct module_attribute___22 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___23 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___22 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___22 core_layout;
	struct module_layout___22 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map___16 *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___13 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	int num_static_call_sites;
	struct static_call_site *static_call_sites;
	bool klp;
	bool klp_alive;
	struct klp_modinfo *klp_info;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct wait_page_queue___12 {
	struct page___24 *page;
	int bit_nr;
	wait_queue_entry_t wait;
};

struct writeback_control___13;

struct readahead_control___12;

struct swap_info_struct___9;

struct address_space_operations___23 {
	int (*writepage)(struct page___24 *, struct writeback_control___13 *);
	int (*readpage)(struct file___23 *, struct page___24 *);
	int (*writepages)(struct address_space___23 *, struct writeback_control___13 *);
	int (*set_page_dirty)(struct page___24 *);
	int (*readpages)(struct file___23 *, struct address_space___23 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___12 *);
	int (*write_begin)(struct file___23 *, struct address_space___23 *, loff_t, unsigned int, unsigned int, struct page___24 **, void **);
	int (*write_end)(struct file___23 *, struct address_space___23 *, loff_t, unsigned int, unsigned int, struct page___24 *, void *);
	sector_t (*bmap)(struct address_space___23 *, sector_t);
	void (*invalidatepage)(struct page___24 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___24 *, gfp_t);
	void (*freepage)(struct page___24 *);
	ssize_t (*direct_IO)(struct kiocb___23 *, struct iov_iter___18 *);
	int (*migratepage)(struct address_space___23 *, struct page___24 *, struct page___24 *, enum migrate_mode);
	bool (*isolate_page)(struct page___24 *, isolate_mode_t);
	void (*putback_page)(struct page___24 *);
	int (*launder_page)(struct page___24 *);
	int (*is_partially_uptodate)(struct page___24 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___24 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___23 *, struct page___24 *);
	int (*swap_activate)(struct swap_info_struct___9 *, struct file___23 *, sector_t *);
	void (*swap_deactivate)(struct file___23 *);
};

struct writeback_control___13 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	unsigned int no_cgroup_owner: 1;
	unsigned int punt_to_cgroup: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bdi_writeback___13 *wb;
	struct inode___23 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
};

struct readahead_control___12 {
	struct file___23 *file;
	struct address_space___23 *mapping;
	struct file_ra_state *ra;
	long unsigned int _index;
	unsigned int _nr_pages;
	unsigned int _batch_count;
};

struct bio_vec___18;

struct iov_iter___18 {
	u8 iter_type;
	bool data_source;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___18 *bvec;
		struct xarray *xarray;
		struct pipe_inode_info___6 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			unsigned int head;
			unsigned int start_head;
		};
		loff_t xarray_start;
	};
};

struct swap_info_struct___9 {
	struct percpu_ref users;
	long unsigned int flags;
	short int prio;
	struct plist_node list;
	signed char type;
	unsigned int max;
	unsigned char *swap_map;
	struct swap_cluster_info *cluster_info;
	struct swap_cluster_list free_clusters;
	unsigned int lowest_bit;
	unsigned int highest_bit;
	unsigned int pages;
	unsigned int inuse_pages;
	unsigned int cluster_next;
	unsigned int cluster_nr;
	unsigned int *cluster_next_cpu;
	struct percpu_cluster *percpu_cluster;
	struct rb_root swap_extent_root;
	struct block_device___14 *bdev;
	struct file___23 *swap_file;
	unsigned int old_block_size;
	struct completion comp;
	long unsigned int *frontswap_map;
	atomic_t frontswap_pages;
	spinlock_t lock;
	spinlock_t cont_lock;
	struct work_struct discard_work;
	struct swap_cluster_list discard_clusters;
	struct plist_node avail_lists[0];
};

struct cdev___10 {
	struct kobject___23 kobj;
	struct module___22 *owner;
	const struct file_operations___23 *ops;
	struct list_head list;
	dev_t dev;
	unsigned int count;
};

struct inode_operations___23 {
	struct dentry___23 * (*lookup)(struct inode___23 *, struct dentry___23 *, unsigned int);
	const char * (*get_link)(struct dentry___23 *, struct inode___23 *, struct delayed_call *);
	int (*permission)(struct user_namespace *, struct inode___23 *, int);
	struct posix_acl * (*get_acl)(struct inode___23 *, int, bool);
	int (*readlink)(struct dentry___23 *, char *, int);
	int (*create)(struct user_namespace *, struct inode___23 *, struct dentry___23 *, umode_t, bool);
	int (*link)(struct dentry___23 *, struct inode___23 *, struct dentry___23 *);
	int (*unlink)(struct inode___23 *, struct dentry___23 *);
	int (*symlink)(struct user_namespace *, struct inode___23 *, struct dentry___23 *, const char *);
	int (*mkdir)(struct user_namespace *, struct inode___23 *, struct dentry___23 *, umode_t);
	int (*rmdir)(struct inode___23 *, struct dentry___23 *);
	int (*mknod)(struct user_namespace *, struct inode___23 *, struct dentry___23 *, umode_t, dev_t);
	int (*rename)(struct user_namespace *, struct inode___23 *, struct dentry___23 *, struct inode___23 *, struct dentry___23 *, unsigned int);
	int (*setattr)(struct user_namespace *, struct dentry___23 *, struct iattr___23 *);
	int (*getattr)(struct user_namespace *, const struct path___23 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___23 *, char *, size_t);
	int (*fiemap)(struct inode___23 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___23 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___23 *, struct dentry___23 *, struct file___23 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace *, struct inode___23 *, struct dentry___23 *, umode_t);
	int (*set_acl)(struct user_namespace *, struct inode___23 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace *, struct dentry___23 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___23 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___23 {
	void (*fl_copy_lock)(struct file_lock___23 *, struct file_lock___23 *);
	void (*fl_release_private)(struct file_lock___23 *);
};

struct lock_manager_operations___23;

struct file_lock___23 {
	struct file_lock___23 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___23 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___23 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___23 *fl_ops;
	const struct lock_manager_operations___23 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___23 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___23 *);
	int (*lm_grant)(struct file_lock___23 *, int);
	bool (*lm_break)(struct file_lock___23 *);
	int (*lm_change)(struct file_lock___23 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___23 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___23 *);
};

struct fasync_struct___23 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___23 *fa_next;
	struct file___23 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___23 {
	struct inode___23 * (*alloc_inode)(struct super_block___23 *);
	void (*destroy_inode)(struct inode___23 *);
	void (*free_inode)(struct inode___23 *);
	void (*dirty_inode)(struct inode___23 *, int);
	int (*write_inode)(struct inode___23 *, struct writeback_control___13 *);
	int (*drop_inode)(struct inode___23 *);
	void (*evict_inode)(struct inode___23 *);
	void (*put_super)(struct super_block___23 *);
	int (*sync_fs)(struct super_block___23 *, int);
	int (*freeze_super)(struct super_block___23 *);
	int (*freeze_fs)(struct super_block___23 *);
	int (*thaw_super)(struct super_block___23 *);
	int (*unfreeze_fs)(struct super_block___23 *);
	int (*statfs)(struct dentry___23 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___23 *, int *, char *);
	void (*umount_begin)(struct super_block___23 *);
	int (*show_options)(struct seq_file___21 *, struct dentry___23 *);
	int (*show_devname)(struct seq_file___21 *, struct dentry___23 *);
	int (*show_path)(struct seq_file___21 *, struct dentry___23 *);
	int (*show_stats)(struct seq_file___21 *, struct dentry___23 *);
	ssize_t (*quota_read)(struct super_block___23 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___23 *, int, const char *, size_t, loff_t);
	struct dquot___23 ** (*get_dquots)(struct inode___23 *);
	long int (*nr_cached_objects)(struct super_block___23 *, struct shrink_control___13 *);
	long int (*free_cached_objects)(struct super_block___23 *, struct shrink_control___13 *);
	struct file___23 * (*real_loop)(struct file___23 *);
};

struct xattr_handler___3 {
	const char *name;
	const char *prefix;
	int flags;
	bool (*list)(struct dentry___23 *);
	int (*get)(const struct xattr_handler___3 *, struct dentry___23 *, struct inode___23 *, const char *, void *, size_t);
	int (*set)(const struct xattr_handler___3 *, struct user_namespace *, struct dentry___23 *, struct inode___23 *, const char *, const void *, size_t, int);
};

struct wakeup_source___25;

struct dev_pm_info___25 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___25 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___25 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___25;

struct bus_type___25;

struct device_driver___25;

struct dev_pm_domain___25;

struct fwnode_handle___22;

struct class___25;

struct attribute_group___23;

struct device___25 {
	struct kobject___23 kobj;
	struct device___25 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___25 *type;
	struct bus_type___25 *bus;
	struct device_driver___25 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___25 power;
	struct dev_pm_domain___25 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node *of_node;
	struct fwnode_handle___22 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___25 *class;
	const struct attribute_group___23 **groups;
	void (*release)(struct device___25 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct block_device___14 {
	sector_t bd_start_sect;
	struct disk_stats *bd_stats;
	long unsigned int bd_stamp;
	bool bd_read_only;
	dev_t bd_dev;
	int bd_openers;
	struct inode___23 *bd_inode;
	struct super_block___23 *bd_super;
	void *bd_claiming;
	struct device___25 bd_device;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct kobject___23 *bd_holder_dir;
	u8 bd_partno;
	spinlock_t bd_size_lock;
	struct gendisk___14 *bd_disk;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	struct super_block___23 *bd_fsfreeze_sb;
	struct partition_meta_info *bd_meta_info;
};

typedef void (*poll_queue_proc___16)(struct file___23 *, wait_queue_head_t *, struct poll_table_struct___16 *);

struct poll_table_struct___16 {
	poll_queue_proc___16 _qproc;
	__poll_t _key;
};

struct seq_file___21 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___21 *op;
	int poll_event;
	const struct file___23 *file;
	void *private;
};

struct fc_log___4;

struct p_log___4 {
	const char *prefix;
	struct fc_log___4 *log;
};

struct fs_context_operations___5;

struct fs_context___5 {
	const struct fs_context_operations___5 *ops;
	struct mutex uapi_mutex;
	struct file_system_type___23 *fs_type;
	void *fs_private;
	void *sget_key;
	struct dentry___23 *root;
	struct user_namespace *user_ns;
	struct net___3 *net_ns;
	const struct cred *cred;
	struct p_log___4 log;
	const char *source;
	void *security;
	void *s_fs_info;
	unsigned int sb_flags;
	unsigned int sb_flags_mask;
	unsigned int s_iflags;
	unsigned int lsm_flags;
	enum fs_context_purpose purpose: 8;
	enum fs_context_phase phase: 8;
	bool need_free: 1;
	bool global: 1;
	bool oldapi: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fs_parameter___5;

typedef int fs_param_type___3(struct p_log___4 *, const struct fs_parameter_spec___3 *, struct fs_parameter___5 *, struct fs_parse_result *);

struct fs_parameter_spec___3 {
	const char *name;
	fs_param_type___3 *type;
	u8 opt;
	short unsigned int flags;
	const void *data;
};

typedef void bio_end_io_t___14(struct bio___14 *);

struct bio_vec___18 {
	struct page___24 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___14;

struct bio___14 {
	struct bio___14 *bi_next;
	struct block_device___14 *bi_bdev;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	atomic_t __bi_remaining;
	struct bvec_iter bi_iter;
	bio_end_io_t___14 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___13 *bi_blkg;
	struct bio_issue bi_issue;
	u64 bi_iocost_cost;
	struct bio_crypt_ctx *bi_crypt_context;
	union {
		struct bio_integrity_payload___14 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___18 *bi_io_vec;
	struct bio_set___14 *bi_pool;
	struct bio_vec___18 bi_inline_vecs[0];
};

struct kernfs_root___23;

struct kernfs_elem_dir___23 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___23 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___23;

struct kernfs_root___23 {
	struct kernfs_node___23 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___23 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___23 {
	struct kernfs_node___23 *target_kn;
};

struct kernfs_ops___23;

struct kernfs_elem_attr___23 {
	const struct kernfs_ops___23 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___23 *notify_next;
};

struct kernfs_node___23 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___23 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___23 dir;
		struct kernfs_elem_symlink___23 symlink;
		struct kernfs_elem_attr___23 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___23;

struct kernfs_ops___23 {
	int (*open)(struct kernfs_open_file___23 *);
	void (*release)(struct kernfs_open_file___23 *);
	int (*seq_show)(struct seq_file___21 *, void *);
	void * (*seq_start)(struct seq_file___21 *, loff_t *);
	void * (*seq_next)(struct seq_file___21 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___21 *, void *);
	ssize_t (*read)(struct kernfs_open_file___23 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___23 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___23 *, struct poll_table_struct___16 *);
	int (*mmap)(struct kernfs_open_file___23 *, struct vm_area_struct___25 *);
};

struct kernfs_syscall_ops___23 {
	int (*show_options)(struct seq_file___21 *, struct kernfs_root___23 *);
	int (*mkdir)(struct kernfs_node___23 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___23 *);
	int (*rename)(struct kernfs_node___23 *, struct kernfs_node___23 *, const char *);
	int (*show_path)(struct seq_file___21 *, struct kernfs_node___23 *, struct kernfs_root___23 *);
};

struct kernfs_open_file___23 {
	struct kernfs_node___23 *kn;
	struct file___23 *file;
	struct seq_file___21 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___23 *vm_ops;
};

struct bin_attribute___23;

struct attribute_group___23 {
	const char *name;
	umode_t (*is_visible)(struct kobject___23 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___23 *, struct bin_attribute___23 *, int);
	struct attribute **attrs;
	struct bin_attribute___23 **bin_attrs;
};

struct bin_attribute___23 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___23 * (*f_mapping)();
	ssize_t (*read)(struct file___23 *, struct kobject___23 *, struct bin_attribute___23 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___23 *, struct kobject___23 *, struct bin_attribute___23 *, char *, loff_t, size_t);
	int (*mmap)(struct file___23 *, struct kobject___23 *, struct bin_attribute___23 *, struct vm_area_struct___25 *);
};

struct sysfs_ops___22 {
	ssize_t (*show)(struct kobject___23 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___23 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___22;

struct kset___22 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___23 kobj;
	const struct kset_uevent_ops___22 *uevent_ops;
};

struct kobj_type___22 {
	void (*release)(struct kobject___23 *);
	const struct sysfs_ops___22 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___23 **default_groups;
	const struct kobj_ns_type_operations * (*child_ns_type)(struct kobject___23 *);
	const void * (*namespace)(struct kobject___23 *);
	void (*get_ownership)(struct kobject___23 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___22 {
	int (* const filter)(struct kset___22 *, struct kobject___23 *);
	const char * (* const name)(struct kset___22 *, struct kobject___23 *);
	int (* const uevent)(struct kset___22 *, struct kobject___23 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___22 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___22 *);
	int (*get)(char *, const struct kernel_param___22 *);
	void (*free)(void *);
};

struct kparam_array___22;

struct kernel_param___22 {
	const char *name;
	struct module___22 *mod;
	const struct kernel_param_ops___22 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___22 *arr;
	};
};

struct kparam_array___22 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___22 *ops;
	void *elem;
};

struct module_attribute___22 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___22 *, struct module_kobject___22 *, char *);
	ssize_t (*store)(struct module_attribute___22 *, struct module_kobject___22 *, const char *, size_t);
	void (*setup)(struct module___22 *, const char *);
	int (*test)(struct module___22 *);
	void (*free)(struct module___22 *);
};

struct trace_event_class___13;

struct trace_event_call___13 {
	struct list_head list;
	struct trace_event_class___13 *class;
	union {
		char *name;
		struct tracepoint___16 *tp;
	};
	struct trace_event event;
	char *print_fmt;
	struct event_filter *filter;
	union {
		void *module;
		atomic_t refcnt;
	};
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
	struct bpf_prog_array___2 *prog_array;
	int (*perf_perm)(struct trace_event_call___13 *, struct perf_event___13 *);
};

struct dev_pagemap_ops___23 {
	void (*page_free)(struct page___24 *);
	void (*kill)(struct dev_pagemap___23 *);
	void (*cleanup)(struct dev_pagemap___23 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___23 *);
};

struct linux_binprm___4 {
	struct vm_area_struct___25 *vma;
	long unsigned int vma_pages;
	struct mm_struct___25 *mm;
	long unsigned int p;
	long unsigned int argmin;
	unsigned int have_execfd: 1;
	unsigned int execfd_creds: 1;
	unsigned int secureexec: 1;
	unsigned int point_of_no_return: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct file___23 *executable;
	struct file___23 *interpreter;
	struct file___23 *file;
	struct cred *cred;
	int unsafe;
	unsigned int per_clear;
	int argc;
	int envc;
	const char *filename;
	const char *interp;
	const char *fdpath;
	unsigned int interp_flags;
	int execfd;
	long unsigned int loader;
	long unsigned int exec;
	struct rlimit rlim_stack;
	char buf[256];
};

struct coredump_params___3 {
	const kernel_siginfo_t *siginfo;
	struct pt_regs *regs;
	struct file___23 *file;
	long unsigned int limit;
	long unsigned int mm_flags;
	loff_t written;
	loff_t pos;
	loff_t to_skip;
};

struct cgroup_namespace___18 {
	struct ns_common ns;
	struct user_namespace *user_ns;
	struct ucounts *ucounts;
	struct css_set___18 *root_cset;
};

struct dev_pm_ops___25 {
	int (*prepare)(struct device___25 *);
	void (*complete)(struct device___25 *);
	int (*suspend)(struct device___25 *);
	int (*resume)(struct device___25 *);
	int (*freeze)(struct device___25 *);
	int (*thaw)(struct device___25 *);
	int (*poweroff)(struct device___25 *);
	int (*restore)(struct device___25 *);
	int (*suspend_late)(struct device___25 *);
	int (*resume_early)(struct device___25 *);
	int (*freeze_late)(struct device___25 *);
	int (*thaw_early)(struct device___25 *);
	int (*poweroff_late)(struct device___25 *);
	int (*restore_early)(struct device___25 *);
	int (*suspend_noirq)(struct device___25 *);
	int (*resume_noirq)(struct device___25 *);
	int (*freeze_noirq)(struct device___25 *);
	int (*thaw_noirq)(struct device___25 *);
	int (*poweroff_noirq)(struct device___25 *);
	int (*restore_noirq)(struct device___25 *);
	int (*runtime_suspend)(struct device___25 *);
	int (*runtime_resume)(struct device___25 *);
	int (*runtime_idle)(struct device___25 *);
};

struct wakeup_source___25 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___25 *dev;
	bool active: 1;
	bool autosleep_enabled: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___25 {
	struct dev_pm_ops___25 ops;
	int (*start)(struct device___25 *);
	void (*detach)(struct device___25 *, bool);
	int (*activate)(struct device___25 *);
	void (*sync)(struct device___25 *);
	void (*dismiss)(struct device___25 *);
};

struct bus_type___25 {
	const char *name;
	const char *dev_name;
	struct device___25 *dev_root;
	const struct attribute_group___23 **bus_groups;
	const struct attribute_group___23 **dev_groups;
	const struct attribute_group___23 **drv_groups;
	int (*match)(struct device___25 *, struct device_driver___25 *);
	int (*uevent)(struct device___25 *, struct kobj_uevent_env *);
	int (*probe)(struct device___25 *);
	void (*sync_state)(struct device___25 *);
	void (*remove)(struct device___25 *);
	void (*shutdown)(struct device___25 *);
	int (*online)(struct device___25 *);
	int (*offline)(struct device___25 *);
	int (*suspend)(struct device___25 *, pm_message_t);
	int (*resume)(struct device___25 *);
	int (*num_vf)(struct device___25 *);
	int (*dma_configure)(struct device___25 *);
	const struct dev_pm_ops___25 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___25 {
	const char *name;
	struct bus_type___25 *bus;
	struct module___22 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___25 *);
	void (*sync_state)(struct device___25 *);
	int (*remove)(struct device___25 *);
	void (*shutdown)(struct device___25 *);
	int (*suspend)(struct device___25 *, pm_message_t);
	int (*resume)(struct device___25 *);
	const struct attribute_group___23 **groups;
	const struct attribute_group___23 **dev_groups;
	const struct dev_pm_ops___25 *pm;
	void (*coredump)(struct device___25 *);
	struct driver_private *p;
};

struct device_type___25 {
	const char *name;
	const struct attribute_group___23 **groups;
	int (*uevent)(struct device___25 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___25 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___25 *);
	const struct dev_pm_ops___25 *pm;
};

struct class___25 {
	const char *name;
	struct module___22 *owner;
	const struct attribute_group___23 **class_groups;
	const struct attribute_group___23 **dev_groups;
	struct kobject___23 *dev_kobj;
	int (*dev_uevent)(struct device___25 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___25 *, umode_t *);
	void (*class_release)(struct class___25 *);
	void (*dev_release)(struct device___25 *);
	int (*shutdown_pre)(struct device___25 *);
	const struct kobj_ns_type_operations *ns_type;
	const void * (*namespace)(struct device___25 *);
	void (*get_ownership)(struct device___25 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___25 *pm;
	struct subsys_private *p;
};

struct fwnode_operations___22;

struct fwnode_handle___22 {
	struct fwnode_handle___22 *secondary;
	const struct fwnode_operations___22 *ops;
	struct device___25 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct cftype___18;

struct cgroup_subsys___18 {
	struct cgroup_subsys_state___18 * (*css_alloc)(struct cgroup_subsys_state___18 *);
	int (*css_online)(struct cgroup_subsys_state___18 *);
	void (*css_offline)(struct cgroup_subsys_state___18 *);
	void (*css_released)(struct cgroup_subsys_state___18 *);
	void (*css_free)(struct cgroup_subsys_state___18 *);
	void (*css_reset)(struct cgroup_subsys_state___18 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___18 *, int);
	int (*css_extra_stat_show)(struct seq_file___21 *, struct cgroup_subsys_state___18 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___26 *, struct css_set___18 *);
	void (*cancel_fork)(struct task_struct___26 *, struct css_set___18 *);
	void (*fork)(struct task_struct___26 *);
	void (*exit)(struct task_struct___26 *);
	void (*release)(struct task_struct___26 *);
	void (*bind)(struct cgroup_subsys_state___18 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___18 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___18 *dfl_cftypes;
	struct cftype___18 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___18 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___18 *updated_children;
	struct cgroup___18 *updated_next;
};

struct cgroup_root___18 {
	struct kernfs_root___23 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___18 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___18 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___18 *ss;
	struct list_head node;
	struct kernfs_ops___23 *kf_ops;
	int (*open)(struct kernfs_open_file___23 *);
	void (*release)(struct kernfs_open_file___23 *);
	u64 (*read_u64)(struct cgroup_subsys_state___18 *, struct cftype___18 *);
	s64 (*read_s64)(struct cgroup_subsys_state___18 *, struct cftype___18 *);
	int (*seq_show)(struct seq_file___21 *, void *);
	void * (*seq_start)(struct seq_file___21 *, loff_t *);
	void * (*seq_next)(struct seq_file___21 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___21 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___18 *, struct cftype___18 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___18 *, struct cftype___18 *, s64);
	ssize_t (*write)(struct kernfs_open_file___23 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___23 *, struct poll_table_struct___16 *);
};

struct block_device_operations___14;

struct gendisk___14 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	short unsigned int events;
	short unsigned int event_flags;
	struct xarray part_tbl;
	struct block_device___14 *part0;
	const struct block_device_operations___14 *fops;
	struct request_queue___14 *queue;
	void *private_data;
	int flags;
	long unsigned int state;
	struct mutex open_mutex;
	unsigned int open_partitions;
	struct backing_dev_info___13 *bdi;
	struct kobject___23 *slave_dir;
	struct list_head slave_bdevs;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___23 integrity_kobj;
	struct cdrom_device_info *cdi;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	u64 diskseq;
};

struct bio_integrity_payload___14 {
	struct bio___14 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___18 *bip_vec;
	struct bio_vec___18 bip_inline_vecs[0];
};

struct blkcg___13;

struct blkg_policy_data___13;

struct blkcg_gq___13 {
	struct request_queue___14 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___13 *blkcg;
	struct blkcg_gq___13 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_iostat_set *iostat_cpu;
	struct blkg_iostat_set iostat;
	struct blkg_policy_data___13 *pd[6];
	spinlock_t async_bio_lock;
	struct bio_list___14 async_bios;
	struct work_struct async_bio_work;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
	struct callback_head callback_head;
};

typedef void integrity_prepare_fn___14(struct request___14 *);

typedef void integrity_complete_fn___14(struct request___14 *, unsigned int);

struct blk_integrity_profile___14 {
	integrity_processing_fn *generate_fn;
	integrity_processing_fn *verify_fn;
	integrity_prepare_fn___14 *prepare_fn;
	integrity_complete_fn___14 *complete_fn;
	const char *name;
};

struct block_device_operations___14 {
	blk_qc_t (*submit_bio)(struct bio___14 *);
	int (*open)(struct block_device___14 *, fmode_t);
	void (*release)(struct gendisk___14 *, fmode_t);
	int (*rw_page)(struct block_device___14 *, sector_t, struct page___24 *, unsigned int);
	int (*ioctl)(struct block_device___14 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___14 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___14 *, unsigned int);
	void (*unlock_native_capacity)(struct gendisk___14 *);
	int (*getgeo)(struct block_device___14 *, struct hd_geometry *);
	int (*set_read_only)(struct block_device___14 *, bool);
	void (*swap_slot_free_notify)(struct block_device___14 *, long unsigned int);
	int (*report_zones)(struct gendisk___14 *, sector_t, unsigned int, report_zones_cb, void *);
	char * (*devnode)(struct gendisk___14 *, umode_t *);
	struct module___22 *owner;
	const struct pr_ops *pr_ops;
	int (*alternative_gpt_sector)(struct gendisk___14 *, sector_t *);
};

struct fwnode_reference_args___22;

struct fwnode_endpoint___22;

struct fwnode_operations___22 {
	struct fwnode_handle___22 * (*get)(struct fwnode_handle___22 *);
	void (*put)(struct fwnode_handle___22 *);
	bool (*device_is_available)(const struct fwnode_handle___22 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___22 *, const struct device___25 *);
	bool (*property_present)(const struct fwnode_handle___22 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___22 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___22 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___22 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___22 *);
	struct fwnode_handle___22 * (*get_parent)(const struct fwnode_handle___22 *);
	struct fwnode_handle___22 * (*get_next_child_node)(const struct fwnode_handle___22 *, struct fwnode_handle___22 *);
	struct fwnode_handle___22 * (*get_named_child_node)(const struct fwnode_handle___22 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___22 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___22 *);
	struct fwnode_handle___22 * (*graph_get_next_endpoint)(const struct fwnode_handle___22 *, struct fwnode_handle___22 *);
	struct fwnode_handle___22 * (*graph_get_remote_endpoint)(const struct fwnode_handle___22 *);
	struct fwnode_handle___22 * (*graph_get_port_parent)(struct fwnode_handle___22 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___22 *, struct fwnode_endpoint___22 *);
	int (*add_links)(struct fwnode_handle___22 *);
};

struct fwnode_endpoint___22 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___22 *local_fwnode;
};

struct fwnode_reference_args___22 {
	struct fwnode_handle___22 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

typedef void rq_end_io_fn___14(struct request___14 *, blk_status_t);

struct request___14 {
	struct request_queue___14 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int tag;
	int internal_tag;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___14 *bio;
	struct bio___14 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct llist_node ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___18 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___14 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___14 *saved_end_io;
		} flush;
	};
	struct gendisk___14 *rq_disk;
	struct block_device___14 *part;
	u64 alloc_time_ns;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int stats_sectors;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	struct bio_crypt_ctx *crypt_ctx;
	struct blk_ksm_keyslot *crypt_keyslot;
	short unsigned int write_hint;
	short unsigned int ioprio;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___14 *end_io;
	void *end_io_data;
};

struct elevator_type___14;

struct elevator_mq_ops___14 {
	int (*init_sched)(struct request_queue___14 *, struct elevator_type___14 *);
	void (*exit_sched)(struct elevator_queue___14 *);
	int (*init_hctx)(struct blk_mq_hw_ctx *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx *, unsigned int);
	void (*depth_updated)(struct blk_mq_hw_ctx *);
	bool (*allow_merge)(struct request_queue___14 *, struct request___14 *, struct bio___14 *);
	bool (*bio_merge)(struct request_queue___14 *, struct bio___14 *, unsigned int);
	int (*request_merge)(struct request_queue___14 *, struct request___14 **, struct bio___14 *);
	void (*request_merged)(struct request_queue___14 *, struct request___14 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___14 *, struct request___14 *, struct request___14 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___14 *);
	void (*finish_request)(struct request___14 *);
	void (*insert_requests)(struct blk_mq_hw_ctx *, struct list_head *, bool);
	struct request___14 * (*dispatch_request)(struct blk_mq_hw_ctx *);
	bool (*has_work)(struct blk_mq_hw_ctx *);
	void (*completed_request)(struct request___14 *, u64);
	void (*requeue_request)(struct request___14 *);
	struct request___14 * (*former_request)(struct request_queue___14 *, struct request___14 *);
	struct request___14 * (*next_request)(struct request_queue___14 *, struct request___14 *);
	void (*init_icq)(struct io_cq___14 *);
	void (*exit_icq)(struct io_cq___14 *);
};

struct elv_fs_entry___14;

struct elevator_type___14 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___14 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___14 *elevator_attrs;
	const char *elevator_name;
	const char *elevator_alias;
	const unsigned int elevator_features;
	struct module___22 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
};

struct elevator_queue___14 {
	struct elevator_type___14 *type;
	void *elevator_data;
	struct kobject___23 kobj;
	struct mutex sysfs_lock;
	unsigned int registered;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hlist_head hash[64];
};

struct elv_fs_entry___14 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___14 *, char *);
	ssize_t (*store)(struct elevator_queue___14 *, const char *, size_t);
};

struct blkcg_policy_data___13;

struct blkcg___13 {
	struct cgroup_subsys_state___18 css;
	spinlock_t lock;
	refcount_t online_pin;
	struct xarray blkg_tree;
	struct blkcg_gq___13 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___13 *cpd[6];
	struct list_head all_blkcgs_node;
	char fc_app_id[129];
	struct list_head cgwb_list;
};

struct blkcg_policy_data___13 {
	struct blkcg___13 *blkcg;
	int plid;
};

struct blkg_policy_data___13 {
	struct blkcg_gq___13 *blkg;
	int plid;
};

struct mem_cgroup_reclaim_iter___13 {
	struct mem_cgroup___13 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___13 {
	struct lruvec___14 lruvec;
	struct lruvec_stats_percpu *lruvec_stats_percpu;
	struct lruvec_stats lruvec_stats;
	long unsigned int lru_zone_size[25];
	struct mem_cgroup_reclaim_iter___13 iter;
	struct shrinker_info *shrinker_info;
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	struct mem_cgroup___13 *memcg;
};

struct obj_cgroup___13 {
	struct percpu_ref refcnt;
	struct mem_cgroup___13 *memcg;
	atomic_t nr_charged_bytes;
	union {
		struct list_head list;
		struct callback_head rcu;
	};
};

typedef struct poll_table_struct___16 poll_table___2;

struct perf_cpu_context___13;

struct perf_output_handle___13;

struct pmu___13 {
	struct list_head entry;
	struct module___22 *module;
	struct device___25 *dev;
	const struct attribute_group___23 **attr_groups;
	const struct attribute_group___23 **attr_update;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___13 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___13 *);
	void (*pmu_disable)(struct pmu___13 *);
	int (*event_init)(struct perf_event___13 *);
	void (*event_mapped)(struct perf_event___13 *, struct mm_struct___25 *);
	void (*event_unmapped)(struct perf_event___13 *, struct mm_struct___25 *);
	int (*add)(struct perf_event___13 *, int);
	void (*del)(struct perf_event___13 *, int);
	void (*start)(struct perf_event___13 *, int);
	void (*stop)(struct perf_event___13 *, int);
	void (*read)(struct perf_event___13 *);
	void (*start_txn)(struct pmu___13 *, unsigned int);
	int (*commit_txn)(struct pmu___13 *);
	void (*cancel_txn)(struct pmu___13 *);
	int (*event_idx)(struct perf_event___13 *);
	void (*sched_task)(struct perf_event_context___13 *, bool);
	struct kmem_cache *task_ctx_cache;
	void (*swap_task_ctx)(struct perf_event_context___13 *, struct perf_event_context___13 *);
	void * (*setup_aux)(struct perf_event___13 *, void **, int, bool);
	void (*free_aux)(void *);
	long int (*snapshot_aux)(struct perf_event___13 *, struct perf_output_handle___13 *, long unsigned int);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___13 *);
	int (*aux_output_match)(struct perf_event___13 *);
	int (*filter_match)(struct perf_event___13 *);
	int (*check_period)(struct perf_event___13 *, u64);
};

struct perf_cpu_context___13 {
	struct perf_event_context___13 ctx;
	struct perf_event_context___13 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___13 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
	int heap_size;
	struct perf_event___13 **heap;
	struct perf_event___13 *heap_default[2];
};

struct perf_output_handle___13 {
	struct perf_event___13 *event;
	struct perf_buffer *rb;
	long unsigned int wakeup;
	long unsigned int size;
	u64 aux_flags;
	union {
		void *addr;
		long unsigned int head;
	};
	int page;
};

struct perf_cgroup___13 {
	struct cgroup_subsys_state___18 css;
	struct perf_cgroup_info *info;
};

struct trace_event_fields___13 {
	const char *type;
	union {
		struct {
			const char *name;
			const int size;
			const int align;
			const int is_signed;
			const int filter_type;
		};
		int (*define_fields)(struct trace_event_call___13 *);
	};
};

struct trace_event_class___13 {
	const char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct trace_event_call___13 *, enum trace_reg, void *);
	struct trace_event_fields___13 *fields_array;
	struct list_head * (*get_fields)(struct trace_event_call___13 *);
	struct list_head fields;
	int (*raw_init)(struct trace_event_call___13 *);
};

struct trace_event_file___8;

struct trace_event_buffer___8 {
	struct trace_buffer *buffer;
	struct ring_buffer_event *event;
	struct trace_event_file___8 *trace_file;
	void *entry;
	unsigned int trace_ctx;
	struct pt_regs *regs;
};

struct trace_event_file___8 {
	struct list_head list;
	struct trace_event_call___13 *event_call;
	struct event_filter *filter;
	struct dentry___23 *dir;
	struct trace_array *tr;
	struct trace_subsystem_dir *system;
	struct list_head triggers;
	long unsigned int flags;
	atomic_t sm_ref;
	atomic_t tm_ref;
};

struct syscall_metadata___3 {
	const char *name;
	int syscall_nr;
	int nb_args;
	const char **types;
	const char **args;
	struct list_head enter_fields;
	struct trace_event_call___13 *enter_event;
	struct trace_event_call___13 *exit_event;
};

enum {
	FUTEX_STATE_OK = 0,
	FUTEX_STATE_EXITING = 1,
	FUTEX_STATE_DEAD = 2,
};

enum proc_hidepid {
	HIDEPID_OFF = 0,
	HIDEPID_NO_ACCESS = 1,
	HIDEPID_INVISIBLE = 2,
	HIDEPID_NOT_PTRACEABLE = 4,
};

enum proc_pidonly {
	PROC_PIDONLY_OFF = 0,
	PROC_PIDONLY_ON = 1,
};

struct proc_fs_info {
	struct pid_namespace___19 *pid_ns;
	struct dentry___23 *proc_self;
	struct dentry___23 *proc_thread_self;
	kgid_t pid_gid;
	enum proc_hidepid hide_pid;
	enum proc_pidonly pidonly;
};

struct tty_operations___3 {
	struct tty_struct___3 * (*lookup)(struct tty_driver___3 *, struct file___23 *, int);
	int (*install)(struct tty_driver___3 *, struct tty_struct___3 *);
	void (*remove)(struct tty_driver___3 *, struct tty_struct___3 *);
	int (*open)(struct tty_struct___3 *, struct file___23 *);
	void (*close)(struct tty_struct___3 *, struct file___23 *);
	void (*shutdown)(struct tty_struct___3 *);
	void (*cleanup)(struct tty_struct___3 *);
	int (*write)(struct tty_struct___3 *, const unsigned char *, int);
	int (*put_char)(struct tty_struct___3 *, unsigned char);
	void (*flush_chars)(struct tty_struct___3 *);
	unsigned int (*write_room)(struct tty_struct___3 *);
	unsigned int (*chars_in_buffer)(struct tty_struct___3 *);
	int (*ioctl)(struct tty_struct___3 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct tty_struct___3 *, unsigned int, long unsigned int);
	void (*set_termios)(struct tty_struct___3 *, struct ktermios *);
	void (*throttle)(struct tty_struct___3 *);
	void (*unthrottle)(struct tty_struct___3 *);
	void (*stop)(struct tty_struct___3 *);
	void (*start)(struct tty_struct___3 *);
	void (*hangup)(struct tty_struct___3 *);
	int (*break_ctl)(struct tty_struct___3 *, int);
	void (*flush_buffer)(struct tty_struct___3 *);
	void (*set_ldisc)(struct tty_struct___3 *);
	void (*wait_until_sent)(struct tty_struct___3 *, int);
	void (*send_xchar)(struct tty_struct___3 *, char);
	int (*tiocmget)(struct tty_struct___3 *);
	int (*tiocmset)(struct tty_struct___3 *, unsigned int, unsigned int);
	int (*resize)(struct tty_struct___3 *, struct winsize *);
	int (*get_icount)(struct tty_struct___3 *, struct serial_icounter_struct *);
	int (*get_serial)(struct tty_struct___3 *, struct serial_struct *);
	int (*set_serial)(struct tty_struct___3 *, struct serial_struct *);
	void (*show_fdinfo)(struct tty_struct___3 *, struct seq_file___21 *);
	int (*poll_init)(struct tty_driver___3 *, int, char *);
	int (*poll_get_char)(struct tty_driver___3 *, int);
	void (*poll_put_char)(struct tty_driver___3 *, int, char);
	int (*proc_show)(struct seq_file___21 *, void *);
};

struct tty_driver___3 {
	int magic;
	struct kref kref;
	struct cdev___10 **cdevs;
	struct module___22 *owner;
	const char *driver_name;
	const char *name;
	int name_base;
	int major;
	int minor_start;
	unsigned int num;
	short int type;
	short int subtype;
	struct ktermios init_termios;
	long unsigned int flags;
	struct proc_dir_entry *proc_entry;
	struct tty_driver___3 *other;
	struct tty_struct___3 **ttys;
	struct tty_port___3 **ports;
	struct ktermios **termios;
	void *driver_state;
	const struct tty_operations___3 *ops;
	struct list_head tty_drivers;
};

struct tty_port_operations___3;

struct tty_port_client_operations___3;

struct tty_port___3 {
	struct tty_bufhead buf;
	struct tty_struct___3 *tty;
	struct tty_struct___3 *itty;
	const struct tty_port_operations___3 *ops;
	const struct tty_port_client_operations___3 *client_ops;
	spinlock_t lock;
	int blocked_open;
	int count;
	wait_queue_head_t open_wait;
	wait_queue_head_t delta_msr_wait;
	long unsigned int flags;
	long unsigned int iflags;
	unsigned char console;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct mutex mutex;
	struct mutex buf_mutex;
	unsigned char *xmit_buf;
	unsigned int close_delay;
	unsigned int closing_wait;
	int drain_delay;
	struct kref kref;
	void *client_data;
};

struct tty_ldisc_ops___3 {
	char *name;
	int num;
	int flags;
	int (*open)(struct tty_struct___3 *);
	void (*close)(struct tty_struct___3 *);
	void (*flush_buffer)(struct tty_struct___3 *);
	ssize_t (*read)(struct tty_struct___3 *, struct file___23 *, unsigned char *, size_t, void **, long unsigned int);
	ssize_t (*write)(struct tty_struct___3 *, struct file___23 *, const unsigned char *, size_t);
	int (*ioctl)(struct tty_struct___3 *, struct file___23 *, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct tty_struct___3 *, struct file___23 *, unsigned int, long unsigned int);
	void (*set_termios)(struct tty_struct___3 *, struct ktermios *);
	__poll_t (*poll)(struct tty_struct___3 *, struct file___23 *, struct poll_table_struct___16 *);
	int (*hangup)(struct tty_struct___3 *);
	void (*receive_buf)(struct tty_struct___3 *, const unsigned char *, const char *, int);
	void (*write_wakeup)(struct tty_struct___3 *);
	void (*dcd_change)(struct tty_struct___3 *, unsigned int);
	int (*receive_buf2)(struct tty_struct___3 *, const unsigned char *, const char *, int);
	struct module___22 *owner;
};

struct tty_ldisc___3 {
	struct tty_ldisc_ops___3 *ops;
	struct tty_struct___3 *tty;
};

struct tty_port_operations___3 {
	int (*carrier_raised)(struct tty_port___3 *);
	void (*dtr_rts)(struct tty_port___3 *, int);
	void (*shutdown)(struct tty_port___3 *);
	int (*activate)(struct tty_port___3 *, struct tty_struct___3 *);
	void (*destruct)(struct tty_port___3 *);
};

struct tty_port_client_operations___3 {
	int (*receive_buf)(struct tty_port___3 *, const unsigned char *, const unsigned char *, size_t);
	void (*write_wakeup)(struct tty_port___3 *);
};

struct fs_parameter___5 {
	const char *key;
	enum fs_value_type type: 8;
	long: 56;
	long: 64;
	union {
		char *string;
		void *blob;
		struct filename *name;
		struct file___23 *file;
	};
	size_t size;
	int dirfd;
};

struct fc_log___4 {
	refcount_t usage;
	u8 head;
	u8 tail;
	u8 need_free;
	struct module___22 *owner;
	char *buffer[8];
};

struct fs_context_operations___5 {
	void (*free)(struct fs_context___5 *);
	int (*dup)(struct fs_context___5 *, struct fs_context___5 *);
	int (*parse_param)(struct fs_context___5 *, struct fs_parameter___5 *);
	int (*parse_monolithic)(struct fs_context___5 *, void *);
	int (*get_tree)(struct fs_context___5 *);
	int (*reconfigure)(struct fs_context___5 *);
};

struct trace_event_raw_task_newtask {
	struct trace_entry ent;
	pid_t pid;
	char comm[16];
	long unsigned int clone_flags;
	short int oom_score_adj;
	char __data[0];
};

struct trace_event_raw_task_rename {
	struct trace_entry ent;
	pid_t pid;
	char oldcomm[16];
	char newcomm[16];
	short int oom_score_adj;
	char __data[0];
};

struct trace_event_data_offsets_task_newtask {};

struct trace_event_data_offsets_task_rename {};

typedef void (*btf_trace_task_newtask)(void *, struct task_struct___26 *, long unsigned int);

typedef void (*btf_trace_task_rename)(void *, struct task_struct___26 *, const char *);

enum netns_bpf_attach_type___2 {
	NETNS_BPF_INVALID___2 = 4294967295,
	NETNS_BPF_FLOW_DISSECTOR___2 = 0,
	NETNS_BPF_SK_LOOKUP___2 = 1,
	MAX_NETNS_BPF_ATTACH_TYPE___2 = 2,
};

struct pipe_buf_operations___6;

struct pipe_buffer___6 {
	struct page___24 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___6 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___6 {
	int (*confirm)(struct pipe_inode_info___6 *, struct pipe_buffer___6 *);
	void (*release)(struct pipe_inode_info___6 *, struct pipe_buffer___6 *);
	bool (*try_steal)(struct pipe_inode_info___6 *, struct pipe_buffer___6 *);
	bool (*get)(struct pipe_inode_info___6 *, struct pipe_buffer___6 *);
};

struct taint_flag {
	char c_true;
	char c_false;
	bool module;
};

struct dentry___24;

struct super_block___24;

struct module___23;

struct file_system_type___24 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___24 * (*mount)(struct file_system_type___24 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___24 *);
	struct module___23 *owner;
	struct file_system_type___24 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___24;

struct kiocb___24;

struct vm_area_struct___26;

struct inode___24;

struct file_lock___24;

struct page___25;

struct seq_file___22;

struct file_operations___24 {
	struct module___23 *owner;
	loff_t (*llseek)(struct file___24 *, loff_t, int);
	ssize_t (*read)(struct file___24 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___24 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___24 *, struct iov_iter___18 *);
	ssize_t (*write_iter)(struct kiocb___24 *, struct iov_iter___18 *);
	int (*iopoll)(struct kiocb___24 *, bool);
	int (*iterate)(struct file___24 *, struct dir_context *);
	int (*iterate_shared)(struct file___24 *, struct dir_context *);
	__poll_t (*poll)(struct file___24 *, struct poll_table_struct *);
	long int (*unlocked_ioctl)(struct file___24 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___24 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___24 *, struct vm_area_struct___26 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___24 *, struct file___24 *);
	int (*flush)(struct file___24 *, fl_owner_t);
	int (*release)(struct inode___24 *, struct file___24 *);
	int (*fsync)(struct file___24 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___24 *, int);
	int (*lock)(struct file___24 *, int, struct file_lock___24 *);
	ssize_t (*sendpage)(struct file___24 *, struct page___25 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___24 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___24 *, long unsigned int);
	int (*flock)(struct file___24 *, int, struct file_lock___24 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___24 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___24 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___24 *, long int, struct file_lock___24 **, void **);
	long int (*fallocate)(struct file___24 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___22 *, struct file___24 *);
	ssize_t (*copy_file_range)(struct file___24 *, loff_t, struct file___24 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___24 *, loff_t, struct file___24 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___24 *, loff_t, loff_t, int);
};

enum ftrace_dump_mode {
	DUMP_NONE = 0,
	DUMP_ALL = 1,
	DUMP_ORIG = 2,
};

struct vmacache___25 {
	u64 seqnum;
	struct vm_area_struct___26 *vmas[4];
};

struct page_frag___25 {
	struct page___25 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___26;

struct pid___20;

struct nsproxy___23;

struct signal_struct___25;

struct vm_struct___21;

struct task_struct___27 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___27 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___26 *mm;
	struct mm_struct___26 *active_mm;
	struct vmacache___25 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int restore_sigmask: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___27 *real_parent;
	struct task_struct___27 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___27 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___20 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	struct posix_cputimers_work posix_cputimers_work;
	const struct cred *ptracer_cred;
	const struct cred *real_cred;
	const struct cred *cred;
	struct key *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___23 *nsproxy;
	struct signal_struct___25 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___27 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context___15 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set *cgroups;
	struct list_head cg_list;
	u32 closid;
	u32 rmid;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	long: 64;
	long: 64;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___25 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup *active_memcg;
	struct request_queue *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___27 *oom_reaper_list;
	struct vm_struct___21 *stack_vm_area;
	refcount_t stack_refcount;
	int patch_state;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	void *mce_vaddr;
	__u64 mce_kflags;
	u64 mce_addr;
	__u64 mce_ripv: 1;
	__u64 mce_whole_page: 1;
	__u64 __mce_reserved: 62;
	long: 2;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct callback_head mce_kill_me;
	int mce_count;
	struct llist_head kretprobe_instances;
	struct callback_head l1d_flush_kill;
	long: 64;
	struct thread_struct___14 thread;
};

typedef struct page___25 *pgtable_t___25;

struct address_space___24;

struct dev_pagemap___24;

struct page___25 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___24 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___6 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___25 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___25 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___26 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___24 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct pv_cpu_ops___20 {
	void (*io_delay)();
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	void (*write_cr4)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___14 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(long unsigned int);
	void (*invalidate_io_bitmap)();
	void (*update_io_bitmap)();
	void (*wbinvd)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int);
	void (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_msr_safe)(unsigned int, int *);
	int (*write_msr_safe)(unsigned int, unsigned int, unsigned int);
	u64 (*read_pmc)(int);
	void (*start_context_switch)(struct task_struct___27 *);
	void (*end_context_switch)(struct task_struct___27 *);
};

struct pv_mmu_ops___21 {
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_one_user)(long unsigned int);
	void (*flush_tlb_multi)(const struct cpumask *, const struct flush_tlb_info___3 *);
	void (*tlb_remove_table)(struct mmu_gather *, void *);
	void (*exit_mmap)(struct mm_struct___26 *);
	struct paravirt_callee_save read_cr2;
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___26 *, struct mm_struct___26 *);
	void (*dup_mmap)(struct mm_struct___26 *, struct mm_struct___26 *);
	int (*pgd_alloc)(struct mm_struct___26 *);
	void (*pgd_free)(struct mm_struct___26 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___26 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___26 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___26 *, long unsigned int);
	void (*alloc_p4d)(struct mm_struct___26 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*release_p4d)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	pte_t (*ptep_modify_prot_start)(struct vm_area_struct___26 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct vm_area_struct___26 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_p4d)(p4d_t *, p4d_t);
	struct paravirt_callee_save p4d_val;
	struct paravirt_callee_save make_p4d;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

struct core_state___25;

struct mm_struct___26 {
	struct {
		struct vm_area_struct___26 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___24 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int mmap_compat_base;
		long unsigned int mmap_compat_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[48];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___25 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___27 *owner;
		struct user_namespace *user_ns;
		struct file___24 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		bool tlb_flush_batched;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct vm_operations_struct___24;

struct vm_area_struct___26 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___26 *vm_next;
	struct vm_area_struct___26 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___26 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___24 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___24 *vm_file;
	struct file___24 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct paravirt_patch_template___21 {
	struct pv_cpu_ops___20 cpu;
	struct pv_irq_ops irq;
	struct pv_mmu_ops___21 mmu;
	struct pv_lock_ops lock;
};

struct seq_operations___22 {
	void * (*start)(struct seq_file___22 *, loff_t *);
	void (*stop)(struct seq_file___22 *, void *);
	void * (*next)(struct seq_file___22 *, void *, loff_t *);
	int (*show)(struct seq_file___22 *, void *);
};

struct smp_ops___7 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*crash_stop_other_cpus)();
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___27 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct pid_namespace___20;

struct upid___20 {
	int nr;
	struct pid_namespace___20 *ns;
};

struct pid_namespace___20 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___27 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___20 *parent;
	struct fs_pin *bacct;
	struct user_namespace *user_ns;
	struct ucounts *ucounts;
	int reboot;
	struct ns_common___2 ns;
};

struct pid___20 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___20 numbers[1];
};

struct tty_struct___4;

struct signal_struct___25 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___27 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___27 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper;
	unsigned int has_child_subreaper;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___20 *pids[4];
	struct pid___20 *tty_old_pgrp;
	int leader;
	struct tty_struct___4 *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___26 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct nsproxy___23 {
	atomic_t count;
	struct uts_namespace *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___20 *pid_ns_for_children;
	struct net *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___2 *cgroup_ns;
};

struct vm_struct___21 {
	struct vm_struct___21 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___25 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct address_space_operations___24;

struct address_space___24 {
	struct inode___24 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___24 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct dev_pagemap_ops___24;

struct dev_pagemap___24 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___24 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vfsmount___24;

struct path___24 {
	struct vfsmount___24 *mnt;
	struct dentry___24 *dentry;
};

struct fown_struct___20 {
	rwlock_t lock;
	struct pid___20 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___24 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	long: 64;
	long: 64;
	struct path___24 f_path;
	struct inode___24 *f_inode;
	const struct file_operations___24 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___20 f_owner;
	const struct cred *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___24 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___24;

struct vm_operations_struct___24 {
	void (*open)(struct vm_area_struct___26 *);
	void (*close)(struct vm_area_struct___26 *);
	int (*may_split)(struct vm_area_struct___26 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___26 *);
	int (*mprotect)(struct vm_area_struct___26 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___24 *);
	vm_fault_t (*huge_fault)(struct vm_fault___24 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___24 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___26 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___24 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___24 *);
	int (*access)(struct vm_area_struct___26 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___26 *);
	int (*set_policy)(struct vm_area_struct___26 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___26 *, long unsigned int);
	struct page___25 * (*find_special_page)(struct vm_area_struct___26 *, long unsigned int);
};

struct core_thread___25 {
	struct task_struct___27 *task;
	struct core_thread___25 *next;
};

struct core_state___25 {
	atomic_t nr_threads;
	struct core_thread___25 dumper;
	struct completion startup;
};

struct vm_fault___24 {
	const struct {
		struct vm_area_struct___26 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___25 *cow_page;
	struct page___25 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___25 prealloc_pte;
};

struct dev_pagemap_ops___24 {
	void (*page_free)(struct page___25 *);
	void (*kill)(struct dev_pagemap___24 *);
	void (*cleanup)(struct dev_pagemap___24 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___24 *);
};

struct dentry_operations___24;

struct dentry___24 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___24 *d_parent;
	struct qstr d_name;
	struct inode___24 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___24 *d_op;
	struct super_block___24 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___24;

struct cdev___11;

struct inode___24 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___24 *i_op;
	struct super_block___24 *i_sb;
	struct address_space___24 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	long: 64;
	long: 64;
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___24 *i_fop;
		void (*free_inode)(struct inode___24 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___24 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct cdev___11 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___24 {
	int (*d_revalidate)(struct dentry___24 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___24 *, unsigned int);
	int (*d_hash)(const struct dentry___24 *, struct qstr *);
	int (*d_compare)(const struct dentry___24 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___24 *);
	int (*d_init)(struct dentry___24 *);
	void (*d_release)(struct dentry___24 *);
	void (*d_prune)(struct dentry___24 *);
	void (*d_iput)(struct dentry___24 *, struct inode___24 *);
	char * (*d_dname)(struct dentry___24 *, char *, int);
	struct vfsmount___24 * (*d_automount)(struct path___24 *);
	int (*d_manage)(const struct path___24 *, bool);
	struct dentry___24 * (*d_real)(struct dentry___24 *, const struct inode___24 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___24;

struct mem_dqinfo___24 {
	struct quota_format_type___24 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___24;

struct quota_info___24 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___24 *files[3];
	struct mem_dqinfo___24 info[3];
	const struct quota_format_ops___24 *ops[3];
};

struct rcuwait___24 {
	struct task_struct___27 *task;
};

struct percpu_rw_semaphore___24 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___24 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___24 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___24 rw_sem[3];
};

struct super_operations___24;

struct dquot_operations___24;

struct quotactl_ops___24;

struct super_block___24 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___24 *s_type;
	const struct super_operations___24 *s_op;
	const struct dquot_operations___24 *dq_op;
	const struct quotactl_ops___24 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___24 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device *s_bdev;
	struct backing_dev_info *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___24 s_dquot;
	struct sb_writers___24 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___24 *s_d_op;
	int cleancache_poolid;
	struct shrinker___13 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___24 {
	struct dentry___24 *mnt_root;
	struct super_block___24 *mnt_sb;
	int mnt_flags;
	struct user_namespace *mnt_userns;
};

struct device___26;

struct tty_driver___4;

struct tty_operations___4;

struct tty_ldisc___4;

struct fasync_struct___24;

struct tty_port___4;

struct tty_struct___4 {
	int magic;
	struct kref kref;
	struct device___26 *dev;
	struct tty_driver___4 *driver;
	const struct tty_operations___4 *ops;
	int index;
	struct ld_semaphore ldisc_sem;
	struct tty_ldisc___4 *ldisc;
	struct mutex atomic_write_lock;
	struct mutex legacy_mutex;
	struct mutex throttle_mutex;
	struct rw_semaphore termios_rwsem;
	struct mutex winsize_mutex;
	struct ktermios termios;
	struct ktermios termios_locked;
	char name[64];
	long unsigned int flags;
	int count;
	struct winsize winsize;
	struct {
		spinlock_t lock;
		bool stopped;
		bool tco_stopped;
		long unsigned int unused[0];
	} flow;
	struct {
		spinlock_t lock;
		struct pid___20 *pgrp;
		struct pid___20 *session;
		unsigned char pktstatus;
		bool packet;
		long unsigned int unused[0];
	} ctrl;
	int hw_stopped;
	unsigned int receive_room;
	int flow_change;
	struct tty_struct___4 *link;
	struct fasync_struct___24 *fasync;
	wait_queue_head_t write_wait;
	wait_queue_head_t read_wait;
	struct work_struct hangup_work;
	void *disc_data;
	void *driver_data;
	spinlock_t files_lock;
	struct list_head tty_files;
	int closing;
	unsigned char *write_buf;
	int write_cnt;
	struct work_struct SAK_work;
	struct tty_port___4 *port;
};

struct kiocb___24 {
	struct file___24 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___24 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___12 *ki_waitq;
	};
};

struct iattr___24 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___24 *ia_file;
};

struct dquot___24 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___24 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___24 {
	int qf_fmt_id;
	const struct quota_format_ops___24 *qf_ops;
	struct module___23 *qf_owner;
	struct quota_format_type___24 *qf_next;
};

struct quota_format_ops___24 {
	int (*check_quota_file)(struct super_block___24 *, int);
	int (*read_file_info)(struct super_block___24 *, int);
	int (*write_file_info)(struct super_block___24 *, int);
	int (*free_file_info)(struct super_block___24 *, int);
	int (*read_dqblk)(struct dquot___24 *);
	int (*commit_dqblk)(struct dquot___24 *);
	int (*release_dqblk)(struct dquot___24 *);
	int (*get_next_id)(struct super_block___24 *, struct kqid *);
};

struct dquot_operations___24 {
	int (*write_dquot)(struct dquot___24 *);
	struct dquot___24 * (*alloc_dquot)(struct super_block___24 *, int);
	void (*destroy_dquot)(struct dquot___24 *);
	int (*acquire_dquot)(struct dquot___24 *);
	int (*release_dquot)(struct dquot___24 *);
	int (*mark_dirty)(struct dquot___24 *);
	int (*write_info)(struct super_block___24 *, int);
	qsize_t * (*get_reserved_space)(struct inode___24 *);
	int (*get_projid)(struct inode___24 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___24 *, qsize_t *);
	int (*get_next_id)(struct super_block___24 *, struct kqid *);
};

struct quotactl_ops___24 {
	int (*quota_on)(struct super_block___24 *, int, int, const struct path___24 *);
	int (*quota_off)(struct super_block___24 *, int);
	int (*quota_enable)(struct super_block___24 *, unsigned int);
	int (*quota_disable)(struct super_block___24 *, unsigned int);
	int (*quota_sync)(struct super_block___24 *, int);
	int (*set_info)(struct super_block___24 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___24 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___24 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___24 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___24 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___24 *, unsigned int);
};

struct kset___23;

struct kobj_type___23;

struct kernfs_node___24;

struct kobject___24 {
	const char *name;
	struct list_head entry;
	struct kobject___24 *parent;
	struct kset___23 *kset;
	struct kobj_type___23 *ktype;
	struct kernfs_node___24 *sd;
	struct kref kref;
	unsigned int state_initialized;
	unsigned int state_in_sysfs;
	unsigned int state_add_uevent_sent;
	unsigned int state_remove_uevent_sent;
	unsigned int uevent_suppress;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___23 {
	struct kobject___24 kobj;
	struct module___23 *mod;
	struct kobject___24 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___23 {
	struct module___23 *mod;
	struct latch_tree_node node;
};

struct module_layout___23 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___23 mtn;
};

struct module_attribute___23;

struct kernel_param___23;

struct module___23 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___23 mkobj;
	struct module_attribute___23 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___24 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___23 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___23 core_layout;
	struct module_layout___23 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map___16 *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___4 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	int num_static_call_sites;
	struct static_call_site *static_call_sites;
	bool klp;
	bool klp_alive;
	struct klp_modinfo *klp_info;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct address_space_operations___24 {
	int (*writepage)(struct page___25 *, struct writeback_control *);
	int (*readpage)(struct file___24 *, struct page___25 *);
	int (*writepages)(struct address_space___24 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___25 *);
	int (*readpages)(struct file___24 *, struct address_space___24 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control *);
	int (*write_begin)(struct file___24 *, struct address_space___24 *, loff_t, unsigned int, unsigned int, struct page___25 **, void **);
	int (*write_end)(struct file___24 *, struct address_space___24 *, loff_t, unsigned int, unsigned int, struct page___25 *, void *);
	sector_t (*bmap)(struct address_space___24 *, sector_t);
	void (*invalidatepage)(struct page___25 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___25 *, gfp_t);
	void (*freepage)(struct page___25 *);
	ssize_t (*direct_IO)(struct kiocb___24 *, struct iov_iter___18 *);
	int (*migratepage)(struct address_space___24 *, struct page___25 *, struct page___25 *, enum migrate_mode);
	bool (*isolate_page)(struct page___25 *, isolate_mode_t);
	void (*putback_page)(struct page___25 *);
	int (*launder_page)(struct page___25 *);
	int (*is_partially_uptodate)(struct page___25 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___25 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___24 *, struct page___25 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___24 *, sector_t *);
	void (*swap_deactivate)(struct file___24 *);
};

struct cdev___11 {
	struct kobject___24 kobj;
	struct module___23 *owner;
	const struct file_operations___24 *ops;
	struct list_head list;
	dev_t dev;
	unsigned int count;
};

struct inode_operations___24 {
	struct dentry___24 * (*lookup)(struct inode___24 *, struct dentry___24 *, unsigned int);
	const char * (*get_link)(struct dentry___24 *, struct inode___24 *, struct delayed_call *);
	int (*permission)(struct user_namespace *, struct inode___24 *, int);
	struct posix_acl * (*get_acl)(struct inode___24 *, int, bool);
	int (*readlink)(struct dentry___24 *, char *, int);
	int (*create)(struct user_namespace *, struct inode___24 *, struct dentry___24 *, umode_t, bool);
	int (*link)(struct dentry___24 *, struct inode___24 *, struct dentry___24 *);
	int (*unlink)(struct inode___24 *, struct dentry___24 *);
	int (*symlink)(struct user_namespace *, struct inode___24 *, struct dentry___24 *, const char *);
	int (*mkdir)(struct user_namespace *, struct inode___24 *, struct dentry___24 *, umode_t);
	int (*rmdir)(struct inode___24 *, struct dentry___24 *);
	int (*mknod)(struct user_namespace *, struct inode___24 *, struct dentry___24 *, umode_t, dev_t);
	int (*rename)(struct user_namespace *, struct inode___24 *, struct dentry___24 *, struct inode___24 *, struct dentry___24 *, unsigned int);
	int (*setattr)(struct user_namespace *, struct dentry___24 *, struct iattr___24 *);
	int (*getattr)(struct user_namespace *, const struct path___24 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___24 *, char *, size_t);
	int (*fiemap)(struct inode___24 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___24 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___24 *, struct dentry___24 *, struct file___24 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace *, struct inode___24 *, struct dentry___24 *, umode_t);
	int (*set_acl)(struct user_namespace *, struct inode___24 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace *, struct dentry___24 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___24 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___24 {
	void (*fl_copy_lock)(struct file_lock___24 *, struct file_lock___24 *);
	void (*fl_release_private)(struct file_lock___24 *);
};

struct lock_manager_operations___24;

struct file_lock___24 {
	struct file_lock___24 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___24 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___24 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___24 *fl_ops;
	const struct lock_manager_operations___24 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___24 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___24 *);
	int (*lm_grant)(struct file_lock___24 *, int);
	bool (*lm_break)(struct file_lock___24 *);
	int (*lm_change)(struct file_lock___24 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___24 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___24 *);
};

struct fasync_struct___24 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___24 *fa_next;
	struct file___24 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___24 {
	struct inode___24 * (*alloc_inode)(struct super_block___24 *);
	void (*destroy_inode)(struct inode___24 *);
	void (*free_inode)(struct inode___24 *);
	void (*dirty_inode)(struct inode___24 *, int);
	int (*write_inode)(struct inode___24 *, struct writeback_control *);
	int (*drop_inode)(struct inode___24 *);
	void (*evict_inode)(struct inode___24 *);
	void (*put_super)(struct super_block___24 *);
	int (*sync_fs)(struct super_block___24 *, int);
	int (*freeze_super)(struct super_block___24 *);
	int (*freeze_fs)(struct super_block___24 *);
	int (*thaw_super)(struct super_block___24 *);
	int (*unfreeze_fs)(struct super_block___24 *);
	int (*statfs)(struct dentry___24 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___24 *, int *, char *);
	void (*umount_begin)(struct super_block___24 *);
	int (*show_options)(struct seq_file___22 *, struct dentry___24 *);
	int (*show_devname)(struct seq_file___22 *, struct dentry___24 *);
	int (*show_path)(struct seq_file___22 *, struct dentry___24 *);
	int (*show_stats)(struct seq_file___22 *, struct dentry___24 *);
	ssize_t (*quota_read)(struct super_block___24 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___24 *, int, const char *, size_t, loff_t);
	struct dquot___24 ** (*get_dquots)(struct inode___24 *);
	long int (*nr_cached_objects)(struct super_block___24 *, struct shrink_control___13 *);
	long int (*free_cached_objects)(struct super_block___24 *, struct shrink_control___13 *);
	struct file___24 * (*real_loop)(struct file___24 *);
};

struct seq_file___22 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___22 *op;
	int poll_event;
	const struct file___24 *file;
	void *private;
};

struct kernfs_root___24;

struct kernfs_elem_dir___24 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___24 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___24;

struct kernfs_root___24 {
	struct kernfs_node___24 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___24 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___24 {
	struct kernfs_node___24 *target_kn;
};

struct kernfs_ops___24;

struct kernfs_elem_attr___24 {
	const struct kernfs_ops___24 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___24 *notify_next;
};

struct kernfs_node___24 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___24 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___24 dir;
		struct kernfs_elem_symlink___24 symlink;
		struct kernfs_elem_attr___24 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___24;

struct kernfs_ops___24 {
	int (*open)(struct kernfs_open_file___24 *);
	void (*release)(struct kernfs_open_file___24 *);
	int (*seq_show)(struct seq_file___22 *, void *);
	void * (*seq_start)(struct seq_file___22 *, loff_t *);
	void * (*seq_next)(struct seq_file___22 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___22 *, void *);
	ssize_t (*read)(struct kernfs_open_file___24 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___24 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___24 *, struct poll_table_struct *);
	int (*mmap)(struct kernfs_open_file___24 *, struct vm_area_struct___26 *);
};

struct kernfs_syscall_ops___24 {
	int (*show_options)(struct seq_file___22 *, struct kernfs_root___24 *);
	int (*mkdir)(struct kernfs_node___24 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___24 *);
	int (*rename)(struct kernfs_node___24 *, struct kernfs_node___24 *, const char *);
	int (*show_path)(struct seq_file___22 *, struct kernfs_node___24 *, struct kernfs_root___24 *);
};

struct kernfs_open_file___24 {
	struct kernfs_node___24 *kn;
	struct file___24 *file;
	struct seq_file___22 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped;
	bool released;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___24 *vm_ops;
};

struct bin_attribute___24;

struct attribute_group___24 {
	const char *name;
	umode_t (*is_visible)(struct kobject___24 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___24 *, struct bin_attribute___24 *, int);
	struct attribute **attrs;
	struct bin_attribute___24 **bin_attrs;
};

struct bin_attribute___24 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___24 * (*f_mapping)();
	ssize_t (*read)(struct file___24 *, struct kobject___24 *, struct bin_attribute___24 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___24 *, struct kobject___24 *, struct bin_attribute___24 *, char *, loff_t, size_t);
	int (*mmap)(struct file___24 *, struct kobject___24 *, struct bin_attribute___24 *, struct vm_area_struct___26 *);
};

struct sysfs_ops___23 {
	ssize_t (*show)(struct kobject___24 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___24 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___23;

struct kset___23 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___24 kobj;
	const struct kset_uevent_ops___23 *uevent_ops;
};

struct kobj_type___23 {
	void (*release)(struct kobject___24 *);
	const struct sysfs_ops___23 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___24 **default_groups;
	const struct kobj_ns_type_operations * (*child_ns_type)(struct kobject___24 *);
	const void * (*namespace)(struct kobject___24 *);
	void (*get_ownership)(struct kobject___24 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___23 {
	int (* const filter)(struct kset___23 *, struct kobject___24 *);
	const char * (* const name)(struct kset___23 *, struct kobject___24 *);
	int (* const uevent)(struct kset___23 *, struct kobject___24 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___23 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___23 *);
	int (*get)(char *, const struct kernel_param___23 *);
	void (*free)(void *);
};

struct kparam_array___23;

struct kernel_param___23 {
	const char *name;
	struct module___23 *mod;
	const struct kernel_param_ops___23 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___23 *arr;
	};
};

struct kparam_array___23 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___23 *ops;
	void *elem;
};

struct module_attribute___23 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___23 *, struct module_kobject___23 *, char *);
	ssize_t (*store)(struct module_attribute___23 *, struct module_kobject___23 *, const char *, size_t);
	void (*setup)(struct module___23 *, const char *);
	int (*test)(struct module___23 *);
	void (*free)(struct module___23 *);
};

enum kmsg_dump_reason {
	KMSG_DUMP_UNDEF = 0,
	KMSG_DUMP_PANIC = 1,
	KMSG_DUMP_OOPS = 2,
	KMSG_DUMP_EMERG = 3,
	KMSG_DUMP_SHUTDOWN = 4,
	KMSG_DUMP_MAX = 5,
};

struct wakeup_source___26;

struct dev_pm_info___26 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___26 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___26 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___26;

struct bus_type___26;

struct device_driver___26;

struct dev_pm_domain___26;

struct fwnode_handle___23;

struct class___26;

struct device___26 {
	struct kobject___24 kobj;
	struct device___26 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___26 *type;
	struct bus_type___26 *bus;
	struct device_driver___26 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___26 power;
	struct dev_pm_domain___26 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node *of_node;
	struct fwnode_handle___23 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___26 *class;
	const struct attribute_group___24 **groups;
	void (*release)(struct device___26 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_ops___26 {
	int (*prepare)(struct device___26 *);
	void (*complete)(struct device___26 *);
	int (*suspend)(struct device___26 *);
	int (*resume)(struct device___26 *);
	int (*freeze)(struct device___26 *);
	int (*thaw)(struct device___26 *);
	int (*poweroff)(struct device___26 *);
	int (*restore)(struct device___26 *);
	int (*suspend_late)(struct device___26 *);
	int (*resume_early)(struct device___26 *);
	int (*freeze_late)(struct device___26 *);
	int (*thaw_early)(struct device___26 *);
	int (*poweroff_late)(struct device___26 *);
	int (*restore_early)(struct device___26 *);
	int (*suspend_noirq)(struct device___26 *);
	int (*resume_noirq)(struct device___26 *);
	int (*freeze_noirq)(struct device___26 *);
	int (*thaw_noirq)(struct device___26 *);
	int (*poweroff_noirq)(struct device___26 *);
	int (*restore_noirq)(struct device___26 *);
	int (*runtime_suspend)(struct device___26 *);
	int (*runtime_resume)(struct device___26 *);
	int (*runtime_idle)(struct device___26 *);
};

struct wakeup_source___26 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___26 *dev;
	bool active;
	bool autosleep_enabled;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___26 {
	struct dev_pm_ops___26 ops;
	int (*start)(struct device___26 *);
	void (*detach)(struct device___26 *, bool);
	int (*activate)(struct device___26 *);
	void (*sync)(struct device___26 *);
	void (*dismiss)(struct device___26 *);
};

struct bus_type___26 {
	const char *name;
	const char *dev_name;
	struct device___26 *dev_root;
	const struct attribute_group___24 **bus_groups;
	const struct attribute_group___24 **dev_groups;
	const struct attribute_group___24 **drv_groups;
	int (*match)(struct device___26 *, struct device_driver___26 *);
	int (*uevent)(struct device___26 *, struct kobj_uevent_env *);
	int (*probe)(struct device___26 *);
	void (*sync_state)(struct device___26 *);
	void (*remove)(struct device___26 *);
	void (*shutdown)(struct device___26 *);
	int (*online)(struct device___26 *);
	int (*offline)(struct device___26 *);
	int (*suspend)(struct device___26 *, pm_message_t);
	int (*resume)(struct device___26 *);
	int (*num_vf)(struct device___26 *);
	int (*dma_configure)(struct device___26 *);
	const struct dev_pm_ops___26 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___26 {
	const char *name;
	struct bus_type___26 *bus;
	struct module___23 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___26 *);
	void (*sync_state)(struct device___26 *);
	int (*remove)(struct device___26 *);
	void (*shutdown)(struct device___26 *);
	int (*suspend)(struct device___26 *, pm_message_t);
	int (*resume)(struct device___26 *);
	const struct attribute_group___24 **groups;
	const struct attribute_group___24 **dev_groups;
	const struct dev_pm_ops___26 *pm;
	void (*coredump)(struct device___26 *);
	struct driver_private *p;
};

struct device_type___26 {
	const char *name;
	const struct attribute_group___24 **groups;
	int (*uevent)(struct device___26 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___26 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___26 *);
	const struct dev_pm_ops___26 *pm;
};

struct class___26 {
	const char *name;
	struct module___23 *owner;
	const struct attribute_group___24 **class_groups;
	const struct attribute_group___24 **dev_groups;
	struct kobject___24 *dev_kobj;
	int (*dev_uevent)(struct device___26 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___26 *, umode_t *);
	void (*class_release)(struct class___26 *);
	void (*dev_release)(struct device___26 *);
	int (*shutdown_pre)(struct device___26 *);
	const struct kobj_ns_type_operations *ns_type;
	const void * (*namespace)(struct device___26 *);
	void (*get_ownership)(struct device___26 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___26 *pm;
	struct subsys_private *p;
};

struct fwnode_operations___23;

struct fwnode_handle___23 {
	struct fwnode_handle___23 *secondary;
	const struct fwnode_operations___23 *ops;
	struct device___26 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct tty_operations___4 {
	struct tty_struct___4 * (*lookup)(struct tty_driver___4 *, struct file___24 *, int);
	int (*install)(struct tty_driver___4 *, struct tty_struct___4 *);
	void (*remove)(struct tty_driver___4 *, struct tty_struct___4 *);
	int (*open)(struct tty_struct___4 *, struct file___24 *);
	void (*close)(struct tty_struct___4 *, struct file___24 *);
	void (*shutdown)(struct tty_struct___4 *);
	void (*cleanup)(struct tty_struct___4 *);
	int (*write)(struct tty_struct___4 *, const unsigned char *, int);
	int (*put_char)(struct tty_struct___4 *, unsigned char);
	void (*flush_chars)(struct tty_struct___4 *);
	unsigned int (*write_room)(struct tty_struct___4 *);
	unsigned int (*chars_in_buffer)(struct tty_struct___4 *);
	int (*ioctl)(struct tty_struct___4 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct tty_struct___4 *, unsigned int, long unsigned int);
	void (*set_termios)(struct tty_struct___4 *, struct ktermios *);
	void (*throttle)(struct tty_struct___4 *);
	void (*unthrottle)(struct tty_struct___4 *);
	void (*stop)(struct tty_struct___4 *);
	void (*start)(struct tty_struct___4 *);
	void (*hangup)(struct tty_struct___4 *);
	int (*break_ctl)(struct tty_struct___4 *, int);
	void (*flush_buffer)(struct tty_struct___4 *);
	void (*set_ldisc)(struct tty_struct___4 *);
	void (*wait_until_sent)(struct tty_struct___4 *, int);
	void (*send_xchar)(struct tty_struct___4 *, char);
	int (*tiocmget)(struct tty_struct___4 *);
	int (*tiocmset)(struct tty_struct___4 *, unsigned int, unsigned int);
	int (*resize)(struct tty_struct___4 *, struct winsize *);
	int (*get_icount)(struct tty_struct___4 *, struct serial_icounter_struct *);
	int (*get_serial)(struct tty_struct___4 *, struct serial_struct *);
	int (*set_serial)(struct tty_struct___4 *, struct serial_struct *);
	void (*show_fdinfo)(struct tty_struct___4 *, struct seq_file___22 *);
	int (*poll_init)(struct tty_driver___4 *, int, char *);
	int (*poll_get_char)(struct tty_driver___4 *, int);
	void (*poll_put_char)(struct tty_driver___4 *, int, char);
	int (*proc_show)(struct seq_file___22 *, void *);
};

struct tty_driver___4 {
	int magic;
	struct kref kref;
	struct cdev___11 **cdevs;
	struct module___23 *owner;
	const char *driver_name;
	const char *name;
	int name_base;
	int major;
	int minor_start;
	unsigned int num;
	short int type;
	short int subtype;
	struct ktermios init_termios;
	long unsigned int flags;
	struct proc_dir_entry *proc_entry;
	struct tty_driver___4 *other;
	struct tty_struct___4 **ttys;
	struct tty_port___4 **ports;
	struct ktermios **termios;
	void *driver_state;
	const struct tty_operations___4 *ops;
	struct list_head tty_drivers;
};

struct tty_port_operations___4;

struct tty_port_client_operations___4;

struct tty_port___4 {
	struct tty_bufhead buf;
	struct tty_struct___4 *tty;
	struct tty_struct___4 *itty;
	const struct tty_port_operations___4 *ops;
	const struct tty_port_client_operations___4 *client_ops;
	spinlock_t lock;
	int blocked_open;
	int count;
	wait_queue_head_t open_wait;
	wait_queue_head_t delta_msr_wait;
	long unsigned int flags;
	long unsigned int iflags;
	unsigned char console;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct mutex mutex;
	struct mutex buf_mutex;
	unsigned char *xmit_buf;
	unsigned int close_delay;
	unsigned int closing_wait;
	int drain_delay;
	struct kref kref;
	void *client_data;
};

struct tty_ldisc_ops___4 {
	char *name;
	int num;
	int flags;
	int (*open)(struct tty_struct___4 *);
	void (*close)(struct tty_struct___4 *);
	void (*flush_buffer)(struct tty_struct___4 *);
	ssize_t (*read)(struct tty_struct___4 *, struct file___24 *, unsigned char *, size_t, void **, long unsigned int);
	ssize_t (*write)(struct tty_struct___4 *, struct file___24 *, const unsigned char *, size_t);
	int (*ioctl)(struct tty_struct___4 *, struct file___24 *, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct tty_struct___4 *, struct file___24 *, unsigned int, long unsigned int);
	void (*set_termios)(struct tty_struct___4 *, struct ktermios *);
	__poll_t (*poll)(struct tty_struct___4 *, struct file___24 *, struct poll_table_struct *);
	int (*hangup)(struct tty_struct___4 *);
	void (*receive_buf)(struct tty_struct___4 *, const unsigned char *, const char *, int);
	void (*write_wakeup)(struct tty_struct___4 *);
	void (*dcd_change)(struct tty_struct___4 *, unsigned int);
	int (*receive_buf2)(struct tty_struct___4 *, const unsigned char *, const char *, int);
	struct module___23 *owner;
};

struct tty_ldisc___4 {
	struct tty_ldisc_ops___4 *ops;
	struct tty_struct___4 *tty;
};

struct tty_port_operations___4 {
	int (*carrier_raised)(struct tty_port___4 *);
	void (*dtr_rts)(struct tty_port___4 *, int);
	void (*shutdown)(struct tty_port___4 *);
	int (*activate)(struct tty_port___4 *, struct tty_struct___4 *);
	void (*destruct)(struct tty_port___4 *);
};

struct tty_port_client_operations___4 {
	int (*receive_buf)(struct tty_port___4 *, const unsigned char *, const unsigned char *, size_t);
	void (*write_wakeup)(struct tty_port___4 *);
};

struct fwnode_reference_args___23;

struct fwnode_endpoint___23;

struct fwnode_operations___23 {
	struct fwnode_handle___23 * (*get)(struct fwnode_handle___23 *);
	void (*put)(struct fwnode_handle___23 *);
	bool (*device_is_available)(const struct fwnode_handle___23 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___23 *, const struct device___26 *);
	bool (*property_present)(const struct fwnode_handle___23 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___23 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___23 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___23 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___23 *);
	struct fwnode_handle___23 * (*get_parent)(const struct fwnode_handle___23 *);
	struct fwnode_handle___23 * (*get_next_child_node)(const struct fwnode_handle___23 *, struct fwnode_handle___23 *);
	struct fwnode_handle___23 * (*get_named_child_node)(const struct fwnode_handle___23 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___23 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___23 *);
	struct fwnode_handle___23 * (*graph_get_next_endpoint)(const struct fwnode_handle___23 *, struct fwnode_handle___23 *);
	struct fwnode_handle___23 * (*graph_get_remote_endpoint)(const struct fwnode_handle___23 *);
	struct fwnode_handle___23 * (*graph_get_port_parent)(struct fwnode_handle___23 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___23 *, struct fwnode_endpoint___23 *);
	int (*add_links)(struct fwnode_handle___23 *);
};

struct fwnode_endpoint___23 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___23 *local_fwnode;
};

struct fwnode_reference_args___23 {
	struct fwnode_handle___23 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

enum con_flush_mode {
	CONSOLE_FLUSH_PENDING = 0,
	CONSOLE_REPLAY_ALL = 1,
};

struct warn_args {
	const char *fmt;
	va_list args;
};

struct dentry___25;

struct super_block___25;

struct module___24;

struct file_system_type___25 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___25 * (*mount)(struct file_system_type___25 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___25 *);
	struct module___24 *owner;
	struct file_system_type___25 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___25;

struct kiocb___25;

struct iov_iter___19;

struct poll_table_struct___17;

struct vm_area_struct___27;

struct inode___25;

struct file_lock___25;

struct page___26;

struct seq_file___23;

struct file_operations___25 {
	struct module___24 *owner;
	loff_t (*llseek)(struct file___25 *, loff_t, int);
	ssize_t (*read)(struct file___25 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___25 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___25 *, struct iov_iter___19 *);
	ssize_t (*write_iter)(struct kiocb___25 *, struct iov_iter___19 *);
	int (*iopoll)(struct kiocb___25 *, bool);
	int (*iterate)(struct file___25 *, struct dir_context *);
	int (*iterate_shared)(struct file___25 *, struct dir_context *);
	__poll_t (*poll)(struct file___25 *, struct poll_table_struct___17 *);
	long int (*unlocked_ioctl)(struct file___25 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___25 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___25 *, struct vm_area_struct___27 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___25 *, struct file___25 *);
	int (*flush)(struct file___25 *, fl_owner_t);
	int (*release)(struct inode___25 *, struct file___25 *);
	int (*fsync)(struct file___25 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___25 *, int);
	int (*lock)(struct file___25 *, int, struct file_lock___25 *);
	ssize_t (*sendpage)(struct file___25 *, struct page___26 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___25 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___25 *, long unsigned int);
	int (*flock)(struct file___25 *, int, struct file_lock___25 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___25 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___25 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___25 *, long int, struct file_lock___25 **, void **);
	long int (*fallocate)(struct file___25 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___23 *, struct file___25 *);
	ssize_t (*copy_file_range)(struct file___25 *, loff_t, struct file___25 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___25 *, loff_t, struct file___25 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___25 *, loff_t, loff_t, int);
};

struct static_call_mod___17 {
	struct static_call_mod___17 *next;
	struct module___24 *mod;
	struct static_call_site *sites;
};

struct static_call_key___17 {
	void *func;
	union {
		long unsigned int type;
		struct static_call_mod___17 *mods;
		struct static_call_site *sites;
	};
};

struct vmacache___26 {
	u64 seqnum;
	struct vm_area_struct___27 *vmas[4];
};

struct page_frag___26 {
	struct page___26 *page;
	__u32 offset;
	__u32 size;
};

struct perf_event___14;

struct thread_struct___15 {
	struct desc_struct tls_array[3];
	long unsigned int sp;
	short unsigned int es;
	short unsigned int ds;
	short unsigned int fsindex;
	short unsigned int gsindex;
	long unsigned int fsbase;
	long unsigned int gsbase;
	struct perf_event___14 *ptrace_bps[4];
	long unsigned int virtual_dr6;
	long unsigned int ptrace_dr7;
	long unsigned int cr2;
	long unsigned int trap_nr;
	long unsigned int error_code;
	struct io_bitmap *io_bitmap;
	long unsigned int iopl_emul;
	unsigned int iopl_warn: 1;
	unsigned int sig_on_uaccess_err: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u32 pkru;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct fpu fpu;
};

struct mm_struct___27;

struct pid___21;

struct nsproxy___24;

struct signal_struct___26;

struct bio_list___15;

struct backing_dev_info___14;

struct io_context___16;

struct css_set___19;

struct perf_event_context___14;

struct mem_cgroup___14;

struct request_queue___15;

struct vm_struct___22;

struct task_struct___28 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___28 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___27 *mm;
	struct mm_struct___27 *active_mm;
	struct vmacache___26 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int restore_sigmask: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___28 *real_parent;
	struct task_struct___28 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___28 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___21 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	struct posix_cputimers_work posix_cputimers_work;
	const struct cred *ptracer_cred;
	const struct cred *real_cred;
	const struct cred *cred;
	struct key *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___24 *nsproxy;
	struct signal_struct___26 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___28 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___15 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___14 *backing_dev_info;
	struct io_context___16 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___19 *cgroups;
	struct list_head cg_list;
	u32 closid;
	u32 rmid;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___14 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	long: 64;
	long: 64;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___26 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___14 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___14 *active_memcg;
	struct request_queue___15 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___28 *oom_reaper_list;
	struct vm_struct___22 *stack_vm_area;
	refcount_t stack_refcount;
	int patch_state;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	void *mce_vaddr;
	__u64 mce_kflags;
	u64 mce_addr;
	__u64 mce_ripv: 1;
	__u64 mce_whole_page: 1;
	__u64 __mce_reserved: 62;
	long: 2;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct callback_head mce_kill_me;
	int mce_count;
	struct llist_head kretprobe_instances;
	struct callback_head l1d_flush_kill;
	long: 64;
	struct thread_struct___15 thread;
};

typedef struct page___26 *pgtable_t___26;

struct address_space___25;

struct dev_pagemap___25;

struct page___26 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___25 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___6 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___26 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___26 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___27 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___25 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct pv_cpu_ops___21 {
	void (*io_delay)();
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	void (*write_cr4)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___15 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(long unsigned int);
	void (*invalidate_io_bitmap)();
	void (*update_io_bitmap)();
	void (*wbinvd)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int);
	void (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_msr_safe)(unsigned int, int *);
	int (*write_msr_safe)(unsigned int, unsigned int, unsigned int);
	u64 (*read_pmc)(int);
	void (*start_context_switch)(struct task_struct___28 *);
	void (*end_context_switch)(struct task_struct___28 *);
};

struct flush_tlb_info___10;

struct pv_mmu_ops___22 {
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_one_user)(long unsigned int);
	void (*flush_tlb_multi)(const struct cpumask *, const struct flush_tlb_info___10 *);
	void (*tlb_remove_table)(struct mmu_gather *, void *);
	void (*exit_mmap)(struct mm_struct___27 *);
	struct paravirt_callee_save read_cr2;
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___27 *, struct mm_struct___27 *);
	void (*dup_mmap)(struct mm_struct___27 *, struct mm_struct___27 *);
	int (*pgd_alloc)(struct mm_struct___27 *);
	void (*pgd_free)(struct mm_struct___27 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___27 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___27 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___27 *, long unsigned int);
	void (*alloc_p4d)(struct mm_struct___27 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*release_p4d)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	pte_t (*ptep_modify_prot_start)(struct vm_area_struct___27 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct vm_area_struct___27 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_p4d)(p4d_t *, p4d_t);
	struct paravirt_callee_save p4d_val;
	struct paravirt_callee_save make_p4d;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

struct flush_tlb_info___10 {
	struct mm_struct___27 *mm;
	long unsigned int start;
	long unsigned int end;
	u64 new_tlb_gen;
	unsigned int initiating_cpu;
	u8 stride_shift;
	u8 freed_tables;
};

struct core_state___26;

struct mm_struct___27 {
	struct {
		struct vm_area_struct___27 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___25 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int mmap_compat_base;
		long unsigned int mmap_compat_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[48];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___26 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___28 *owner;
		struct user_namespace *user_ns;
		struct file___25 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		bool tlb_flush_batched;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct vm_operations_struct___25;

struct vm_area_struct___27 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___27 *vm_next;
	struct vm_area_struct___27 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___27 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___25 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___25 *vm_file;
	struct file___25 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct paravirt_patch_template___22 {
	struct pv_cpu_ops___21 cpu;
	struct pv_irq_ops irq;
	struct pv_mmu_ops___22 mmu;
	struct pv_lock_ops lock;
};

struct tracepoint___17 {
	const char *name;
	struct static_key key;
	struct static_call_key___17 *static_call_key;
	void *static_call_tramp;
	void *iterator;
	int (*regfunc)();
	void (*unregfunc)();
	struct tracepoint_func *funcs;
};

struct bpf_raw_event_map___17 {
	struct tracepoint___17 *tp;
	void *bpf_func;
	u32 num_args;
	u32 writable_size;
	long: 64;
};

struct seq_operations___23 {
	void * (*start)(struct seq_file___23 *, loff_t *);
	void (*stop)(struct seq_file___23 *, void *);
	void * (*next)(struct seq_file___23 *, void *, loff_t *);
	int (*show)(struct seq_file___23 *, void *);
};

struct hw_perf_event___14 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___28 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	union {
		struct {
			u64 last_period;
			local64_t period_left;
		};
		struct {
			u64 saved_metric;
			u64 saved_slots;
		};
	};
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___14)(struct perf_event___14 *, struct perf_sample_data *, struct pt_regs *);

struct pmu___14;

struct fasync_struct___25;

struct pid_namespace___21;

struct trace_event_call___14;

struct perf_cgroup___14;

struct perf_event___14 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___14 *group_leader;
	struct pmu___14 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___14 hw;
	struct perf_event_context___14 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___14 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___28 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct perf_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___25 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	long unsigned int pending_addr;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	struct perf_addr_filter_range *addr_filter_ranges;
	long unsigned int addr_filters_gen;
	struct perf_event___14 *aux_event;
	void (*destroy)(struct perf_event___14 *);
	struct callback_head callback_head;
	struct pid_namespace___21 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___14 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___14 orig_overflow_handler;
	struct bpf_prog *prog;
	u64 bpf_cookie;
	struct trace_event_call___14 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___14 *cgrp;
	void *security;
	struct list_head sb_list;
};

struct smp_ops___8 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*crash_stop_other_cpus)();
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___28 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct upid___21 {
	int nr;
	struct pid_namespace___21 *ns;
};

struct pid_namespace___21 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___28 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___21 *parent;
	struct fs_pin *bacct;
	struct user_namespace *user_ns;
	struct ucounts *ucounts;
	int reboot;
	struct ns_common ns;
};

struct pid___21 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___21 numbers[1];
};

struct signal_struct___26 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___28 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___28 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___21 *pids[4];
	struct pid___21 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___27 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct cgroup_namespace___19;

struct nsproxy___24 {
	atomic_t count;
	struct uts_namespace *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___21 *pid_ns_for_children;
	struct net *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___19 *cgroup_ns;
};

struct bio___15;

struct bio_list___15 {
	struct bio___15 *head;
	struct bio___15 *tail;
};

struct cgroup_subsys_state___19;

struct bdi_writeback___14 {
	struct backing_dev_info___14 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	atomic_t writeback_inodes;
	struct percpu_counter stat[4];
	long unsigned int congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	struct delayed_work bw_dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___19 *memcg_css;
	struct cgroup_subsys_state___19 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	struct list_head b_attached;
	struct list_head offline_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
};

struct device___27;

struct backing_dev_info___14 {
	u64 id;
	struct rb_node rb_node;
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___14 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct mutex cgwb_release_mutex;
	struct rw_semaphore wb_switch_rwsem;
	wait_queue_head_t wb_waitq;
	struct device___27 *dev;
	char dev_name[64];
	struct device___27 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___25 *debug_dir;
};

struct io_cq___15;

struct io_context___16 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	struct xarray icq_tree;
	struct io_cq___15 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct cgroup___19;

struct css_set___19 {
	struct cgroup_subsys_state___19 *subsys[14];
	refcount_t refcount;
	struct css_set___19 *dom_cset;
	struct cgroup___19 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___19 *mg_src_cgrp;
	struct cgroup___19 *mg_dst_cgrp;
	struct css_set___19 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___14 {
	struct pmu___14 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	int rotate_necessary;
	refcount_t refcount;
	struct task_struct___28 *task;
	u64 time;
	u64 timestamp;
	u64 timeoffset;
	struct perf_event_context___14 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

struct cgroup_subsys___19;

struct cgroup_subsys_state___19 {
	struct cgroup___19 *cgroup;
	struct cgroup_subsys___19 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___19 *parent;
};

struct kernfs_node___25;

struct cgroup_file___19 {
	struct kernfs_node___25 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct obj_cgroup___14;

struct mem_cgroup_per_node___14;

struct mem_cgroup___14 {
	struct cgroup_subsys_state___19 css;
	struct mem_cgroup_id id;
	struct page_counter memory;
	union {
		struct page_counter swap;
		struct page_counter memsw;
	};
	struct page_counter kmem;
	struct page_counter tcpmem;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool oom_group;
	bool oom_lock;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___19 events_file;
	struct cgroup_file___19 events_local_file;
	struct cgroup_file___19 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	struct memcg_vmstats vmstats;
	atomic_long_t memory_events[8];
	atomic_long_t memory_events_local[8];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct obj_cgroup___14 *objcg;
	struct list_head objcg_list;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad2_;
	atomic_t moving_account;
	struct task_struct___28 *move_lock_task;
	struct memcg_vmstats_percpu *vmstats_percpu;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct memcg_cgwb_frn cgwb_frn[4];
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct deferred_split deferred_split_queue;
	struct mem_cgroup_per_node___14 *nodeinfo[0];
	long: 64;
};

struct kset___24;

struct kobj_type___24;

struct kobject___25 {
	const char *name;
	struct list_head entry;
	struct kobject___25 *parent;
	struct kset___24 *kset;
	struct kobj_type___24 *ktype;
	struct kernfs_node___25 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct blk_integrity_profile___15;

struct blk_integrity___15 {
	const struct blk_integrity_profile___15 *profile;
	unsigned char flags;
	unsigned char tuple_size;
	unsigned char interval_exp;
	unsigned char tag_size;
};

struct bio_set___15 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	struct bio_alloc_cache *cache;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	unsigned int back_pad;
	spinlock_t rescue_lock;
	struct bio_list___15 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	struct hlist_node cpuhp_dead;
};

struct request___15;

struct elevator_queue___15;

struct gendisk___15;

struct blkcg_gq___14;

struct request_queue___15 {
	struct request___15 *last_merge;
	struct elevator_queue___15 *elevator;
	struct percpu_ref q_usage_counter;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	const struct blk_mq_ops *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx **queue_hw_ctx;
	unsigned int nr_hw_queues;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	spinlock_t queue_lock;
	struct gendisk___15 *disk;
	struct kobject___25 kobj;
	struct kobject___25 *mq_kobj;
	struct blk_integrity___15 integrity;
	struct device___27 *dev;
	enum rpm_status rpm_status;
	long unsigned int nr_requests;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_keyslot_manager *ksm;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	atomic_t nr_active_requests_shared_sbitmap;
	struct sbitmap_queue sched_bitmap_tags;
	struct sbitmap_queue sched_breserved_tags;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___14 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int required_elevator_features;
	unsigned int nr_zones;
	long unsigned int *conv_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int max_open_zones;
	unsigned int max_active_zones;
	int node;
	struct mutex debugfs_mutex;
	struct blk_trace *blk_trace;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	struct mutex sysfs_dir_lock;
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	int mq_freeze_depth;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct mutex mq_freeze_lock;
	struct blk_mq_tag_set *tag_set;
	struct list_head tag_set_list;
	struct bio_set___15 bio_split;
	struct dentry___25 *debugfs_dir;
	struct dentry___25 *sched_debugfs_dir;
	struct dentry___25 *rqos_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	u64 write_hints[5];
};

struct vm_struct___22 {
	struct vm_struct___22 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___26 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct address_space_operations___25;

struct address_space___25 {
	struct inode___25 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___25 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct dev_pagemap_ops___25;

struct dev_pagemap___25 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___25 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vfsmount___25;

struct path___25 {
	struct vfsmount___25 *mnt;
	struct dentry___25 *dentry;
};

struct fown_struct___21 {
	rwlock_t lock;
	struct pid___21 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___25 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	long: 64;
	long: 64;
	struct path___25 f_path;
	struct inode___25 *f_inode;
	const struct file_operations___25 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___21 f_owner;
	const struct cred *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___25 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___25;

struct vm_operations_struct___25 {
	void (*open)(struct vm_area_struct___27 *);
	void (*close)(struct vm_area_struct___27 *);
	int (*may_split)(struct vm_area_struct___27 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___27 *);
	int (*mprotect)(struct vm_area_struct___27 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___25 *);
	vm_fault_t (*huge_fault)(struct vm_fault___25 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___25 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___27 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___25 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___25 *);
	int (*access)(struct vm_area_struct___27 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___27 *);
	int (*set_policy)(struct vm_area_struct___27 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___27 *, long unsigned int);
	struct page___26 * (*find_special_page)(struct vm_area_struct___27 *, long unsigned int);
};

struct core_thread___26 {
	struct task_struct___28 *task;
	struct core_thread___26 *next;
};

struct core_state___26 {
	atomic_t nr_threads;
	struct core_thread___26 dumper;
	struct completion startup;
};

struct vm_fault___25 {
	const struct {
		struct vm_area_struct___27 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___26 *cow_page;
	struct page___26 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___26 prealloc_pte;
};

struct pglist_data___15;

struct lruvec___15 {
	struct list_head lists[5];
	spinlock_t lru_lock;
	long unsigned int anon_cost;
	long unsigned int file_cost;
	atomic_long_t nonresident_age;
	long unsigned int refaults[2];
	long unsigned int flags;
	struct pglist_data___15 *pgdat;
};

struct zone___15 {
	long unsigned int _watermark[3];
	long unsigned int watermark_boost;
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[5];
	int node;
	struct pglist_data___15 *zone_pgdat;
	struct per_cpu_pages *per_cpu_pageset;
	struct per_cpu_zonestat *per_cpu_zonestats;
	int pageset_high;
	int pageset_batch;
	long unsigned int zone_start_pfn;
	atomic_long_t managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int present_early_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	seqlock_t span_seqlock;
	int initialized;
	int: 32;
	struct zone_padding _pad1_;
	struct free_area free_area[11];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	long unsigned int compact_init_migrate_pfn;
	long unsigned int compact_init_free_pfn;
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	short: 16;
	struct zone_padding _pad3_;
	atomic_long_t vm_stat[11];
	atomic_long_t vm_numa_event[6];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___15 {
	struct zone___15 *zone;
	int zone_idx;
};

struct zonelist___15 {
	struct zoneref___15 _zonerefs[5121];
};

struct pglist_data___15 {
	struct zone___15 node_zones[5];
	struct zonelist___15 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___28 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_highest_zoneidx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_highest_zoneidx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___28 *kcompactd;
	bool proactive_compact_trigger;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct deferred_split deferred_split_queue;
	struct lruvec___15 __lruvec;
	long unsigned int flags;
	long: 64;
	struct zone_padding _pad2_;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[39];
};

struct dentry_operations___25;

struct dentry___25 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___25 *d_parent;
	struct qstr d_name;
	struct inode___25 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___25 *d_op;
	struct super_block___25 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___25;

struct inode___25 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___25 *i_op;
	struct super_block___25 *i_sb;
	struct address_space___25 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___14 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	long: 64;
	long: 64;
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___25 *i_fop;
		void (*free_inode)(struct inode___25 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___25 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct cdev___11 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___25 {
	int (*d_revalidate)(struct dentry___25 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___25 *, unsigned int);
	int (*d_hash)(const struct dentry___25 *, struct qstr *);
	int (*d_compare)(const struct dentry___25 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___25 *);
	int (*d_init)(struct dentry___25 *);
	void (*d_release)(struct dentry___25 *);
	void (*d_prune)(struct dentry___25 *);
	void (*d_iput)(struct dentry___25 *, struct inode___25 *);
	char * (*d_dname)(struct dentry___25 *, char *, int);
	struct vfsmount___25 * (*d_automount)(struct path___25 *);
	int (*d_manage)(const struct path___25 *, bool);
	struct dentry___25 * (*d_real)(struct dentry___25 *, const struct inode___25 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___25;

struct mem_dqinfo___25 {
	struct quota_format_type___25 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___25;

struct quota_info___25 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___25 *files[3];
	struct mem_dqinfo___25 info[3];
	const struct quota_format_ops___25 *ops[3];
};

struct rcuwait___25 {
	struct task_struct___28 *task;
};

struct percpu_rw_semaphore___25 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___25 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___25 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___25 rw_sem[3];
};

struct shrink_control___14;

struct shrinker___14 {
	long unsigned int (*count_objects)(struct shrinker___14 *, struct shrink_control___14 *);
	long unsigned int (*scan_objects)(struct shrinker___14 *, struct shrink_control___14 *);
	long int batch;
	int seeks;
	unsigned int flags;
	struct list_head list;
	int id;
	atomic_long_t *nr_deferred;
};

struct super_operations___25;

struct dquot_operations___25;

struct quotactl_ops___25;

struct block_device___15;

struct super_block___25 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___25 *s_type;
	const struct super_operations___25 *s_op;
	const struct dquot_operations___25 *dq_op;
	const struct quotactl_ops___25 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___25 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___15 *s_bdev;
	struct backing_dev_info___14 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___25 s_dquot;
	struct sb_writers___25 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___25 *s_d_op;
	int cleancache_poolid;
	struct shrinker___14 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___25 {
	struct dentry___25 *mnt_root;
	struct super_block___25 *mnt_sb;
	int mnt_flags;
	struct user_namespace *mnt_userns;
};

struct shrink_control___14 {
	gfp_t gfp_mask;
	int nid;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	struct mem_cgroup___14 *memcg;
};

struct psi_group___19 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___28 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___19;

struct cgroup_rstat_cpu___19;

struct cgroup___19 {
	struct cgroup_subsys_state___19 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___25 *kn;
	struct cgroup_file___19 procs_file;
	struct cgroup_file___19 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___19 *subsys[14];
	struct cgroup_root___19 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___19 *dom_cgrp;
	struct cgroup___19 *old_dom_cgrp;
	struct cgroup_rstat_cpu___19 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___19 psi;
	struct cgroup_bpf___2 bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct io_cq___15 {
	struct request_queue___15 *q;
	struct io_context___16 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct wait_page_queue___13;

struct kiocb___25 {
	struct file___25 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___25 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___13 *ki_waitq;
	};
};

struct iattr___25 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___25 *ia_file;
};

struct dquot___25 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___25 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___25 {
	int qf_fmt_id;
	const struct quota_format_ops___25 *qf_ops;
	struct module___24 *qf_owner;
	struct quota_format_type___25 *qf_next;
};

struct quota_format_ops___25 {
	int (*check_quota_file)(struct super_block___25 *, int);
	int (*read_file_info)(struct super_block___25 *, int);
	int (*write_file_info)(struct super_block___25 *, int);
	int (*free_file_info)(struct super_block___25 *, int);
	int (*read_dqblk)(struct dquot___25 *);
	int (*commit_dqblk)(struct dquot___25 *);
	int (*release_dqblk)(struct dquot___25 *);
	int (*get_next_id)(struct super_block___25 *, struct kqid *);
};

struct dquot_operations___25 {
	int (*write_dquot)(struct dquot___25 *);
	struct dquot___25 * (*alloc_dquot)(struct super_block___25 *, int);
	void (*destroy_dquot)(struct dquot___25 *);
	int (*acquire_dquot)(struct dquot___25 *);
	int (*release_dquot)(struct dquot___25 *);
	int (*mark_dirty)(struct dquot___25 *);
	int (*write_info)(struct super_block___25 *, int);
	qsize_t * (*get_reserved_space)(struct inode___25 *);
	int (*get_projid)(struct inode___25 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___25 *, qsize_t *);
	int (*get_next_id)(struct super_block___25 *, struct kqid *);
};

struct quotactl_ops___25 {
	int (*quota_on)(struct super_block___25 *, int, int, const struct path___25 *);
	int (*quota_off)(struct super_block___25 *, int);
	int (*quota_enable)(struct super_block___25 *, unsigned int);
	int (*quota_disable)(struct super_block___25 *, unsigned int);
	int (*quota_sync)(struct super_block___25 *, int);
	int (*set_info)(struct super_block___25 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___25 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___25 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___25 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___25 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___25 *, unsigned int);
};

struct module_kobject___24 {
	struct kobject___25 kobj;
	struct module___24 *mod;
	struct kobject___25 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___24 {
	struct module___24 *mod;
	struct latch_tree_node node;
};

struct module_layout___24 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___24 mtn;
};

struct module_attribute___24;

struct kernel_param___24;

struct module___24 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___24 mkobj;
	struct module_attribute___24 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___25 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___24 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___24 core_layout;
	struct module_layout___24 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map___17 *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___14 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	int num_static_call_sites;
	struct static_call_site *static_call_sites;
	bool klp;
	bool klp_alive;
	struct klp_modinfo *klp_info;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct wait_page_queue___13 {
	struct page___26 *page;
	int bit_nr;
	wait_queue_entry_t wait;
};

struct writeback_control___14;

struct readahead_control___13;

struct swap_info_struct___10;

struct address_space_operations___25 {
	int (*writepage)(struct page___26 *, struct writeback_control___14 *);
	int (*readpage)(struct file___25 *, struct page___26 *);
	int (*writepages)(struct address_space___25 *, struct writeback_control___14 *);
	int (*set_page_dirty)(struct page___26 *);
	int (*readpages)(struct file___25 *, struct address_space___25 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___13 *);
	int (*write_begin)(struct file___25 *, struct address_space___25 *, loff_t, unsigned int, unsigned int, struct page___26 **, void **);
	int (*write_end)(struct file___25 *, struct address_space___25 *, loff_t, unsigned int, unsigned int, struct page___26 *, void *);
	sector_t (*bmap)(struct address_space___25 *, sector_t);
	void (*invalidatepage)(struct page___26 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___26 *, gfp_t);
	void (*freepage)(struct page___26 *);
	ssize_t (*direct_IO)(struct kiocb___25 *, struct iov_iter___19 *);
	int (*migratepage)(struct address_space___25 *, struct page___26 *, struct page___26 *, enum migrate_mode);
	bool (*isolate_page)(struct page___26 *, isolate_mode_t);
	void (*putback_page)(struct page___26 *);
	int (*launder_page)(struct page___26 *);
	int (*is_partially_uptodate)(struct page___26 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___26 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___25 *, struct page___26 *);
	int (*swap_activate)(struct swap_info_struct___10 *, struct file___25 *, sector_t *);
	void (*swap_deactivate)(struct file___25 *);
};

struct writeback_control___14 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	unsigned int no_cgroup_owner: 1;
	unsigned int punt_to_cgroup: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bdi_writeback___14 *wb;
	struct inode___25 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
};

struct readahead_control___13 {
	struct file___25 *file;
	struct address_space___25 *mapping;
	struct file_ra_state *ra;
	long unsigned int _index;
	unsigned int _nr_pages;
	unsigned int _batch_count;
};

struct bio_vec___19;

struct iov_iter___19 {
	u8 iter_type;
	bool data_source;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___19 *bvec;
		struct xarray *xarray;
		struct pipe_inode_info *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			unsigned int head;
			unsigned int start_head;
		};
		loff_t xarray_start;
	};
};

struct swap_info_struct___10 {
	struct percpu_ref users;
	long unsigned int flags;
	short int prio;
	struct plist_node list;
	signed char type;
	unsigned int max;
	unsigned char *swap_map;
	struct swap_cluster_info *cluster_info;
	struct swap_cluster_list free_clusters;
	unsigned int lowest_bit;
	unsigned int highest_bit;
	unsigned int pages;
	unsigned int inuse_pages;
	unsigned int cluster_next;
	unsigned int cluster_nr;
	unsigned int *cluster_next_cpu;
	struct percpu_cluster *percpu_cluster;
	struct rb_root swap_extent_root;
	struct block_device___15 *bdev;
	struct file___25 *swap_file;
	unsigned int old_block_size;
	struct completion comp;
	long unsigned int *frontswap_map;
	atomic_t frontswap_pages;
	spinlock_t lock;
	spinlock_t cont_lock;
	struct work_struct discard_work;
	struct swap_cluster_list discard_clusters;
	struct plist_node avail_lists[0];
};

struct inode_operations___25 {
	struct dentry___25 * (*lookup)(struct inode___25 *, struct dentry___25 *, unsigned int);
	const char * (*get_link)(struct dentry___25 *, struct inode___25 *, struct delayed_call *);
	int (*permission)(struct user_namespace *, struct inode___25 *, int);
	struct posix_acl * (*get_acl)(struct inode___25 *, int, bool);
	int (*readlink)(struct dentry___25 *, char *, int);
	int (*create)(struct user_namespace *, struct inode___25 *, struct dentry___25 *, umode_t, bool);
	int (*link)(struct dentry___25 *, struct inode___25 *, struct dentry___25 *);
	int (*unlink)(struct inode___25 *, struct dentry___25 *);
	int (*symlink)(struct user_namespace *, struct inode___25 *, struct dentry___25 *, const char *);
	int (*mkdir)(struct user_namespace *, struct inode___25 *, struct dentry___25 *, umode_t);
	int (*rmdir)(struct inode___25 *, struct dentry___25 *);
	int (*mknod)(struct user_namespace *, struct inode___25 *, struct dentry___25 *, umode_t, dev_t);
	int (*rename)(struct user_namespace *, struct inode___25 *, struct dentry___25 *, struct inode___25 *, struct dentry___25 *, unsigned int);
	int (*setattr)(struct user_namespace *, struct dentry___25 *, struct iattr___25 *);
	int (*getattr)(struct user_namespace *, const struct path___25 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___25 *, char *, size_t);
	int (*fiemap)(struct inode___25 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___25 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___25 *, struct dentry___25 *, struct file___25 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace *, struct inode___25 *, struct dentry___25 *, umode_t);
	int (*set_acl)(struct user_namespace *, struct inode___25 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace *, struct dentry___25 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___25 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___25 {
	void (*fl_copy_lock)(struct file_lock___25 *, struct file_lock___25 *);
	void (*fl_release_private)(struct file_lock___25 *);
};

struct lock_manager_operations___25;

struct file_lock___25 {
	struct file_lock___25 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___25 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___25 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___25 *fl_ops;
	const struct lock_manager_operations___25 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___25 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___25 *);
	int (*lm_grant)(struct file_lock___25 *, int);
	bool (*lm_break)(struct file_lock___25 *);
	int (*lm_change)(struct file_lock___25 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___25 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___25 *);
};

struct fasync_struct___25 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___25 *fa_next;
	struct file___25 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___25 {
	struct inode___25 * (*alloc_inode)(struct super_block___25 *);
	void (*destroy_inode)(struct inode___25 *);
	void (*free_inode)(struct inode___25 *);
	void (*dirty_inode)(struct inode___25 *, int);
	int (*write_inode)(struct inode___25 *, struct writeback_control___14 *);
	int (*drop_inode)(struct inode___25 *);
	void (*evict_inode)(struct inode___25 *);
	void (*put_super)(struct super_block___25 *);
	int (*sync_fs)(struct super_block___25 *, int);
	int (*freeze_super)(struct super_block___25 *);
	int (*freeze_fs)(struct super_block___25 *);
	int (*thaw_super)(struct super_block___25 *);
	int (*unfreeze_fs)(struct super_block___25 *);
	int (*statfs)(struct dentry___25 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___25 *, int *, char *);
	void (*umount_begin)(struct super_block___25 *);
	int (*show_options)(struct seq_file___23 *, struct dentry___25 *);
	int (*show_devname)(struct seq_file___23 *, struct dentry___25 *);
	int (*show_path)(struct seq_file___23 *, struct dentry___25 *);
	int (*show_stats)(struct seq_file___23 *, struct dentry___25 *);
	ssize_t (*quota_read)(struct super_block___25 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___25 *, int, const char *, size_t, loff_t);
	struct dquot___25 ** (*get_dquots)(struct inode___25 *);
	long int (*nr_cached_objects)(struct super_block___25 *, struct shrink_control___14 *);
	long int (*free_cached_objects)(struct super_block___25 *, struct shrink_control___14 *);
	struct file___25 * (*real_loop)(struct file___25 *);
};

struct wakeup_source___27;

struct dev_pm_qos___4;

struct dev_pm_info___27 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___27 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___27 *, s32);
	struct dev_pm_qos___4 *qos;
};

struct device_type___27;

struct bus_type___27;

struct device_driver___27;

struct dev_pm_domain___27;

struct device_node___16;

struct fwnode_handle___24;

struct class___27;

struct attribute_group___25;

struct device___27 {
	struct kobject___25 kobj;
	struct device___27 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___27 *type;
	struct bus_type___27 *bus;
	struct device_driver___27 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___27 power;
	struct dev_pm_domain___27 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___16 *of_node;
	struct fwnode_handle___24 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___27 *class;
	const struct attribute_group___25 **groups;
	void (*release)(struct device___27 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct block_device___15 {
	sector_t bd_start_sect;
	struct disk_stats *bd_stats;
	long unsigned int bd_stamp;
	bool bd_read_only;
	dev_t bd_dev;
	int bd_openers;
	struct inode___25 *bd_inode;
	struct super_block___25 *bd_super;
	void *bd_claiming;
	struct device___27 bd_device;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct kobject___25 *bd_holder_dir;
	u8 bd_partno;
	spinlock_t bd_size_lock;
	struct gendisk___15 *bd_disk;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	struct super_block___25 *bd_fsfreeze_sb;
	struct partition_meta_info *bd_meta_info;
};

typedef void (*poll_queue_proc___17)(struct file___25 *, wait_queue_head_t *, struct poll_table_struct___17 *);

struct poll_table_struct___17 {
	poll_queue_proc___17 _qproc;
	__poll_t _key;
};

struct seq_file___23 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___23 *op;
	int poll_event;
	const struct file___25 *file;
	void *private;
};

typedef void bio_end_io_t___15(struct bio___15 *);

struct bio_vec___19 {
	struct page___26 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___15;

struct bio___15 {
	struct bio___15 *bi_next;
	struct block_device___15 *bi_bdev;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	atomic_t __bi_remaining;
	struct bvec_iter bi_iter;
	bio_end_io_t___15 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___14 *bi_blkg;
	struct bio_issue bi_issue;
	u64 bi_iocost_cost;
	struct bio_crypt_ctx *bi_crypt_context;
	union {
		struct bio_integrity_payload___15 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___19 *bi_io_vec;
	struct bio_set___15 *bi_pool;
	struct bio_vec___19 bi_inline_vecs[0];
};

struct kernfs_root___25;

struct kernfs_elem_dir___25 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___25 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___25;

struct kernfs_root___25 {
	struct kernfs_node___25 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___25 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___25 {
	struct kernfs_node___25 *target_kn;
};

struct kernfs_ops___25;

struct kernfs_elem_attr___25 {
	const struct kernfs_ops___25 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___25 *notify_next;
};

struct kernfs_node___25 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___25 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___25 dir;
		struct kernfs_elem_symlink___25 symlink;
		struct kernfs_elem_attr___25 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___25;

struct kernfs_ops___25 {
	int (*open)(struct kernfs_open_file___25 *);
	void (*release)(struct kernfs_open_file___25 *);
	int (*seq_show)(struct seq_file___23 *, void *);
	void * (*seq_start)(struct seq_file___23 *, loff_t *);
	void * (*seq_next)(struct seq_file___23 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___23 *, void *);
	ssize_t (*read)(struct kernfs_open_file___25 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___25 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___25 *, struct poll_table_struct___17 *);
	int (*mmap)(struct kernfs_open_file___25 *, struct vm_area_struct___27 *);
};

struct kernfs_syscall_ops___25 {
	int (*show_options)(struct seq_file___23 *, struct kernfs_root___25 *);
	int (*mkdir)(struct kernfs_node___25 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___25 *);
	int (*rename)(struct kernfs_node___25 *, struct kernfs_node___25 *, const char *);
	int (*show_path)(struct seq_file___23 *, struct kernfs_node___25 *, struct kernfs_root___25 *);
};

struct kernfs_open_file___25 {
	struct kernfs_node___25 *kn;
	struct file___25 *file;
	struct seq_file___23 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___25 *vm_ops;
};

struct bin_attribute___25;

struct attribute_group___25 {
	const char *name;
	umode_t (*is_visible)(struct kobject___25 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___25 *, struct bin_attribute___25 *, int);
	struct attribute **attrs;
	struct bin_attribute___25 **bin_attrs;
};

struct bin_attribute___25 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___25 * (*f_mapping)();
	ssize_t (*read)(struct file___25 *, struct kobject___25 *, struct bin_attribute___25 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___25 *, struct kobject___25 *, struct bin_attribute___25 *, char *, loff_t, size_t);
	int (*mmap)(struct file___25 *, struct kobject___25 *, struct bin_attribute___25 *, struct vm_area_struct___27 *);
};

struct sysfs_ops___24 {
	ssize_t (*show)(struct kobject___25 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___25 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___24;

struct kset___24 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___25 kobj;
	const struct kset_uevent_ops___24 *uevent_ops;
};

struct kobj_type___24 {
	void (*release)(struct kobject___25 *);
	const struct sysfs_ops___24 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___25 **default_groups;
	const struct kobj_ns_type_operations * (*child_ns_type)(struct kobject___25 *);
	const void * (*namespace)(struct kobject___25 *);
	void (*get_ownership)(struct kobject___25 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___24 {
	int (* const filter)(struct kset___24 *, struct kobject___25 *);
	const char * (* const name)(struct kset___24 *, struct kobject___25 *);
	int (* const uevent)(struct kset___24 *, struct kobject___25 *, struct kobj_uevent_env *);
};

struct fwnode_operations___24;

struct fwnode_handle___24 {
	struct fwnode_handle___24 *secondary;
	const struct fwnode_operations___24 *ops;
	struct device___27 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct fwnode_reference_args___24;

struct fwnode_endpoint___24;

struct fwnode_operations___24 {
	struct fwnode_handle___24 * (*get)(struct fwnode_handle___24 *);
	void (*put)(struct fwnode_handle___24 *);
	bool (*device_is_available)(const struct fwnode_handle___24 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___24 *, const struct device___27 *);
	bool (*property_present)(const struct fwnode_handle___24 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___24 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___24 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___24 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___24 *);
	struct fwnode_handle___24 * (*get_parent)(const struct fwnode_handle___24 *);
	struct fwnode_handle___24 * (*get_next_child_node)(const struct fwnode_handle___24 *, struct fwnode_handle___24 *);
	struct fwnode_handle___24 * (*get_named_child_node)(const struct fwnode_handle___24 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___24 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___24 *);
	struct fwnode_handle___24 * (*graph_get_next_endpoint)(const struct fwnode_handle___24 *, struct fwnode_handle___24 *);
	struct fwnode_handle___24 * (*graph_get_remote_endpoint)(const struct fwnode_handle___24 *);
	struct fwnode_handle___24 * (*graph_get_port_parent)(struct fwnode_handle___24 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___24 *, struct fwnode_endpoint___24 *);
	int (*add_links)(struct fwnode_handle___24 *);
};

struct fwnode_endpoint___24 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___24 *local_fwnode;
};

struct fwnode_reference_args___24 {
	struct fwnode_handle___24 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct device_node___16 {
	const char *name;
	phandle phandle;
	const char *full_name;
	struct fwnode_handle___24 fwnode;
	struct property *properties;
	struct property *deadprops;
	struct device_node___16 *parent;
	struct device_node___16 *child;
	struct device_node___16 *sibling;
	long unsigned int _flags;
	void *data;
};

struct dev_pm_ops___27 {
	int (*prepare)(struct device___27 *);
	void (*complete)(struct device___27 *);
	int (*suspend)(struct device___27 *);
	int (*resume)(struct device___27 *);
	int (*freeze)(struct device___27 *);
	int (*thaw)(struct device___27 *);
	int (*poweroff)(struct device___27 *);
	int (*restore)(struct device___27 *);
	int (*suspend_late)(struct device___27 *);
	int (*resume_early)(struct device___27 *);
	int (*freeze_late)(struct device___27 *);
	int (*thaw_early)(struct device___27 *);
	int (*poweroff_late)(struct device___27 *);
	int (*restore_early)(struct device___27 *);
	int (*suspend_noirq)(struct device___27 *);
	int (*resume_noirq)(struct device___27 *);
	int (*freeze_noirq)(struct device___27 *);
	int (*thaw_noirq)(struct device___27 *);
	int (*poweroff_noirq)(struct device___27 *);
	int (*restore_noirq)(struct device___27 *);
	int (*runtime_suspend)(struct device___27 *);
	int (*runtime_resume)(struct device___27 *);
	int (*runtime_idle)(struct device___27 *);
};

struct wakeup_source___27 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___27 *dev;
	bool active: 1;
	bool autosleep_enabled: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_qos_request___4;

struct dev_pm_qos___4 {
	struct pm_qos_constraints resume_latency;
	struct pm_qos_constraints latency_tolerance;
	struct freq_constraints freq;
	struct pm_qos_flags flags;
	struct dev_pm_qos_request___4 *resume_latency_req;
	struct dev_pm_qos_request___4 *latency_tolerance_req;
	struct dev_pm_qos_request___4 *flags_req;
};

struct dev_pm_domain___27 {
	struct dev_pm_ops___27 ops;
	int (*start)(struct device___27 *);
	void (*detach)(struct device___27 *, bool);
	int (*activate)(struct device___27 *);
	void (*sync)(struct device___27 *);
	void (*dismiss)(struct device___27 *);
};

struct bus_type___27 {
	const char *name;
	const char *dev_name;
	struct device___27 *dev_root;
	const struct attribute_group___25 **bus_groups;
	const struct attribute_group___25 **dev_groups;
	const struct attribute_group___25 **drv_groups;
	int (*match)(struct device___27 *, struct device_driver___27 *);
	int (*uevent)(struct device___27 *, struct kobj_uevent_env *);
	int (*probe)(struct device___27 *);
	void (*sync_state)(struct device___27 *);
	void (*remove)(struct device___27 *);
	void (*shutdown)(struct device___27 *);
	int (*online)(struct device___27 *);
	int (*offline)(struct device___27 *);
	int (*suspend)(struct device___27 *, pm_message_t);
	int (*resume)(struct device___27 *);
	int (*num_vf)(struct device___27 *);
	int (*dma_configure)(struct device___27 *);
	const struct dev_pm_ops___27 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___27 {
	const char *name;
	struct bus_type___27 *bus;
	struct module___24 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___27 *);
	void (*sync_state)(struct device___27 *);
	int (*remove)(struct device___27 *);
	void (*shutdown)(struct device___27 *);
	int (*suspend)(struct device___27 *, pm_message_t);
	int (*resume)(struct device___27 *);
	const struct attribute_group___25 **groups;
	const struct attribute_group___25 **dev_groups;
	const struct dev_pm_ops___27 *pm;
	void (*coredump)(struct device___27 *);
	struct driver_private *p;
};

struct device_type___27 {
	const char *name;
	const struct attribute_group___25 **groups;
	int (*uevent)(struct device___27 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___27 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___27 *);
	const struct dev_pm_ops___27 *pm;
};

struct class___27 {
	const char *name;
	struct module___24 *owner;
	const struct attribute_group___25 **class_groups;
	const struct attribute_group___25 **dev_groups;
	struct kobject___25 *dev_kobj;
	int (*dev_uevent)(struct device___27 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___27 *, umode_t *);
	void (*class_release)(struct class___27 *);
	void (*dev_release)(struct device___27 *);
	int (*shutdown_pre)(struct device___27 *);
	const struct kobj_ns_type_operations *ns_type;
	const void * (*namespace)(struct device___27 *);
	void (*get_ownership)(struct device___27 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___27 *pm;
	struct subsys_private *p;
};

struct device_attribute___6 {
	struct attribute attr;
	ssize_t (*show)(struct device___27 *, struct device_attribute___6 *, char *);
	ssize_t (*store)(struct device___27 *, struct device_attribute___6 *, const char *, size_t);
};

struct dev_pagemap_ops___25 {
	void (*page_free)(struct page___26 *);
	void (*kill)(struct dev_pagemap___25 *);
	void (*cleanup)(struct dev_pagemap___25 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___25 *);
};

struct cgroup_namespace___19 {
	struct ns_common ns;
	struct user_namespace *user_ns;
	struct ucounts *ucounts;
	struct css_set___19 *root_cset;
};

struct kernel_param_ops___24 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___24 *);
	int (*get)(char *, const struct kernel_param___24 *);
	void (*free)(void *);
};

struct kparam_array___24;

struct kernel_param___24 {
	const char *name;
	struct module___24 *mod;
	const struct kernel_param_ops___24 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___24 *arr;
	};
};

struct kparam_array___24 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___24 *ops;
	void *elem;
};

struct module_attribute___24 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___24 *, struct module_kobject___24 *, char *);
	ssize_t (*store)(struct module_attribute___24 *, struct module_kobject___24 *, const char *, size_t);
	void (*setup)(struct module___24 *, const char *);
	int (*test)(struct module___24 *);
	void (*free)(struct module___24 *);
};

struct trace_event_class___14;

struct trace_event_call___14 {
	struct list_head list;
	struct trace_event_class___14 *class;
	union {
		char *name;
		struct tracepoint___17 *tp;
	};
	struct trace_event event;
	char *print_fmt;
	struct event_filter *filter;
	union {
		void *module;
		atomic_t refcnt;
	};
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
	struct bpf_prog_array___2 *prog_array;
	int (*perf_perm)(struct trace_event_call___14 *, struct perf_event___14 *);
};

struct cftype___19;

struct cgroup_subsys___19 {
	struct cgroup_subsys_state___19 * (*css_alloc)(struct cgroup_subsys_state___19 *);
	int (*css_online)(struct cgroup_subsys_state___19 *);
	void (*css_offline)(struct cgroup_subsys_state___19 *);
	void (*css_released)(struct cgroup_subsys_state___19 *);
	void (*css_free)(struct cgroup_subsys_state___19 *);
	void (*css_reset)(struct cgroup_subsys_state___19 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___19 *, int);
	int (*css_extra_stat_show)(struct seq_file___23 *, struct cgroup_subsys_state___19 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___28 *, struct css_set___19 *);
	void (*cancel_fork)(struct task_struct___28 *, struct css_set___19 *);
	void (*fork)(struct task_struct___28 *);
	void (*exit)(struct task_struct___28 *);
	void (*release)(struct task_struct___28 *);
	void (*bind)(struct cgroup_subsys_state___19 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___19 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___19 *dfl_cftypes;
	struct cftype___19 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___19 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___19 *updated_children;
	struct cgroup___19 *updated_next;
};

struct cgroup_root___19 {
	struct kernfs_root___25 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___19 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___19 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___19 *ss;
	struct list_head node;
	struct kernfs_ops___25 *kf_ops;
	int (*open)(struct kernfs_open_file___25 *);
	void (*release)(struct kernfs_open_file___25 *);
	u64 (*read_u64)(struct cgroup_subsys_state___19 *, struct cftype___19 *);
	s64 (*read_s64)(struct cgroup_subsys_state___19 *, struct cftype___19 *);
	int (*seq_show)(struct seq_file___23 *, void *);
	void * (*seq_start)(struct seq_file___23 *, loff_t *);
	void * (*seq_next)(struct seq_file___23 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___23 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___19 *, struct cftype___19 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___19 *, struct cftype___19 *, s64);
	ssize_t (*write)(struct kernfs_open_file___25 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___25 *, struct poll_table_struct___17 *);
};

struct block_device_operations___15;

struct gendisk___15 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	short unsigned int events;
	short unsigned int event_flags;
	struct xarray part_tbl;
	struct block_device___15 *part0;
	const struct block_device_operations___15 *fops;
	struct request_queue___15 *queue;
	void *private_data;
	int flags;
	long unsigned int state;
	struct mutex open_mutex;
	unsigned int open_partitions;
	struct backing_dev_info___14 *bdi;
	struct kobject___25 *slave_dir;
	struct list_head slave_bdevs;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___25 integrity_kobj;
	struct cdrom_device_info *cdi;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	u64 diskseq;
};

struct bio_integrity_payload___15 {
	struct bio___15 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___19 *bip_vec;
	struct bio_vec___19 bip_inline_vecs[0];
};

struct blkcg___14;

struct blkg_policy_data___14;

struct blkcg_gq___14 {
	struct request_queue___15 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___14 *blkcg;
	struct blkcg_gq___14 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_iostat_set *iostat_cpu;
	struct blkg_iostat_set iostat;
	struct blkg_policy_data___14 *pd[6];
	spinlock_t async_bio_lock;
	struct bio_list___15 async_bios;
	struct work_struct async_bio_work;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
	struct callback_head callback_head;
};

typedef void integrity_prepare_fn___15(struct request___15 *);

typedef void integrity_complete_fn___15(struct request___15 *, unsigned int);

struct blk_integrity_profile___15 {
	integrity_processing_fn *generate_fn;
	integrity_processing_fn *verify_fn;
	integrity_prepare_fn___15 *prepare_fn;
	integrity_complete_fn___15 *complete_fn;
	const char *name;
};

struct block_device_operations___15 {
	blk_qc_t (*submit_bio)(struct bio___15 *);
	int (*open)(struct block_device___15 *, fmode_t);
	void (*release)(struct gendisk___15 *, fmode_t);
	int (*rw_page)(struct block_device___15 *, sector_t, struct page___26 *, unsigned int);
	int (*ioctl)(struct block_device___15 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___15 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___15 *, unsigned int);
	void (*unlock_native_capacity)(struct gendisk___15 *);
	int (*getgeo)(struct block_device___15 *, struct hd_geometry *);
	int (*set_read_only)(struct block_device___15 *, bool);
	void (*swap_slot_free_notify)(struct block_device___15 *, long unsigned int);
	int (*report_zones)(struct gendisk___15 *, sector_t, unsigned int, report_zones_cb, void *);
	char * (*devnode)(struct gendisk___15 *, umode_t *);
	struct module___24 *owner;
	const struct pr_ops *pr_ops;
	int (*alternative_gpt_sector)(struct gendisk___15 *, sector_t *);
};

typedef void rq_end_io_fn___15(struct request___15 *, blk_status_t);

struct request___15 {
	struct request_queue___15 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int tag;
	int internal_tag;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___15 *bio;
	struct bio___15 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct llist_node ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___19 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___15 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___15 *saved_end_io;
		} flush;
	};
	struct gendisk___15 *rq_disk;
	struct block_device___15 *part;
	u64 alloc_time_ns;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int stats_sectors;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	struct bio_crypt_ctx *crypt_ctx;
	struct blk_ksm_keyslot *crypt_keyslot;
	short unsigned int write_hint;
	short unsigned int ioprio;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___15 *end_io;
	void *end_io_data;
};

struct elevator_type___15;

struct elevator_mq_ops___15 {
	int (*init_sched)(struct request_queue___15 *, struct elevator_type___15 *);
	void (*exit_sched)(struct elevator_queue___15 *);
	int (*init_hctx)(struct blk_mq_hw_ctx *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx *, unsigned int);
	void (*depth_updated)(struct blk_mq_hw_ctx *);
	bool (*allow_merge)(struct request_queue___15 *, struct request___15 *, struct bio___15 *);
	bool (*bio_merge)(struct request_queue___15 *, struct bio___15 *, unsigned int);
	int (*request_merge)(struct request_queue___15 *, struct request___15 **, struct bio___15 *);
	void (*request_merged)(struct request_queue___15 *, struct request___15 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___15 *, struct request___15 *, struct request___15 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___15 *);
	void (*finish_request)(struct request___15 *);
	void (*insert_requests)(struct blk_mq_hw_ctx *, struct list_head *, bool);
	struct request___15 * (*dispatch_request)(struct blk_mq_hw_ctx *);
	bool (*has_work)(struct blk_mq_hw_ctx *);
	void (*completed_request)(struct request___15 *, u64);
	void (*requeue_request)(struct request___15 *);
	struct request___15 * (*former_request)(struct request_queue___15 *, struct request___15 *);
	struct request___15 * (*next_request)(struct request_queue___15 *, struct request___15 *);
	void (*init_icq)(struct io_cq___15 *);
	void (*exit_icq)(struct io_cq___15 *);
};

struct elv_fs_entry___15;

struct elevator_type___15 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___15 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___15 *elevator_attrs;
	const char *elevator_name;
	const char *elevator_alias;
	const unsigned int elevator_features;
	struct module___24 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
};

struct elevator_queue___15 {
	struct elevator_type___15 *type;
	void *elevator_data;
	struct kobject___25 kobj;
	struct mutex sysfs_lock;
	unsigned int registered: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hlist_head hash[64];
};

struct elv_fs_entry___15 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___15 *, char *);
	ssize_t (*store)(struct elevator_queue___15 *, const char *, size_t);
};

struct blkcg_policy_data___14;

struct blkcg___14 {
	struct cgroup_subsys_state___19 css;
	spinlock_t lock;
	refcount_t online_pin;
	struct xarray blkg_tree;
	struct blkcg_gq___14 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___14 *cpd[6];
	struct list_head all_blkcgs_node;
	char fc_app_id[129];
	struct list_head cgwb_list;
};

struct blkcg_policy_data___14 {
	struct blkcg___14 *blkcg;
	int plid;
};

struct blkg_policy_data___14 {
	struct blkcg_gq___14 *blkg;
	int plid;
};

struct mem_cgroup_reclaim_iter___14 {
	struct mem_cgroup___14 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___14 {
	struct lruvec___15 lruvec;
	struct lruvec_stats_percpu *lruvec_stats_percpu;
	struct lruvec_stats lruvec_stats;
	long unsigned int lru_zone_size[25];
	struct mem_cgroup_reclaim_iter___14 iter;
	struct shrinker_info *shrinker_info;
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	struct mem_cgroup___14 *memcg;
};

struct obj_cgroup___14 {
	struct percpu_ref refcnt;
	struct mem_cgroup___14 *memcg;
	atomic_t nr_charged_bytes;
	union {
		struct list_head list;
		struct callback_head rcu;
	};
};

struct smp_hotplug_thread {
	struct task_struct___28 **store;
	struct list_head list;
	int (*thread_should_run)(unsigned int);
	void (*thread_fn)(unsigned int);
	void (*create)(unsigned int);
	void (*setup)(unsigned int);
	void (*cleanup)(unsigned int, bool);
	void (*park)(unsigned int);
	void (*unpark)(unsigned int);
	bool selfparking;
	const char *thread_comm;
};

struct dev_pm_qos_request___4 {
	enum dev_pm_qos_req_type type;
	union {
		struct plist_node pnode;
		struct pm_qos_flags_request flr;
		struct freq_qos_request freq;
	} data;
	struct device___27 *dev;
};

struct perf_cpu_context___14;

struct perf_output_handle___14;

struct pmu___14 {
	struct list_head entry;
	struct module___24 *module;
	struct device___27 *dev;
	const struct attribute_group___25 **attr_groups;
	const struct attribute_group___25 **attr_update;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___14 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___14 *);
	void (*pmu_disable)(struct pmu___14 *);
	int (*event_init)(struct perf_event___14 *);
	void (*event_mapped)(struct perf_event___14 *, struct mm_struct___27 *);
	void (*event_unmapped)(struct perf_event___14 *, struct mm_struct___27 *);
	int (*add)(struct perf_event___14 *, int);
	void (*del)(struct perf_event___14 *, int);
	void (*start)(struct perf_event___14 *, int);
	void (*stop)(struct perf_event___14 *, int);
	void (*read)(struct perf_event___14 *);
	void (*start_txn)(struct pmu___14 *, unsigned int);
	int (*commit_txn)(struct pmu___14 *);
	void (*cancel_txn)(struct pmu___14 *);
	int (*event_idx)(struct perf_event___14 *);
	void (*sched_task)(struct perf_event_context___14 *, bool);
	struct kmem_cache *task_ctx_cache;
	void (*swap_task_ctx)(struct perf_event_context___14 *, struct perf_event_context___14 *);
	void * (*setup_aux)(struct perf_event___14 *, void **, int, bool);
	void (*free_aux)(void *);
	long int (*snapshot_aux)(struct perf_event___14 *, struct perf_output_handle___14 *, long unsigned int);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___14 *);
	int (*aux_output_match)(struct perf_event___14 *);
	int (*filter_match)(struct perf_event___14 *);
	int (*check_period)(struct perf_event___14 *, u64);
};

struct perf_cpu_context___14 {
	struct perf_event_context___14 ctx;
	struct perf_event_context___14 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___14 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
	int heap_size;
	struct perf_event___14 **heap;
	struct perf_event___14 *heap_default[2];
};

struct perf_output_handle___14 {
	struct perf_event___14 *event;
	struct perf_buffer *rb;
	long unsigned int wakeup;
	long unsigned int size;
	u64 aux_flags;
	union {
		void *addr;
		long unsigned int head;
	};
	int page;
};

struct perf_cgroup___14 {
	struct cgroup_subsys_state___19 css;
	struct perf_cgroup_info *info;
};

struct trace_event_fields___14 {
	const char *type;
	union {
		struct {
			const char *name;
			const int size;
			const int align;
			const int is_signed;
			const int filter_type;
		};
		int (*define_fields)(struct trace_event_call___14 *);
	};
};

struct trace_event_class___14 {
	const char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct trace_event_call___14 *, enum trace_reg, void *);
	struct trace_event_fields___14 *fields_array;
	struct list_head * (*get_fields)(struct trace_event_call___14 *);
	struct list_head fields;
	int (*raw_init)(struct trace_event_call___14 *);
};

struct trace_event_file___9;

struct trace_event_buffer___9 {
	struct trace_buffer *buffer;
	struct ring_buffer_event *event;
	struct trace_event_file___9 *trace_file;
	void *entry;
	unsigned int trace_ctx;
	struct pt_regs *regs;
};

struct trace_event_file___9 {
	struct list_head list;
	struct trace_event_call___14 *event_call;
	struct event_filter *filter;
	struct dentry___25 *dir;
	struct trace_array *tr;
	struct trace_subsystem_dir *system;
	struct list_head triggers;
	long unsigned int flags;
	atomic_t sm_ref;
	atomic_t tm_ref;
};

struct trace_event_raw_cpuhp_enter {
	struct trace_entry ent;
	unsigned int cpu;
	int target;
	int idx;
	void *fun;
	char __data[0];
};

struct trace_event_raw_cpuhp_multi_enter {
	struct trace_entry ent;
	unsigned int cpu;
	int target;
	int idx;
	void *fun;
	char __data[0];
};

struct trace_event_raw_cpuhp_exit {
	struct trace_entry ent;
	unsigned int cpu;
	int state;
	int idx;
	int ret;
	char __data[0];
};

struct trace_event_data_offsets_cpuhp_enter {};

struct trace_event_data_offsets_cpuhp_multi_enter {};

struct trace_event_data_offsets_cpuhp_exit {};

typedef void (*btf_trace_cpuhp_enter)(void *, unsigned int, int, int, int (*)(unsigned int));

typedef void (*btf_trace_cpuhp_multi_enter)(void *, unsigned int, int, int, int (*)(unsigned int, struct hlist_node *), struct hlist_node *);

typedef void (*btf_trace_cpuhp_exit)(void *, unsigned int, int, int, int);

struct cpuhp_cpu_state {
	enum cpuhp_state state;
	enum cpuhp_state target;
	enum cpuhp_state fail;
	struct task_struct___28 *thread;
	bool should_run;
	bool rollback;
	bool single;
	bool bringup;
	int cpu;
	struct hlist_node *node;
	struct hlist_node *last;
	enum cpuhp_state cb_state;
	int result;
	struct completion done_up;
	struct completion done_down;
};

struct cpuhp_step {
	const char *name;
	union {
		int (*single)(unsigned int);
		int (*multi)(unsigned int, struct hlist_node *);
	} startup;
	union {
		int (*single)(unsigned int);
		int (*multi)(unsigned int, struct hlist_node *);
	} teardown;
	struct hlist_head list;
	bool cant_stop;
	bool multi_instance;
};

enum cpu_mitigations {
	CPU_MITIGATIONS_OFF = 0,
	CPU_MITIGATIONS_AUTO = 1,
	CPU_MITIGATIONS_AUTO_NOSMT = 2,
};

struct dentry___26;

struct super_block___26;

struct module___25;

struct file_system_type___26 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___26 * (*mount)(struct file_system_type___26 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___26 *);
	struct module___25 *owner;
	struct file_system_type___26 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___26;

struct kiocb___26;

struct iov_iter___20;

struct poll_table_struct___18;

struct vm_area_struct___28;

struct inode___26;

struct file_lock___26;

struct page___27;

struct pipe_inode_info___7;

struct seq_file___24;

struct file_operations___26 {
	struct module___25 *owner;
	loff_t (*llseek)(struct file___26 *, loff_t, int);
	ssize_t (*read)(struct file___26 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___26 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___26 *, struct iov_iter___20 *);
	ssize_t (*write_iter)(struct kiocb___26 *, struct iov_iter___20 *);
	int (*iopoll)(struct kiocb___26 *, bool);
	int (*iterate)(struct file___26 *, struct dir_context *);
	int (*iterate_shared)(struct file___26 *, struct dir_context *);
	__poll_t (*poll)(struct file___26 *, struct poll_table_struct___18 *);
	long int (*unlocked_ioctl)(struct file___26 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___26 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___26 *, struct vm_area_struct___28 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___26 *, struct file___26 *);
	int (*flush)(struct file___26 *, fl_owner_t);
	int (*release)(struct inode___26 *, struct file___26 *);
	int (*fsync)(struct file___26 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___26 *, int);
	int (*lock)(struct file___26 *, int, struct file_lock___26 *);
	ssize_t (*sendpage)(struct file___26 *, struct page___27 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___26 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___26 *, long unsigned int);
	int (*flock)(struct file___26 *, int, struct file_lock___26 *);
	ssize_t (*splice_write)(struct pipe_inode_info___7 *, struct file___26 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___26 *, loff_t *, struct pipe_inode_info___7 *, size_t, unsigned int);
	int (*setlease)(struct file___26 *, long int, struct file_lock___26 **, void **);
	long int (*fallocate)(struct file___26 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___24 *, struct file___26 *);
	ssize_t (*copy_file_range)(struct file___26 *, loff_t, struct file___26 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___26 *, loff_t, struct file___26 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___26 *, loff_t, loff_t, int);
};

struct static_call_mod___18 {
	struct static_call_mod___18 *next;
	struct module___25 *mod;
	struct static_call_site *sites;
};

struct static_call_key___18 {
	void *func;
	union {
		long unsigned int type;
		struct static_call_mod___18 *mods;
		struct static_call_site *sites;
	};
};

struct __kernel_old_timeval {
	__kernel_long_t tv_sec;
	__kernel_long_t tv_usec;
};

struct vmacache___27 {
	u64 seqnum;
	struct vm_area_struct___28 *vmas[4];
};

struct page_frag___27 {
	struct page___27 *page;
	__u32 offset;
	__u32 size;
};

struct perf_event___15;

struct thread_struct___16 {
	struct desc_struct tls_array[3];
	long unsigned int sp;
	short unsigned int es;
	short unsigned int ds;
	short unsigned int fsindex;
	short unsigned int gsindex;
	long unsigned int fsbase;
	long unsigned int gsbase;
	struct perf_event___15 *ptrace_bps[4];
	long unsigned int virtual_dr6;
	long unsigned int ptrace_dr7;
	long unsigned int cr2;
	long unsigned int trap_nr;
	long unsigned int error_code;
	struct io_bitmap *io_bitmap;
	long unsigned int iopl_emul;
	unsigned int iopl_warn: 1;
	unsigned int sig_on_uaccess_err: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u32 pkru;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct fpu fpu;
};

struct mm_struct___28;

struct pid___22;

struct fs_struct___4;

struct files_struct___3;

struct nsproxy___25;

struct signal_struct___27;

struct bio_list___16;

struct backing_dev_info___15;

struct io_context___17;

struct css_set___20;

struct perf_event_context___15;

struct mem_cgroup___15;

struct request_queue___16;

struct vm_struct___23;

struct task_struct___29 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___29 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___28 *mm;
	struct mm_struct___28 *active_mm;
	struct vmacache___27 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int restore_sigmask: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___29 *real_parent;
	struct task_struct___29 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___29 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___22 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	struct posix_cputimers_work posix_cputimers_work;
	const struct cred *ptracer_cred;
	const struct cred *real_cred;
	const struct cred *cred;
	struct key *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct___4 *fs;
	struct files_struct___3 *files;
	struct io_uring_task *io_uring;
	struct nsproxy___25 *nsproxy;
	struct signal_struct___27 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___29 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___16 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___15 *backing_dev_info;
	struct io_context___17 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___20 *cgroups;
	struct list_head cg_list;
	u32 closid;
	u32 rmid;
	struct robust_list_head___2 *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___15 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	struct pipe_inode_info___7 *splice_pipe;
	struct page_frag___27 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___15 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___15 *active_memcg;
	struct request_queue___16 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___29 *oom_reaper_list;
	struct vm_struct___23 *stack_vm_area;
	refcount_t stack_refcount;
	int patch_state;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	void *mce_vaddr;
	__u64 mce_kflags;
	u64 mce_addr;
	__u64 mce_ripv: 1;
	__u64 mce_whole_page: 1;
	__u64 __mce_reserved: 62;
	long: 2;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct callback_head mce_kill_me;
	int mce_count;
	struct llist_head kretprobe_instances;
	struct callback_head l1d_flush_kill;
	long: 64;
	struct thread_struct___16 thread;
};

typedef struct page___27 *pgtable_t___27;

struct address_space___26;

struct page_pool___7;

struct dev_pagemap___26;

struct page___27 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___26 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___7 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___27 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___27 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___28 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___26 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct pv_cpu_ops___22 {
	void (*io_delay)();
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	void (*write_cr4)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___16 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(long unsigned int);
	void (*invalidate_io_bitmap)();
	void (*update_io_bitmap)();
	void (*wbinvd)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int);
	void (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_msr_safe)(unsigned int, int *);
	int (*write_msr_safe)(unsigned int, unsigned int, unsigned int);
	u64 (*read_pmc)(int);
	void (*start_context_switch)(struct task_struct___29 *);
	void (*end_context_switch)(struct task_struct___29 *);
};

struct flush_tlb_info___11;

struct pv_mmu_ops___23 {
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_one_user)(long unsigned int);
	void (*flush_tlb_multi)(const struct cpumask *, const struct flush_tlb_info___11 *);
	void (*tlb_remove_table)(struct mmu_gather *, void *);
	void (*exit_mmap)(struct mm_struct___28 *);
	struct paravirt_callee_save read_cr2;
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___28 *, struct mm_struct___28 *);
	void (*dup_mmap)(struct mm_struct___28 *, struct mm_struct___28 *);
	int (*pgd_alloc)(struct mm_struct___28 *);
	void (*pgd_free)(struct mm_struct___28 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___28 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___28 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___28 *, long unsigned int);
	void (*alloc_p4d)(struct mm_struct___28 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*release_p4d)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	pte_t (*ptep_modify_prot_start)(struct vm_area_struct___28 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct vm_area_struct___28 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_p4d)(p4d_t *, p4d_t);
	struct paravirt_callee_save p4d_val;
	struct paravirt_callee_save make_p4d;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

struct flush_tlb_info___11 {
	struct mm_struct___28 *mm;
	long unsigned int start;
	long unsigned int end;
	u64 new_tlb_gen;
	unsigned int initiating_cpu;
	u8 stride_shift;
	u8 freed_tables;
};

struct linux_binfmt___4;

struct core_state___27;

struct mm_struct___28 {
	struct {
		struct vm_area_struct___28 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___26 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int mmap_compat_base;
		long unsigned int mmap_compat_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[48];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___4 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___27 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___29 *owner;
		struct user_namespace *user_ns;
		struct file___26 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		bool tlb_flush_batched;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct vm_operations_struct___26;

struct vm_area_struct___28 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___28 *vm_next;
	struct vm_area_struct___28 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___28 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___26 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___26 *vm_file;
	struct file___26 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct paravirt_patch_template___23 {
	struct pv_cpu_ops___22 cpu;
	struct pv_irq_ops irq;
	struct pv_mmu_ops___23 mmu;
	struct pv_lock_ops lock;
};

struct tracepoint___18 {
	const char *name;
	struct static_key key;
	struct static_call_key___18 *static_call_key;
	void *static_call_tramp;
	void *iterator;
	int (*regfunc)();
	void (*unregfunc)();
	struct tracepoint_func *funcs;
};

struct bpf_raw_event_map___18 {
	struct tracepoint___18 *tp;
	void *bpf_func;
	u32 num_args;
	u32 writable_size;
	long: 64;
};

struct seq_operations___24 {
	void * (*start)(struct seq_file___24 *, loff_t *);
	void (*stop)(struct seq_file___24 *, void *);
	void * (*next)(struct seq_file___24 *, void *, loff_t *);
	int (*show)(struct seq_file___24 *, void *);
};

struct hw_perf_event___15 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___29 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	union {
		struct {
			u64 last_period;
			local64_t period_left;
		};
		struct {
			u64 saved_metric;
			u64 saved_slots;
		};
	};
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___15)(struct perf_event___15 *, struct perf_sample_data *, struct pt_regs *);

struct pmu___15;

struct fasync_struct___26;

struct pid_namespace___22;

struct trace_event_call___15;

struct perf_cgroup___15;

struct perf_event___15 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___15 *group_leader;
	struct pmu___15 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___15 hw;
	struct perf_event_context___15 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___15 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___29 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct perf_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___26 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	long unsigned int pending_addr;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	struct perf_addr_filter_range *addr_filter_ranges;
	long unsigned int addr_filters_gen;
	struct perf_event___15 *aux_event;
	void (*destroy)(struct perf_event___15 *);
	struct callback_head callback_head;
	struct pid_namespace___22 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___15 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___15 orig_overflow_handler;
	struct bpf_prog *prog;
	u64 bpf_cookie;
	struct trace_event_call___15 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___15 *cgrp;
	void *security;
	struct list_head sb_list;
};

struct old_timeval32 {
	old_time32_t tv_sec;
	s32 tv_usec;
};

struct address_space_operations___26;

struct address_space___26 {
	struct inode___26 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___26 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct device___28;

struct page_pool_params___7 {
	unsigned int flags;
	unsigned int order;
	unsigned int pool_size;
	int nid;
	struct device___28 *dev;
	enum dma_data_direction dma_dir;
	unsigned int max_len;
	unsigned int offset;
};

struct pp_alloc_cache___7 {
	u32 count;
	struct page___27 *cache[128];
};

struct page_pool___7 {
	struct page_pool_params___7 p;
	struct delayed_work release_dw;
	void (*disconnect)(void *);
	long unsigned int defer_start;
	long unsigned int defer_warn;
	u32 pages_state_hold_cnt;
	unsigned int frag_offset;
	struct page___27 *frag_page;
	long int frag_users;
	long: 64;
	long: 64;
	struct pp_alloc_cache___7 alloc;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct ptr_ring ring;
	atomic_t pages_state_release_cnt;
	refcount_t user_cnt;
	u64 destroy_cnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pagemap_ops___26;

struct dev_pagemap___26 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___26 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vfsmount___26;

struct path___26 {
	struct vfsmount___26 *mnt;
	struct dentry___26 *dentry;
};

struct fown_struct___22 {
	rwlock_t lock;
	struct pid___22 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___26 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___26 f_path;
	struct inode___26 *f_inode;
	const struct file_operations___26 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___22 f_owner;
	const struct cred *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___26 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___26;

struct vm_operations_struct___26 {
	void (*open)(struct vm_area_struct___28 *);
	void (*close)(struct vm_area_struct___28 *);
	int (*may_split)(struct vm_area_struct___28 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___28 *);
	int (*mprotect)(struct vm_area_struct___28 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___26 *);
	vm_fault_t (*huge_fault)(struct vm_fault___26 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___26 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___28 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___26 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___26 *);
	int (*access)(struct vm_area_struct___28 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___28 *);
	int (*set_policy)(struct vm_area_struct___28 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___28 *, long unsigned int);
	struct page___27 * (*find_special_page)(struct vm_area_struct___28 *, long unsigned int);
};

struct core_thread___27 {
	struct task_struct___29 *task;
	struct core_thread___27 *next;
};

struct core_state___27 {
	atomic_t nr_threads;
	struct core_thread___27 dumper;
	struct completion startup;
};

struct linux_binprm___5;

struct coredump_params___4;

struct linux_binfmt___4 {
	struct list_head lh;
	struct module___25 *module;
	int (*load_binary)(struct linux_binprm___5 *);
	int (*load_shlib)(struct file___26 *);
	int (*core_dump)(struct coredump_params___4 *);
	long unsigned int min_coredump;
};

struct vm_fault___26 {
	const struct {
		struct vm_area_struct___28 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___27 *cow_page;
	struct page___27 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___27 prealloc_pte;
};

struct pglist_data___16;

struct lruvec___16 {
	struct list_head lists[5];
	spinlock_t lru_lock;
	long unsigned int anon_cost;
	long unsigned int file_cost;
	atomic_long_t nonresident_age;
	long unsigned int refaults[2];
	long unsigned int flags;
	struct pglist_data___16 *pgdat;
};

struct zone___16 {
	long unsigned int _watermark[3];
	long unsigned int watermark_boost;
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[5];
	int node;
	struct pglist_data___16 *zone_pgdat;
	struct per_cpu_pages *per_cpu_pageset;
	struct per_cpu_zonestat *per_cpu_zonestats;
	int pageset_high;
	int pageset_batch;
	long unsigned int zone_start_pfn;
	atomic_long_t managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int present_early_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	seqlock_t span_seqlock;
	int initialized;
	int: 32;
	struct zone_padding _pad1_;
	struct free_area free_area[11];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	long unsigned int compact_init_migrate_pfn;
	long unsigned int compact_init_free_pfn;
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	short: 16;
	struct zone_padding _pad3_;
	atomic_long_t vm_stat[11];
	atomic_long_t vm_numa_event[6];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___16 {
	struct zone___16 *zone;
	int zone_idx;
};

struct zonelist___16 {
	struct zoneref___16 _zonerefs[5121];
};

struct pglist_data___16 {
	struct zone___16 node_zones[5];
	struct zonelist___16 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___29 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_highest_zoneidx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_highest_zoneidx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___29 *kcompactd;
	bool proactive_compact_trigger;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct deferred_split deferred_split_queue;
	struct lruvec___16 __lruvec;
	long unsigned int flags;
	long: 64;
	struct zone_padding _pad2_;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[39];
};

struct shrink_control___15 {
	gfp_t gfp_mask;
	int nid;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	struct mem_cgroup___15 *memcg;
};

struct cgroup___20;

struct cgroup_subsys___20;

struct cgroup_subsys_state___20 {
	struct cgroup___20 *cgroup;
	struct cgroup_subsys___20 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___20 *parent;
};

struct kernfs_node___26;

struct cgroup_file___20 {
	struct kernfs_node___26 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct obj_cgroup___15;

struct mem_cgroup_per_node___15;

struct mem_cgroup___15 {
	struct cgroup_subsys_state___20 css;
	struct mem_cgroup_id id;
	struct page_counter memory;
	union {
		struct page_counter swap;
		struct page_counter memsw;
	};
	struct page_counter kmem;
	struct page_counter tcpmem;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool oom_group;
	bool oom_lock;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___20 events_file;
	struct cgroup_file___20 events_local_file;
	struct cgroup_file___20 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	struct memcg_vmstats vmstats;
	atomic_long_t memory_events[8];
	atomic_long_t memory_events_local[8];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct obj_cgroup___15 *objcg;
	struct list_head objcg_list;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad2_;
	atomic_t moving_account;
	struct task_struct___29 *move_lock_task;
	struct memcg_vmstats_percpu *vmstats_percpu;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct memcg_cgwb_frn cgwb_frn[4];
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct deferred_split deferred_split_queue;
	struct mem_cgroup_per_node___15 *nodeinfo[0];
	long: 64;
};

struct shrinker___15 {
	long unsigned int (*count_objects)(struct shrinker___15 *, struct shrink_control___15 *);
	long unsigned int (*scan_objects)(struct shrinker___15 *, struct shrink_control___15 *);
	long int batch;
	int seeks;
	unsigned int flags;
	struct list_head list;
	int id;
	atomic_long_t *nr_deferred;
};

struct rusage {
	struct __kernel_old_timeval ru_utime;
	struct __kernel_old_timeval ru_stime;
	__kernel_long_t ru_maxrss;
	__kernel_long_t ru_ixrss;
	__kernel_long_t ru_idrss;
	__kernel_long_t ru_isrss;
	__kernel_long_t ru_minflt;
	__kernel_long_t ru_majflt;
	__kernel_long_t ru_nswap;
	__kernel_long_t ru_inblock;
	__kernel_long_t ru_oublock;
	__kernel_long_t ru_msgsnd;
	__kernel_long_t ru_msgrcv;
	__kernel_long_t ru_nsignals;
	__kernel_long_t ru_nvcsw;
	__kernel_long_t ru_nivcsw;
};

struct dev_pagemap_ops___26 {
	void (*page_free)(struct page___27 *);
	void (*kill)(struct dev_pagemap___26 *);
	void (*cleanup)(struct dev_pagemap___26 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___26 *);
};

struct upid___22 {
	int nr;
	struct pid_namespace___22 *ns;
};

struct pid_namespace___22 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___29 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___22 *parent;
	struct fs_pin *bacct;
	struct user_namespace *user_ns;
	struct ucounts *ucounts;
	int reboot;
	struct ns_common ns;
};

struct pid___22 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___22 numbers[1];
};

struct tty_struct___5;

struct signal_struct___27 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___29 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___29 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper;
	unsigned int has_child_subreaper;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___22 *pids[4];
	struct pid___22 *tty_old_pgrp;
	int leader;
	struct tty_struct___5 *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___28 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct fs_struct___4 {
	int users;
	spinlock_t lock;
	seqcount_spinlock_t seq;
	int umask;
	int in_exec;
	struct path___26 root;
	struct path___26 pwd;
};

struct fdtable___2 {
	unsigned int max_fds;
	struct file___26 **fd;
	long unsigned int *close_on_exec;
	long unsigned int *open_fds;
	long unsigned int *full_fds_bits;
	struct callback_head rcu;
};

struct files_struct___3 {
	atomic_t count;
	bool resize_in_progress;
	wait_queue_head_t resize_wait;
	struct fdtable___2 *fdt;
	struct fdtable___2 fdtab;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t file_lock;
	unsigned int next_fd;
	long unsigned int close_on_exec_init[1];
	long unsigned int open_fds_init[1];
	long unsigned int full_fds_bits_init[1];
	struct file___26 *fd_array[64];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct net___4;

struct cgroup_namespace___20;

struct nsproxy___25 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___22 *pid_ns_for_children;
	struct net___4 *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___20 *cgroup_ns;
};

struct bio___16;

struct bio_list___16 {
	struct bio___16 *head;
	struct bio___16 *tail;
};

struct bdi_writeback___15 {
	struct backing_dev_info___15 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	atomic_t writeback_inodes;
	struct percpu_counter stat[4];
	long unsigned int congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	struct delayed_work bw_dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___20 *memcg_css;
	struct cgroup_subsys_state___20 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	struct list_head b_attached;
	struct list_head offline_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
};

struct backing_dev_info___15 {
	u64 id;
	struct rb_node rb_node;
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___15 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct mutex cgwb_release_mutex;
	struct rw_semaphore wb_switch_rwsem;
	wait_queue_head_t wb_waitq;
	struct device___28 *dev;
	char dev_name[64];
	struct device___28 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___26 *debug_dir;
};

struct io_cq___16;

struct io_context___17 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	struct xarray icq_tree;
	struct io_cq___16 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct css_set___20 {
	struct cgroup_subsys_state___20 *subsys[14];
	refcount_t refcount;
	struct css_set___20 *dom_cset;
	struct cgroup___20 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___20 *mg_src_cgrp;
	struct cgroup___20 *mg_dst_cgrp;
	struct css_set___20 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___15 {
	struct pmu___15 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	int rotate_necessary;
	refcount_t refcount;
	struct task_struct___29 *task;
	u64 time;
	u64 timestamp;
	u64 timeoffset;
	struct perf_event_context___15 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

struct pipe_buffer___7;

struct pipe_inode_info___7 {
	struct mutex mutex;
	wait_queue_head_t rd_wait;
	wait_queue_head_t wr_wait;
	unsigned int head;
	unsigned int tail;
	unsigned int max_usage;
	unsigned int ring_size;
	bool note_loss;
	unsigned int nr_accounted;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int r_counter;
	unsigned int w_counter;
	unsigned int poll_usage;
	struct page___27 *tmp_page;
	struct fasync_struct___26 *fasync_readers;
	struct fasync_struct___26 *fasync_writers;
	struct pipe_buffer___7 *bufs;
	struct user_struct *user;
	struct watch_queue *watch_queue;
};

struct kset___25;

struct kobj_type___25;

struct kobject___26 {
	const char *name;
	struct list_head entry;
	struct kobject___26 *parent;
	struct kset___25 *kset;
	struct kobj_type___25 *ktype;
	struct kernfs_node___26 *sd;
	struct kref kref;
	unsigned int state_initialized;
	unsigned int state_in_sysfs;
	unsigned int state_add_uevent_sent;
	unsigned int state_remove_uevent_sent;
	unsigned int uevent_suppress;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct blk_integrity_profile___16;

struct blk_integrity___16 {
	const struct blk_integrity_profile___16 *profile;
	unsigned char flags;
	unsigned char tuple_size;
	unsigned char interval_exp;
	unsigned char tag_size;
};

struct bio_set___16 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	struct bio_alloc_cache *cache;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	unsigned int back_pad;
	spinlock_t rescue_lock;
	struct bio_list___16 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	struct hlist_node cpuhp_dead;
};

struct request___16;

struct elevator_queue___16;

struct gendisk___16;

struct blkcg_gq___15;

struct request_queue___16 {
	struct request___16 *last_merge;
	struct elevator_queue___16 *elevator;
	struct percpu_ref q_usage_counter;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	const struct blk_mq_ops *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx **queue_hw_ctx;
	unsigned int nr_hw_queues;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	spinlock_t queue_lock;
	struct gendisk___16 *disk;
	struct kobject___26 kobj;
	struct kobject___26 *mq_kobj;
	struct blk_integrity___16 integrity;
	struct device___28 *dev;
	enum rpm_status rpm_status;
	long unsigned int nr_requests;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_keyslot_manager *ksm;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	atomic_t nr_active_requests_shared_sbitmap;
	struct sbitmap_queue sched_bitmap_tags;
	struct sbitmap_queue sched_breserved_tags;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___15 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int required_elevator_features;
	unsigned int nr_zones;
	long unsigned int *conv_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int max_open_zones;
	unsigned int max_active_zones;
	int node;
	struct mutex debugfs_mutex;
	struct blk_trace *blk_trace;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	struct mutex sysfs_dir_lock;
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	int mq_freeze_depth;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct mutex mq_freeze_lock;
	struct blk_mq_tag_set *tag_set;
	struct list_head tag_set_list;
	struct bio_set___16 bio_split;
	struct dentry___26 *debugfs_dir;
	struct dentry___26 *sched_debugfs_dir;
	struct dentry___26 *rqos_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	u64 write_hints[5];
};

struct vm_struct___23 {
	struct vm_struct___23 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___27 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct dentry_operations___26;

struct dentry___26 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___26 *d_parent;
	struct qstr d_name;
	struct inode___26 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___26 *d_op;
	struct super_block___26 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___26;

struct cdev___12;

struct inode___26 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___26 *i_op;
	struct super_block___26 *i_sb;
	struct address_space___26 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___15 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___26 *i_fop;
		void (*free_inode)(struct inode___26 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___26 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___7 *i_pipe;
		struct cdev___12 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___26 {
	int (*d_revalidate)(struct dentry___26 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___26 *, unsigned int);
	int (*d_hash)(const struct dentry___26 *, struct qstr *);
	int (*d_compare)(const struct dentry___26 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___26 *);
	int (*d_init)(struct dentry___26 *);
	void (*d_release)(struct dentry___26 *);
	void (*d_prune)(struct dentry___26 *);
	void (*d_iput)(struct dentry___26 *, struct inode___26 *);
	char * (*d_dname)(struct dentry___26 *, char *, int);
	struct vfsmount___26 * (*d_automount)(struct path___26 *);
	int (*d_manage)(const struct path___26 *, bool);
	struct dentry___26 * (*d_real)(struct dentry___26 *, const struct inode___26 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___26;

struct mem_dqinfo___26 {
	struct quota_format_type___26 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___26;

struct quota_info___26 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___26 *files[3];
	struct mem_dqinfo___26 info[3];
	const struct quota_format_ops___26 *ops[3];
};

struct rcuwait___26 {
	struct task_struct___29 *task;
};

struct percpu_rw_semaphore___26 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___26 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___26 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___26 rw_sem[3];
};

struct super_operations___26;

struct dquot_operations___26;

struct quotactl_ops___26;

struct block_device___16;

struct super_block___26 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___26 *s_type;
	const struct super_operations___26 *s_op;
	const struct dquot_operations___26 *dq_op;
	const struct quotactl_ops___26 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___26 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___16 *s_bdev;
	struct backing_dev_info___15 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___26 s_dquot;
	struct sb_writers___26 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___26 *s_d_op;
	int cleancache_poolid;
	struct shrinker___15 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___26 {
	struct dentry___26 *mnt_root;
	struct super_block___26 *mnt_sb;
	int mnt_flags;
	struct user_namespace *mnt_userns;
};

typedef struct {} mm_segment_t;

struct psi_group___20 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___29 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___20;

struct cgroup_rstat_cpu___20;

struct cgroup___20 {
	struct cgroup_subsys_state___20 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___26 *kn;
	struct cgroup_file___20 procs_file;
	struct cgroup_file___20 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___20 *subsys[14];
	struct cgroup_root___20 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___20 *dom_cgrp;
	struct cgroup___20 *old_dom_cgrp;
	struct cgroup_rstat_cpu___20 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___20 psi;
	struct cgroup_bpf___2 bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct tty_driver___5;

struct tty_operations___5;

struct tty_ldisc___5;

struct tty_port___5;

struct tty_struct___5 {
	int magic;
	struct kref kref;
	struct device___28 *dev;
	struct tty_driver___5 *driver;
	const struct tty_operations___5 *ops;
	int index;
	struct ld_semaphore ldisc_sem;
	struct tty_ldisc___5 *ldisc;
	struct mutex atomic_write_lock;
	struct mutex legacy_mutex;
	struct mutex throttle_mutex;
	struct rw_semaphore termios_rwsem;
	struct mutex winsize_mutex;
	struct ktermios termios;
	struct ktermios termios_locked;
	char name[64];
	long unsigned int flags;
	int count;
	struct winsize winsize;
	struct {
		spinlock_t lock;
		bool stopped;
		bool tco_stopped;
		long unsigned int unused[0];
	} flow;
	struct {
		spinlock_t lock;
		struct pid___22 *pgrp;
		struct pid___22 *session;
		unsigned char pktstatus;
		bool packet;
		long unsigned int unused[0];
	} ctrl;
	int hw_stopped;
	unsigned int receive_room;
	int flow_change;
	struct tty_struct___5 *link;
	struct fasync_struct___26 *fasync;
	wait_queue_head_t write_wait;
	wait_queue_head_t read_wait;
	struct work_struct hangup_work;
	void *disc_data;
	void *driver_data;
	spinlock_t files_lock;
	struct list_head tty_files;
	int closing;
	unsigned char *write_buf;
	int write_cnt;
	struct work_struct SAK_work;
	struct tty_port___5 *port;
};

struct io_cq___16 {
	struct request_queue___16 *q;
	struct io_context___17 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct wait_page_queue___14;

struct kiocb___26 {
	struct file___26 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___26 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___14 *ki_waitq;
	};
};

struct iattr___26 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___26 *ia_file;
};

struct dquot___26 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___26 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___26 {
	int qf_fmt_id;
	const struct quota_format_ops___26 *qf_ops;
	struct module___25 *qf_owner;
	struct quota_format_type___26 *qf_next;
};

struct quota_format_ops___26 {
	int (*check_quota_file)(struct super_block___26 *, int);
	int (*read_file_info)(struct super_block___26 *, int);
	int (*write_file_info)(struct super_block___26 *, int);
	int (*free_file_info)(struct super_block___26 *, int);
	int (*read_dqblk)(struct dquot___26 *);
	int (*commit_dqblk)(struct dquot___26 *);
	int (*release_dqblk)(struct dquot___26 *);
	int (*get_next_id)(struct super_block___26 *, struct kqid *);
};

struct dquot_operations___26 {
	int (*write_dquot)(struct dquot___26 *);
	struct dquot___26 * (*alloc_dquot)(struct super_block___26 *, int);
	void (*destroy_dquot)(struct dquot___26 *);
	int (*acquire_dquot)(struct dquot___26 *);
	int (*release_dquot)(struct dquot___26 *);
	int (*mark_dirty)(struct dquot___26 *);
	int (*write_info)(struct super_block___26 *, int);
	qsize_t * (*get_reserved_space)(struct inode___26 *);
	int (*get_projid)(struct inode___26 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___26 *, qsize_t *);
	int (*get_next_id)(struct super_block___26 *, struct kqid *);
};

struct quotactl_ops___26 {
	int (*quota_on)(struct super_block___26 *, int, int, const struct path___26 *);
	int (*quota_off)(struct super_block___26 *, int);
	int (*quota_enable)(struct super_block___26 *, unsigned int);
	int (*quota_disable)(struct super_block___26 *, unsigned int);
	int (*quota_sync)(struct super_block___26 *, int);
	int (*set_info)(struct super_block___26 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___26 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___26 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___26 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___26 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___26 *, unsigned int);
};

struct module_kobject___25 {
	struct kobject___26 kobj;
	struct module___25 *mod;
	struct kobject___26 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___25 {
	struct module___25 *mod;
	struct latch_tree_node node;
};

struct module_layout___25 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___25 mtn;
};

struct module_attribute___25;

struct kernel_param___25;

struct module___25 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___25 mkobj;
	struct module_attribute___25 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___26 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___25 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___25 core_layout;
	struct module_layout___25 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map___18 *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___15 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	int num_static_call_sites;
	struct static_call_site *static_call_sites;
	bool klp;
	bool klp_alive;
	struct klp_modinfo *klp_info;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct wait_page_queue___14 {
	struct page___27 *page;
	int bit_nr;
	wait_queue_entry_t wait;
};

struct writeback_control___15;

struct readahead_control___14;

struct address_space_operations___26 {
	int (*writepage)(struct page___27 *, struct writeback_control___15 *);
	int (*readpage)(struct file___26 *, struct page___27 *);
	int (*writepages)(struct address_space___26 *, struct writeback_control___15 *);
	int (*set_page_dirty)(struct page___27 *);
	int (*readpages)(struct file___26 *, struct address_space___26 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___14 *);
	int (*write_begin)(struct file___26 *, struct address_space___26 *, loff_t, unsigned int, unsigned int, struct page___27 **, void **);
	int (*write_end)(struct file___26 *, struct address_space___26 *, loff_t, unsigned int, unsigned int, struct page___27 *, void *);
	sector_t (*bmap)(struct address_space___26 *, sector_t);
	void (*invalidatepage)(struct page___27 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___27 *, gfp_t);
	void (*freepage)(struct page___27 *);
	ssize_t (*direct_IO)(struct kiocb___26 *, struct iov_iter___20 *);
	int (*migratepage)(struct address_space___26 *, struct page___27 *, struct page___27 *, enum migrate_mode);
	bool (*isolate_page)(struct page___27 *, isolate_mode_t);
	void (*putback_page)(struct page___27 *);
	int (*launder_page)(struct page___27 *);
	int (*is_partially_uptodate)(struct page___27 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___27 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___26 *, struct page___27 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___26 *, sector_t *);
	void (*swap_deactivate)(struct file___26 *);
};

struct writeback_control___15 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate;
	unsigned int for_background;
	unsigned int tagged_writepages;
	unsigned int for_reclaim;
	unsigned int range_cyclic;
	unsigned int for_sync;
	unsigned int no_cgroup_owner;
	unsigned int punt_to_cgroup;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bdi_writeback___15 *wb;
	struct inode___26 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
};

struct readahead_control___14 {
	struct file___26 *file;
	struct address_space___26 *mapping;
	struct file_ra_state *ra;
	long unsigned int _index;
	unsigned int _nr_pages;
	unsigned int _batch_count;
};

struct bio_vec___20;

struct iov_iter___20 {
	u8 iter_type;
	bool data_source;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___20 *bvec;
		struct xarray *xarray;
		struct pipe_inode_info___7 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			unsigned int head;
			unsigned int start_head;
		};
		loff_t xarray_start;
	};
};

struct cdev___12 {
	struct kobject___26 kobj;
	struct module___25 *owner;
	const struct file_operations___26 *ops;
	struct list_head list;
	dev_t dev;
	unsigned int count;
};

struct inode_operations___26 {
	struct dentry___26 * (*lookup)(struct inode___26 *, struct dentry___26 *, unsigned int);
	const char * (*get_link)(struct dentry___26 *, struct inode___26 *, struct delayed_call *);
	int (*permission)(struct user_namespace *, struct inode___26 *, int);
	struct posix_acl * (*get_acl)(struct inode___26 *, int, bool);
	int (*readlink)(struct dentry___26 *, char *, int);
	int (*create)(struct user_namespace *, struct inode___26 *, struct dentry___26 *, umode_t, bool);
	int (*link)(struct dentry___26 *, struct inode___26 *, struct dentry___26 *);
	int (*unlink)(struct inode___26 *, struct dentry___26 *);
	int (*symlink)(struct user_namespace *, struct inode___26 *, struct dentry___26 *, const char *);
	int (*mkdir)(struct user_namespace *, struct inode___26 *, struct dentry___26 *, umode_t);
	int (*rmdir)(struct inode___26 *, struct dentry___26 *);
	int (*mknod)(struct user_namespace *, struct inode___26 *, struct dentry___26 *, umode_t, dev_t);
	int (*rename)(struct user_namespace *, struct inode___26 *, struct dentry___26 *, struct inode___26 *, struct dentry___26 *, unsigned int);
	int (*setattr)(struct user_namespace *, struct dentry___26 *, struct iattr___26 *);
	int (*getattr)(struct user_namespace *, const struct path___26 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___26 *, char *, size_t);
	int (*fiemap)(struct inode___26 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___26 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___26 *, struct dentry___26 *, struct file___26 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace *, struct inode___26 *, struct dentry___26 *, umode_t);
	int (*set_acl)(struct user_namespace *, struct inode___26 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace *, struct dentry___26 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___26 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___26 {
	void (*fl_copy_lock)(struct file_lock___26 *, struct file_lock___26 *);
	void (*fl_release_private)(struct file_lock___26 *);
};

struct lock_manager_operations___26;

struct file_lock___26 {
	struct file_lock___26 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___26 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___26 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___26 *fl_ops;
	const struct lock_manager_operations___26 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___26 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___26 *);
	int (*lm_grant)(struct file_lock___26 *, int);
	bool (*lm_break)(struct file_lock___26 *);
	int (*lm_change)(struct file_lock___26 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___26 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___26 *);
};

struct fasync_struct___26 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___26 *fa_next;
	struct file___26 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___26 {
	struct inode___26 * (*alloc_inode)(struct super_block___26 *);
	void (*destroy_inode)(struct inode___26 *);
	void (*free_inode)(struct inode___26 *);
	void (*dirty_inode)(struct inode___26 *, int);
	int (*write_inode)(struct inode___26 *, struct writeback_control___15 *);
	int (*drop_inode)(struct inode___26 *);
	void (*evict_inode)(struct inode___26 *);
	void (*put_super)(struct super_block___26 *);
	int (*sync_fs)(struct super_block___26 *, int);
	int (*freeze_super)(struct super_block___26 *);
	int (*freeze_fs)(struct super_block___26 *);
	int (*thaw_super)(struct super_block___26 *);
	int (*unfreeze_fs)(struct super_block___26 *);
	int (*statfs)(struct dentry___26 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___26 *, int *, char *);
	void (*umount_begin)(struct super_block___26 *);
	int (*show_options)(struct seq_file___24 *, struct dentry___26 *);
	int (*show_devname)(struct seq_file___24 *, struct dentry___26 *);
	int (*show_path)(struct seq_file___24 *, struct dentry___26 *);
	int (*show_stats)(struct seq_file___24 *, struct dentry___26 *);
	ssize_t (*quota_read)(struct super_block___26 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___26 *, int, const char *, size_t, loff_t);
	struct dquot___26 ** (*get_dquots)(struct inode___26 *);
	long int (*nr_cached_objects)(struct super_block___26 *, struct shrink_control___15 *);
	long int (*free_cached_objects)(struct super_block___26 *, struct shrink_control___15 *);
	struct file___26 * (*real_loop)(struct file___26 *);
};

struct wakeup_source___28;

struct dev_pm_info___28 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___28 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___28 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___28;

struct bus_type___28;

struct device_driver___28;

struct dev_pm_domain___28;

struct fwnode_handle___25;

struct class___28;

struct attribute_group___26;

struct device___28 {
	struct kobject___26 kobj;
	struct device___28 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___28 *type;
	struct bus_type___28 *bus;
	struct device_driver___28 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___28 power;
	struct dev_pm_domain___28 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node *of_node;
	struct fwnode_handle___25 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___28 *class;
	const struct attribute_group___26 **groups;
	void (*release)(struct device___28 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct block_device___16 {
	sector_t bd_start_sect;
	struct disk_stats *bd_stats;
	long unsigned int bd_stamp;
	bool bd_read_only;
	dev_t bd_dev;
	int bd_openers;
	struct inode___26 *bd_inode;
	struct super_block___26 *bd_super;
	void *bd_claiming;
	struct device___28 bd_device;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct kobject___26 *bd_holder_dir;
	u8 bd_partno;
	spinlock_t bd_size_lock;
	struct gendisk___16 *bd_disk;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	struct super_block___26 *bd_fsfreeze_sb;
	struct partition_meta_info *bd_meta_info;
};

typedef void (*poll_queue_proc___18)(struct file___26 *, wait_queue_head_t *, struct poll_table_struct___18 *);

struct poll_table_struct___18 {
	poll_queue_proc___18 _qproc;
	__poll_t _key;
};

struct seq_file___24 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___24 *op;
	int poll_event;
	const struct file___26 *file;
	void *private;
};

typedef void bio_end_io_t___16(struct bio___16 *);

struct bio_vec___20 {
	struct page___27 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___16;

struct bio___16 {
	struct bio___16 *bi_next;
	struct block_device___16 *bi_bdev;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	atomic_t __bi_remaining;
	struct bvec_iter bi_iter;
	bio_end_io_t___16 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___15 *bi_blkg;
	struct bio_issue bi_issue;
	u64 bi_iocost_cost;
	struct bio_crypt_ctx *bi_crypt_context;
	union {
		struct bio_integrity_payload___16 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___20 *bi_io_vec;
	struct bio_set___16 *bi_pool;
	struct bio_vec___20 bi_inline_vecs[0];
};

struct kernfs_root___26;

struct kernfs_elem_dir___26 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___26 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___26;

struct kernfs_root___26 {
	struct kernfs_node___26 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___26 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___26 {
	struct kernfs_node___26 *target_kn;
};

struct kernfs_ops___26;

struct kernfs_elem_attr___26 {
	const struct kernfs_ops___26 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___26 *notify_next;
};

struct kernfs_node___26 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___26 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___26 dir;
		struct kernfs_elem_symlink___26 symlink;
		struct kernfs_elem_attr___26 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___26;

struct kernfs_ops___26 {
	int (*open)(struct kernfs_open_file___26 *);
	void (*release)(struct kernfs_open_file___26 *);
	int (*seq_show)(struct seq_file___24 *, void *);
	void * (*seq_start)(struct seq_file___24 *, loff_t *);
	void * (*seq_next)(struct seq_file___24 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___24 *, void *);
	ssize_t (*read)(struct kernfs_open_file___26 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___26 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___26 *, struct poll_table_struct___18 *);
	int (*mmap)(struct kernfs_open_file___26 *, struct vm_area_struct___28 *);
};

struct kernfs_syscall_ops___26 {
	int (*show_options)(struct seq_file___24 *, struct kernfs_root___26 *);
	int (*mkdir)(struct kernfs_node___26 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___26 *);
	int (*rename)(struct kernfs_node___26 *, struct kernfs_node___26 *, const char *);
	int (*show_path)(struct seq_file___24 *, struct kernfs_node___26 *, struct kernfs_root___26 *);
};

struct kernfs_open_file___26 {
	struct kernfs_node___26 *kn;
	struct file___26 *file;
	struct seq_file___24 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped;
	bool released;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___26 *vm_ops;
};

struct bin_attribute___26;

struct attribute_group___26 {
	const char *name;
	umode_t (*is_visible)(struct kobject___26 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___26 *, struct bin_attribute___26 *, int);
	struct attribute **attrs;
	struct bin_attribute___26 **bin_attrs;
};

struct bin_attribute___26 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___26 * (*f_mapping)();
	ssize_t (*read)(struct file___26 *, struct kobject___26 *, struct bin_attribute___26 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___26 *, struct kobject___26 *, struct bin_attribute___26 *, char *, loff_t, size_t);
	int (*mmap)(struct file___26 *, struct kobject___26 *, struct bin_attribute___26 *, struct vm_area_struct___28 *);
};

struct sysfs_ops___25 {
	ssize_t (*show)(struct kobject___26 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___26 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___25;

struct kset___25 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___26 kobj;
	const struct kset_uevent_ops___25 *uevent_ops;
};

struct kobj_type___25 {
	void (*release)(struct kobject___26 *);
	const struct sysfs_ops___25 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___26 **default_groups;
	const struct kobj_ns_type_operations * (*child_ns_type)(struct kobject___26 *);
	const void * (*namespace)(struct kobject___26 *);
	void (*get_ownership)(struct kobject___26 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___25 {
	int (* const filter)(struct kset___25 *, struct kobject___26 *);
	const char * (* const name)(struct kset___25 *, struct kobject___26 *);
	int (* const uevent)(struct kset___25 *, struct kobject___26 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___25 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___25 *);
	int (*get)(char *, const struct kernel_param___25 *);
	void (*free)(void *);
};

struct kparam_array___25;

struct kernel_param___25 {
	const char *name;
	struct module___25 *mod;
	const struct kernel_param_ops___25 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___25 *arr;
	};
};

struct kparam_array___25 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___25 *ops;
	void *elem;
};

struct module_attribute___25 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___25 *, struct module_kobject___25 *, char *);
	ssize_t (*store)(struct module_attribute___25 *, struct module_kobject___25 *, const char *, size_t);
	void (*setup)(struct module___25 *, const char *);
	int (*test)(struct module___25 *);
	void (*free)(struct module___25 *);
};

struct trace_event_class___15;

struct trace_event_call___15 {
	struct list_head list;
	struct trace_event_class___15 *class;
	union {
		char *name;
		struct tracepoint___18 *tp;
	};
	struct trace_event event;
	char *print_fmt;
	struct event_filter *filter;
	union {
		void *module;
		atomic_t refcnt;
	};
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
	struct bpf_prog_array___2 *prog_array;
	int (*perf_perm)(struct trace_event_call___15 *, struct perf_event___15 *);
};

struct dev_pm_ops___28 {
	int (*prepare)(struct device___28 *);
	void (*complete)(struct device___28 *);
	int (*suspend)(struct device___28 *);
	int (*resume)(struct device___28 *);
	int (*freeze)(struct device___28 *);
	int (*thaw)(struct device___28 *);
	int (*poweroff)(struct device___28 *);
	int (*restore)(struct device___28 *);
	int (*suspend_late)(struct device___28 *);
	int (*resume_early)(struct device___28 *);
	int (*freeze_late)(struct device___28 *);
	int (*thaw_early)(struct device___28 *);
	int (*poweroff_late)(struct device___28 *);
	int (*restore_early)(struct device___28 *);
	int (*suspend_noirq)(struct device___28 *);
	int (*resume_noirq)(struct device___28 *);
	int (*freeze_noirq)(struct device___28 *);
	int (*thaw_noirq)(struct device___28 *);
	int (*poweroff_noirq)(struct device___28 *);
	int (*restore_noirq)(struct device___28 *);
	int (*runtime_suspend)(struct device___28 *);
	int (*runtime_resume)(struct device___28 *);
	int (*runtime_idle)(struct device___28 *);
};

struct wakeup_source___28 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___28 *dev;
	bool active;
	bool autosleep_enabled;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___28 {
	struct dev_pm_ops___28 ops;
	int (*start)(struct device___28 *);
	void (*detach)(struct device___28 *, bool);
	int (*activate)(struct device___28 *);
	void (*sync)(struct device___28 *);
	void (*dismiss)(struct device___28 *);
};

struct bus_type___28 {
	const char *name;
	const char *dev_name;
	struct device___28 *dev_root;
	const struct attribute_group___26 **bus_groups;
	const struct attribute_group___26 **dev_groups;
	const struct attribute_group___26 **drv_groups;
	int (*match)(struct device___28 *, struct device_driver___28 *);
	int (*uevent)(struct device___28 *, struct kobj_uevent_env *);
	int (*probe)(struct device___28 *);
	void (*sync_state)(struct device___28 *);
	void (*remove)(struct device___28 *);
	void (*shutdown)(struct device___28 *);
	int (*online)(struct device___28 *);
	int (*offline)(struct device___28 *);
	int (*suspend)(struct device___28 *, pm_message_t);
	int (*resume)(struct device___28 *);
	int (*num_vf)(struct device___28 *);
	int (*dma_configure)(struct device___28 *);
	const struct dev_pm_ops___28 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___28 {
	const char *name;
	struct bus_type___28 *bus;
	struct module___25 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___28 *);
	void (*sync_state)(struct device___28 *);
	int (*remove)(struct device___28 *);
	void (*shutdown)(struct device___28 *);
	int (*suspend)(struct device___28 *, pm_message_t);
	int (*resume)(struct device___28 *);
	const struct attribute_group___26 **groups;
	const struct attribute_group___26 **dev_groups;
	const struct dev_pm_ops___28 *pm;
	void (*coredump)(struct device___28 *);
	struct driver_private *p;
};

struct device_type___28 {
	const char *name;
	const struct attribute_group___26 **groups;
	int (*uevent)(struct device___28 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___28 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___28 *);
	const struct dev_pm_ops___28 *pm;
};

struct class___28 {
	const char *name;
	struct module___25 *owner;
	const struct attribute_group___26 **class_groups;
	const struct attribute_group___26 **dev_groups;
	struct kobject___26 *dev_kobj;
	int (*dev_uevent)(struct device___28 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___28 *, umode_t *);
	void (*class_release)(struct class___28 *);
	void (*dev_release)(struct device___28 *);
	int (*shutdown_pre)(struct device___28 *);
	const struct kobj_ns_type_operations *ns_type;
	const void * (*namespace)(struct device___28 *);
	void (*get_ownership)(struct device___28 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___28 *pm;
	struct subsys_private *p;
};

struct fwnode_operations___25;

struct fwnode_handle___25 {
	struct fwnode_handle___25 *secondary;
	const struct fwnode_operations___25 *ops;
	struct device___28 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct tty_operations___5 {
	struct tty_struct___5 * (*lookup)(struct tty_driver___5 *, struct file___26 *, int);
	int (*install)(struct tty_driver___5 *, struct tty_struct___5 *);
	void (*remove)(struct tty_driver___5 *, struct tty_struct___5 *);
	int (*open)(struct tty_struct___5 *, struct file___26 *);
	void (*close)(struct tty_struct___5 *, struct file___26 *);
	void (*shutdown)(struct tty_struct___5 *);
	void (*cleanup)(struct tty_struct___5 *);
	int (*write)(struct tty_struct___5 *, const unsigned char *, int);
	int (*put_char)(struct tty_struct___5 *, unsigned char);
	void (*flush_chars)(struct tty_struct___5 *);
	unsigned int (*write_room)(struct tty_struct___5 *);
	unsigned int (*chars_in_buffer)(struct tty_struct___5 *);
	int (*ioctl)(struct tty_struct___5 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct tty_struct___5 *, unsigned int, long unsigned int);
	void (*set_termios)(struct tty_struct___5 *, struct ktermios *);
	void (*throttle)(struct tty_struct___5 *);
	void (*unthrottle)(struct tty_struct___5 *);
	void (*stop)(struct tty_struct___5 *);
	void (*start)(struct tty_struct___5 *);
	void (*hangup)(struct tty_struct___5 *);
	int (*break_ctl)(struct tty_struct___5 *, int);
	void (*flush_buffer)(struct tty_struct___5 *);
	void (*set_ldisc)(struct tty_struct___5 *);
	void (*wait_until_sent)(struct tty_struct___5 *, int);
	void (*send_xchar)(struct tty_struct___5 *, char);
	int (*tiocmget)(struct tty_struct___5 *);
	int (*tiocmset)(struct tty_struct___5 *, unsigned int, unsigned int);
	int (*resize)(struct tty_struct___5 *, struct winsize *);
	int (*get_icount)(struct tty_struct___5 *, struct serial_icounter_struct *);
	int (*get_serial)(struct tty_struct___5 *, struct serial_struct *);
	int (*set_serial)(struct tty_struct___5 *, struct serial_struct *);
	void (*show_fdinfo)(struct tty_struct___5 *, struct seq_file___24 *);
	int (*poll_init)(struct tty_driver___5 *, int, char *);
	int (*poll_get_char)(struct tty_driver___5 *, int);
	void (*poll_put_char)(struct tty_driver___5 *, int, char);
	int (*proc_show)(struct seq_file___24 *, void *);
};

struct tty_driver___5 {
	int magic;
	struct kref kref;
	struct cdev___12 **cdevs;
	struct module___25 *owner;
	const char *driver_name;
	const char *name;
	int name_base;
	int major;
	int minor_start;
	unsigned int num;
	short int type;
	short int subtype;
	struct ktermios init_termios;
	long unsigned int flags;
	struct proc_dir_entry *proc_entry;
	struct tty_driver___5 *other;
	struct tty_struct___5 **ttys;
	struct tty_port___5 **ports;
	struct ktermios **termios;
	void *driver_state;
	const struct tty_operations___5 *ops;
	struct list_head tty_drivers;
};

struct tty_port_operations___5;

struct tty_port_client_operations___5;

struct tty_port___5 {
	struct tty_bufhead buf;
	struct tty_struct___5 *tty;
	struct tty_struct___5 *itty;
	const struct tty_port_operations___5 *ops;
	const struct tty_port_client_operations___5 *client_ops;
	spinlock_t lock;
	int blocked_open;
	int count;
	wait_queue_head_t open_wait;
	wait_queue_head_t delta_msr_wait;
	long unsigned int flags;
	long unsigned int iflags;
	unsigned char console;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct mutex mutex;
	struct mutex buf_mutex;
	unsigned char *xmit_buf;
	unsigned int close_delay;
	unsigned int closing_wait;
	int drain_delay;
	struct kref kref;
	void *client_data;
};

struct tty_ldisc_ops___5 {
	char *name;
	int num;
	int flags;
	int (*open)(struct tty_struct___5 *);
	void (*close)(struct tty_struct___5 *);
	void (*flush_buffer)(struct tty_struct___5 *);
	ssize_t (*read)(struct tty_struct___5 *, struct file___26 *, unsigned char *, size_t, void **, long unsigned int);
	ssize_t (*write)(struct tty_struct___5 *, struct file___26 *, const unsigned char *, size_t);
	int (*ioctl)(struct tty_struct___5 *, struct file___26 *, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct tty_struct___5 *, struct file___26 *, unsigned int, long unsigned int);
	void (*set_termios)(struct tty_struct___5 *, struct ktermios *);
	__poll_t (*poll)(struct tty_struct___5 *, struct file___26 *, struct poll_table_struct___18 *);
	int (*hangup)(struct tty_struct___5 *);
	void (*receive_buf)(struct tty_struct___5 *, const unsigned char *, const char *, int);
	void (*write_wakeup)(struct tty_struct___5 *);
	void (*dcd_change)(struct tty_struct___5 *, unsigned int);
	int (*receive_buf2)(struct tty_struct___5 *, const unsigned char *, const char *, int);
	struct module___25 *owner;
};

struct tty_ldisc___5 {
	struct tty_ldisc_ops___5 *ops;
	struct tty_struct___5 *tty;
};

struct tty_port_operations___5 {
	int (*carrier_raised)(struct tty_port___5 *);
	void (*dtr_rts)(struct tty_port___5 *, int);
	void (*shutdown)(struct tty_port___5 *);
	int (*activate)(struct tty_port___5 *, struct tty_struct___5 *);
	void (*destruct)(struct tty_port___5 *);
};

struct tty_port_client_operations___5 {
	int (*receive_buf)(struct tty_port___5 *, const unsigned char *, const unsigned char *, size_t);
	void (*write_wakeup)(struct tty_port___5 *);
};

struct linux_binprm___5 {
	struct vm_area_struct___28 *vma;
	long unsigned int vma_pages;
	struct mm_struct___28 *mm;
	long unsigned int p;
	long unsigned int argmin;
	unsigned int have_execfd;
	unsigned int execfd_creds;
	unsigned int secureexec;
	unsigned int point_of_no_return;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct file___26 *executable;
	struct file___26 *interpreter;
	struct file___26 *file;
	struct cred *cred;
	int unsafe;
	unsigned int per_clear;
	int argc;
	int envc;
	const char *filename;
	const char *interp;
	const char *fdpath;
	unsigned int interp_flags;
	int execfd;
	long unsigned int loader;
	long unsigned int exec;
	struct rlimit rlim_stack;
	char buf[256];
};

struct coredump_params___4 {
	const kernel_siginfo_t *siginfo;
	struct pt_regs *regs;
	struct file___26 *file;
	long unsigned int limit;
	long unsigned int mm_flags;
	loff_t written;
	loff_t pos;
	loff_t to_skip;
};

typedef struct {
	u64 key[2];
} siphash_key_t___2;

struct fqdir___3;

struct netns_ipv4___3 {
	struct inet_timewait_death_row tcp_death_row;
	struct ctl_table_header *forw_hdr;
	struct ctl_table_header *frags_hdr;
	struct ctl_table_header *ipv4_hdr;
	struct ctl_table_header *route_hdr;
	struct ctl_table_header *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct ip_ra_chain *ra_chain;
	struct mutex ra_mutex;
	struct fib_rules_ops *rules_ops;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	unsigned int fib_rules_require_fldissect;
	bool fib_has_custom_rules;
	bool fib_has_custom_local_routes;
	bool fib_offload_disabled;
	atomic_t fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	struct sock *fibnl;
	struct sock **icmp_sk;
	struct sock *mc_autojoin_sk;
	struct inet_peer_base *peers;
	struct sock **tcp_sk;
	struct fqdir___3 *fqdir;
	u8 sysctl_icmp_echo_ignore_all;
	u8 sysctl_icmp_echo_enable_probe;
	u8 sysctl_icmp_echo_ignore_broadcasts;
	u8 sysctl_icmp_ignore_bogus_error_responses;
	u8 sysctl_icmp_errors_use_inbound_ifaddr;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	struct local_ports ip_local_ports;
	u8 sysctl_tcp_ecn;
	u8 sysctl_tcp_ecn_fallback;
	u8 sysctl_ip_default_ttl;
	u8 sysctl_ip_no_pmtu_disc;
	u8 sysctl_ip_fwd_use_pmtu;
	u8 sysctl_ip_fwd_update_priority;
	u8 sysctl_ip_nonlocal_bind;
	u8 sysctl_ip_autobind_reuse;
	u8 sysctl_ip_dynaddr;
	u8 sysctl_ip_early_demux;
	u8 sysctl_raw_l3mdev_accept;
	u8 sysctl_tcp_early_demux;
	u8 sysctl_udp_early_demux;
	u8 sysctl_nexthop_compat_mode;
	u8 sysctl_fwmark_reflect;
	u8 sysctl_tcp_fwmark_accept;
	u8 sysctl_tcp_l3mdev_accept;
	u8 sysctl_tcp_mtu_probing;
	int sysctl_tcp_mtu_probe_floor;
	int sysctl_tcp_base_mss;
	int sysctl_tcp_min_snd_mss;
	int sysctl_tcp_probe_threshold;
	u32 sysctl_tcp_probe_interval;
	int sysctl_tcp_keepalive_time;
	int sysctl_tcp_keepalive_intvl;
	u8 sysctl_tcp_keepalive_probes;
	u8 sysctl_tcp_syn_retries;
	u8 sysctl_tcp_synack_retries;
	u8 sysctl_tcp_syncookies;
	u8 sysctl_tcp_migrate_req;
	int sysctl_tcp_reordering;
	u8 sysctl_tcp_retries1;
	u8 sysctl_tcp_retries2;
	u8 sysctl_tcp_orphan_retries;
	u8 sysctl_tcp_tw_reuse;
	int sysctl_tcp_fin_timeout;
	unsigned int sysctl_tcp_notsent_lowat;
	u8 sysctl_tcp_sack;
	u8 sysctl_tcp_window_scaling;
	u8 sysctl_tcp_timestamps;
	u8 sysctl_tcp_early_retrans;
	u8 sysctl_tcp_recovery;
	u8 sysctl_tcp_thin_linear_timeouts;
	u8 sysctl_tcp_slow_start_after_idle;
	u8 sysctl_tcp_retrans_collapse;
	u8 sysctl_tcp_stdurg;
	u8 sysctl_tcp_rfc1337;
	u8 sysctl_tcp_abort_on_overflow;
	u8 sysctl_tcp_fack;
	int sysctl_tcp_max_reordering;
	int sysctl_tcp_adv_win_scale;
	u8 sysctl_tcp_dsack;
	u8 sysctl_tcp_app_win;
	u8 sysctl_tcp_frto;
	u8 sysctl_tcp_nometrics_save;
	u8 sysctl_tcp_no_ssthresh_metrics_save;
	u8 sysctl_tcp_moderate_rcvbuf;
	u8 sysctl_tcp_tso_win_divisor;
	u8 sysctl_tcp_workaround_signed_windows;
	int sysctl_tcp_limit_output_bytes;
	int sysctl_tcp_challenge_ack_limit;
	int sysctl_tcp_min_rtt_wlen;
	u8 sysctl_tcp_min_tso_segs;
	u8 sysctl_tcp_autocorking;
	u8 sysctl_tcp_reflect_tos;
	u8 sysctl_tcp_comp_sack_nr;
	int sysctl_tcp_invalid_ratelimit;
	int sysctl_tcp_pacing_ss_ratio;
	int sysctl_tcp_pacing_ca_ratio;
	int sysctl_tcp_wmem[3];
	int sysctl_tcp_rmem[3];
	long unsigned int sysctl_tcp_comp_sack_delay_ns;
	long unsigned int sysctl_tcp_comp_sack_slack_ns;
	int sysctl_max_syn_backlog;
	int sysctl_tcp_fastopen;
	const struct tcp_congestion_ops *tcp_congestion_control;
	struct tcp_fastopen_context *tcp_fastopen_ctx;
	unsigned int sysctl_tcp_fastopen_blackhole_timeout;
	atomic_t tfo_active_disable_times;
	long unsigned int tfo_active_disable_stamp;
	int sysctl_udp_wmem_min;
	int sysctl_udp_rmem_min;
	u8 sysctl_fib_notify_on_flag_change;
	u8 sysctl_udp_l3mdev_accept;
	u8 sysctl_igmp_llm_reports;
	int sysctl_igmp_max_memberships;
	int sysctl_igmp_max_msf;
	int sysctl_igmp_qrv;
	struct ping_group_range ping_group_range;
	atomic_t dev_addr_genid;
	long unsigned int *sysctl_local_reserved_ports;
	int sysctl_ip_prot_sock;
	struct list_head mr_tables;
	struct fib_rules_ops *mr_rules_ops;
	u32 sysctl_fib_multipath_hash_fields;
	u8 sysctl_fib_multipath_use_neigh;
	u8 sysctl_fib_multipath_hash_policy;
	struct fib_notifier_ops *notifier_ops;
	unsigned int fib_seq;
	struct fib_notifier_ops *ipmr_notifier_ops;
	unsigned int ipmr_seq;
	atomic_t rt_genid;
	siphash_key_t___2 ip_id_key;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dst_ops___3 {
	short unsigned int family;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___3 *);
	struct dst_entry * (*check)(struct dst_entry *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry *);
	unsigned int (*mtu)(const struct dst_entry *);
	u32 * (*cow_metrics)(struct dst_entry *, long unsigned int);
	void (*destroy)(struct dst_entry *);
	void (*ifdown)(struct dst_entry *, struct net_device *, int);
	struct dst_entry * (*negative_advice)(struct dst_entry *);
	void (*link_failure)(struct sk_buff___3 *);
	void (*update_pmtu)(struct dst_entry *, struct sock *, struct sk_buff___3 *, u32, bool);
	void (*redirect)(struct dst_entry *, struct sock *, struct sk_buff___3 *);
	int (*local_out)(struct net___4 *, struct sock *, struct sk_buff___3 *);
	struct neighbour * (*neigh_lookup)(const struct dst_entry *, struct sk_buff___3 *, const void *);
	void (*confirm_neigh)(const struct dst_entry *, const void *);
	struct kmem_cache *kmem_cachep;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv6___3 {
	struct dst_ops___3 ip6_dst_ops;
	struct netns_sysctl_ipv6 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	struct fqdir___3 *fqdir;
	struct fib6_info *fib6_null_entry;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	struct list_head fib6_walkers;
	rwlock_t fib6_walker_lock;
	spinlock_t fib6_gc_lock;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	unsigned char flowlabel_has_excl;
	bool fib6_has_custom_rules;
	unsigned int fib6_rules_require_fldissect;
	unsigned int fib6_routes_require_src;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops *fib6_rules_ops;
	struct sock **icmp_sk;
	struct sock *ndisc_sk;
	struct sock *tcp_sk;
	struct sock *igmp_sk;
	struct sock *mc_autojoin_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops *mr6_rules_ops;
	atomic_t dev_addr_genid;
	atomic_t fib6_sernum;
	struct seg6_pernet_data *seg6_data;
	struct fib_notifier_ops *notifier_ops;
	struct fib_notifier_ops *ip6mr_notifier_ops;
	unsigned int ipmr_seq;
	struct {
		struct hlist_head head;
		spinlock_t lock;
		u32 seq;
	} ip6addrlbl_table;
	long: 64;
	long: 64;
	struct ioam6_pernet_data *ioam6_data;
};

struct netns_ieee802154_lowpan___3 {
	struct netns_sysctl_lowpan sysctl;
	struct fqdir___3 *fqdir;
};

struct netns_xfrm___3 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	struct hlist_head *state_byseq;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[3];
	struct xfrm_policy_hash policy_bydst[3];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct xfrm_policy_hthresh policy_hthresh;
	struct list_head inexact_bins;
	struct sock *nlsk;
	struct sock *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	u8 policy_default;
	struct ctl_table_header *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___3 xfrm4_dst_ops;
	struct dst_ops___3 xfrm6_dst_ops;
	spinlock_t xfrm_state_lock;
	seqcount_spinlock_t xfrm_state_hash_generation;
	seqcount_spinlock_t xfrm_policy_hash_generation;
	spinlock_t xfrm_policy_lock;
	struct mutex xfrm_cfg_mutex;
	long: 64;
	long: 64;
};

struct net___4 {
	refcount_t passive;
	spinlock_t rules_mod_lock;
	unsigned int dev_unreg_count;
	unsigned int dev_base_seq;
	int ifindex;
	spinlock_t nsid_lock;
	atomic_t fnhe_genid;
	struct list_head list;
	struct list_head exit_list;
	struct llist_node cleanup_list;
	struct key_tag *key_domain;
	struct user_namespace *user_ns;
	struct ucounts *ucounts;
	struct idr netns_ids;
	struct ns_common ns;
	struct list_head dev_base_head;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set sysctls;
	struct sock *rtnl;
	struct sock *genl_sock;
	struct uevent_sock *uevent_sock;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	struct raw_notifier_head netdev_chain;
	u32 hash_mix;
	struct net_device *loopback_dev;
	struct list_head rules_ops;
	struct netns_core core;
	struct netns_mib mib;
	struct netns_packet packet;
	struct netns_unix unx;
	struct netns_nexthop nexthop;
	struct netns_ipv4___3 ipv4;
	struct netns_ipv6___3 ipv6;
	struct netns_ieee802154_lowpan___3 ieee802154_lowpan;
	struct netns_sctp sctp;
	struct netns_nf nf;
	struct netns_ct ct;
	struct netns_nftables nft;
	struct sk_buff_head___2 wext_nlevents;
	struct net_generic *gen;
	struct netns_bpf___2 bpf;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_xfrm___3 xfrm;
	u64 net_cookie;
	struct netns_ipvs *ipvs;
	struct netns_mpls mpls;
	struct netns_can can;
	struct netns_xdp xdp;
	struct netns_mctp mctp;
	struct sock *crypto_nlsk;
	struct sock *diag_nlsk;
	struct netns_smc smc;
	long: 64;
};

struct cgroup_namespace___20 {
	struct ns_common ns;
	struct user_namespace *user_ns;
	struct ucounts *ucounts;
	struct css_set___20 *root_cset;
};

struct cftype___20;

struct cgroup_subsys___20 {
	struct cgroup_subsys_state___20 * (*css_alloc)(struct cgroup_subsys_state___20 *);
	int (*css_online)(struct cgroup_subsys_state___20 *);
	void (*css_offline)(struct cgroup_subsys_state___20 *);
	void (*css_released)(struct cgroup_subsys_state___20 *);
	void (*css_free)(struct cgroup_subsys_state___20 *);
	void (*css_reset)(struct cgroup_subsys_state___20 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___20 *, int);
	int (*css_extra_stat_show)(struct seq_file___24 *, struct cgroup_subsys_state___20 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___29 *, struct css_set___20 *);
	void (*cancel_fork)(struct task_struct___29 *, struct css_set___20 *);
	void (*fork)(struct task_struct___29 *);
	void (*exit)(struct task_struct___29 *);
	void (*release)(struct task_struct___29 *);
	void (*bind)(struct cgroup_subsys_state___20 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___20 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___20 *dfl_cftypes;
	struct cftype___20 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___20 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___20 *updated_children;
	struct cgroup___20 *updated_next;
};

struct cgroup_root___20 {
	struct kernfs_root___26 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___20 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___20 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___20 *ss;
	struct list_head node;
	struct kernfs_ops___26 *kf_ops;
	int (*open)(struct kernfs_open_file___26 *);
	void (*release)(struct kernfs_open_file___26 *);
	u64 (*read_u64)(struct cgroup_subsys_state___20 *, struct cftype___20 *);
	s64 (*read_s64)(struct cgroup_subsys_state___20 *, struct cftype___20 *);
	int (*seq_show)(struct seq_file___24 *, void *);
	void * (*seq_start)(struct seq_file___24 *, loff_t *);
	void * (*seq_next)(struct seq_file___24 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___24 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___20 *, struct cftype___20 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___20 *, struct cftype___20 *, s64);
	ssize_t (*write)(struct kernfs_open_file___26 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___26 *, struct poll_table_struct___18 *);
};

struct perf_cpu_context___15;

struct perf_output_handle___15;

struct pmu___15 {
	struct list_head entry;
	struct module___25 *module;
	struct device___28 *dev;
	const struct attribute_group___26 **attr_groups;
	const struct attribute_group___26 **attr_update;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___15 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___15 *);
	void (*pmu_disable)(struct pmu___15 *);
	int (*event_init)(struct perf_event___15 *);
	void (*event_mapped)(struct perf_event___15 *, struct mm_struct___28 *);
	void (*event_unmapped)(struct perf_event___15 *, struct mm_struct___28 *);
	int (*add)(struct perf_event___15 *, int);
	void (*del)(struct perf_event___15 *, int);
	void (*start)(struct perf_event___15 *, int);
	void (*stop)(struct perf_event___15 *, int);
	void (*read)(struct perf_event___15 *);
	void (*start_txn)(struct pmu___15 *, unsigned int);
	int (*commit_txn)(struct pmu___15 *);
	void (*cancel_txn)(struct pmu___15 *);
	int (*event_idx)(struct perf_event___15 *);
	void (*sched_task)(struct perf_event_context___15 *, bool);
	struct kmem_cache *task_ctx_cache;
	void (*swap_task_ctx)(struct perf_event_context___15 *, struct perf_event_context___15 *);
	void * (*setup_aux)(struct perf_event___15 *, void **, int, bool);
	void (*free_aux)(void *);
	long int (*snapshot_aux)(struct perf_event___15 *, struct perf_output_handle___15 *, long unsigned int);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___15 *);
	int (*aux_output_match)(struct perf_event___15 *);
	int (*filter_match)(struct perf_event___15 *);
	int (*check_period)(struct perf_event___15 *, u64);
};

struct compat_rusage {
	struct old_timeval32 ru_utime;
	struct old_timeval32 ru_stime;
	compat_long_t ru_maxrss;
	compat_long_t ru_ixrss;
	compat_long_t ru_idrss;
	compat_long_t ru_isrss;
	compat_long_t ru_minflt;
	compat_long_t ru_majflt;
	compat_long_t ru_nswap;
	compat_long_t ru_inblock;
	compat_long_t ru_oublock;
	compat_long_t ru_msgsnd;
	compat_long_t ru_msgrcv;
	compat_long_t ru_nsignals;
	compat_long_t ru_nvcsw;
	compat_long_t ru_nivcsw;
};

struct perf_cpu_context___15 {
	struct perf_event_context___15 ctx;
	struct perf_event_context___15 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___15 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
	int heap_size;
	struct perf_event___15 **heap;
	struct perf_event___15 *heap_default[2];
};

struct perf_output_handle___15 {
	struct perf_event___15 *event;
	struct perf_buffer *rb;
	long unsigned int wakeup;
	long unsigned int size;
	u64 aux_flags;
	union {
		void *addr;
		long unsigned int head;
	};
	int page;
};

struct perf_cgroup___15 {
	struct cgroup_subsys_state___20 css;
	struct perf_cgroup_info *info;
};

struct trace_event_fields___15 {
	const char *type;
	union {
		struct {
			const char *name;
			const int size;
			const int align;
			const int is_signed;
			const int filter_type;
		};
		int (*define_fields)(struct trace_event_call___15 *);
	};
};

struct trace_event_class___15 {
	const char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct trace_event_call___15 *, enum trace_reg, void *);
	struct trace_event_fields___15 *fields_array;
	struct list_head * (*get_fields)(struct trace_event_call___15 *);
	struct list_head fields;
	int (*raw_init)(struct trace_event_call___15 *);
};

struct syscall_metadata___4 {
	const char *name;
	int syscall_nr;
	int nb_args;
	const char **types;
	const char **args;
	struct list_head enter_fields;
	struct trace_event_call___15 *enter_event;
	struct trace_event_call___15 *exit_event;
};

struct pipe_buf_operations___7;

struct pipe_buffer___7 {
	struct page___27 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___7 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___7 {
	int (*confirm)(struct pipe_inode_info___7 *, struct pipe_buffer___7 *);
	void (*release)(struct pipe_inode_info___7 *, struct pipe_buffer___7 *);
	bool (*try_steal)(struct pipe_inode_info___7 *, struct pipe_buffer___7 *);
	bool (*get)(struct pipe_inode_info___7 *, struct pipe_buffer___7 *);
};

struct block_device_operations___16;

struct gendisk___16 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	short unsigned int events;
	short unsigned int event_flags;
	struct xarray part_tbl;
	struct block_device___16 *part0;
	const struct block_device_operations___16 *fops;
	struct request_queue___16 *queue;
	void *private_data;
	int flags;
	long unsigned int state;
	struct mutex open_mutex;
	unsigned int open_partitions;
	struct backing_dev_info___15 *bdi;
	struct kobject___26 *slave_dir;
	struct list_head slave_bdevs;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___26 integrity_kobj;
	struct cdrom_device_info *cdi;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	u64 diskseq;
};

struct bio_integrity_payload___16 {
	struct bio___16 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___20 *bip_vec;
	struct bio_vec___20 bip_inline_vecs[0];
};

struct blkcg___15;

struct blkg_policy_data___15;

struct blkcg_gq___15 {
	struct request_queue___16 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___15 *blkcg;
	struct blkcg_gq___15 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_iostat_set *iostat_cpu;
	struct blkg_iostat_set iostat;
	struct blkg_policy_data___15 *pd[6];
	spinlock_t async_bio_lock;
	struct bio_list___16 async_bios;
	struct work_struct async_bio_work;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
	struct callback_head callback_head;
};

typedef void integrity_prepare_fn___16(struct request___16 *);

typedef void integrity_complete_fn___16(struct request___16 *, unsigned int);

struct blk_integrity_profile___16 {
	integrity_processing_fn *generate_fn;
	integrity_processing_fn *verify_fn;
	integrity_prepare_fn___16 *prepare_fn;
	integrity_complete_fn___16 *complete_fn;
	const char *name;
};

struct block_device_operations___16 {
	blk_qc_t (*submit_bio)(struct bio___16 *);
	int (*open)(struct block_device___16 *, fmode_t);
	void (*release)(struct gendisk___16 *, fmode_t);
	int (*rw_page)(struct block_device___16 *, sector_t, struct page___27 *, unsigned int);
	int (*ioctl)(struct block_device___16 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___16 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___16 *, unsigned int);
	void (*unlock_native_capacity)(struct gendisk___16 *);
	int (*getgeo)(struct block_device___16 *, struct hd_geometry *);
	int (*set_read_only)(struct block_device___16 *, bool);
	void (*swap_slot_free_notify)(struct block_device___16 *, long unsigned int);
	int (*report_zones)(struct gendisk___16 *, sector_t, unsigned int, report_zones_cb, void *);
	char * (*devnode)(struct gendisk___16 *, umode_t *);
	struct module___25 *owner;
	const struct pr_ops *pr_ops;
	int (*alternative_gpt_sector)(struct gendisk___16 *, sector_t *);
};

struct fwnode_reference_args___25;

struct fwnode_endpoint___25;

struct fwnode_operations___25 {
	struct fwnode_handle___25 * (*get)(struct fwnode_handle___25 *);
	void (*put)(struct fwnode_handle___25 *);
	bool (*device_is_available)(const struct fwnode_handle___25 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___25 *, const struct device___28 *);
	bool (*property_present)(const struct fwnode_handle___25 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___25 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___25 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___25 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___25 *);
	struct fwnode_handle___25 * (*get_parent)(const struct fwnode_handle___25 *);
	struct fwnode_handle___25 * (*get_next_child_node)(const struct fwnode_handle___25 *, struct fwnode_handle___25 *);
	struct fwnode_handle___25 * (*get_named_child_node)(const struct fwnode_handle___25 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___25 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___25 *);
	struct fwnode_handle___25 * (*graph_get_next_endpoint)(const struct fwnode_handle___25 *, struct fwnode_handle___25 *);
	struct fwnode_handle___25 * (*graph_get_remote_endpoint)(const struct fwnode_handle___25 *);
	struct fwnode_handle___25 * (*graph_get_port_parent)(struct fwnode_handle___25 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___25 *, struct fwnode_endpoint___25 *);
	int (*add_links)(struct fwnode_handle___25 *);
};

struct fwnode_endpoint___25 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___25 *local_fwnode;
};

struct fwnode_reference_args___25 {
	struct fwnode_handle___25 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

typedef void rq_end_io_fn___16(struct request___16 *, blk_status_t);

struct request___16 {
	struct request_queue___16 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int tag;
	int internal_tag;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___16 *bio;
	struct bio___16 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct llist_node ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___20 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___16 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___16 *saved_end_io;
		} flush;
	};
	struct gendisk___16 *rq_disk;
	struct block_device___16 *part;
	u64 alloc_time_ns;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int stats_sectors;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	struct bio_crypt_ctx *crypt_ctx;
	struct blk_ksm_keyslot *crypt_keyslot;
	short unsigned int write_hint;
	short unsigned int ioprio;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___16 *end_io;
	void *end_io_data;
};

struct elevator_type___16;

struct elevator_mq_ops___16 {
	int (*init_sched)(struct request_queue___16 *, struct elevator_type___16 *);
	void (*exit_sched)(struct elevator_queue___16 *);
	int (*init_hctx)(struct blk_mq_hw_ctx *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx *, unsigned int);
	void (*depth_updated)(struct blk_mq_hw_ctx *);
	bool (*allow_merge)(struct request_queue___16 *, struct request___16 *, struct bio___16 *);
	bool (*bio_merge)(struct request_queue___16 *, struct bio___16 *, unsigned int);
	int (*request_merge)(struct request_queue___16 *, struct request___16 **, struct bio___16 *);
	void (*request_merged)(struct request_queue___16 *, struct request___16 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___16 *, struct request___16 *, struct request___16 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___16 *);
	void (*finish_request)(struct request___16 *);
	void (*insert_requests)(struct blk_mq_hw_ctx *, struct list_head *, bool);
	struct request___16 * (*dispatch_request)(struct blk_mq_hw_ctx *);
	bool (*has_work)(struct blk_mq_hw_ctx *);
	void (*completed_request)(struct request___16 *, u64);
	void (*requeue_request)(struct request___16 *);
	struct request___16 * (*former_request)(struct request_queue___16 *, struct request___16 *);
	struct request___16 * (*next_request)(struct request_queue___16 *, struct request___16 *);
	void (*init_icq)(struct io_cq___16 *);
	void (*exit_icq)(struct io_cq___16 *);
};

struct elv_fs_entry___16;

struct elevator_type___16 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___16 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___16 *elevator_attrs;
	const char *elevator_name;
	const char *elevator_alias;
	const unsigned int elevator_features;
	struct module___25 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
};

struct elevator_queue___16 {
	struct elevator_type___16 *type;
	void *elevator_data;
	struct kobject___26 kobj;
	struct mutex sysfs_lock;
	unsigned int registered;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hlist_head hash[64];
};

struct elv_fs_entry___16 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___16 *, char *);
	ssize_t (*store)(struct elevator_queue___16 *, const char *, size_t);
};

struct blkcg_policy_data___15;

struct blkcg___15 {
	struct cgroup_subsys_state___20 css;
	spinlock_t lock;
	refcount_t online_pin;
	struct xarray blkg_tree;
	struct blkcg_gq___15 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___15 *cpd[6];
	struct list_head all_blkcgs_node;
	char fc_app_id[129];
	struct list_head cgwb_list;
};

struct blkcg_policy_data___15 {
	struct blkcg___15 *blkcg;
	int plid;
};

struct blkg_policy_data___15 {
	struct blkcg_gq___15 *blkg;
	int plid;
};

struct mem_cgroup_reclaim_iter___15 {
	struct mem_cgroup___15 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___15 {
	struct lruvec___16 lruvec;
	struct lruvec_stats_percpu *lruvec_stats_percpu;
	struct lruvec_stats lruvec_stats;
	long unsigned int lru_zone_size[25];
	struct mem_cgroup_reclaim_iter___15 iter;
	struct shrinker_info *shrinker_info;
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	struct mem_cgroup___15 *memcg;
};

struct obj_cgroup___15 {
	struct percpu_ref refcnt;
	struct mem_cgroup___15 *memcg;
	atomic_t nr_charged_bytes;
	union {
		struct list_head list;
		struct callback_head rcu;
	};
};

struct inet_frags___3;

struct fqdir___3 {
	long int high_thresh;
	long int low_thresh;
	int timeout;
	int max_dist;
	struct inet_frags___3 *f;
	struct net___4 *net;
	bool dead;
	long: 56;
	long: 64;
	long: 64;
	struct rhashtable rhashtable;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	atomic_long_t mem;
	struct work_struct destroy_work;
	struct llist_node free_list;
	long: 64;
	long: 64;
};

struct inet_frag_queue___3;

struct inet_frags___3 {
	unsigned int qsize;
	void (*constructor)(struct inet_frag_queue___3 *, const void *);
	void (*destructor)(struct inet_frag_queue___3 *);
	void (*frag_expire)(struct timer_list *);
	struct kmem_cache *frags_cachep;
	const char *frags_cache_name;
	struct rhashtable_params rhash_params;
	refcount_t refcnt;
	struct completion completion;
};

struct inet_frag_queue___3 {
	struct rhash_head node;
	union {
		struct frag_v4_compare_key v4;
		struct frag_v6_compare_key v6;
	} key;
	struct timer_list timer;
	spinlock_t lock;
	refcount_t refcnt;
	struct rb_root rb_fragments;
	struct sk_buff___3 *fragments_tail;
	struct sk_buff___3 *last_run_head;
	ktime_t stamp;
	int len;
	int meat;
	__u8 flags;
	u16 max_size;
	struct fqdir___3 *fqdir;
	struct callback_head rcu;
};

struct waitid_info {
	pid_t pid;
	uid_t uid;
	int status;
	int cause;
};

struct wait_opts {
	enum pid_type wo_type;
	int wo_flags;
	struct pid___22 *wo_pid;
	struct waitid_info *wo_info;
	int wo_stat;
	struct rusage *wo_rusage;
	wait_queue_entry_t child_wait;
	int notask_error;
};

struct softirq_action {
	void (*action)(struct softirq_action *);
};

struct tasklet_struct {
	struct tasklet_struct *next;
	long unsigned int state;
	atomic_t count;
	bool use_callback;
	union {
		void (*func)(long unsigned int);
		void (*callback)(struct tasklet_struct *);
	};
	long unsigned int data;
};

enum {
	TASKLET_STATE_SCHED = 0,
	TASKLET_STATE_RUN = 1,
};

struct kernel_stat {
	long unsigned int irqs_sum;
	unsigned int softirqs[10];
};

struct wait_bit_key {
	void *flags;
	int bit_nr;
	long unsigned int timeout;
};

struct wait_bit_queue_entry {
	struct wait_bit_key key;
	struct wait_queue_entry wq_entry;
};

struct smp_hotplug_thread___2 {
	struct task_struct___8 **store;
	struct list_head list;
	int (*thread_should_run)(unsigned int);
	void (*thread_fn)(unsigned int);
	void (*create)(unsigned int);
	void (*setup)(unsigned int);
	void (*cleanup)(unsigned int, bool);
	void (*park)(unsigned int);
	void (*unpark)(unsigned int);
	bool selfparking;
	const char *thread_comm;
};

struct trace_event_raw_irq_handler_entry {
	struct trace_entry ent;
	int irq;
	u32 __data_loc_name;
	char __data[0];
};

struct trace_event_raw_irq_handler_exit {
	struct trace_entry ent;
	int irq;
	int ret;
	char __data[0];
};

struct trace_event_raw_softirq {
	struct trace_entry ent;
	unsigned int vec;
	char __data[0];
};

struct trace_event_data_offsets_irq_handler_entry {
	u32 name;
};

struct trace_event_data_offsets_irq_handler_exit {};

struct trace_event_data_offsets_softirq {};

typedef void (*btf_trace_irq_handler_entry)(void *, int, struct irqaction *);

typedef void (*btf_trace_irq_handler_exit)(void *, int, struct irqaction *, int);

typedef void (*btf_trace_softirq_entry)(void *, unsigned int);

typedef void (*btf_trace_softirq_exit)(void *, unsigned int);

typedef void (*btf_trace_softirq_raise)(void *, unsigned int);

struct tasklet_head {
	struct tasklet_struct *head;
	struct tasklet_struct **tail;
};

struct pseudo_fs_context {
	const struct super_operations___2 *ops;
	const struct xattr_handler **xattr;
	const struct dentry_operations___2 *dops;
	long unsigned int magic;
};

typedef void (*dr_release_t)(struct device___27 *, void *);

typedef int (*dr_match_t)(struct device___27 *, void *, void *);

struct resource_entry {
	struct list_head node;
	struct resource *res;
	resource_size_t offset;
	struct resource __res;
};

struct resource_constraint {
	resource_size_t min;
	resource_size_t max;
	resource_size_t align;
	resource_size_t (*alignf)(void *, const struct resource *, resource_size_t, resource_size_t);
	void *alignf_data;
};

enum {
	MAX_IORES_LEVEL = 5,
};

struct region_devres {
	struct resource *parent;
	resource_size_t start;
	resource_size_t n;
};

typedef __kernel_clock_t clock_t;

struct dentry___27;

struct super_block___27;

struct module___26;

struct file_system_type___27 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___27 * (*mount)(struct file_system_type___27 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___27 *);
	struct module___26 *owner;
	struct file_system_type___27 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___27;

struct kiocb___27;

struct iov_iter___21;

struct poll_table_struct___19;

struct vm_area_struct___29;

struct inode___27;

struct file_lock___27;

struct page___28;

struct pipe_inode_info___8;

struct seq_file___25;

struct file_operations___27 {
	struct module___26 *owner;
	loff_t (*llseek)(struct file___27 *, loff_t, int);
	ssize_t (*read)(struct file___27 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___27 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___27 *, struct iov_iter___21 *);
	ssize_t (*write_iter)(struct kiocb___27 *, struct iov_iter___21 *);
	int (*iopoll)(struct kiocb___27 *, bool);
	int (*iterate)(struct file___27 *, struct dir_context *);
	int (*iterate_shared)(struct file___27 *, struct dir_context *);
	__poll_t (*poll)(struct file___27 *, struct poll_table_struct___19 *);
	long int (*unlocked_ioctl)(struct file___27 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___27 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___27 *, struct vm_area_struct___29 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___27 *, struct file___27 *);
	int (*flush)(struct file___27 *, fl_owner_t);
	int (*release)(struct inode___27 *, struct file___27 *);
	int (*fsync)(struct file___27 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___27 *, int);
	int (*lock)(struct file___27 *, int, struct file_lock___27 *);
	ssize_t (*sendpage)(struct file___27 *, struct page___28 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___27 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___27 *, long unsigned int);
	int (*flock)(struct file___27 *, int, struct file_lock___27 *);
	ssize_t (*splice_write)(struct pipe_inode_info___8 *, struct file___27 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___27 *, loff_t *, struct pipe_inode_info___8 *, size_t, unsigned int);
	int (*setlease)(struct file___27 *, long int, struct file_lock___27 **, void **);
	long int (*fallocate)(struct file___27 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___25 *, struct file___27 *);
	ssize_t (*copy_file_range)(struct file___27 *, loff_t, struct file___27 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___27 *, loff_t, struct file___27 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___27 *, loff_t, loff_t, int);
};

struct static_call_mod___19 {
	struct static_call_mod___19 *next;
	struct module___26 *mod;
	struct static_call_site *sites;
};

struct static_call_key___19 {
	void *func;
	union {
		long unsigned int type;
		struct static_call_mod___19 *mods;
		struct static_call_site *sites;
	};
};

typedef struct page___28 *pgtable_t___28;

struct address_space___27;

struct page_pool___8;

struct mm_struct___29;

struct dev_pagemap___27;

struct page___28 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___27 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___8 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___28 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___28 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___29 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___27 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct perf_event___16;

struct thread_struct___17 {
	struct desc_struct tls_array[3];
	long unsigned int sp;
	short unsigned int es;
	short unsigned int ds;
	short unsigned int fsindex;
	short unsigned int gsindex;
	long unsigned int fsbase;
	long unsigned int gsbase;
	struct perf_event___16 *ptrace_bps[4];
	long unsigned int virtual_dr6;
	long unsigned int ptrace_dr7;
	long unsigned int cr2;
	long unsigned int trap_nr;
	long unsigned int error_code;
	struct io_bitmap *io_bitmap;
	long unsigned int iopl_emul;
	unsigned int iopl_warn: 1;
	unsigned int sig_on_uaccess_err: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u32 pkru;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct fpu fpu;
};

struct vmacache___28 {
	u64 seqnum;
	struct vm_area_struct___29 *vmas[4];
};

struct page_frag___28 {
	struct page___28 *page;
	__u32 offset;
	__u32 size;
};

struct pid___23;

struct nsproxy___26;

struct signal_struct___28;

struct bio_list___17;

struct backing_dev_info___16;

struct io_context___18;

struct css_set___21;

struct perf_event_context___16;

struct mem_cgroup___16;

struct request_queue___17;

struct vm_struct___24;

struct task_struct___30 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___30 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___29 *mm;
	struct mm_struct___29 *active_mm;
	struct vmacache___28 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int restore_sigmask: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___30 *real_parent;
	struct task_struct___30 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___30 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___23 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	struct posix_cputimers_work posix_cputimers_work;
	const struct cred *ptracer_cred;
	const struct cred *real_cred;
	const struct cred *cred;
	struct key *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___26 *nsproxy;
	struct signal_struct___28 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___30 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___17 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___16 *backing_dev_info;
	struct io_context___18 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___21 *cgroups;
	struct list_head cg_list;
	u32 closid;
	u32 rmid;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___16 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	struct pipe_inode_info___8 *splice_pipe;
	struct page_frag___28 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___16 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___16 *active_memcg;
	struct request_queue___17 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___30 *oom_reaper_list;
	struct vm_struct___24 *stack_vm_area;
	refcount_t stack_refcount;
	int patch_state;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	void *mce_vaddr;
	__u64 mce_kflags;
	u64 mce_addr;
	__u64 mce_ripv: 1;
	__u64 mce_whole_page: 1;
	__u64 __mce_reserved: 62;
	long: 2;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct callback_head mce_kill_me;
	int mce_count;
	struct llist_head kretprobe_instances;
	struct callback_head l1d_flush_kill;
	long: 64;
	struct thread_struct___17 thread;
};

struct linux_binfmt___5;

struct core_state___28;

struct mm_struct___29 {
	struct {
		struct vm_area_struct___29 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___27 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int mmap_compat_base;
		long unsigned int mmap_compat_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[48];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___5 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___28 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___30 *owner;
		struct user_namespace *user_ns;
		struct file___27 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		bool tlb_flush_batched;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct vm_operations_struct___27;

struct vm_area_struct___29 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___29 *vm_next;
	struct vm_area_struct___29 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___29 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___27 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___27 *vm_file;
	struct file___27 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct tracepoint___19 {
	const char *name;
	struct static_key key;
	struct static_call_key___19 *static_call_key;
	void *static_call_tramp;
	void *iterator;
	int (*regfunc)();
	void (*unregfunc)();
	struct tracepoint_func *funcs;
};

struct bpf_raw_event_map___19 {
	struct tracepoint___19 *tp;
	void *bpf_func;
	u32 num_args;
	u32 writable_size;
	long: 64;
};

struct seq_operations___25 {
	void * (*start)(struct seq_file___25 *, loff_t *);
	void (*stop)(struct seq_file___25 *, void *);
	void * (*next)(struct seq_file___25 *, void *, loff_t *);
	int (*show)(struct seq_file___25 *, void *);
};

struct hw_perf_event___16 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___30 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	union {
		struct {
			u64 last_period;
			local64_t period_left;
		};
		struct {
			u64 saved_metric;
			u64 saved_slots;
		};
	};
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___16)(struct perf_event___16 *, struct perf_sample_data *, struct pt_regs *);

struct pmu___16;

struct fasync_struct___27;

struct pid_namespace___23;

struct bpf_prog___3;

struct trace_event_call___16;

struct perf_cgroup___16;

struct perf_event___16 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___16 *group_leader;
	struct pmu___16 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___16 hw;
	struct perf_event_context___16 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___16 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___30 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct perf_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___27 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	long unsigned int pending_addr;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	struct perf_addr_filter_range *addr_filter_ranges;
	long unsigned int addr_filters_gen;
	struct perf_event___16 *aux_event;
	void (*destroy)(struct perf_event___16 *);
	struct callback_head callback_head;
	struct pid_namespace___23 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___16 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___16 orig_overflow_handler;
	struct bpf_prog___3 *prog;
	u64 bpf_cookie;
	struct trace_event_call___16 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___16 *cgrp;
	void *security;
	struct list_head sb_list;
};

struct address_space_operations___27;

struct address_space___27 {
	struct inode___27 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___27 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct device___29;

struct page_pool_params___8 {
	unsigned int flags;
	unsigned int order;
	unsigned int pool_size;
	int nid;
	struct device___29 *dev;
	enum dma_data_direction dma_dir;
	unsigned int max_len;
	unsigned int offset;
};

struct pp_alloc_cache___8 {
	u32 count;
	struct page___28 *cache[128];
};

struct page_pool___8 {
	struct page_pool_params___8 p;
	struct delayed_work release_dw;
	void (*disconnect)(void *);
	long unsigned int defer_start;
	long unsigned int defer_warn;
	u32 pages_state_hold_cnt;
	unsigned int frag_offset;
	struct page___28 *frag_page;
	long int frag_users;
	long: 64;
	long: 64;
	struct pp_alloc_cache___8 alloc;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct ptr_ring ring;
	atomic_t pages_state_release_cnt;
	refcount_t user_cnt;
	u64 destroy_cnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pagemap_ops___27;

struct dev_pagemap___27 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___27 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vfsmount___27;

struct path___27 {
	struct vfsmount___27 *mnt;
	struct dentry___27 *dentry;
};

struct fown_struct___23 {
	rwlock_t lock;
	struct pid___23 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___27 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___27 f_path;
	struct inode___27 *f_inode;
	const struct file_operations___27 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___23 f_owner;
	const struct cred *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___27 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___27;

struct vm_operations_struct___27 {
	void (*open)(struct vm_area_struct___29 *);
	void (*close)(struct vm_area_struct___29 *);
	int (*may_split)(struct vm_area_struct___29 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___29 *);
	int (*mprotect)(struct vm_area_struct___29 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___27 *);
	vm_fault_t (*huge_fault)(struct vm_fault___27 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___27 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___29 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___27 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___27 *);
	int (*access)(struct vm_area_struct___29 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___29 *);
	int (*set_policy)(struct vm_area_struct___29 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___29 *, long unsigned int);
	struct page___28 * (*find_special_page)(struct vm_area_struct___29 *, long unsigned int);
};

struct core_thread___28 {
	struct task_struct___30 *task;
	struct core_thread___28 *next;
};

struct core_state___28 {
	atomic_t nr_threads;
	struct core_thread___28 dumper;
	struct completion startup;
};

struct linux_binprm___6;

struct coredump_params___5;

struct linux_binfmt___5 {
	struct list_head lh;
	struct module___26 *module;
	int (*load_binary)(struct linux_binprm___6 *);
	int (*load_shlib)(struct file___27 *);
	int (*core_dump)(struct coredump_params___5 *);
	long unsigned int min_coredump;
};

struct vm_fault___27 {
	const struct {
		struct vm_area_struct___29 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___28 *cow_page;
	struct page___28 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___28 prealloc_pte;
};

struct pglist_data___17;

struct lruvec___17 {
	struct list_head lists[5];
	spinlock_t lru_lock;
	long unsigned int anon_cost;
	long unsigned int file_cost;
	atomic_long_t nonresident_age;
	long unsigned int refaults[2];
	long unsigned int flags;
	struct pglist_data___17 *pgdat;
};

struct zone___17 {
	long unsigned int _watermark[3];
	long unsigned int watermark_boost;
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[5];
	int node;
	struct pglist_data___17 *zone_pgdat;
	struct per_cpu_pages *per_cpu_pageset;
	struct per_cpu_zonestat *per_cpu_zonestats;
	int pageset_high;
	int pageset_batch;
	long unsigned int zone_start_pfn;
	atomic_long_t managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int present_early_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	seqlock_t span_seqlock;
	int initialized;
	int: 32;
	struct zone_padding _pad1_;
	struct free_area free_area[11];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	long unsigned int compact_init_migrate_pfn;
	long unsigned int compact_init_free_pfn;
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	short: 16;
	struct zone_padding _pad3_;
	atomic_long_t vm_stat[11];
	atomic_long_t vm_numa_event[6];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___17 {
	struct zone___17 *zone;
	int zone_idx;
};

struct zonelist___17 {
	struct zoneref___17 _zonerefs[5121];
};

struct pglist_data___17 {
	struct zone___17 node_zones[5];
	struct zonelist___17 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___30 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_highest_zoneidx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_highest_zoneidx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___30 *kcompactd;
	bool proactive_compact_trigger;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct deferred_split deferred_split_queue;
	struct lruvec___17 __lruvec;
	long unsigned int flags;
	long: 64;
	struct zone_padding _pad2_;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[39];
};

struct irq_domain_ops___15;

struct fwnode_handle___26;

struct irq_domain___15 {
	struct list_head link;
	const char *name;
	const struct irq_domain_ops___15 *ops;
	void *host_data;
	unsigned int flags;
	unsigned int mapcount;
	struct fwnode_handle___26 *fwnode;
	enum irq_domain_bus_token bus_token;
	struct irq_domain_chip_generic *gc;
	struct irq_domain___15 *parent;
	irq_hw_number_t hwirq_max;
	unsigned int revmap_size;
	struct xarray revmap_tree;
	struct mutex revmap_mutex;
	struct irq_data *revmap[0];
};

struct kernfs_root___27;

struct kernfs_elem_dir___27 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___27 *root;
	long unsigned int rev;
};

struct kernfs_node___27;

struct kernfs_syscall_ops___27;

struct kernfs_root___27 {
	struct kernfs_node___27 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___27 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___27 {
	struct kernfs_node___27 *target_kn;
};

struct kernfs_ops___27;

struct kernfs_elem_attr___27 {
	const struct kernfs_ops___27 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___27 *notify_next;
};

struct kernfs_node___27 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___27 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___27 dir;
		struct kernfs_elem_symlink___27 symlink;
		struct kernfs_elem_attr___27 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___27;

struct kernfs_ops___27 {
	int (*open)(struct kernfs_open_file___27 *);
	void (*release)(struct kernfs_open_file___27 *);
	int (*seq_show)(struct seq_file___25 *, void *);
	void * (*seq_start)(struct seq_file___25 *, loff_t *);
	void * (*seq_next)(struct seq_file___25 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___25 *, void *);
	ssize_t (*read)(struct kernfs_open_file___27 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___27 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___27 *, struct poll_table_struct___19 *);
	int (*mmap)(struct kernfs_open_file___27 *, struct vm_area_struct___29 *);
};

struct kernfs_syscall_ops___27 {
	int (*show_options)(struct seq_file___25 *, struct kernfs_root___27 *);
	int (*mkdir)(struct kernfs_node___27 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___27 *);
	int (*rename)(struct kernfs_node___27 *, struct kernfs_node___27 *, const char *);
	int (*show_path)(struct seq_file___25 *, struct kernfs_node___27 *, struct kernfs_root___27 *);
};

struct seq_file___25 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___25 *op;
	int poll_event;
	const struct file___27 *file;
	void *private;
};

struct kernfs_open_file___27 {
	struct kernfs_node___27 *kn;
	struct file___27 *file;
	struct seq_file___25 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped;
	bool released;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___27 *vm_ops;
};

typedef void (*poll_queue_proc___19)(struct file___27 *, wait_queue_head_t *, struct poll_table_struct___19 *);

struct poll_table_struct___19 {
	poll_queue_proc___19 _qproc;
	__poll_t _key;
};

struct sock___2;

struct kobj_ns_type_operations___2 {
	enum kobj_ns_type type;
	bool (*current_may_mount)();
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___2 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

typedef struct {
	struct net *net;
} possible_net_t___3;

struct proto___2;

struct sock_common___2 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 1;
	unsigned char skc_ipv6only: 1;
	unsigned char skc_net_refcnt: 1;
	long: 31;
	long: 64;
	long: 64;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_node skc_portaddr_node;
	};
	struct proto___2 *skc_prot;
	possible_net_t___3 skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	atomic64_t skc_cookie;
	union {
		long unsigned int skc_flags;
		struct sock___2 *skc_listener;
		struct inet_timewait_death_row *skc_tw_dr;
	};
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	short unsigned int skc_tx_queue_mapping;
	short unsigned int skc_rx_queue_mapping;
	union {
		int skc_incoming_cpu;
		u32 skc_rcv_wnd;
		u32 skc_tw_rcv_nxt;
	};
	refcount_t skc_refcnt;
	int skc_dontcopy_end[0];
	union {
		u32 skc_rxhash;
		u32 skc_window_clamp;
		u32 skc_tw_snd_nxt;
	};
};

struct sk_buff___4;

struct sk_buff_head___3 {
	struct sk_buff___4 *next;
	struct sk_buff___4 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct cgroup___21;

struct sock_cgroup_data___2 {
	struct cgroup___21 *cgroup;
	u32 classid;
	u16 prioidx;
};

struct sk_filter___2;

struct socket_wq___2;

struct dst_entry___2;

struct socket___2;

struct net_device___3;

struct sock___2 {
	struct sock_common___2 __sk_common;
	socket_lock_t sk_lock;
	atomic_t sk_drops;
	int sk_rcvlowat;
	struct sk_buff_head___3 sk_error_queue;
	struct sk_buff___4 *sk_rx_skb_cache;
	struct sk_buff_head___3 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___4 *head;
		struct sk_buff___4 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	unsigned int sk_ll_usec;
	unsigned int sk_napi_id;
	int sk_rcvbuf;
	struct sk_filter___2 *sk_filter;
	union {
		struct socket_wq___2 *sk_wq;
		struct socket_wq___2 *sk_wq_raw;
	};
	struct xfrm_policy *sk_policy[2];
	struct dst_entry___2 *sk_rx_dst;
	int sk_rx_dst_ifindex;
	u32 sk_rx_dst_cookie;
	struct dst_entry___2 *sk_dst_cache;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	int sk_wmem_queued;
	refcount_t sk_wmem_alloc;
	long unsigned int sk_tsq_flags;
	union {
		struct sk_buff___4 *sk_send_head;
		struct rb_root tcp_rtx_queue;
	};
	struct sk_buff___4 *sk_tx_skb_cache;
	struct sk_buff_head___3 sk_write_queue;
	__s32 sk_peek_off;
	int sk_write_pending;
	__u32 sk_dst_pending_confirm;
	u32 sk_pacing_status;
	long int sk_sndtimeo;
	struct timer_list sk_timer;
	__u32 sk_priority;
	__u32 sk_mark;
	long unsigned int sk_pacing_rate;
	long unsigned int sk_max_pacing_rate;
	struct page_frag___28 sk_frag;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	netdev_features_t sk_route_forced_caps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	gfp_t sk_allocation;
	__u32 sk_txhash;
	u8 sk_padding: 1;
	u8 sk_kern_sock: 1;
	u8 sk_no_check_tx: 1;
	u8 sk_no_check_rx: 1;
	u8 sk_userlocks: 4;
	long: 4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u8 sk_pacing_shift;
	u16 sk_type;
	u16 sk_protocol;
	u16 sk_gso_max_segs;
	long unsigned int sk_lingertime;
	struct proto___2 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	u32 sk_ack_backlog;
	u32 sk_max_ack_backlog;
	kuid_t sk_uid;
	u8 sk_prefer_busy_poll;
	u16 sk_busy_poll_budget;
	spinlock_t sk_peer_lock;
	struct pid___23 *sk_peer_pid;
	const struct cred *sk_peer_cred;
	long int sk_rcvtimeo;
	ktime_t sk_stamp;
	u16 sk_tsflags;
	int sk_bind_phc;
	u8 sk_shutdown;
	atomic_t sk_tskey;
	atomic_t sk_zckey;
	u8 sk_clockid;
	u8 sk_txtime_deadline_mode: 1;
	u8 sk_txtime_report_errors: 1;
	u8 sk_txtime_unused: 6;
	long: 58;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct socket___2 *sk_socket;
	void *sk_user_data;
	void *sk_security;
	struct sock_cgroup_data___2 sk_cgrp_data;
	struct mem_cgroup___16 *sk_memcg;
	void (*sk_state_change)(struct sock___2 *);
	void (*sk_data_ready)(struct sock___2 *);
	void (*sk_write_space)(struct sock___2 *);
	void (*sk_error_report)(struct sock___2 *);
	int (*sk_backlog_rcv)(struct sock___2 *, struct sk_buff___4 *);
	struct sk_buff___4 * (*sk_validate_xmit_skb)(struct sock___2 *, struct net_device___3 *, struct sk_buff___4 *);
	void (*sk_destruct)(struct sock___2 *);
	struct sock_reuseport *sk_reuseport_cb;
	struct bpf_local_storage *sk_bpf_storage;
	struct callback_head sk_rcu;
};

struct kobject___27;

struct bin_attribute___27;

struct attribute_group___27 {
	const char *name;
	umode_t (*is_visible)(struct kobject___27 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___27 *, struct bin_attribute___27 *, int);
	struct attribute **attrs;
	struct bin_attribute___27 **bin_attrs;
};

struct kset___26;

struct kobj_type___26;

struct kobject___27 {
	const char *name;
	struct list_head entry;
	struct kobject___27 *parent;
	struct kset___26 *kset;
	struct kobj_type___26 *ktype;
	struct kernfs_node___27 *sd;
	struct kref kref;
	unsigned int state_initialized;
	unsigned int state_in_sysfs;
	unsigned int state_add_uevent_sent;
	unsigned int state_remove_uevent_sent;
	unsigned int uevent_suppress;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bin_attribute___27 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___27 * (*f_mapping)();
	ssize_t (*read)(struct file___27 *, struct kobject___27 *, struct bin_attribute___27 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___27 *, struct kobject___27 *, struct bin_attribute___27 *, char *, loff_t, size_t);
	int (*mmap)(struct file___27 *, struct kobject___27 *, struct bin_attribute___27 *, struct vm_area_struct___29 *);
};

struct sysfs_ops___26 {
	ssize_t (*show)(struct kobject___27 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___27 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___26;

struct kset___26 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___27 kobj;
	const struct kset_uevent_ops___26 *uevent_ops;
};

struct kobj_type___26 {
	void (*release)(struct kobject___27 *);
	const struct sysfs_ops___26 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___27 **default_groups;
	const struct kobj_ns_type_operations___2 * (*child_ns_type)(struct kobject___27 *);
	const void * (*namespace)(struct kobject___27 *);
	void (*get_ownership)(struct kobject___27 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___26 {
	int (* const filter)(struct kset___26 *, struct kobject___27 *);
	const char * (* const name)(struct kset___26 *, struct kobject___27 *);
	int (* const uevent)(struct kset___26 *, struct kobject___27 *, struct kobj_uevent_env *);
};

struct kernel_param___26;

struct kernel_param_ops___26 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___26 *);
	int (*get)(char *, const struct kernel_param___26 *);
	void (*free)(void *);
};

struct kparam_array___26;

struct kernel_param___26 {
	const char *name;
	struct module___26 *mod;
	const struct kernel_param_ops___26 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___26 *arr;
	};
};

struct kparam_array___26 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___26 *ops;
	void *elem;
};

struct module_kobject___26 {
	struct kobject___27 kobj;
	struct module___26 *mod;
	struct kobject___27 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___26 {
	struct module___26 *mod;
	struct latch_tree_node node;
};

struct module_layout___26 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___26 mtn;
};

struct module_attribute___26;

struct module___26 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___26 mkobj;
	struct module_attribute___26 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___27 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___26 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___26 core_layout;
	struct module_layout___26 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map___19 *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___16 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	int num_static_call_sites;
	struct static_call_site *static_call_sites;
	bool klp;
	bool klp_alive;
	struct klp_modinfo *klp_info;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_attribute___26 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___26 *, struct module_kobject___26 *, char *);
	ssize_t (*store)(struct module_attribute___26 *, struct module_kobject___26 *, const char *, size_t);
	void (*setup)(struct module___26 *, const char *);
	int (*test)(struct module___26 *);
	void (*free)(struct module___26 *);
};

struct trace_event_class___16;

struct bpf_prog_array___3;

struct trace_event_call___16 {
	struct list_head list;
	struct trace_event_class___16 *class;
	union {
		char *name;
		struct tracepoint___19 *tp;
	};
	struct trace_event event;
	char *print_fmt;
	struct event_filter *filter;
	union {
		void *module;
		atomic_t refcnt;
	};
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
	struct bpf_prog_array___3 *prog_array;
	int (*perf_perm)(struct trace_event_call___16 *, struct perf_event___16 *);
};

struct dentry_stat_t {
	long int nr_dentry;
	long int nr_unused;
	long int age_limit;
	long int want_pages;
	long int nr_negative;
	long int dummy;
};

struct dentry_operations___27;

struct dentry___27 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___27 *d_parent;
	struct qstr d_name;
	struct inode___27 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___27 *d_op;
	struct super_block___27 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___27;

struct bdi_writeback___16;

struct inode___27 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___27 *i_op;
	struct super_block___27 *i_sb;
	struct address_space___27 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___16 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___27 *i_fop;
		void (*free_inode)(struct inode___27 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___27 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___8 *i_pipe;
		struct cdev *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___27 {
	int (*d_revalidate)(struct dentry___27 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___27 *, unsigned int);
	int (*d_hash)(const struct dentry___27 *, struct qstr *);
	int (*d_compare)(const struct dentry___27 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___27 *);
	int (*d_init)(struct dentry___27 *);
	void (*d_release)(struct dentry___27 *);
	void (*d_prune)(struct dentry___27 *);
	void (*d_iput)(struct dentry___27 *, struct inode___27 *);
	char * (*d_dname)(struct dentry___27 *, char *, int);
	struct vfsmount___27 * (*d_automount)(struct path___27 *);
	int (*d_manage)(const struct path___27 *, bool);
	struct dentry___27 * (*d_real)(struct dentry___27 *, const struct inode___27 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___27;

struct mem_dqinfo___27 {
	struct quota_format_type___27 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___27;

struct quota_info___27 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___27 *files[3];
	struct mem_dqinfo___27 info[3];
	const struct quota_format_ops___27 *ops[3];
};

struct rcuwait___27 {
	struct task_struct___30 *task;
};

struct percpu_rw_semaphore___27 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___27 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___27 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___27 rw_sem[3];
};

struct shrink_control___16;

struct shrinker___16 {
	long unsigned int (*count_objects)(struct shrinker___16 *, struct shrink_control___16 *);
	long unsigned int (*scan_objects)(struct shrinker___16 *, struct shrink_control___16 *);
	long int batch;
	int seeks;
	unsigned int flags;
	struct list_head list;
	int id;
	atomic_long_t *nr_deferred;
};

struct super_operations___27;

struct dquot_operations___27;

struct quotactl_ops___27;

struct block_device___17;

struct super_block___27 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___27 *s_type;
	const struct super_operations___27 *s_op;
	const struct dquot_operations___27 *dq_op;
	const struct quotactl_ops___27 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___27 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___17 *s_bdev;
	struct backing_dev_info___16 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___27 s_dquot;
	struct sb_writers___27 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___27 *s_d_op;
	int cleancache_poolid;
	struct shrinker___16 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___27 {
	struct dentry___27 *mnt_root;
	struct super_block___27 *mnt_sb;
	int mnt_flags;
	struct user_namespace *mnt_userns;
};

struct shrink_control___16 {
	gfp_t gfp_mask;
	int nid;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	struct mem_cgroup___16 *memcg;
};

struct cgroup_subsys___21;

struct cgroup_subsys_state___21 {
	struct cgroup___21 *cgroup;
	struct cgroup_subsys___21 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___21 *parent;
};

struct cgroup_file___21 {
	struct kernfs_node___27 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct obj_cgroup___16;

struct mem_cgroup_per_node___16;

struct mem_cgroup___16 {
	struct cgroup_subsys_state___21 css;
	struct mem_cgroup_id id;
	struct page_counter memory;
	union {
		struct page_counter swap;
		struct page_counter memsw;
	};
	struct page_counter kmem;
	struct page_counter tcpmem;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool oom_group;
	bool oom_lock;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___21 events_file;
	struct cgroup_file___21 events_local_file;
	struct cgroup_file___21 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	struct memcg_vmstats vmstats;
	atomic_long_t memory_events[8];
	atomic_long_t memory_events_local[8];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct obj_cgroup___16 *objcg;
	struct list_head objcg_list;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad2_;
	atomic_t moving_account;
	struct task_struct___30 *move_lock_task;
	struct memcg_vmstats_percpu *vmstats_percpu;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct memcg_cgwb_frn cgwb_frn[4];
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct deferred_split deferred_split_queue;
	struct mem_cgroup_per_node___16 *nodeinfo[0];
	long: 64;
};

struct upid___23 {
	int nr;
	struct pid_namespace___23 *ns;
};

struct pid_namespace___23 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___30 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___23 *parent;
	struct fs_pin *bacct;
	struct user_namespace *user_ns;
	struct ucounts *ucounts;
	int reboot;
	struct ns_common ns;
};

struct pid___23 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___23 numbers[1];
};

struct signal_struct___28 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___30 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___30 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper;
	unsigned int has_child_subreaper;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___23 *pids[4];
	struct pid___23 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___29 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct cgroup_namespace___21;

struct nsproxy___26 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___23 *pid_ns_for_children;
	struct net *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___21 *cgroup_ns;
};

struct bio___17;

struct bio_list___17 {
	struct bio___17 *head;
	struct bio___17 *tail;
};

struct bdi_writeback___16 {
	struct backing_dev_info___16 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	atomic_t writeback_inodes;
	struct percpu_counter stat[4];
	long unsigned int congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	struct delayed_work bw_dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___21 *memcg_css;
	struct cgroup_subsys_state___21 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	struct list_head b_attached;
	struct list_head offline_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
};

struct backing_dev_info___16 {
	u64 id;
	struct rb_node rb_node;
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___16 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct mutex cgwb_release_mutex;
	struct rw_semaphore wb_switch_rwsem;
	wait_queue_head_t wb_waitq;
	struct device___29 *dev;
	char dev_name[64];
	struct device___29 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___27 *debug_dir;
};

struct io_cq___17;

struct io_context___18 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	struct xarray icq_tree;
	struct io_cq___17 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct css_set___21 {
	struct cgroup_subsys_state___21 *subsys[14];
	refcount_t refcount;
	struct css_set___21 *dom_cset;
	struct cgroup___21 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___21 *mg_src_cgrp;
	struct cgroup___21 *mg_dst_cgrp;
	struct css_set___21 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___16 {
	struct pmu___16 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	int rotate_necessary;
	refcount_t refcount;
	struct task_struct___30 *task;
	u64 time;
	u64 timestamp;
	u64 timeoffset;
	struct perf_event_context___16 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

struct pipe_buffer___8;

struct pipe_inode_info___8 {
	struct mutex mutex;
	wait_queue_head_t rd_wait;
	wait_queue_head_t wr_wait;
	unsigned int head;
	unsigned int tail;
	unsigned int max_usage;
	unsigned int ring_size;
	bool note_loss;
	unsigned int nr_accounted;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int r_counter;
	unsigned int w_counter;
	unsigned int poll_usage;
	struct page___28 *tmp_page;
	struct fasync_struct___27 *fasync_readers;
	struct fasync_struct___27 *fasync_writers;
	struct pipe_buffer___8 *bufs;
	struct user_struct *user;
	struct watch_queue *watch_queue;
};

struct blk_integrity_profile___17;

struct blk_integrity___17 {
	const struct blk_integrity_profile___17 *profile;
	unsigned char flags;
	unsigned char tuple_size;
	unsigned char interval_exp;
	unsigned char tag_size;
};

struct bio_set___17 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	struct bio_alloc_cache *cache;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	unsigned int back_pad;
	spinlock_t rescue_lock;
	struct bio_list___17 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	struct hlist_node cpuhp_dead;
};

struct request___17;

struct elevator_queue___17;

struct gendisk___17;

struct blkcg_gq___16;

struct request_queue___17 {
	struct request___17 *last_merge;
	struct elevator_queue___17 *elevator;
	struct percpu_ref q_usage_counter;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	const struct blk_mq_ops *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx **queue_hw_ctx;
	unsigned int nr_hw_queues;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	spinlock_t queue_lock;
	struct gendisk___17 *disk;
	struct kobject___27 kobj;
	struct kobject___27 *mq_kobj;
	struct blk_integrity___17 integrity;
	struct device___29 *dev;
	enum rpm_status rpm_status;
	long unsigned int nr_requests;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_keyslot_manager *ksm;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	atomic_t nr_active_requests_shared_sbitmap;
	struct sbitmap_queue sched_bitmap_tags;
	struct sbitmap_queue sched_breserved_tags;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___16 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int required_elevator_features;
	unsigned int nr_zones;
	long unsigned int *conv_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int max_open_zones;
	unsigned int max_active_zones;
	int node;
	struct mutex debugfs_mutex;
	struct blk_trace *blk_trace;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	struct mutex sysfs_dir_lock;
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	int mq_freeze_depth;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct mutex mq_freeze_lock;
	struct blk_mq_tag_set *tag_set;
	struct list_head tag_set_list;
	struct bio_set___17 bio_split;
	struct dentry___27 *debugfs_dir;
	struct dentry___27 *sched_debugfs_dir;
	struct dentry___27 *rqos_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	u64 write_hints[5];
};

struct vm_struct___24 {
	struct vm_struct___24 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___28 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct psi_group___21 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___30 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_bpf___3 {
	struct bpf_prog_array___3 *effective[23];
	struct list_head progs[23];
	u32 flags[23];
	struct list_head storages;
	struct bpf_prog_array___3 *inactive;
	struct percpu_ref refcnt;
	struct work_struct release_work;
};

struct cgroup_root___21;

struct cgroup_rstat_cpu___21;

struct cgroup___21 {
	struct cgroup_subsys_state___21 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___27 *kn;
	struct cgroup_file___21 procs_file;
	struct cgroup_file___21 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___21 *subsys[14];
	struct cgroup_root___21 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___21 *dom_cgrp;
	struct cgroup___21 *old_dom_cgrp;
	struct cgroup_rstat_cpu___21 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___21 psi;
	struct cgroup_bpf___3 bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct io_cq___17 {
	struct request_queue___17 *q;
	struct io_context___18 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct files_stat_struct {
	long unsigned int nr_files;
	long unsigned int nr_free_files;
	long unsigned int max_files;
};

struct inodes_stat_t {
	long int nr_inodes;
	long int nr_unused;
	long int dummy[5];
};

struct wait_page_queue___15;

struct kiocb___27 {
	struct file___27 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___27 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___15 *ki_waitq;
	};
};

struct iattr___27 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___27 *ia_file;
};

struct dquot___27 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___27 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___27 {
	int qf_fmt_id;
	const struct quota_format_ops___27 *qf_ops;
	struct module___26 *qf_owner;
	struct quota_format_type___27 *qf_next;
};

struct quota_format_ops___27 {
	int (*check_quota_file)(struct super_block___27 *, int);
	int (*read_file_info)(struct super_block___27 *, int);
	int (*write_file_info)(struct super_block___27 *, int);
	int (*free_file_info)(struct super_block___27 *, int);
	int (*read_dqblk)(struct dquot___27 *);
	int (*commit_dqblk)(struct dquot___27 *);
	int (*release_dqblk)(struct dquot___27 *);
	int (*get_next_id)(struct super_block___27 *, struct kqid *);
};

struct dquot_operations___27 {
	int (*write_dquot)(struct dquot___27 *);
	struct dquot___27 * (*alloc_dquot)(struct super_block___27 *, int);
	void (*destroy_dquot)(struct dquot___27 *);
	int (*acquire_dquot)(struct dquot___27 *);
	int (*release_dquot)(struct dquot___27 *);
	int (*mark_dirty)(struct dquot___27 *);
	int (*write_info)(struct super_block___27 *, int);
	qsize_t * (*get_reserved_space)(struct inode___27 *);
	int (*get_projid)(struct inode___27 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___27 *, qsize_t *);
	int (*get_next_id)(struct super_block___27 *, struct kqid *);
};

struct quotactl_ops___27 {
	int (*quota_on)(struct super_block___27 *, int, int, const struct path___27 *);
	int (*quota_off)(struct super_block___27 *, int);
	int (*quota_enable)(struct super_block___27 *, unsigned int);
	int (*quota_disable)(struct super_block___27 *, unsigned int);
	int (*quota_sync)(struct super_block___27 *, int);
	int (*set_info)(struct super_block___27 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___27 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___27 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___27 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___27 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___27 *, unsigned int);
};

struct wait_page_queue___15 {
	struct page___28 *page;
	int bit_nr;
	wait_queue_entry_t wait;
};

struct writeback_control___16;

struct readahead_control___15;

struct swap_info_struct___11;

struct address_space_operations___27 {
	int (*writepage)(struct page___28 *, struct writeback_control___16 *);
	int (*readpage)(struct file___27 *, struct page___28 *);
	int (*writepages)(struct address_space___27 *, struct writeback_control___16 *);
	int (*set_page_dirty)(struct page___28 *);
	int (*readpages)(struct file___27 *, struct address_space___27 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___15 *);
	int (*write_begin)(struct file___27 *, struct address_space___27 *, loff_t, unsigned int, unsigned int, struct page___28 **, void **);
	int (*write_end)(struct file___27 *, struct address_space___27 *, loff_t, unsigned int, unsigned int, struct page___28 *, void *);
	sector_t (*bmap)(struct address_space___27 *, sector_t);
	void (*invalidatepage)(struct page___28 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___28 *, gfp_t);
	void (*freepage)(struct page___28 *);
	ssize_t (*direct_IO)(struct kiocb___27 *, struct iov_iter___21 *);
	int (*migratepage)(struct address_space___27 *, struct page___28 *, struct page___28 *, enum migrate_mode);
	bool (*isolate_page)(struct page___28 *, isolate_mode_t);
	void (*putback_page)(struct page___28 *);
	int (*launder_page)(struct page___28 *);
	int (*is_partially_uptodate)(struct page___28 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___28 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___27 *, struct page___28 *);
	int (*swap_activate)(struct swap_info_struct___11 *, struct file___27 *, sector_t *);
	void (*swap_deactivate)(struct file___27 *);
};

struct writeback_control___16 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate;
	unsigned int for_background;
	unsigned int tagged_writepages;
	unsigned int for_reclaim;
	unsigned int range_cyclic;
	unsigned int for_sync;
	unsigned int no_cgroup_owner;
	unsigned int punt_to_cgroup;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bdi_writeback___16 *wb;
	struct inode___27 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
};

struct readahead_control___15 {
	struct file___27 *file;
	struct address_space___27 *mapping;
	struct file_ra_state *ra;
	long unsigned int _index;
	unsigned int _nr_pages;
	unsigned int _batch_count;
};

struct bio_vec___21;

struct iov_iter___21 {
	u8 iter_type;
	bool data_source;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___21 *bvec;
		struct xarray *xarray;
		struct pipe_inode_info___8 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			unsigned int head;
			unsigned int start_head;
		};
		loff_t xarray_start;
	};
};

struct swap_info_struct___11 {
	struct percpu_ref users;
	long unsigned int flags;
	short int prio;
	struct plist_node list;
	signed char type;
	unsigned int max;
	unsigned char *swap_map;
	struct swap_cluster_info *cluster_info;
	struct swap_cluster_list free_clusters;
	unsigned int lowest_bit;
	unsigned int highest_bit;
	unsigned int pages;
	unsigned int inuse_pages;
	unsigned int cluster_next;
	unsigned int cluster_nr;
	unsigned int *cluster_next_cpu;
	struct percpu_cluster *percpu_cluster;
	struct rb_root swap_extent_root;
	struct block_device___17 *bdev;
	struct file___27 *swap_file;
	unsigned int old_block_size;
	struct completion comp;
	long unsigned int *frontswap_map;
	atomic_t frontswap_pages;
	spinlock_t lock;
	spinlock_t cont_lock;
	struct work_struct discard_work;
	struct swap_cluster_list discard_clusters;
	struct plist_node avail_lists[0];
};

struct inode_operations___27 {
	struct dentry___27 * (*lookup)(struct inode___27 *, struct dentry___27 *, unsigned int);
	const char * (*get_link)(struct dentry___27 *, struct inode___27 *, struct delayed_call *);
	int (*permission)(struct user_namespace *, struct inode___27 *, int);
	struct posix_acl * (*get_acl)(struct inode___27 *, int, bool);
	int (*readlink)(struct dentry___27 *, char *, int);
	int (*create)(struct user_namespace *, struct inode___27 *, struct dentry___27 *, umode_t, bool);
	int (*link)(struct dentry___27 *, struct inode___27 *, struct dentry___27 *);
	int (*unlink)(struct inode___27 *, struct dentry___27 *);
	int (*symlink)(struct user_namespace *, struct inode___27 *, struct dentry___27 *, const char *);
	int (*mkdir)(struct user_namespace *, struct inode___27 *, struct dentry___27 *, umode_t);
	int (*rmdir)(struct inode___27 *, struct dentry___27 *);
	int (*mknod)(struct user_namespace *, struct inode___27 *, struct dentry___27 *, umode_t, dev_t);
	int (*rename)(struct user_namespace *, struct inode___27 *, struct dentry___27 *, struct inode___27 *, struct dentry___27 *, unsigned int);
	int (*setattr)(struct user_namespace *, struct dentry___27 *, struct iattr___27 *);
	int (*getattr)(struct user_namespace *, const struct path___27 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___27 *, char *, size_t);
	int (*fiemap)(struct inode___27 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___27 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___27 *, struct dentry___27 *, struct file___27 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace *, struct inode___27 *, struct dentry___27 *, umode_t);
	int (*set_acl)(struct user_namespace *, struct inode___27 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace *, struct dentry___27 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___27 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___27 {
	void (*fl_copy_lock)(struct file_lock___27 *, struct file_lock___27 *);
	void (*fl_release_private)(struct file_lock___27 *);
};

struct lock_manager_operations___27;

struct file_lock___27 {
	struct file_lock___27 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___27 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___27 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___27 *fl_ops;
	const struct lock_manager_operations___27 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___27 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___27 *);
	int (*lm_grant)(struct file_lock___27 *, int);
	bool (*lm_break)(struct file_lock___27 *);
	int (*lm_change)(struct file_lock___27 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___27 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___27 *);
};

struct fasync_struct___27 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___27 *fa_next;
	struct file___27 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___27 {
	struct inode___27 * (*alloc_inode)(struct super_block___27 *);
	void (*destroy_inode)(struct inode___27 *);
	void (*free_inode)(struct inode___27 *);
	void (*dirty_inode)(struct inode___27 *, int);
	int (*write_inode)(struct inode___27 *, struct writeback_control___16 *);
	int (*drop_inode)(struct inode___27 *);
	void (*evict_inode)(struct inode___27 *);
	void (*put_super)(struct super_block___27 *);
	int (*sync_fs)(struct super_block___27 *, int);
	int (*freeze_super)(struct super_block___27 *);
	int (*freeze_fs)(struct super_block___27 *);
	int (*thaw_super)(struct super_block___27 *);
	int (*unfreeze_fs)(struct super_block___27 *);
	int (*statfs)(struct dentry___27 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___27 *, int *, char *);
	void (*umount_begin)(struct super_block___27 *);
	int (*show_options)(struct seq_file___25 *, struct dentry___27 *);
	int (*show_devname)(struct seq_file___25 *, struct dentry___27 *);
	int (*show_path)(struct seq_file___25 *, struct dentry___27 *);
	int (*show_stats)(struct seq_file___25 *, struct dentry___27 *);
	ssize_t (*quota_read)(struct super_block___27 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___27 *, int, const char *, size_t, loff_t);
	struct dquot___27 ** (*get_dquots)(struct inode___27 *);
	long int (*nr_cached_objects)(struct super_block___27 *, struct shrink_control___16 *);
	long int (*free_cached_objects)(struct super_block___27 *, struct shrink_control___16 *);
	struct file___27 * (*real_loop)(struct file___27 *);
};

struct wakeup_source___29;

struct dev_pm_info___29 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___29 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___29 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___29;

struct bus_type___29;

struct device_driver___29;

struct dev_pm_domain___29;

struct device_node___17;

struct class___29;

struct device___29 {
	struct kobject___27 kobj;
	struct device___29 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___29 *type;
	struct bus_type___29 *bus;
	struct device_driver___29 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___29 power;
	struct dev_pm_domain___29 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___15 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___17 *of_node;
	struct fwnode_handle___26 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___29 *class;
	const struct attribute_group___27 **groups;
	void (*release)(struct device___29 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct block_device___17 {
	sector_t bd_start_sect;
	struct disk_stats *bd_stats;
	long unsigned int bd_stamp;
	bool bd_read_only;
	dev_t bd_dev;
	int bd_openers;
	struct inode___27 *bd_inode;
	struct super_block___27 *bd_super;
	void *bd_claiming;
	struct device___29 bd_device;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct kobject___27 *bd_holder_dir;
	u8 bd_partno;
	spinlock_t bd_size_lock;
	struct gendisk___17 *bd_disk;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	struct super_block___27 *bd_fsfreeze_sb;
	struct partition_meta_info *bd_meta_info;
};

typedef void bio_end_io_t___17(struct bio___17 *);

struct bio_vec___21 {
	struct page___28 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___17;

struct bio___17 {
	struct bio___17 *bi_next;
	struct block_device___17 *bi_bdev;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	atomic_t __bi_remaining;
	struct bvec_iter bi_iter;
	bio_end_io_t___17 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___16 *bi_blkg;
	struct bio_issue bi_issue;
	u64 bi_iocost_cost;
	struct bio_crypt_ctx *bi_crypt_context;
	union {
		struct bio_integrity_payload___17 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___21 *bi_io_vec;
	struct bio_set___17 *bi_pool;
	struct bio_vec___21 bi_inline_vecs[0];
};

struct dev_pagemap_ops___27 {
	void (*page_free)(struct page___28 *);
	void (*kill)(struct dev_pagemap___27 *);
	void (*cleanup)(struct dev_pagemap___27 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___27 *);
};

struct fib_rules_ops___2;

struct fqdir___4;

struct fib_notifier_ops___2;

struct netns_ipv4___4 {
	struct inet_timewait_death_row tcp_death_row;
	struct ctl_table_header *forw_hdr;
	struct ctl_table_header *frags_hdr;
	struct ctl_table_header *ipv4_hdr;
	struct ctl_table_header *route_hdr;
	struct ctl_table_header *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct ip_ra_chain *ra_chain;
	struct mutex ra_mutex;
	struct fib_rules_ops___2 *rules_ops;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	unsigned int fib_rules_require_fldissect;
	bool fib_has_custom_rules;
	bool fib_has_custom_local_routes;
	bool fib_offload_disabled;
	atomic_t fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	struct sock___2 *fibnl;
	struct sock___2 **icmp_sk;
	struct sock___2 *mc_autojoin_sk;
	struct inet_peer_base *peers;
	struct sock___2 **tcp_sk;
	struct fqdir___4 *fqdir;
	u8 sysctl_icmp_echo_ignore_all;
	u8 sysctl_icmp_echo_enable_probe;
	u8 sysctl_icmp_echo_ignore_broadcasts;
	u8 sysctl_icmp_ignore_bogus_error_responses;
	u8 sysctl_icmp_errors_use_inbound_ifaddr;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	struct local_ports ip_local_ports;
	u8 sysctl_tcp_ecn;
	u8 sysctl_tcp_ecn_fallback;
	u8 sysctl_ip_default_ttl;
	u8 sysctl_ip_no_pmtu_disc;
	u8 sysctl_ip_fwd_use_pmtu;
	u8 sysctl_ip_fwd_update_priority;
	u8 sysctl_ip_nonlocal_bind;
	u8 sysctl_ip_autobind_reuse;
	u8 sysctl_ip_dynaddr;
	u8 sysctl_ip_early_demux;
	u8 sysctl_raw_l3mdev_accept;
	u8 sysctl_tcp_early_demux;
	u8 sysctl_udp_early_demux;
	u8 sysctl_nexthop_compat_mode;
	u8 sysctl_fwmark_reflect;
	u8 sysctl_tcp_fwmark_accept;
	u8 sysctl_tcp_l3mdev_accept;
	u8 sysctl_tcp_mtu_probing;
	int sysctl_tcp_mtu_probe_floor;
	int sysctl_tcp_base_mss;
	int sysctl_tcp_min_snd_mss;
	int sysctl_tcp_probe_threshold;
	u32 sysctl_tcp_probe_interval;
	int sysctl_tcp_keepalive_time;
	int sysctl_tcp_keepalive_intvl;
	u8 sysctl_tcp_keepalive_probes;
	u8 sysctl_tcp_syn_retries;
	u8 sysctl_tcp_synack_retries;
	u8 sysctl_tcp_syncookies;
	u8 sysctl_tcp_migrate_req;
	int sysctl_tcp_reordering;
	u8 sysctl_tcp_retries1;
	u8 sysctl_tcp_retries2;
	u8 sysctl_tcp_orphan_retries;
	u8 sysctl_tcp_tw_reuse;
	int sysctl_tcp_fin_timeout;
	unsigned int sysctl_tcp_notsent_lowat;
	u8 sysctl_tcp_sack;
	u8 sysctl_tcp_window_scaling;
	u8 sysctl_tcp_timestamps;
	u8 sysctl_tcp_early_retrans;
	u8 sysctl_tcp_recovery;
	u8 sysctl_tcp_thin_linear_timeouts;
	u8 sysctl_tcp_slow_start_after_idle;
	u8 sysctl_tcp_retrans_collapse;
	u8 sysctl_tcp_stdurg;
	u8 sysctl_tcp_rfc1337;
	u8 sysctl_tcp_abort_on_overflow;
	u8 sysctl_tcp_fack;
	int sysctl_tcp_max_reordering;
	int sysctl_tcp_adv_win_scale;
	u8 sysctl_tcp_dsack;
	u8 sysctl_tcp_app_win;
	u8 sysctl_tcp_frto;
	u8 sysctl_tcp_nometrics_save;
	u8 sysctl_tcp_no_ssthresh_metrics_save;
	u8 sysctl_tcp_moderate_rcvbuf;
	u8 sysctl_tcp_tso_win_divisor;
	u8 sysctl_tcp_workaround_signed_windows;
	int sysctl_tcp_limit_output_bytes;
	int sysctl_tcp_challenge_ack_limit;
	int sysctl_tcp_min_rtt_wlen;
	u8 sysctl_tcp_min_tso_segs;
	u8 sysctl_tcp_autocorking;
	u8 sysctl_tcp_reflect_tos;
	u8 sysctl_tcp_comp_sack_nr;
	int sysctl_tcp_invalid_ratelimit;
	int sysctl_tcp_pacing_ss_ratio;
	int sysctl_tcp_pacing_ca_ratio;
	int sysctl_tcp_wmem[3];
	int sysctl_tcp_rmem[3];
	long unsigned int sysctl_tcp_comp_sack_delay_ns;
	long unsigned int sysctl_tcp_comp_sack_slack_ns;
	int sysctl_max_syn_backlog;
	int sysctl_tcp_fastopen;
	const struct tcp_congestion_ops *tcp_congestion_control;
	struct tcp_fastopen_context *tcp_fastopen_ctx;
	unsigned int sysctl_tcp_fastopen_blackhole_timeout;
	atomic_t tfo_active_disable_times;
	long unsigned int tfo_active_disable_stamp;
	int sysctl_udp_wmem_min;
	int sysctl_udp_rmem_min;
	u8 sysctl_fib_notify_on_flag_change;
	u8 sysctl_udp_l3mdev_accept;
	u8 sysctl_igmp_llm_reports;
	int sysctl_igmp_max_memberships;
	int sysctl_igmp_max_msf;
	int sysctl_igmp_qrv;
	struct ping_group_range ping_group_range;
	atomic_t dev_addr_genid;
	long unsigned int *sysctl_local_reserved_ports;
	int sysctl_ip_prot_sock;
	struct list_head mr_tables;
	struct fib_rules_ops___2 *mr_rules_ops;
	u32 sysctl_fib_multipath_hash_fields;
	u8 sysctl_fib_multipath_use_neigh;
	u8 sysctl_fib_multipath_hash_policy;
	struct fib_notifier_ops___2 *notifier_ops;
	unsigned int fib_seq;
	struct fib_notifier_ops___2 *ipmr_notifier_ops;
	unsigned int ipmr_seq;
	atomic_t rt_genid;
	siphash_key_t ip_id_key;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct neighbour___2;

struct dst_ops___4 {
	short unsigned int family;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___4 *);
	struct dst_entry___2 * (*check)(struct dst_entry___2 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___2 *);
	unsigned int (*mtu)(const struct dst_entry___2 *);
	u32 * (*cow_metrics)(struct dst_entry___2 *, long unsigned int);
	void (*destroy)(struct dst_entry___2 *);
	void (*ifdown)(struct dst_entry___2 *, struct net_device___3 *, int);
	struct dst_entry___2 * (*negative_advice)(struct dst_entry___2 *);
	void (*link_failure)(struct sk_buff___4 *);
	void (*update_pmtu)(struct dst_entry___2 *, struct sock___2 *, struct sk_buff___4 *, u32, bool);
	void (*redirect)(struct dst_entry___2 *, struct sock___2 *, struct sk_buff___4 *);
	int (*local_out)(struct net *, struct sock___2 *, struct sk_buff___4 *);
	struct neighbour___2 * (*neigh_lookup)(const struct dst_entry___2 *, struct sk_buff___4 *, const void *);
	void (*confirm_neigh)(const struct dst_entry___2 *, const void *);
	struct kmem_cache *kmem_cachep;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv6___4 {
	struct dst_ops___4 ip6_dst_ops;
	struct netns_sysctl_ipv6 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	struct fqdir___4 *fqdir;
	struct fib6_info *fib6_null_entry;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	struct list_head fib6_walkers;
	rwlock_t fib6_walker_lock;
	spinlock_t fib6_gc_lock;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	unsigned char flowlabel_has_excl;
	bool fib6_has_custom_rules;
	unsigned int fib6_rules_require_fldissect;
	unsigned int fib6_routes_require_src;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops___2 *fib6_rules_ops;
	struct sock___2 **icmp_sk;
	struct sock___2 *ndisc_sk;
	struct sock___2 *tcp_sk;
	struct sock___2 *igmp_sk;
	struct sock___2 *mc_autojoin_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops___2 *mr6_rules_ops;
	atomic_t dev_addr_genid;
	atomic_t fib6_sernum;
	struct seg6_pernet_data *seg6_data;
	struct fib_notifier_ops___2 *notifier_ops;
	struct fib_notifier_ops___2 *ip6mr_notifier_ops;
	unsigned int ipmr_seq;
	struct {
		struct hlist_head head;
		spinlock_t lock;
		u32 seq;
	} ip6addrlbl_table;
	struct ioam6_pernet_data *ioam6_data;
};

struct netns_ieee802154_lowpan___4 {
	struct netns_sysctl_lowpan sysctl;
	struct fqdir___4 *fqdir;
};

struct netns_sctp___2 {
	struct sctp_mib *sctp_statistics;
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header *sysctl_header;
	struct sock___2 *ctl_sock;
	struct sock___2 *udp4_sock;
	struct sock___2 *udp6_sock;
	int udp_port;
	int encap_port;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	unsigned int probe_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int ps_retrans;
	int pf_enable;
	int pf_expose;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int reconf_enable;
	int auth_enable;
	int intl_enable;
	int ecn_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct netns_bpf___3 {
	struct bpf_prog_array___3 *run_array[2];
	struct bpf_prog___3 *progs[2];
	struct list_head links[2];
};

struct netns_xfrm___4 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	struct hlist_head *state_byseq;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[3];
	struct xfrm_policy_hash policy_bydst[3];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct xfrm_policy_hthresh policy_hthresh;
	struct list_head inexact_bins;
	struct sock___2 *nlsk;
	struct sock___2 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	u8 policy_default;
	struct ctl_table_header *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___4 xfrm4_dst_ops;
	struct dst_ops___4 xfrm6_dst_ops;
	spinlock_t xfrm_state_lock;
	seqcount_spinlock_t xfrm_state_hash_generation;
	seqcount_spinlock_t xfrm_policy_hash_generation;
	spinlock_t xfrm_policy_lock;
	struct mutex xfrm_cfg_mutex;
	long: 64;
	long: 64;
};

struct net {
	refcount_t passive;
	spinlock_t rules_mod_lock;
	unsigned int dev_unreg_count;
	unsigned int dev_base_seq;
	int ifindex;
	spinlock_t nsid_lock;
	atomic_t fnhe_genid;
	struct list_head list;
	struct list_head exit_list;
	struct llist_node cleanup_list;
	struct key_tag *key_domain;
	struct user_namespace *user_ns;
	struct ucounts *ucounts;
	struct idr netns_ids;
	struct ns_common ns;
	struct list_head dev_base_head;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set sysctls;
	struct sock___2 *rtnl;
	struct sock___2 *genl_sock;
	struct uevent_sock *uevent_sock;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	struct raw_notifier_head netdev_chain;
	u32 hash_mix;
	struct net_device___3 *loopback_dev;
	struct list_head rules_ops;
	struct netns_core core;
	struct netns_mib mib;
	struct netns_packet packet;
	struct netns_unix unx;
	struct netns_nexthop nexthop;
	struct netns_ipv4___4 ipv4;
	struct netns_ipv6___4 ipv6;
	struct netns_ieee802154_lowpan___4 ieee802154_lowpan;
	struct netns_sctp___2 sctp;
	struct netns_nf nf;
	struct netns_ct ct;
	struct netns_nftables nft;
	struct sk_buff_head___3 wext_nlevents;
	struct net_generic *gen;
	struct netns_bpf___3 bpf;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_xfrm___4 xfrm;
	u64 net_cookie;
	struct netns_ipvs *ipvs;
	struct netns_mpls mpls;
	struct netns_can can;
	struct netns_xdp xdp;
	struct netns_mctp mctp;
	struct sock___2 *crypto_nlsk;
	struct sock___2 *diag_nlsk;
	struct netns_smc smc;
	long: 64;
};

struct cgroup_namespace___21 {
	struct ns_common ns;
	struct user_namespace *user_ns;
	struct ucounts *ucounts;
	struct css_set___21 *root_cset;
};

struct bpf_iter_aux_info___3;

typedef int (*bpf_iter_init_seq_priv_t___3)(void *, struct bpf_iter_aux_info___3 *);

struct bpf_map___3;

struct bpf_iter_aux_info___3 {
	struct bpf_map___3 *map;
};

struct bpf_iter_seq_info___3 {
	const struct seq_operations___25 *seq_ops;
	bpf_iter_init_seq_priv_t___3 init_seq_private;
	bpf_iter_fini_seq_priv_t fini_seq_private;
	u32 seq_priv_size;
};

struct bpf_prog_aux___3;

struct bpf_map_ops___3 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___3 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___3 *, struct file___27 *);
	void (*map_free)(struct bpf_map___3 *);
	int (*map_get_next_key)(struct bpf_map___3 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___3 *);
	void * (*map_lookup_elem_sys_only)(struct bpf_map___3 *, void *);
	int (*map_lookup_batch)(struct bpf_map___3 *, const union bpf_attr *, union bpf_attr *);
	int (*map_lookup_and_delete_elem)(struct bpf_map___3 *, void *, void *, u64);
	int (*map_lookup_and_delete_batch)(struct bpf_map___3 *, const union bpf_attr *, union bpf_attr *);
	int (*map_update_batch)(struct bpf_map___3 *, const union bpf_attr *, union bpf_attr *);
	int (*map_delete_batch)(struct bpf_map___3 *, const union bpf_attr *, union bpf_attr *);
	void * (*map_lookup_elem)(struct bpf_map___3 *, void *);
	int (*map_update_elem)(struct bpf_map___3 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___3 *, void *);
	int (*map_push_elem)(struct bpf_map___3 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___3 *, void *);
	int (*map_peek_elem)(struct bpf_map___3 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___3 *, struct file___27 *, int);
	void (*map_fd_put_ptr)(void *);
	int (*map_gen_lookup)(struct bpf_map___3 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___3 *, void *, struct seq_file___25 *);
	int (*map_check_btf)(const struct bpf_map___3 *, const struct btf *, const struct btf_type *, const struct btf_type *);
	int (*map_poke_track)(struct bpf_map___3 *, struct bpf_prog_aux___3 *);
	void (*map_poke_untrack)(struct bpf_map___3 *, struct bpf_prog_aux___3 *);
	void (*map_poke_run)(struct bpf_map___3 *, u32, struct bpf_prog___3 *, struct bpf_prog___3 *);
	int (*map_direct_value_addr)(const struct bpf_map___3 *, u64 *, u32);
	int (*map_direct_value_meta)(const struct bpf_map___3 *, u64, u32 *);
	int (*map_mmap)(struct bpf_map___3 *, struct vm_area_struct___29 *);
	__poll_t (*map_poll)(struct bpf_map___3 *, struct file___27 *, struct poll_table_struct___19 *);
	int (*map_local_storage_charge)(struct bpf_local_storage_map *, void *, u32);
	void (*map_local_storage_uncharge)(struct bpf_local_storage_map *, void *, u32);
	struct bpf_local_storage ** (*map_owner_storage_ptr)(void *);
	int (*map_redirect)(struct bpf_map___3 *, u32, u64);
	bool (*map_meta_equal)(const struct bpf_map___3 *, const struct bpf_map___3 *);
	int (*map_set_for_each_callback_args)(struct bpf_verifier_env *, struct bpf_func_state *, struct bpf_func_state *);
	int (*map_for_each_callback)(struct bpf_map___3 *, void *, void *, u64);
	const char * const map_btf_name;
	int *map_btf_id;
	const struct bpf_iter_seq_info___3 *iter_seq_info;
};

struct bpf_map___3 {
	const struct bpf_map_ops___3 *ops;
	struct bpf_map___3 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	int spin_lock_off;
	int timer_off;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	struct mem_cgroup___16 *memcg;
	char name[16];
	u32 btf_vmlinux_value_type_id;
	bool bypass_spec_v1;
	bool frozen;
	long: 16;
	long: 64;
	long: 64;
	atomic64_t refcnt;
	atomic64_t usercnt;
	struct work_struct work;
	struct mutex freeze_mutex;
	atomic64_t writecnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_trampoline___3;

struct bpf_jit_poke_descriptor___3;

struct bpf_prog_ops___3;

struct btf_mod_pair___3;

struct bpf_prog_offload___3;

struct bpf_prog_aux___3 {
	atomic64_t refcnt;
	u32 used_map_cnt;
	u32 used_btf_cnt;
	u32 max_ctx_offset;
	u32 max_pkt_offset;
	u32 max_tp_access;
	u32 stack_depth;
	u32 id;
	u32 func_cnt;
	u32 func_idx;
	u32 attach_btf_id;
	u32 ctx_arg_info_size;
	u32 max_rdonly_access;
	u32 max_rdwr_access;
	struct btf *attach_btf;
	const struct bpf_ctx_arg_aux *ctx_arg_info;
	struct mutex dst_mutex;
	struct bpf_prog___3 *dst_prog;
	struct bpf_trampoline___3 *dst_trampoline;
	enum bpf_prog_type saved_dst_prog_type;
	enum bpf_attach_type saved_dst_attach_type;
	bool verifier_zext;
	bool offload_requested;
	bool attach_btf_trace;
	bool func_proto_unreliable;
	bool sleepable;
	bool tail_call_reachable;
	struct hlist_node tramp_hlist;
	const struct btf_type *attach_func_proto;
	const char *attach_func_name;
	struct bpf_prog___3 **func;
	void *jit_data;
	struct bpf_jit_poke_descriptor___3 *poke_tab;
	struct bpf_kfunc_desc_tab *kfunc_tab;
	u32 size_poke_tab;
	struct bpf_ksym ksym;
	const struct bpf_prog_ops___3 *ops;
	struct bpf_map___3 **used_maps;
	struct mutex used_maps_mutex;
	struct btf_mod_pair___3 *used_btfs;
	struct bpf_prog___3 *prog;
	struct user_struct *user;
	u64 load_time;
	struct bpf_map___3 *cgroup_storage[2];
	char name[16];
	void *security;
	struct bpf_prog_offload___3 *offload;
	struct btf *btf;
	struct bpf_func_info *func_info;
	struct bpf_func_info_aux *func_info_aux;
	struct bpf_line_info *linfo;
	void **jited_linfo;
	u32 func_info_cnt;
	u32 nr_linfo;
	u32 linfo_idx;
	u32 num_exentries;
	struct exception_table_entry *extable;
	union {
		struct work_struct work;
		struct callback_head rcu;
	};
};

struct bpf_prog___3 {
	u16 pages;
	u16 jited: 1;
	u16 jit_requested: 1;
	u16 gpl_compatible: 1;
	u16 cb_access: 1;
	u16 dst_needed: 1;
	u16 blinded: 1;
	u16 is_func: 1;
	u16 kprobe_override: 1;
	u16 has_callchain_buf: 1;
	u16 enforce_expected_attach_type: 1;
	u16 call_get_stack: 1;
	u16 call_get_func_ip: 1;
	enum bpf_prog_type type;
	enum bpf_attach_type expected_attach_type;
	u32 len;
	u32 jited_len;
	u8 tag[8];
	struct bpf_prog_stats *stats;
	int *active;
	unsigned int (*bpf_func)(const void *, const struct bpf_insn *);
	struct bpf_prog_aux___3 *aux;
	struct sock_fprog_kern *orig_prog;
	struct sock_filter insns[0];
	struct bpf_insn insnsi[0];
};

struct bpf_offloaded_map___3;

struct bpf_map_dev_ops___3 {
	int (*map_get_next_key)(struct bpf_offloaded_map___3 *, void *, void *);
	int (*map_lookup_elem)(struct bpf_offloaded_map___3 *, void *, void *);
	int (*map_update_elem)(struct bpf_offloaded_map___3 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_offloaded_map___3 *, void *);
};

struct bpf_offloaded_map___3 {
	struct bpf_map___3 map;
	struct net_device___3 *netdev;
	const struct bpf_map_dev_ops___3 *dev_ops;
	void *dev_priv;
	struct list_head offloads;
	long: 64;
	long: 64;
	long: 64;
};

typedef rx_handler_result_t rx_handler_func_t___3(struct sk_buff___4 **);

struct bpf_xdp_entity___3 {
	struct bpf_prog___3 *prog;
	struct bpf_xdp_link *link;
};

struct netdev_name_node___3;

struct net_device_ops___3;

struct l3mdev_ops___3;

struct ndisc_ops___3;

struct xfrmdev_ops___3;

struct header_ops___3;

struct inet6_dev___3;

struct netdev_rx_queue___3;

struct mini_Qdisc___3;

struct netdev_queue___3;

struct Qdisc___3;

struct rtnl_link_ops___3;

struct dcbnl_rtnl_ops___3;

struct net_device___3 {
	char name[16];
	struct netdev_name_node___3 *name_node;
	struct dev_ifalias *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head close_list;
	struct list_head ptype_all;
	struct list_head ptype_specific;
	struct {
		struct list_head upper;
		struct list_head lower;
	} adj_list;
	unsigned int flags;
	unsigned int priv_flags;
	const struct net_device_ops___3 *netdev_ops;
	int ifindex;
	short unsigned int gflags;
	short unsigned int hard_header_len;
	unsigned int mtu;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	netdev_features_t gso_partial_features;
	unsigned int min_mtu;
	unsigned int max_mtu;
	short unsigned int type;
	unsigned char min_header_len;
	unsigned char name_assign_type;
	int group;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	atomic_long_t tx_dropped;
	atomic_long_t rx_nohandler;
	atomic_t carrier_up_count;
	atomic_t carrier_down_count;
	const struct iw_handler_def *wireless_handlers;
	struct iw_public_data *wireless_data;
	const struct ethtool_ops *ethtool_ops;
	const struct l3mdev_ops___3 *l3mdev_ops;
	const struct ndisc_ops___3 *ndisc_ops;
	const struct xfrmdev_ops___3 *xfrmdev_ops;
	const struct tlsdev_ops *tlsdev_ops;
	const struct header_ops___3 *header_ops;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	unsigned char upper_level;
	unsigned char lower_level;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	short unsigned int padded;
	spinlock_t addr_list_lock;
	int irq;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___26 *queues_kset;
	unsigned int promiscuity;
	unsigned int allmulti;
	bool uc_promisc;
	struct vlan_info *vlan_info;
	struct dsa_port *dsa_ptr;
	struct tipc_bearer *tipc_ptr;
	void *atalk_ptr;
	struct in_device *ip_ptr;
	struct dn_dev *dn_ptr;
	struct inet6_dev___3 *ip6_ptr;
	void *ax25_ptr;
	struct wireless_dev *ieee80211_ptr;
	struct wpan_dev *ieee802154_ptr;
	struct mpls_dev *mpls_ptr;
	struct mctp_dev *mctp_ptr;
	unsigned char *dev_addr;
	struct netdev_rx_queue___3 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	struct bpf_prog___3 *xdp_prog;
	long unsigned int gro_flush_timeout;
	int napi_defer_hard_irqs;
	rx_handler_func_t___3 *rx_handler;
	void *rx_handler_data;
	struct mini_Qdisc___3 *miniq_ingress;
	struct netdev_queue___3 *ingress_queue;
	struct nf_hook_entries *nf_hooks_ingress;
	unsigned char broadcast[32];
	struct cpu_rmap *rx_cpu_rmap;
	struct hlist_node index_hlist;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___3 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc___3 *qdisc;
	unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	struct xdp_dev_bulk_queue *xdp_bulkq;
	struct xps_dev_maps *xps_maps[2];
	struct mini_Qdisc___3 *miniq_egress;
	struct hlist_head qdisc_hash[16];
	struct timer_list watchdog_timer;
	int watchdog_timeo;
	u32 proto_down_reason;
	struct list_head todo_list;
	int *pcpu_refcnt;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___3 = 0,
		NETREG_REGISTERED___3 = 1,
		NETREG_UNREGISTERING___3 = 2,
		NETREG_UNREGISTERED___3 = 3,
		NETREG_RELEASED___3 = 4,
		NETREG_DUMMY___3 = 5,
	} reg_state: 8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___3 = 0,
		RTNL_LINK_INITIALIZING___3 = 1,
	} rtnl_link_state: 16;
	long: 16;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	bool needs_free_netdev;
	void (*priv_destructor)(struct net_device___3 *);
	struct netpoll_info *npinfo;
	possible_net_t___3 nd_net;
	void *ml_priv;
	enum netdev_ml_priv_type ml_priv_type;
	union {
		struct pcpu_lstats *lstats;
		struct pcpu_sw_netstats *tstats;
		struct pcpu_dstats *dstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___29 dev;
	const struct attribute_group___27 *sysfs_groups[4];
	const struct attribute_group___27 *sysfs_rx_queue_group;
	const struct rtnl_link_ops___3 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___3 *dcbnl_ops;
	s16 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	unsigned int fcoe_ddp_xid;
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct sfp_bus *sfp_bus;
	struct lock_class_key *qdisc_tx_busylock;
	struct lock_class_key *qdisc_running_key;
	bool proto_down;
	unsigned int wol_enabled: 1;
	unsigned int threaded: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct list_head net_notifier_list;
	const struct macsec_ops *macsec_ops;
	const struct udp_tunnel_nic_info *udp_tunnel_nic_info;
	struct udp_tunnel_nic *udp_tunnel_nic;
	struct bpf_xdp_entity___3 xdp_state[3];
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_prog_ops___3 {
	int (*test_run)(struct bpf_prog___3 *, const union bpf_attr *, union bpf_attr *);
};

struct bpf_prog_offload___3 {
	struct bpf_prog___3 *prog;
	struct net_device___3 *netdev;
	struct bpf_offload_dev *offdev;
	void *dev_priv;
	struct list_head offloads;
	bool dev_state;
	bool opt_failed;
	void *jited_image;
	u32 jited_len;
};

struct bpf_trampoline___3 {
	struct hlist_node hlist;
	struct mutex mutex;
	refcount_t refcnt;
	u64 key;
	struct {
		struct btf_func_model model;
		void *addr;
		bool ftrace_managed;
	} func;
	struct bpf_prog___3 *extension_prog;
	struct hlist_head progs_hlist[3];
	int progs_cnt[3];
	struct bpf_tramp_image *cur_image;
	u64 selector;
	struct module___26 *mod;
};

struct bpf_jit_poke_descriptor___3 {
	void *tailcall_target;
	void *tailcall_bypass;
	void *bypass_addr;
	void *aux;
	union {
		struct {
			struct bpf_map___3 *map;
			u32 key;
		} tail_call;
	};
	bool tailcall_target_stable;
	u8 adj_off;
	u16 reason;
	u32 insn_idx;
};

struct btf_mod_pair___3 {
	struct btf *btf;
	struct module___26 *module;
};

struct bpf_prog_array_item___3 {
	struct bpf_prog___3 *prog;
	union {
		struct bpf_cgroup_storage *cgroup_storage[2];
		u64 bpf_cookie;
	};
};

struct bpf_prog_array___3 {
	struct callback_head rcu;
	struct bpf_prog_array_item___3 items[0];
};

struct sk_buff___4 {
	union {
		struct {
			struct sk_buff___4 *next;
			struct sk_buff___4 *prev;
			union {
				struct net_device___3 *dev;
				long unsigned int dev_scratch;
			};
		};
		struct rb_node rbnode;
		struct list_head list;
	};
	union {
		struct sock___2 *sk;
		int ip_defrag_offset;
	};
	union {
		ktime_t tstamp;
		u64 skb_mstamp_ns;
	};
	char cb[48];
	union {
		struct {
			long unsigned int _skb_refdst;
			void (*destructor)(struct sk_buff___4 *);
		};
		struct list_head tcp_tsorted_anchor;
		long unsigned int _sk_redir;
	};
	long unsigned int _nfct;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	__u16 queue_mapping;
	__u8 __cloned_offset[0];
	__u8 cloned: 1;
	__u8 nohdr: 1;
	__u8 fclone: 2;
	__u8 peeked: 1;
	__u8 head_frag: 1;
	__u8 pfmemalloc: 1;
	__u8 pp_recycle: 1;
	long: 55;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 active_extensions;
	__u32 headers_start[0];
	__u8 __pkt_type_offset[0];
	__u8 pkt_type: 3;
	__u8 ignore_df: 1;
	__u8 nf_trace: 1;
	__u8 ip_summed: 2;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 sw_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	long: 15;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 __pkt_vlan_present_offset[0];
	__u8 vlan_present: 1;
	__u8 csum_complete_sw: 1;
	__u8 csum_level: 2;
	__u8 csum_not_inet: 1;
	__u8 dst_pending_confirm: 1;
	__u8 ndisc_nodetype: 2;
	__u8 ipvs_property: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	__u8 offload_fwd_mark: 1;
	__u8 offload_l3_fwd_mark: 1;
	__u8 tc_skip_classify: 1;
	__u8 tc_at_ingress: 1;
	__u8 redirected: 1;
	__u8 from_ingress: 1;
	__u8 decrypted: 1;
	__u8 slow_gro: 1;
	long: 47;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u16 tc_index;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	int skb_iif;
	__u32 hash;
	__be16 vlan_proto;
	__u16 vlan_tci;
	union {
		unsigned int napi_id;
		unsigned int sender_cpu;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__be16 protocol;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	__u32 headers_end[0];
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	refcount_t users;
	struct skb_ext *extensions;
};

struct cftype___21;

struct cgroup_subsys___21 {
	struct cgroup_subsys_state___21 * (*css_alloc)(struct cgroup_subsys_state___21 *);
	int (*css_online)(struct cgroup_subsys_state___21 *);
	void (*css_offline)(struct cgroup_subsys_state___21 *);
	void (*css_released)(struct cgroup_subsys_state___21 *);
	void (*css_free)(struct cgroup_subsys_state___21 *);
	void (*css_reset)(struct cgroup_subsys_state___21 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___21 *, int);
	int (*css_extra_stat_show)(struct seq_file___25 *, struct cgroup_subsys_state___21 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___30 *, struct css_set___21 *);
	void (*cancel_fork)(struct task_struct___30 *, struct css_set___21 *);
	void (*fork)(struct task_struct___30 *);
	void (*exit)(struct task_struct___30 *);
	void (*release)(struct task_struct___30 *);
	void (*bind)(struct cgroup_subsys_state___21 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___21 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___21 *dfl_cftypes;
	struct cftype___21 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___21 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___21 *updated_children;
	struct cgroup___21 *updated_next;
};

struct cgroup_root___21 {
	struct kernfs_root___27 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___21 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___21 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___21 *ss;
	struct list_head node;
	struct kernfs_ops___27 *kf_ops;
	int (*open)(struct kernfs_open_file___27 *);
	void (*release)(struct kernfs_open_file___27 *);
	u64 (*read_u64)(struct cgroup_subsys_state___21 *, struct cftype___21 *);
	s64 (*read_s64)(struct cgroup_subsys_state___21 *, struct cftype___21 *);
	int (*seq_show)(struct seq_file___25 *, void *);
	void * (*seq_start)(struct seq_file___25 *, loff_t *);
	void * (*seq_next)(struct seq_file___25 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___25 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___21 *, struct cftype___21 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___21 *, struct cftype___21 *, s64);
	ssize_t (*write)(struct kernfs_open_file___27 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___27 *, struct poll_table_struct___19 *);
};

struct dev_pm_ops___29 {
	int (*prepare)(struct device___29 *);
	void (*complete)(struct device___29 *);
	int (*suspend)(struct device___29 *);
	int (*resume)(struct device___29 *);
	int (*freeze)(struct device___29 *);
	int (*thaw)(struct device___29 *);
	int (*poweroff)(struct device___29 *);
	int (*restore)(struct device___29 *);
	int (*suspend_late)(struct device___29 *);
	int (*resume_early)(struct device___29 *);
	int (*freeze_late)(struct device___29 *);
	int (*thaw_early)(struct device___29 *);
	int (*poweroff_late)(struct device___29 *);
	int (*restore_early)(struct device___29 *);
	int (*suspend_noirq)(struct device___29 *);
	int (*resume_noirq)(struct device___29 *);
	int (*freeze_noirq)(struct device___29 *);
	int (*thaw_noirq)(struct device___29 *);
	int (*poweroff_noirq)(struct device___29 *);
	int (*restore_noirq)(struct device___29 *);
	int (*runtime_suspend)(struct device___29 *);
	int (*runtime_resume)(struct device___29 *);
	int (*runtime_idle)(struct device___29 *);
};

struct wakeup_source___29 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___29 *dev;
	bool active;
	bool autosleep_enabled;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___29 {
	struct dev_pm_ops___29 ops;
	int (*start)(struct device___29 *);
	void (*detach)(struct device___29 *, bool);
	int (*activate)(struct device___29 *);
	void (*sync)(struct device___29 *);
	void (*dismiss)(struct device___29 *);
};

struct bus_type___29 {
	const char *name;
	const char *dev_name;
	struct device___29 *dev_root;
	const struct attribute_group___27 **bus_groups;
	const struct attribute_group___27 **dev_groups;
	const struct attribute_group___27 **drv_groups;
	int (*match)(struct device___29 *, struct device_driver___29 *);
	int (*uevent)(struct device___29 *, struct kobj_uevent_env *);
	int (*probe)(struct device___29 *);
	void (*sync_state)(struct device___29 *);
	void (*remove)(struct device___29 *);
	void (*shutdown)(struct device___29 *);
	int (*online)(struct device___29 *);
	int (*offline)(struct device___29 *);
	int (*suspend)(struct device___29 *, pm_message_t);
	int (*resume)(struct device___29 *);
	int (*num_vf)(struct device___29 *);
	int (*dma_configure)(struct device___29 *);
	const struct dev_pm_ops___29 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___29 {
	const char *name;
	struct bus_type___29 *bus;
	struct module___26 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___29 *);
	void (*sync_state)(struct device___29 *);
	int (*remove)(struct device___29 *);
	void (*shutdown)(struct device___29 *);
	int (*suspend)(struct device___29 *, pm_message_t);
	int (*resume)(struct device___29 *);
	const struct attribute_group___27 **groups;
	const struct attribute_group___27 **dev_groups;
	const struct dev_pm_ops___29 *pm;
	void (*coredump)(struct device___29 *);
	struct driver_private *p;
};

struct device_type___29 {
	const char *name;
	const struct attribute_group___27 **groups;
	int (*uevent)(struct device___29 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___29 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___29 *);
	const struct dev_pm_ops___29 *pm;
};

struct class___29 {
	const char *name;
	struct module___26 *owner;
	const struct attribute_group___27 **class_groups;
	const struct attribute_group___27 **dev_groups;
	struct kobject___27 *dev_kobj;
	int (*dev_uevent)(struct device___29 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___29 *, umode_t *);
	void (*class_release)(struct class___29 *);
	void (*dev_release)(struct device___29 *);
	int (*shutdown_pre)(struct device___29 *);
	const struct kobj_ns_type_operations___2 *ns_type;
	const void * (*namespace)(struct device___29 *);
	void (*get_ownership)(struct device___29 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___29 *pm;
	struct subsys_private *p;
};

struct fwnode_operations___26;

struct fwnode_handle___26 {
	struct fwnode_handle___26 *secondary;
	const struct fwnode_operations___26 *ops;
	struct device___29 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct device_node___17 {
	const char *name;
	phandle phandle;
	const char *full_name;
	struct fwnode_handle___26 fwnode;
	struct property *properties;
	struct property *deadprops;
	struct device_node___17 *parent;
	struct device_node___17 *child;
	struct device_node___17 *sibling;
	long unsigned int _flags;
	void *data;
};

struct block_device_operations___17;

struct gendisk___17 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	short unsigned int events;
	short unsigned int event_flags;
	struct xarray part_tbl;
	struct block_device___17 *part0;
	const struct block_device_operations___17 *fops;
	struct request_queue___17 *queue;
	void *private_data;
	int flags;
	long unsigned int state;
	struct mutex open_mutex;
	unsigned int open_partitions;
	struct backing_dev_info___16 *bdi;
	struct kobject___27 *slave_dir;
	struct list_head slave_bdevs;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___27 integrity_kobj;
	struct cdrom_device_info *cdi;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	u64 diskseq;
};

struct bio_integrity_payload___17 {
	struct bio___17 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___21 *bip_vec;
	struct bio_vec___21 bip_inline_vecs[0];
};

struct blkcg___16;

struct blkg_policy_data___16;

struct blkcg_gq___16 {
	struct request_queue___17 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___16 *blkcg;
	struct blkcg_gq___16 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_iostat_set *iostat_cpu;
	struct blkg_iostat_set iostat;
	struct blkg_policy_data___16 *pd[6];
	spinlock_t async_bio_lock;
	struct bio_list___17 async_bios;
	struct work_struct async_bio_work;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
	struct callback_head callback_head;
};

typedef void integrity_prepare_fn___17(struct request___17 *);

typedef void integrity_complete_fn___17(struct request___17 *, unsigned int);

struct blk_integrity_profile___17 {
	integrity_processing_fn *generate_fn;
	integrity_processing_fn *verify_fn;
	integrity_prepare_fn___17 *prepare_fn;
	integrity_complete_fn___17 *complete_fn;
	const char *name;
};

struct block_device_operations___17 {
	blk_qc_t (*submit_bio)(struct bio___17 *);
	int (*open)(struct block_device___17 *, fmode_t);
	void (*release)(struct gendisk___17 *, fmode_t);
	int (*rw_page)(struct block_device___17 *, sector_t, struct page___28 *, unsigned int);
	int (*ioctl)(struct block_device___17 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___17 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___17 *, unsigned int);
	void (*unlock_native_capacity)(struct gendisk___17 *);
	int (*getgeo)(struct block_device___17 *, struct hd_geometry *);
	int (*set_read_only)(struct block_device___17 *, bool);
	void (*swap_slot_free_notify)(struct block_device___17 *, long unsigned int);
	int (*report_zones)(struct gendisk___17 *, sector_t, unsigned int, report_zones_cb, void *);
	char * (*devnode)(struct gendisk___17 *, umode_t *);
	struct module___26 *owner;
	const struct pr_ops *pr_ops;
	int (*alternative_gpt_sector)(struct gendisk___17 *, sector_t *);
};

struct fwnode_reference_args___26;

struct fwnode_endpoint___26;

struct fwnode_operations___26 {
	struct fwnode_handle___26 * (*get)(struct fwnode_handle___26 *);
	void (*put)(struct fwnode_handle___26 *);
	bool (*device_is_available)(const struct fwnode_handle___26 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___26 *, const struct device___29 *);
	bool (*property_present)(const struct fwnode_handle___26 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___26 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___26 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___26 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___26 *);
	struct fwnode_handle___26 * (*get_parent)(const struct fwnode_handle___26 *);
	struct fwnode_handle___26 * (*get_next_child_node)(const struct fwnode_handle___26 *, struct fwnode_handle___26 *);
	struct fwnode_handle___26 * (*get_named_child_node)(const struct fwnode_handle___26 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___26 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___26 *);
	struct fwnode_handle___26 * (*graph_get_next_endpoint)(const struct fwnode_handle___26 *, struct fwnode_handle___26 *);
	struct fwnode_handle___26 * (*graph_get_remote_endpoint)(const struct fwnode_handle___26 *);
	struct fwnode_handle___26 * (*graph_get_port_parent)(struct fwnode_handle___26 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___26 *, struct fwnode_endpoint___26 *);
	int (*add_links)(struct fwnode_handle___26 *);
};

struct fwnode_endpoint___26 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___26 *local_fwnode;
};

struct fwnode_reference_args___26 {
	struct fwnode_handle___26 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

typedef void rq_end_io_fn___17(struct request___17 *, blk_status_t);

struct request___17 {
	struct request_queue___17 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int tag;
	int internal_tag;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___17 *bio;
	struct bio___17 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct llist_node ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___21 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___17 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___17 *saved_end_io;
		} flush;
	};
	struct gendisk___17 *rq_disk;
	struct block_device___17 *part;
	u64 alloc_time_ns;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int stats_sectors;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	struct bio_crypt_ctx *crypt_ctx;
	struct blk_ksm_keyslot *crypt_keyslot;
	short unsigned int write_hint;
	short unsigned int ioprio;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___17 *end_io;
	void *end_io_data;
};

struct elevator_type___17;

struct elevator_mq_ops___17 {
	int (*init_sched)(struct request_queue___17 *, struct elevator_type___17 *);
	void (*exit_sched)(struct elevator_queue___17 *);
	int (*init_hctx)(struct blk_mq_hw_ctx *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx *, unsigned int);
	void (*depth_updated)(struct blk_mq_hw_ctx *);
	bool (*allow_merge)(struct request_queue___17 *, struct request___17 *, struct bio___17 *);
	bool (*bio_merge)(struct request_queue___17 *, struct bio___17 *, unsigned int);
	int (*request_merge)(struct request_queue___17 *, struct request___17 **, struct bio___17 *);
	void (*request_merged)(struct request_queue___17 *, struct request___17 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___17 *, struct request___17 *, struct request___17 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___17 *);
	void (*finish_request)(struct request___17 *);
	void (*insert_requests)(struct blk_mq_hw_ctx *, struct list_head *, bool);
	struct request___17 * (*dispatch_request)(struct blk_mq_hw_ctx *);
	bool (*has_work)(struct blk_mq_hw_ctx *);
	void (*completed_request)(struct request___17 *, u64);
	void (*requeue_request)(struct request___17 *);
	struct request___17 * (*former_request)(struct request_queue___17 *, struct request___17 *);
	struct request___17 * (*next_request)(struct request_queue___17 *, struct request___17 *);
	void (*init_icq)(struct io_cq___17 *);
	void (*exit_icq)(struct io_cq___17 *);
};

struct elv_fs_entry___17;

struct elevator_type___17 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___17 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___17 *elevator_attrs;
	const char *elevator_name;
	const char *elevator_alias;
	const unsigned int elevator_features;
	struct module___26 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
};

struct elevator_queue___17 {
	struct elevator_type___17 *type;
	void *elevator_data;
	struct kobject___27 kobj;
	struct mutex sysfs_lock;
	unsigned int registered;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hlist_head hash[64];
};

struct elv_fs_entry___17 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___17 *, char *);
	ssize_t (*store)(struct elevator_queue___17 *, const char *, size_t);
};

struct blkcg_policy_data___16;

struct blkcg___16 {
	struct cgroup_subsys_state___21 css;
	spinlock_t lock;
	refcount_t online_pin;
	struct xarray blkg_tree;
	struct blkcg_gq___16 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___16 *cpd[6];
	struct list_head all_blkcgs_node;
	char fc_app_id[129];
	struct list_head cgwb_list;
};

struct blkcg_policy_data___16 {
	struct blkcg___16 *blkcg;
	int plid;
};

struct blkg_policy_data___16 {
	struct blkcg_gq___16 *blkg;
	int plid;
};

struct mem_cgroup_reclaim_iter___16 {
	struct mem_cgroup___16 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___16 {
	struct lruvec___17 lruvec;
	struct lruvec_stats_percpu *lruvec_stats_percpu;
	struct lruvec_stats lruvec_stats;
	long unsigned int lru_zone_size[25];
	struct mem_cgroup_reclaim_iter___16 iter;
	struct shrinker_info *shrinker_info;
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	struct mem_cgroup___16 *memcg;
};

struct obj_cgroup___16 {
	struct percpu_ref refcnt;
	struct mem_cgroup___16 *memcg;
	atomic_t nr_charged_bytes;
	union {
		struct list_head list;
		struct callback_head rcu;
	};
};

struct msghdr___2 {
	void *msg_name;
	int msg_namelen;
	struct iov_iter___21 msg_iter;
	union {
		void *msg_control;
		void *msg_control_user;
	};
	bool msg_control_is_user;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__kernel_size_t msg_controllen;
	unsigned int msg_flags;
	struct kiocb___27 *msg_iocb;
};

struct socket_wq___2 {
	wait_queue_head_t wait;
	struct fasync_struct___27 *fasync_list;
	long unsigned int flags;
	struct callback_head rcu;
	long: 64;
};

struct proto_ops___2;

struct socket___2 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct file___27 *file;
	struct sock___2 *sk;
	const struct proto_ops___2 *ops;
	long: 64;
	long: 64;
	long: 64;
	struct socket_wq___2 wq;
};

typedef int (*sk_read_actor_t___2)(read_descriptor_t *, struct sk_buff___4 *, unsigned int, size_t);

struct proto_ops___2 {
	int family;
	struct module___26 *owner;
	int (*release)(struct socket___2 *);
	int (*bind)(struct socket___2 *, struct sockaddr *, int);
	int (*connect)(struct socket___2 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___2 *, struct socket___2 *);
	int (*accept)(struct socket___2 *, struct socket___2 *, int, bool);
	int (*getname)(struct socket___2 *, struct sockaddr *, int);
	__poll_t (*poll)(struct file___27 *, struct socket___2 *, struct poll_table_struct___19 *);
	int (*ioctl)(struct socket___2 *, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct socket___2 *, unsigned int, long unsigned int);
	int (*gettstamp)(struct socket___2 *, void *, bool, bool);
	int (*listen)(struct socket___2 *, int);
	int (*shutdown)(struct socket___2 *, int);
	int (*setsockopt)(struct socket___2 *, int, int, sockptr_t, unsigned int);
	int (*getsockopt)(struct socket___2 *, int, int, char *, int *);
	void (*show_fdinfo)(struct seq_file___25 *, struct socket___2 *);
	int (*sendmsg)(struct socket___2 *, struct msghdr___2 *, size_t);
	int (*recvmsg)(struct socket___2 *, struct msghdr___2 *, size_t, int);
	int (*mmap)(struct file___27 *, struct socket___2 *, struct vm_area_struct___29 *);
	ssize_t (*sendpage)(struct socket___2 *, struct page___28 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___2 *, loff_t *, struct pipe_inode_info___8 *, size_t, unsigned int);
	int (*set_peek_off)(struct sock___2 *, int);
	int (*peek_len)(struct socket___2 *);
	int (*read_sock)(struct sock___2 *, read_descriptor_t *, sk_read_actor_t___2);
	int (*sendpage_locked)(struct sock___2 *, struct page___28 *, int, size_t, int);
	int (*sendmsg_locked)(struct sock___2 *, struct msghdr___2 *, size_t);
	int (*set_rcvlowat)(struct sock___2 *, int);
};

struct perf_cpu_context___16;

struct perf_output_handle___16;

struct pmu___16 {
	struct list_head entry;
	struct module___26 *module;
	struct device___29 *dev;
	const struct attribute_group___27 **attr_groups;
	const struct attribute_group___27 **attr_update;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___16 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___16 *);
	void (*pmu_disable)(struct pmu___16 *);
	int (*event_init)(struct perf_event___16 *);
	void (*event_mapped)(struct perf_event___16 *, struct mm_struct___29 *);
	void (*event_unmapped)(struct perf_event___16 *, struct mm_struct___29 *);
	int (*add)(struct perf_event___16 *, int);
	void (*del)(struct perf_event___16 *, int);
	void (*start)(struct perf_event___16 *, int);
	void (*stop)(struct perf_event___16 *, int);
	void (*read)(struct perf_event___16 *);
	void (*start_txn)(struct pmu___16 *, unsigned int);
	int (*commit_txn)(struct pmu___16 *);
	void (*cancel_txn)(struct pmu___16 *);
	int (*event_idx)(struct perf_event___16 *);
	void (*sched_task)(struct perf_event_context___16 *, bool);
	struct kmem_cache *task_ctx_cache;
	void (*swap_task_ctx)(struct perf_event_context___16 *, struct perf_event_context___16 *);
	void * (*setup_aux)(struct perf_event___16 *, void **, int, bool);
	void (*free_aux)(void *);
	long int (*snapshot_aux)(struct perf_event___16 *, struct perf_output_handle___16 *, long unsigned int);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___16 *);
	int (*aux_output_match)(struct perf_event___16 *);
	int (*filter_match)(struct perf_event___16 *);
	int (*check_period)(struct perf_event___16 *, u64);
};

struct perf_cpu_context___16 {
	struct perf_event_context___16 ctx;
	struct perf_event_context___16 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___16 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
	int heap_size;
	struct perf_event___16 **heap;
	struct perf_event___16 *heap_default[2];
};

struct perf_output_handle___16 {
	struct perf_event___16 *event;
	struct perf_buffer *rb;
	long unsigned int wakeup;
	long unsigned int size;
	u64 aux_flags;
	union {
		void *addr;
		long unsigned int head;
	};
	int page;
};

struct perf_cgroup___16 {
	struct cgroup_subsys_state___21 css;
	struct perf_cgroup_info *info;
};

struct trace_event_fields___16 {
	const char *type;
	union {
		struct {
			const char *name;
			const int size;
			const int align;
			const int is_signed;
			const int filter_type;
		};
		int (*define_fields)(struct trace_event_call___16 *);
	};
};

struct trace_event_class___16 {
	const char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct trace_event_call___16 *, enum trace_reg, void *);
	struct trace_event_fields___16 *fields_array;
	struct list_head * (*get_fields)(struct trace_event_call___16 *);
	struct list_head fields;
	int (*raw_init)(struct trace_event_call___16 *);
};

struct inet_frags___4;

struct fqdir___4 {
	long int high_thresh;
	long int low_thresh;
	int timeout;
	int max_dist;
	struct inet_frags___4 *f;
	struct net *net;
	bool dead;
	long: 56;
	long: 64;
	long: 64;
	struct rhashtable rhashtable;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	atomic_long_t mem;
	struct work_struct destroy_work;
	struct llist_node free_list;
	long: 64;
	long: 64;
};

struct inet_frag_queue___4;

struct inet_frags___4 {
	unsigned int qsize;
	void (*constructor)(struct inet_frag_queue___4 *, const void *);
	void (*destructor)(struct inet_frag_queue___4 *);
	void (*frag_expire)(struct timer_list *);
	struct kmem_cache *frags_cachep;
	const char *frags_cache_name;
	struct rhashtable_params rhash_params;
	refcount_t refcnt;
	struct completion completion;
};

struct inet_frag_queue___4 {
	struct rhash_head node;
	union {
		struct frag_v4_compare_key v4;
		struct frag_v6_compare_key v6;
	} key;
	struct timer_list timer;
	spinlock_t lock;
	refcount_t refcnt;
	struct rb_root rb_fragments;
	struct sk_buff___4 *fragments_tail;
	struct sk_buff___4 *last_run_head;
	ktime_t stamp;
	int len;
	int meat;
	__u8 flags;
	u16 max_size;
	struct fqdir___4 *fqdir;
	struct callback_head rcu;
};

struct fib_rule___2;

struct fib_lookup_arg___2;

struct fib_rules_ops___2 {
	int family;
	struct list_head list;
	int rule_size;
	int addr_size;
	int unresolved_rules;
	int nr_goto_rules;
	unsigned int fib_rules_seq;
	int (*action)(struct fib_rule___2 *, struct flowi *, int, struct fib_lookup_arg___2 *);
	bool (*suppress)(struct fib_rule___2 *, int, struct fib_lookup_arg___2 *);
	int (*match)(struct fib_rule___2 *, struct flowi *, int);
	int (*configure)(struct fib_rule___2 *, struct sk_buff___4 *, struct fib_rule_hdr *, struct nlattr **, struct netlink_ext_ack *);
	int (*delete)(struct fib_rule___2 *);
	int (*compare)(struct fib_rule___2 *, struct fib_rule_hdr *, struct nlattr **);
	int (*fill)(struct fib_rule___2 *, struct sk_buff___4 *, struct fib_rule_hdr *);
	size_t (*nlmsg_payload)(struct fib_rule___2 *);
	void (*flush_cache)(struct fib_rules_ops___2 *);
	int nlgroup;
	const struct nla_policy *policy;
	struct list_head rules_list;
	struct module___26 *owner;
	struct net *fro_net;
	struct callback_head rcu;
};

struct fib_notifier_ops___2 {
	int family;
	struct list_head list;
	unsigned int (*fib_seq_read)(struct net *);
	int (*fib_dump)(struct net *, struct notifier_block *, struct netlink_ext_ack *);
	struct module___26 *owner;
	struct callback_head rcu;
};

struct dst_entry___2 {
	struct net_device___3 *dev;
	struct dst_ops___4 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct xfrm_state *xfrm;
	int (*input)(struct sk_buff___4 *);
	int (*output)(struct net *, struct sock___2 *, struct sk_buff___4 *);
	short unsigned int flags;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	struct lwtunnel_state *lwtstate;
	struct callback_head callback_head;
	short int error;
	short int __pad;
	__u32 tclassid;
};

struct neigh_table___2;

struct neigh_parms___3;

struct neigh_ops___2;

struct neighbour___2 {
	struct neighbour___2 *next;
	struct neigh_table___2 *tbl;
	struct neigh_parms___3 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	refcount_t refcnt;
	unsigned int arp_queue_len_bytes;
	struct sk_buff_head___3 arp_queue;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	u8 protocol;
	seqlock_t ha_lock;
	int: 32;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___2 *, struct sk_buff___4 *);
	const struct neigh_ops___2 *ops;
	struct list_head gc_list;
	struct callback_head rcu;
	struct net_device___3 *dev;
	u8 primary_key[0];
};

struct pipe_buf_operations___8;

struct pipe_buffer___8 {
	struct page___28 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___8 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___8 {
	int (*confirm)(struct pipe_inode_info___8 *, struct pipe_buffer___8 *);
	void (*release)(struct pipe_inode_info___8 *, struct pipe_buffer___8 *);
	bool (*try_steal)(struct pipe_inode_info___8 *, struct pipe_buffer___8 *);
	bool (*get)(struct pipe_inode_info___8 *, struct pipe_buffer___8 *);
};

struct dcbnl_rtnl_ops___3 {
	int (*ieee_getets)(struct net_device___3 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___3 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___3 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___3 *, struct ieee_maxrate *);
	int (*ieee_getqcn)(struct net_device___3 *, struct ieee_qcn *);
	int (*ieee_setqcn)(struct net_device___3 *, struct ieee_qcn *);
	int (*ieee_getqcnstats)(struct net_device___3 *, struct ieee_qcn_stats *);
	int (*ieee_getpfc)(struct net_device___3 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___3 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___3 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___3 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___3 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___3 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___3 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___3 *);
	u8 (*setstate)(struct net_device___3 *, u8);
	void (*getpermhwaddr)(struct net_device___3 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___3 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___3 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___3 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___3 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___3 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___3 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___3 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___3 *, int, u8 *);
	void (*setpfccfg)(struct net_device___3 *, int, u8);
	void (*getpfccfg)(struct net_device___3 *, int, u8 *);
	u8 (*setall)(struct net_device___3 *);
	u8 (*getcap)(struct net_device___3 *, int, u8 *);
	int (*getnumtcs)(struct net_device___3 *, int, u8 *);
	int (*setnumtcs)(struct net_device___3 *, int, u8);
	u8 (*getpfcstate)(struct net_device___3 *);
	void (*setpfcstate)(struct net_device___3 *, u8);
	void (*getbcncfg)(struct net_device___3 *, int, u32 *);
	void (*setbcncfg)(struct net_device___3 *, int, u32);
	void (*getbcnrp)(struct net_device___3 *, int, u8 *);
	void (*setbcnrp)(struct net_device___3 *, int, u8);
	int (*setapp)(struct net_device___3 *, u8, u16, u8);
	int (*getapp)(struct net_device___3 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___3 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___3 *, int, u8);
	u8 (*getdcbx)(struct net_device___3 *);
	u8 (*setdcbx)(struct net_device___3 *, u8);
	int (*peer_getappinfo)(struct net_device___3 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___3 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___3 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___3 *, struct cee_pfc *);
	int (*dcbnl_getbuffer)(struct net_device___3 *, struct dcbnl_buffer *);
	int (*dcbnl_setbuffer)(struct net_device___3 *, struct dcbnl_buffer *);
};

struct xdp_rxq_info___3 {
	struct net_device___3 *dev;
	u32 queue_index;
	u32 reg_state;
	struct xdp_mem_info mem;
	unsigned int napi_id;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct xdp_txq_info___3 {
	struct net_device___3 *dev;
};

struct xdp_buff___3 {
	void *data;
	void *data_end;
	void *data_meta;
	void *data_hard_start;
	struct xdp_rxq_info___3 *rxq;
	struct xdp_txq_info___3 *txq;
	u32 frame_sz;
};

struct xdp_frame___3 {
	void *data;
	u16 len;
	u16 headroom;
	u32 metasize: 8;
	u32 frame_sz: 24;
	long: 40;
	long: 64;
	struct xdp_mem_info mem;
	struct net_device___3 *dev_rx;
};

struct netlink_callback___3 {
	struct sk_buff___4 *skb;
	const struct nlmsghdr *nlh;
	int (*dump)(struct sk_buff___4 *, struct netlink_callback___3 *);
	int (*done)(struct netlink_callback___3 *);
	void *data;
	struct module___26 *module;
	struct netlink_ext_ack *extack;
	u16 family;
	u16 answer_flags;
	u32 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	bool strict_check;
	union {
		u8 ctx[48];
		long int args[6];
	};
};

struct header_ops___3 {
	int (*create)(struct sk_buff___4 *, struct net_device___3 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___4 *, unsigned char *);
	int (*cache)(const struct neighbour___2 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___3 *, const unsigned char *);
	bool (*validate)(const char *, unsigned int);
	__be16 (*parse_protocol)(const struct sk_buff___4 *);
};

struct netdev_queue___3 {
	struct net_device___3 *dev;
	struct Qdisc___3 *qdisc;
	struct Qdisc___3 *qdisc_sleeping;
	struct kobject___27 kobj;
	int numa_node;
	long unsigned int tx_maxrate;
	long unsigned int trans_timeout;
	struct net_device___3 *sb_dev;
	struct xsk_buff_pool *pool;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
};

struct qdisc_skb_head___3 {
	struct sk_buff___4 *head;
	struct sk_buff___4 *tail;
	__u32 qlen;
	spinlock_t lock;
};

struct Qdisc_ops___3;

struct Qdisc___3 {
	int (*enqueue)(struct sk_buff___4 *, struct Qdisc___3 *, struct sk_buff___4 **);
	struct sk_buff___4 * (*dequeue)(struct Qdisc___3 *);
	unsigned int flags;
	u32 limit;
	const struct Qdisc_ops___3 *ops;
	struct qdisc_size_table *stab;
	struct hlist_node hash;
	u32 handle;
	u32 parent;
	struct netdev_queue___3 *dev_queue;
	struct net_rate_estimator *rate_est;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	int pad;
	refcount_t refcnt;
	long: 64;
	long: 64;
	long: 64;
	struct sk_buff_head___3 gso_skb;
	struct qdisc_skb_head___3 q;
	struct gnet_stats_basic_packed bstats;
	seqcount_t running;
	struct gnet_stats_queue qstats;
	long unsigned int state;
	struct Qdisc___3 *next_sched;
	struct sk_buff_head___3 skb_bad_txq;
	spinlock_t busylock;
	spinlock_t seqlock;
	struct callback_head rcu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long int privdata[0];
};

struct netdev_rx_queue___3 {
	struct xdp_rxq_info___3 xdp_rxq;
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___27 kobj;
	struct net_device___3 *dev;
	struct xsk_buff_pool *pool;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct net_device_path___3 {
	enum net_device_path_type type;
	const struct net_device___3 *dev;
	union {
		struct {
			u16 id;
			__be16 proto;
			u8 h_dest[6];
		} encap;
		struct {
			enum {
				DEV_PATH_BR_VLAN_KEEP___3 = 0,
				DEV_PATH_BR_VLAN_TAG___3 = 1,
				DEV_PATH_BR_VLAN_UNTAG___3 = 2,
				DEV_PATH_BR_VLAN_UNTAG_HW___3 = 3,
			} vlan_mode;
			u16 vlan_id;
			__be16 vlan_proto;
		} bridge;
		struct {
			int port;
			u16 proto;
		} dsa;
	};
};

struct net_device_path_ctx___3 {
	const struct net_device___3 *dev;
	const u8 *daddr;
	int num_vlans;
	struct {
		u16 id;
		__be16 proto;
	} vlan[2];
};

struct netdev_bpf___3 {
	enum bpf_netdev_command command;
	union {
		struct {
			u32 flags;
			struct bpf_prog___3 *prog;
			struct netlink_ext_ack *extack;
		};
		struct {
			struct bpf_offloaded_map___3 *offmap;
		};
		struct {
			struct xsk_buff_pool *pool;
			u16 queue_id;
		} xsk;
	};
};

struct xfrmdev_ops___3 {
	int (*xdo_dev_state_add)(struct xfrm_state *);
	void (*xdo_dev_state_delete)(struct xfrm_state *);
	void (*xdo_dev_state_free)(struct xfrm_state *);
	bool (*xdo_dev_offload_ok)(struct sk_buff___4 *, struct xfrm_state *);
	void (*xdo_dev_state_advance_esn)(struct xfrm_state *);
};

struct netdev_name_node___3 {
	struct hlist_node hlist;
	struct list_head list;
	struct net_device___3 *dev;
	const char *name;
};

struct net_device_ops___3 {
	int (*ndo_init)(struct net_device___3 *);
	void (*ndo_uninit)(struct net_device___3 *);
	int (*ndo_open)(struct net_device___3 *);
	int (*ndo_stop)(struct net_device___3 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___4 *, struct net_device___3 *);
	netdev_features_t (*ndo_features_check)(struct sk_buff___4 *, struct net_device___3 *, netdev_features_t);
	u16 (*ndo_select_queue)(struct net_device___3 *, struct sk_buff___4 *, struct net_device___3 *);
	void (*ndo_change_rx_flags)(struct net_device___3 *, int);
	void (*ndo_set_rx_mode)(struct net_device___3 *);
	int (*ndo_set_mac_address)(struct net_device___3 *, void *);
	int (*ndo_validate_addr)(struct net_device___3 *);
	int (*ndo_do_ioctl)(struct net_device___3 *, struct ifreq *, int);
	int (*ndo_eth_ioctl)(struct net_device___3 *, struct ifreq *, int);
	int (*ndo_siocbond)(struct net_device___3 *, struct ifreq *, int);
	int (*ndo_siocwandev)(struct net_device___3 *, struct if_settings *);
	int (*ndo_siocdevprivate)(struct net_device___3 *, struct ifreq *, void *, int);
	int (*ndo_set_config)(struct net_device___3 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___3 *, int);
	int (*ndo_neigh_setup)(struct net_device___3 *, struct neigh_parms___3 *);
	void (*ndo_tx_timeout)(struct net_device___3 *, unsigned int);
	void (*ndo_get_stats64)(struct net_device___3 *, struct rtnl_link_stats64 *);
	bool (*ndo_has_offload_stats)(const struct net_device___3 *, int);
	int (*ndo_get_offload_stats)(int, const struct net_device___3 *, void *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___3 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___3 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___3 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___3 *);
	int (*ndo_netpoll_setup)(struct net_device___3 *, struct netpoll_info *);
	void (*ndo_netpoll_cleanup)(struct net_device___3 *);
	int (*ndo_set_vf_mac)(struct net_device___3 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___3 *, int, u16, u8, __be16);
	int (*ndo_set_vf_rate)(struct net_device___3 *, int, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___3 *, int, bool);
	int (*ndo_set_vf_trust)(struct net_device___3 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___3 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___3 *, int, int);
	int (*ndo_get_vf_stats)(struct net_device___3 *, int, struct ifla_vf_stats *);
	int (*ndo_set_vf_port)(struct net_device___3 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___3 *, int, struct sk_buff___4 *);
	int (*ndo_get_vf_guid)(struct net_device___3 *, int, struct ifla_vf_guid *, struct ifla_vf_guid *);
	int (*ndo_set_vf_guid)(struct net_device___3 *, int, u64, int);
	int (*ndo_set_vf_rss_query_en)(struct net_device___3 *, int, bool);
	int (*ndo_setup_tc)(struct net_device___3 *, enum tc_setup_type, void *);
	int (*ndo_fcoe_enable)(struct net_device___3 *);
	int (*ndo_fcoe_disable)(struct net_device___3 *);
	int (*ndo_fcoe_ddp_setup)(struct net_device___3 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_ddp_done)(struct net_device___3 *, u16);
	int (*ndo_fcoe_ddp_target)(struct net_device___3 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_get_hbainfo)(struct net_device___3 *, struct netdev_fcoe_hbainfo *);
	int (*ndo_fcoe_get_wwn)(struct net_device___3 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___3 *, const struct sk_buff___4 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___3 *, struct net_device___3 *, struct netlink_ext_ack *);
	int (*ndo_del_slave)(struct net_device___3 *, struct net_device___3 *);
	struct net_device___3 * (*ndo_get_xmit_slave)(struct net_device___3 *, struct sk_buff___4 *, bool);
	struct net_device___3 * (*ndo_sk_get_lower_dev)(struct net_device___3 *, struct sock___2 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___3 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___3 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct net_device___3 *, struct neighbour___2 *);
	void (*ndo_neigh_destroy)(struct net_device___3 *, struct neighbour___2 *);
	int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___3 *, const unsigned char *, u16, u16, struct netlink_ext_ack *);
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___3 *, const unsigned char *, u16);
	int (*ndo_fdb_dump)(struct sk_buff___4 *, struct netlink_callback___3 *, struct net_device___3 *, struct net_device___3 *, int *);
	int (*ndo_fdb_get)(struct sk_buff___4 *, struct nlattr **, struct net_device___3 *, const unsigned char *, u16, u32, u32, struct netlink_ext_ack *);
	int (*ndo_bridge_setlink)(struct net_device___3 *, struct nlmsghdr *, u16, struct netlink_ext_ack *);
	int (*ndo_bridge_getlink)(struct sk_buff___4 *, u32, u32, struct net_device___3 *, u32, int);
	int (*ndo_bridge_dellink)(struct net_device___3 *, struct nlmsghdr *, u16);
	int (*ndo_change_carrier)(struct net_device___3 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___3 *, struct netdev_phys_item_id *);
	int (*ndo_get_port_parent_id)(struct net_device___3 *, struct netdev_phys_item_id *);
	int (*ndo_get_phys_port_name)(struct net_device___3 *, char *, size_t);
	void * (*ndo_dfwd_add_station)(struct net_device___3 *, struct net_device___3 *);
	void (*ndo_dfwd_del_station)(struct net_device___3 *, void *);
	int (*ndo_set_tx_maxrate)(struct net_device___3 *, int, u32);
	int (*ndo_get_iflink)(const struct net_device___3 *);
	int (*ndo_change_proto_down)(struct net_device___3 *, bool);
	int (*ndo_fill_metadata_dst)(struct net_device___3 *, struct sk_buff___4 *);
	void (*ndo_set_rx_headroom)(struct net_device___3 *, int);
	int (*ndo_bpf)(struct net_device___3 *, struct netdev_bpf___3 *);
	int (*ndo_xdp_xmit)(struct net_device___3 *, int, struct xdp_frame___3 **, u32);
	struct net_device___3 * (*ndo_xdp_get_xmit_slave)(struct net_device___3 *, struct xdp_buff___3 *);
	int (*ndo_xsk_wakeup)(struct net_device___3 *, u32, u32);
	struct devlink_port * (*ndo_get_devlink_port)(struct net_device___3 *);
	int (*ndo_tunnel_ctl)(struct net_device___3 *, struct ip_tunnel_parm *, int);
	struct net_device___3 * (*ndo_get_peer_dev)(struct net_device___3 *);
	int (*ndo_fill_forward_path)(struct net_device_path_ctx___3 *, struct net_device_path___3 *);
};

struct neigh_parms___3 {
	possible_net_t___3 net;
	struct net_device___3 *dev;
	struct list_head list;
	int (*neigh_setup)(struct neighbour___2 *);
	struct neigh_table___2 *tbl;
	void *sysctl_table;
	int dead;
	refcount_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[13];
	long unsigned int data_state[1];
};

struct l3mdev_ops___3 {
	u32 (*l3mdev_fib_table)(const struct net_device___3 *);
	struct sk_buff___4 * (*l3mdev_l3_rcv)(struct net_device___3 *, struct sk_buff___4 *, u16);
	struct sk_buff___4 * (*l3mdev_l3_out)(struct net_device___3 *, struct sock___2 *, struct sk_buff___4 *, u16);
	struct dst_entry___2 * (*l3mdev_link_scope_lookup)(const struct net_device___3 *, struct flowi6 *);
};

struct ndisc_ops___3 {
	int (*is_useropt)(u8);
	int (*parse_options)(const struct net_device___3 *, struct nd_opt_hdr *, struct ndisc_options *);
	void (*update)(const struct net_device___3 *, struct neighbour___2 *, u32, u8, const struct ndisc_options *);
	int (*opt_addr_space)(const struct net_device___3 *, u8, struct neighbour___2 *, u8 *, u8 **);
	void (*fill_addr_option)(const struct net_device___3 *, struct sk_buff___4 *, u8, const u8 *);
	void (*prefix_rcv_add_addr)(struct net *, struct net_device___3 *, const struct prefix_info *, struct inet6_dev___3 *, struct in6_addr *, int, u32, bool, bool, __u32, u32, bool);
};

struct ifmcaddr6___2;

struct inet6_dev___3 {
	struct net_device___3 *dev;
	struct list_head addr_list;
	struct ifmcaddr6___2 *mc_list;
	struct ifmcaddr6___2 *mc_tomb;
	unsigned char mc_qrv;
	unsigned char mc_gq_running;
	unsigned char mc_ifc_count;
	unsigned char mc_dad_count;
	long unsigned int mc_v1_seen;
	long unsigned int mc_qi;
	long unsigned int mc_qri;
	long unsigned int mc_maxdelay;
	struct delayed_work mc_gq_work;
	struct delayed_work mc_ifc_work;
	struct delayed_work mc_dad_work;
	struct delayed_work mc_query_work;
	struct delayed_work mc_report_work;
	struct sk_buff_head___3 mc_query_queue;
	struct sk_buff_head___3 mc_report_queue;
	spinlock_t mc_query_lock;
	spinlock_t mc_report_lock;
	struct mutex mc_lock;
	struct ifacaddr6 *ac_list;
	rwlock_t lock;
	refcount_t refcnt;
	__u32 if_flags;
	int dead;
	u32 desync_factor;
	struct list_head tempaddr_list;
	struct in6_addr token;
	struct neigh_parms___3 *nd_parms;
	struct ipv6_devconf cnf;
	struct ipv6_devstat stats;
	struct timer_list rs_timer;
	__s32 rs_interval;
	__u8 rs_probes;
	long unsigned int tstamp;
	struct callback_head rcu;
	unsigned int ra_mtu;
};

struct tcf_proto___3;

struct tcf_block___3;

struct mini_Qdisc___3 {
	struct tcf_proto___3 *filter_list;
	struct tcf_block___3 *block;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	struct callback_head rcu;
};

struct rtnl_link_ops___3 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	struct net_device___3 * (*alloc)(struct nlattr **, const char *, unsigned char, unsigned int, unsigned int);
	void (*setup)(struct net_device___3 *);
	bool netns_refund;
	unsigned int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*newlink)(struct net *, struct net_device___3 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*changelink)(struct net_device___3 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	void (*dellink)(struct net_device___3 *, struct list_head *);
	size_t (*get_size)(const struct net_device___3 *);
	int (*fill_info)(struct sk_buff___4 *, const struct net_device___3 *);
	size_t (*get_xstats_size)(const struct net_device___3 *);
	int (*fill_xstats)(struct sk_buff___4 *, const struct net_device___3 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	unsigned int slave_maxtype;
	const struct nla_policy *slave_policy;
	int (*slave_changelink)(struct net_device___3 *, struct net_device___3 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	size_t (*get_slave_size)(const struct net_device___3 *, const struct net_device___3 *);
	int (*fill_slave_info)(struct sk_buff___4 *, const struct net_device___3 *, const struct net_device___3 *);
	struct net * (*get_link_net)(const struct net_device___3 *);
	size_t (*get_linkxstats_size)(const struct net_device___3 *, int);
	int (*fill_linkxstats)(struct sk_buff___4 *, const struct net_device___3 *, int *, int);
};

struct gnet_dump___3 {
	spinlock_t *lock;
	struct sk_buff___4 *skb;
	struct nlattr *tail;
	int compat_tc_stats;
	int compat_xstats;
	int padattr;
	void *xstats;
	int xstats_len;
	struct tc_stats tc_stats;
};

struct Qdisc_class_ops___3;

struct Qdisc_ops___3 {
	struct Qdisc_ops___3 *next;
	const struct Qdisc_class_ops___3 *cl_ops;
	char id[16];
	int priv_size;
	unsigned int static_flags;
	int (*enqueue)(struct sk_buff___4 *, struct Qdisc___3 *, struct sk_buff___4 **);
	struct sk_buff___4 * (*dequeue)(struct Qdisc___3 *);
	struct sk_buff___4 * (*peek)(struct Qdisc___3 *);
	int (*init)(struct Qdisc___3 *, struct nlattr *, struct netlink_ext_ack *);
	void (*reset)(struct Qdisc___3 *);
	void (*destroy)(struct Qdisc___3 *);
	int (*change)(struct Qdisc___3 *, struct nlattr *, struct netlink_ext_ack *);
	void (*attach)(struct Qdisc___3 *);
	int (*change_tx_queue_len)(struct Qdisc___3 *, unsigned int);
	void (*change_real_num_tx)(struct Qdisc___3 *, unsigned int);
	int (*dump)(struct Qdisc___3 *, struct sk_buff___4 *);
	int (*dump_stats)(struct Qdisc___3 *, struct gnet_dump___3 *);
	void (*ingress_block_set)(struct Qdisc___3 *, u32);
	void (*egress_block_set)(struct Qdisc___3 *, u32);
	u32 (*ingress_block_get)(struct Qdisc___3 *);
	u32 (*egress_block_get)(struct Qdisc___3 *);
	struct module___26 *owner;
};

struct Qdisc_class_ops___3 {
	unsigned int flags;
	struct netdev_queue___3 * (*select_queue)(struct Qdisc___3 *, struct tcmsg *);
	int (*graft)(struct Qdisc___3 *, long unsigned int, struct Qdisc___3 *, struct Qdisc___3 **, struct netlink_ext_ack *);
	struct Qdisc___3 * (*leaf)(struct Qdisc___3 *, long unsigned int);
	void (*qlen_notify)(struct Qdisc___3 *, long unsigned int);
	long unsigned int (*find)(struct Qdisc___3 *, u32);
	int (*change)(struct Qdisc___3 *, u32, u32, struct nlattr **, long unsigned int *, struct netlink_ext_ack *);
	int (*delete)(struct Qdisc___3 *, long unsigned int, struct netlink_ext_ack *);
	void (*walk)(struct Qdisc___3 *, struct qdisc_walker *);
	struct tcf_block___3 * (*tcf_block)(struct Qdisc___3 *, long unsigned int, struct netlink_ext_ack *);
	long unsigned int (*bind_tcf)(struct Qdisc___3 *, long unsigned int, u32);
	void (*unbind_tcf)(struct Qdisc___3 *, long unsigned int);
	int (*dump)(struct Qdisc___3 *, long unsigned int, struct sk_buff___4 *, struct tcmsg *);
	int (*dump_stats)(struct Qdisc___3 *, long unsigned int, struct gnet_dump___3 *);
};

struct tcf_chain___3;

struct tcf_block___3 {
	struct mutex lock;
	struct list_head chain_list;
	u32 index;
	u32 classid;
	refcount_t refcnt;
	struct net *net;
	struct Qdisc___3 *q;
	struct rw_semaphore cb_lock;
	struct flow_block flow_block;
	struct list_head owner_list;
	bool keep_dst;
	atomic_t offloadcnt;
	unsigned int nooffloaddevcnt;
	unsigned int lockeddevcnt;
	struct {
		struct tcf_chain___3 *chain;
		struct list_head filter_chain_list;
	} chain0;
	struct callback_head rcu;
	struct hlist_head proto_destroy_ht[128];
	struct mutex proto_destroy_lock;
};

struct tcf_result___3;

struct tcf_proto_ops___3;

struct tcf_proto___3 {
	struct tcf_proto___3 *next;
	void *root;
	int (*classify)(struct sk_buff___4 *, const struct tcf_proto___3 *, struct tcf_result___3 *);
	__be16 protocol;
	u32 prio;
	void *data;
	const struct tcf_proto_ops___3 *ops;
	struct tcf_chain___3 *chain;
	spinlock_t lock;
	bool deleting;
	refcount_t refcnt;
	struct callback_head rcu;
	struct hlist_node destroy_ht_node;
};

struct tcf_result___3 {
	union {
		struct {
			long unsigned int class;
			u32 classid;
		};
		const struct tcf_proto___3 *goto_tp;
		struct {
			bool ingress;
			struct gnet_stats_queue *qstats;
		};
	};
};

struct tcf_proto_ops___3 {
	struct list_head head;
	char kind[16];
	int (*classify)(struct sk_buff___4 *, const struct tcf_proto___3 *, struct tcf_result___3 *);
	int (*init)(struct tcf_proto___3 *);
	void (*destroy)(struct tcf_proto___3 *, bool, struct netlink_ext_ack *);
	void * (*get)(struct tcf_proto___3 *, u32);
	void (*put)(struct tcf_proto___3 *, void *);
	int (*change)(struct net *, struct sk_buff___4 *, struct tcf_proto___3 *, long unsigned int, u32, struct nlattr **, void **, u32, struct netlink_ext_ack *);
	int (*delete)(struct tcf_proto___3 *, void *, bool *, bool, struct netlink_ext_ack *);
	bool (*delete_empty)(struct tcf_proto___3 *);
	void (*walk)(struct tcf_proto___3 *, struct tcf_walker *, bool);
	int (*reoffload)(struct tcf_proto___3 *, bool, flow_setup_cb_t *, void *, struct netlink_ext_ack *);
	void (*hw_add)(struct tcf_proto___3 *, void *);
	void (*hw_del)(struct tcf_proto___3 *, void *);
	void (*bind_class)(void *, u32, long unsigned int, void *, long unsigned int);
	void * (*tmplt_create)(struct net *, struct tcf_chain___3 *, struct nlattr **, struct netlink_ext_ack *);
	void (*tmplt_destroy)(void *);
	int (*dump)(struct net *, struct tcf_proto___3 *, void *, struct sk_buff___4 *, struct tcmsg *, bool);
	int (*terse_dump)(struct net *, struct tcf_proto___3 *, void *, struct sk_buff___4 *, struct tcmsg *, bool);
	int (*tmplt_dump)(struct sk_buff___4 *, struct net *, void *);
	struct module___26 *owner;
	int flags;
};

struct tcf_chain___3 {
	struct mutex filter_chain_lock;
	struct tcf_proto___3 *filter_chain;
	struct list_head list;
	struct tcf_block___3 *block;
	u32 index;
	unsigned int refcnt;
	unsigned int action_refcnt;
	bool explicitly_created;
	bool flushing;
	const struct tcf_proto_ops___3 *tmplt_ops;
	void *tmplt_priv;
	struct callback_head rcu;
};

struct sk_filter___2 {
	refcount_t refcnt;
	struct callback_head rcu;
	struct bpf_prog___3 *prog;
};

struct pneigh_entry___2;

struct neigh_hash_table___2;

struct neigh_table___2 {
	int family;
	unsigned int entry_size;
	unsigned int key_len;
	__be16 protocol;
	__u32 (*hash)(const void *, const struct net_device___3 *, __u32 *);
	bool (*key_eq)(const struct neighbour___2 *, const void *);
	int (*constructor)(struct neighbour___2 *);
	int (*pconstructor)(struct pneigh_entry___2 *);
	void (*pdestructor)(struct pneigh_entry___2 *);
	void (*proxy_redo)(struct sk_buff___4 *);
	int (*is_multicast)(const void *);
	bool (*allow_add)(const struct net_device___3 *, struct netlink_ext_ack *);
	char *id;
	struct neigh_parms___3 parms;
	struct list_head parms_list;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___3 proxy_queue;
	atomic_t entries;
	atomic_t gc_entries;
	struct list_head gc_list;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___2 *nht;
	struct pneigh_entry___2 **phash_buckets;
};

struct neigh_ops___2 {
	int family;
	void (*solicit)(struct neighbour___2 *, struct sk_buff___4 *);
	void (*error_report)(struct neighbour___2 *, struct sk_buff___4 *);
	int (*output)(struct neighbour___2 *, struct sk_buff___4 *);
	int (*connected_output)(struct neighbour___2 *, struct sk_buff___4 *);
};

struct pneigh_entry___2 {
	struct pneigh_entry___2 *next;
	possible_net_t___3 net;
	struct net_device___3 *dev;
	u8 flags;
	u8 protocol;
	u8 key[0];
};

struct neigh_hash_table___2 {
	struct neighbour___2 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct fib_rule___2 {
	struct list_head list;
	int iifindex;
	int oifindex;
	u32 mark;
	u32 mark_mask;
	u32 flags;
	u32 table;
	u8 action;
	u8 l3mdev;
	u8 proto;
	u8 ip_proto;
	u32 target;
	__be64 tun_id;
	struct fib_rule___2 *ctarget;
	struct net *fr_net;
	refcount_t refcnt;
	u32 pref;
	int suppress_ifgroup;
	int suppress_prefixlen;
	char iifname[16];
	char oifname[16];
	struct fib_kuid_range uid_range;
	struct fib_rule_port_range sport_range;
	struct fib_rule_port_range dport_range;
	struct callback_head rcu;
};

struct fib_lookup_arg___2 {
	void *lookup_ptr;
	const void *lookup_data;
	void *result;
	struct fib_rule___2 *rule;
	u32 table;
	int flags;
};

struct request_sock_ops___2;

struct timewait_sock_ops___2;

struct proto___2 {
	void (*close)(struct sock___2 *, long int);
	int (*pre_connect)(struct sock___2 *, struct sockaddr *, int);
	int (*connect)(struct sock___2 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___2 *, int);
	struct sock___2 * (*accept)(struct sock___2 *, int, int *, bool);
	int (*ioctl)(struct sock___2 *, int, long unsigned int);
	int (*init)(struct sock___2 *);
	void (*destroy)(struct sock___2 *);
	void (*shutdown)(struct sock___2 *, int);
	int (*setsockopt)(struct sock___2 *, int, int, sockptr_t, unsigned int);
	int (*getsockopt)(struct sock___2 *, int, int, char *, int *);
	void (*keepalive)(struct sock___2 *, int);
	int (*compat_ioctl)(struct sock___2 *, unsigned int, long unsigned int);
	int (*sendmsg)(struct sock___2 *, struct msghdr___2 *, size_t);
	int (*recvmsg)(struct sock___2 *, struct msghdr___2 *, size_t, int, int, int *);
	int (*sendpage)(struct sock___2 *, struct page___28 *, int, size_t, int);
	int (*bind)(struct sock___2 *, struct sockaddr *, int);
	int (*bind_add)(struct sock___2 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___2 *, struct sk_buff___4 *);
	bool (*bpf_bypass_getsockopt)(int, int);
	void (*release_cb)(struct sock___2 *);
	int (*hash)(struct sock___2 *);
	void (*unhash)(struct sock___2 *);
	void (*rehash)(struct sock___2 *);
	int (*get_port)(struct sock___2 *, short unsigned int);
	int (*psock_update_sk_prot)(struct sock___2 *, struct sk_psock *, bool);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___2 *, int);
	bool (*sock_is_readable)(struct sock___2 *);
	void (*enter_memory_pressure)(struct sock___2 *);
	void (*leave_memory_pressure)(struct sock___2 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	long unsigned int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	u32 sysctl_wmem_offset;
	u32 sysctl_rmem_offset;
	int max_header;
	bool no_autobind;
	struct kmem_cache *slab;
	unsigned int obj_size;
	slab_flags_t slab_flags;
	unsigned int useroffset;
	unsigned int usersize;
	unsigned int *orphan_count;
	struct request_sock_ops___2 *rsk_prot;
	struct timewait_sock_ops___2 *twsk_prot;
	union {
		struct inet_hashinfo *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
		struct smc_hashinfo *smc_hash;
	} h;
	struct module___26 *owner;
	char name[32];
	struct list_head node;
	int (*diag_destroy)(struct sock___2 *, int);
};

struct request_sock___2;

struct request_sock_ops___2 {
	int family;
	unsigned int obj_size;
	struct kmem_cache *slab;
	char *slab_name;
	int (*rtx_syn_ack)(const struct sock___2 *, struct request_sock___2 *);
	void (*send_ack)(const struct sock___2 *, struct sk_buff___4 *, struct request_sock___2 *);
	void (*send_reset)(const struct sock___2 *, struct sk_buff___4 *);
	void (*destructor)(struct request_sock___2 *);
	void (*syn_ack_timeout)(const struct request_sock___2 *);
};

struct timewait_sock_ops___2 {
	struct kmem_cache *twsk_slab;
	char *twsk_slab_name;
	unsigned int twsk_obj_size;
	int (*twsk_unique)(struct sock___2 *, struct sock___2 *, void *);
	void (*twsk_destructor)(struct sock___2 *);
};

struct request_sock___2 {
	struct sock_common___2 __req_common;
	struct request_sock___2 *dl_next;
	u16 mss;
	u8 num_retrans;
	u8 syncookie: 1;
	u8 num_timeout: 7;
	long: 25;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u32 ts_recent;
	struct timer_list rsk_timer;
	const struct request_sock_ops___2 *rsk_ops;
	struct sock___2 *sk;
	struct saved_syn *saved_syn;
	u32 secid;
	u32 peer_secid;
};

struct ifmcaddr6___2 {
	struct in6_addr mca_addr;
	struct inet6_dev___3 *idev;
	struct ifmcaddr6___2 *next;
	struct ip6_sf_list *mca_sources;
	struct ip6_sf_list *mca_tomb;
	unsigned int mca_sfmode;
	unsigned char mca_crcount;
	long unsigned int mca_sfcount[2];
	struct delayed_work mca_work;
	unsigned int mca_flags;
	int mca_users;
	refcount_t mca_refcnt;
	long unsigned int mca_cstamp;
	long unsigned int mca_tstamp;
	struct callback_head rcu;
};

struct irq_fwspec___14 {
	struct fwnode_handle___26 *fwnode;
	int param_count;
	u32 param[16];
};

struct irq_domain_ops___15 {
	int (*match)(struct irq_domain___15 *, struct device_node___17 *, enum irq_domain_bus_token);
	int (*select)(struct irq_domain___15 *, struct irq_fwspec___14 *, enum irq_domain_bus_token);
	int (*map)(struct irq_domain___15 *, unsigned int, irq_hw_number_t);
	void (*unmap)(struct irq_domain___15 *, unsigned int);
	int (*xlate)(struct irq_domain___15 *, struct device_node___17 *, const u32 *, unsigned int, long unsigned int *, unsigned int *);
	int (*alloc)(struct irq_domain___15 *, unsigned int, unsigned int, void *);
	void (*free)(struct irq_domain___15 *, unsigned int, unsigned int);
	int (*activate)(struct irq_domain___15 *, struct irq_data *, bool);
	void (*deactivate)(struct irq_domain___15 *, struct irq_data *);
	int (*translate)(struct irq_domain___15 *, struct irq_fwspec___14 *, long unsigned int *, unsigned int *);
};

struct linux_binprm___6 {
	struct vm_area_struct___29 *vma;
	long unsigned int vma_pages;
	struct mm_struct___29 *mm;
	long unsigned int p;
	long unsigned int argmin;
	unsigned int have_execfd;
	unsigned int execfd_creds;
	unsigned int secureexec;
	unsigned int point_of_no_return;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct file___27 *executable;
	struct file___27 *interpreter;
	struct file___27 *file;
	struct cred *cred;
	int unsafe;
	unsigned int per_clear;
	int argc;
	int envc;
	const char *filename;
	const char *interp;
	const char *fdpath;
	unsigned int interp_flags;
	int execfd;
	long unsigned int loader;
	long unsigned int exec;
	struct rlimit rlim_stack;
	char buf[256];
};

struct coredump_params___5 {
	const kernel_siginfo_t *siginfo;
	struct pt_regs *regs;
	struct file___27 *file;
	long unsigned int limit;
	long unsigned int mm_flags;
	loff_t written;
	loff_t pos;
	loff_t to_skip;
};

enum sysctl_writes_mode {
	SYSCTL_WRITES_LEGACY = 4294967295,
	SYSCTL_WRITES_WARN = 0,
	SYSCTL_WRITES_STRICT = 1,
};

struct do_proc_dointvec_minmax_conv_param {
	int *min;
	int *max;
};

struct do_proc_douintvec_minmax_conv_param {
	unsigned int *min;
	unsigned int *max;
};

struct __user_cap_header_struct {
	__u32 version;
	int pid;
};

typedef struct __user_cap_header_struct *cap_user_header_t;

struct __user_cap_data_struct {
	__u32 effective;
	__u32 permitted;
	__u32 inheritable;
};

typedef struct __user_cap_data_struct *cap_user_data_t;

struct sigqueue {
	struct list_head list;
	int flags;
	kernel_siginfo_t info;
	struct ucounts *ucounts;
};

typedef int wait_bit_action_f(struct wait_bit_key *, int);

struct ptrace_peeksiginfo_args {
	__u64 off;
	__u32 flags;
	__s32 nr;
};

struct ptrace_syscall_info {
	__u8 op;
	__u8 pad[3];
	__u32 arch;
	__u64 instruction_pointer;
	__u64 stack_pointer;
	union {
		struct {
			__u64 nr;
			__u64 args[6];
		} entry;
		struct {
			__s64 rval;
			__u8 is_error;
		} exit;
		struct {
			__u64 nr;
			__u64 args[6];
			__u32 ret_data;
		} seccomp;
	};
};

struct ptrace_rseq_configuration {
	__u64 rseq_abi_pointer;
	__u32 rseq_abi_size;
	__u32 signature;
	__u32 flags;
	__u32 pad;
};

struct compat_iovec {
	compat_uptr_t iov_base;
	compat_size_t iov_len;
};

struct user_regset___3;

typedef int user_regset_active_fn___3(struct task_struct___10 *, const struct user_regset___3 *);

typedef int user_regset_get2_fn___3(struct task_struct___10 *, const struct user_regset___3 *, struct membuf);

typedef int user_regset_set_fn___3(struct task_struct___10 *, const struct user_regset___3 *, unsigned int, unsigned int, const void *, const void *);

typedef int user_regset_writeback_fn___3(struct task_struct___10 *, const struct user_regset___3 *, int);

struct user_regset___3 {
	user_regset_get2_fn___3 *regset_get;
	user_regset_set_fn___3 *set;
	user_regset_active_fn___3 *active;
	user_regset_writeback_fn___3 *writeback;
	unsigned int n;
	unsigned int size;
	unsigned int align;
	unsigned int bias;
	unsigned int core_note_type;
};

struct user_regset_view___2 {
	const char *name;
	const struct user_regset___3 *regsets;
	unsigned int n;
	u32 e_flags;
	u16 e_machine;
	u8 ei_osabi;
};

struct vm_area_struct___30;

struct vmacache___29 {
	u64 seqnum;
	struct vm_area_struct___30 *vmas[4];
};

struct page___29;

struct page_frag___29 {
	struct page___29 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___30;

struct task_struct___31 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___31 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___30 *mm;
	struct mm_struct___30 *active_mm;
	struct vmacache___29 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int restore_sigmask: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___31 *real_parent;
	struct task_struct___31 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___31 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___23 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	struct posix_cputimers_work posix_cputimers_work;
	const struct cred___2 *ptracer_cred;
	const struct cred___2 *real_cred;
	const struct cred___2 *cred;
	struct key *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___26 *nsproxy;
	struct signal_struct___3 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___31 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context___2 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set *cgroups;
	struct list_head cg_list;
	u32 closid;
	u32 rmid;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	struct pipe_inode_info *splice_pipe;
	struct page_frag___29 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup *active_memcg;
	struct request_queue *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___31 *oom_reaper_list;
	struct vm_struct___3 *stack_vm_area;
	refcount_t stack_refcount;
	int patch_state;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	void *mce_vaddr;
	__u64 mce_kflags;
	u64 mce_addr;
	__u64 mce_ripv: 1;
	__u64 mce_whole_page: 1;
	__u64 __mce_reserved: 62;
	long: 2;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct callback_head mce_kill_me;
	int mce_count;
	struct llist_head kretprobe_instances;
	struct callback_head l1d_flush_kill;
	long: 64;
	struct thread_struct___17 thread;
};

typedef struct page___29 *pgtable_t___29;

struct page___29 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___27 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___8 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___29 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___29 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___30 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___27 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct pv_cpu_ops___23 {
	void (*io_delay)();
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	void (*write_cr4)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___17 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(long unsigned int);
	void (*invalidate_io_bitmap)();
	void (*update_io_bitmap)();
	void (*wbinvd)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int);
	void (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_msr_safe)(unsigned int, int *);
	int (*write_msr_safe)(unsigned int, unsigned int, unsigned int);
	u64 (*read_pmc)(int);
	void (*start_context_switch)(struct task_struct___31 *);
	void (*end_context_switch)(struct task_struct___31 *);
};

struct pv_mmu_ops___24 {
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_one_user)(long unsigned int);
	void (*flush_tlb_multi)(const struct cpumask *, const struct flush_tlb_info___3 *);
	void (*tlb_remove_table)(struct mmu_gather *, void *);
	void (*exit_mmap)(struct mm_struct___30 *);
	struct paravirt_callee_save read_cr2;
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___30 *, struct mm_struct___30 *);
	void (*dup_mmap)(struct mm_struct___30 *, struct mm_struct___30 *);
	int (*pgd_alloc)(struct mm_struct___30 *);
	void (*pgd_free)(struct mm_struct___30 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___30 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___30 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___30 *, long unsigned int);
	void (*alloc_p4d)(struct mm_struct___30 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*release_p4d)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	pte_t (*ptep_modify_prot_start)(struct vm_area_struct___30 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct vm_area_struct___30 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_p4d)(p4d_t *, p4d_t);
	struct paravirt_callee_save p4d_val;
	struct paravirt_callee_save make_p4d;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

struct core_state___29;

struct user_namespace___3;

struct mm_struct___30 {
	struct {
		struct vm_area_struct___30 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___7 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int mmap_compat_base;
		long unsigned int mmap_compat_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[48];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___29 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___31 *owner;
		struct user_namespace___3 *user_ns;
		struct file___7 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		bool tlb_flush_batched;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct vm_area_struct___30 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___30 *vm_next;
	struct vm_area_struct___30 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___30 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___6 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___7 *vm_file;
	struct file___7 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct paravirt_patch_template___24 {
	struct pv_cpu_ops___23 cpu;
	struct pv_irq_ops irq;
	struct pv_mmu_ops___24 mmu;
	struct pv_lock_ops lock;
};

struct proc_ns_operations___3;

struct ns_common___3 {
	atomic_long_t stashed;
	const struct proc_ns_operations___3 *ops;
	unsigned int inum;
	refcount_t count;
};

struct ucounts___3;

struct user_namespace___3 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	struct user_namespace___3 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___3 ns;
	long unsigned int flags;
	bool parent_could_setfcap;
	struct list_head keyring_name_list;
	struct key *user_keyring_register;
	struct rw_semaphore keyring_sem;
	struct key *persistent_keyring_register;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___3 *ucounts;
	long int ucount_max[16];
};

struct ucounts___3 {
	struct hlist_node node;
	struct user_namespace___3 *ns;
	kuid_t uid;
	atomic_t count;
	atomic_long_t ucount[16];
};

struct core_thread___29 {
	struct task_struct___31 *task;
	struct core_thread___29 *next;
};

struct core_state___29 {
	atomic_t nr_threads;
	struct core_thread___29 dumper;
	struct completion startup;
};

struct proc_ns_operations___3 {
	const char *name;
	const char *real_ns_name;
	int type;
	struct ns_common___3 * (*get)(struct task_struct___31 *);
	void (*put)(struct ns_common___3 *);
	int (*install)(struct nsset___2 *, struct ns_common___3 *);
	struct user_namespace___3 * (*owner)(struct ns_common___3 *);
	struct ns_common___3 * (*get_parent)(struct ns_common___3 *);
};

struct dentry___28;

struct super_block___28;

struct module___27;

struct file_system_type___28 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___28 * (*mount)(struct file_system_type___28 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___28 *);
	struct module___27 *owner;
	struct file_system_type___28 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___28;

struct kiocb___28;

struct iov_iter___22;

struct poll_table_struct___20;

struct vm_area_struct___31;

struct inode___28;

struct file_lock___28;

struct page___30;

struct seq_file___26;

struct file_operations___28 {
	struct module___27 *owner;
	loff_t (*llseek)(struct file___28 *, loff_t, int);
	ssize_t (*read)(struct file___28 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___28 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___28 *, struct iov_iter___22 *);
	ssize_t (*write_iter)(struct kiocb___28 *, struct iov_iter___22 *);
	int (*iopoll)(struct kiocb___28 *, bool);
	int (*iterate)(struct file___28 *, struct dir_context *);
	int (*iterate_shared)(struct file___28 *, struct dir_context *);
	__poll_t (*poll)(struct file___28 *, struct poll_table_struct___20 *);
	long int (*unlocked_ioctl)(struct file___28 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___28 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___28 *, struct vm_area_struct___31 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___28 *, struct file___28 *);
	int (*flush)(struct file___28 *, fl_owner_t);
	int (*release)(struct inode___28 *, struct file___28 *);
	int (*fsync)(struct file___28 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___28 *, int);
	int (*lock)(struct file___28 *, int, struct file_lock___28 *);
	ssize_t (*sendpage)(struct file___28 *, struct page___30 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___28 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___28 *, long unsigned int);
	int (*flock)(struct file___28 *, int, struct file_lock___28 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___28 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___28 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___28 *, long int, struct file_lock___28 **, void **);
	long int (*fallocate)(struct file___28 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___26 *, struct file___28 *);
	ssize_t (*copy_file_range)(struct file___28 *, loff_t, struct file___28 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___28 *, loff_t, struct file___28 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___28 *, loff_t, loff_t, int);
};

struct static_call_mod___20 {
	struct static_call_mod___20 *next;
	struct module___27 *mod;
	struct static_call_site *sites;
};

struct static_call_key___20 {
	void *func;
	union {
		long unsigned int type;
		struct static_call_mod___20 *mods;
		struct static_call_site *sites;
	};
};

struct vmacache___30 {
	u64 seqnum;
	struct vm_area_struct___31 *vmas[4];
};

struct page_frag___30 {
	struct page___30 *page;
	__u32 offset;
	__u32 size;
};

struct perf_event___17;

struct thread_struct___18 {
	struct desc_struct tls_array[3];
	long unsigned int sp;
	short unsigned int es;
	short unsigned int ds;
	short unsigned int fsindex;
	short unsigned int gsindex;
	long unsigned int fsbase;
	long unsigned int gsbase;
	struct perf_event___17 *ptrace_bps[4];
	long unsigned int virtual_dr6;
	long unsigned int ptrace_dr7;
	long unsigned int cr2;
	long unsigned int trap_nr;
	long unsigned int error_code;
	struct io_bitmap *io_bitmap;
	long unsigned int iopl_emul;
	unsigned int iopl_warn: 1;
	unsigned int sig_on_uaccess_err: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u32 pkru;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct fpu fpu;
};

struct mm_struct___31;

struct pid___24;

struct nsproxy___27;

struct signal_struct___29;

struct bio_list___18;

struct backing_dev_info___17;

struct io_context___19;

struct css_set___22;

struct perf_event_context___17;

struct mem_cgroup___17;

struct request_queue___18;

struct vm_struct___25;

struct task_struct___32 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___32 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___31 *mm;
	struct mm_struct___31 *active_mm;
	struct vmacache___30 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int restore_sigmask: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___32 *real_parent;
	struct task_struct___32 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___32 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___24 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	struct posix_cputimers_work posix_cputimers_work;
	const struct cred *ptracer_cred;
	const struct cred *real_cred;
	const struct cred *cred;
	struct key *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___27 *nsproxy;
	struct signal_struct___29 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___32 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___18 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___17 *backing_dev_info;
	struct io_context___19 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___22 *cgroups;
	struct list_head cg_list;
	u32 closid;
	u32 rmid;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___17 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	long: 64;
	long: 64;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___30 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___17 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___17 *active_memcg;
	struct request_queue___18 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___32 *oom_reaper_list;
	struct vm_struct___25 *stack_vm_area;
	refcount_t stack_refcount;
	int patch_state;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	void *mce_vaddr;
	__u64 mce_kflags;
	u64 mce_addr;
	__u64 mce_ripv: 1;
	__u64 mce_whole_page: 1;
	__u64 __mce_reserved: 62;
	long: 2;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct callback_head mce_kill_me;
	int mce_count;
	struct llist_head kretprobe_instances;
	struct callback_head l1d_flush_kill;
	long: 64;
	struct thread_struct___18 thread;
};

typedef struct page___30 *pgtable_t___30;

struct address_space___28;

struct dev_pagemap___28;

struct page___30 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___28 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___8 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___30 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___30 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___31 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___28 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct pv_cpu_ops___24 {
	void (*io_delay)();
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	void (*write_cr4)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___18 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(long unsigned int);
	void (*invalidate_io_bitmap)();
	void (*update_io_bitmap)();
	void (*wbinvd)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int);
	void (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_msr_safe)(unsigned int, int *);
	int (*write_msr_safe)(unsigned int, unsigned int, unsigned int);
	u64 (*read_pmc)(int);
	void (*start_context_switch)(struct task_struct___32 *);
	void (*end_context_switch)(struct task_struct___32 *);
};

struct pv_mmu_ops___25 {
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_one_user)(long unsigned int);
	void (*flush_tlb_multi)(const struct cpumask *, const struct flush_tlb_info___3 *);
	void (*tlb_remove_table)(struct mmu_gather *, void *);
	void (*exit_mmap)(struct mm_struct___31 *);
	struct paravirt_callee_save read_cr2;
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___31 *, struct mm_struct___31 *);
	void (*dup_mmap)(struct mm_struct___31 *, struct mm_struct___31 *);
	int (*pgd_alloc)(struct mm_struct___31 *);
	void (*pgd_free)(struct mm_struct___31 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___31 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___31 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___31 *, long unsigned int);
	void (*alloc_p4d)(struct mm_struct___31 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*release_p4d)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	pte_t (*ptep_modify_prot_start)(struct vm_area_struct___31 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct vm_area_struct___31 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_p4d)(p4d_t *, p4d_t);
	struct paravirt_callee_save p4d_val;
	struct paravirt_callee_save make_p4d;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

struct linux_binfmt___6;

struct core_state___30;

struct mm_struct___31 {
	struct {
		struct vm_area_struct___31 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___28 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int mmap_compat_base;
		long unsigned int mmap_compat_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[48];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___6 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___30 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___32 *owner;
		struct user_namespace___3 *user_ns;
		struct file___28 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		bool tlb_flush_batched;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct vm_operations_struct___28;

struct vm_area_struct___31 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___31 *vm_next;
	struct vm_area_struct___31 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___31 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___28 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___28 *vm_file;
	struct file___28 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct paravirt_patch_template___25 {
	struct pv_cpu_ops___24 cpu;
	struct pv_irq_ops irq;
	struct pv_mmu_ops___25 mmu;
	struct pv_lock_ops lock;
};

struct tracepoint___20 {
	const char *name;
	struct static_key key;
	struct static_call_key___20 *static_call_key;
	void *static_call_tramp;
	void *iterator;
	int (*regfunc)();
	void (*unregfunc)();
	struct tracepoint_func *funcs;
};

struct bpf_raw_event_map___20 {
	struct tracepoint___20 *tp;
	void *bpf_func;
	u32 num_args;
	u32 writable_size;
	long: 64;
};

struct seq_operations___26 {
	void * (*start)(struct seq_file___26 *, loff_t *);
	void (*stop)(struct seq_file___26 *, void *);
	void * (*next)(struct seq_file___26 *, void *, loff_t *);
	int (*show)(struct seq_file___26 *, void *);
};

struct hw_perf_event___17 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___32 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	union {
		struct {
			u64 last_period;
			local64_t period_left;
		};
		struct {
			u64 saved_metric;
			u64 saved_slots;
		};
	};
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___17)(struct perf_event___17 *, struct perf_sample_data *, struct pt_regs *);

struct pmu___17;

struct fasync_struct___28;

struct pid_namespace___24;

struct trace_event_call___17;

struct perf_cgroup___17;

struct perf_event___17 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___17 *group_leader;
	struct pmu___17 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___17 hw;
	struct perf_event_context___17 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___17 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___32 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct perf_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___28 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	long unsigned int pending_addr;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	struct perf_addr_filter_range *addr_filter_ranges;
	long unsigned int addr_filters_gen;
	struct perf_event___17 *aux_event;
	void (*destroy)(struct perf_event___17 *);
	struct callback_head callback_head;
	struct pid_namespace___24 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___17 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___17 orig_overflow_handler;
	struct bpf_prog *prog;
	u64 bpf_cookie;
	struct trace_event_call___17 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___17 *cgrp;
	void *security;
	struct list_head sb_list;
};

struct address_space_operations___28;

struct address_space___28 {
	struct inode___28 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___28 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct dev_pagemap_ops___28;

struct dev_pagemap___28 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___28 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vfsmount___28;

struct path___28 {
	struct vfsmount___28 *mnt;
	struct dentry___28 *dentry;
};

struct fown_struct___24 {
	rwlock_t lock;
	struct pid___24 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___28 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	long: 64;
	long: 64;
	struct path___28 f_path;
	struct inode___28 *f_inode;
	const struct file_operations___28 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___24 f_owner;
	const struct cred *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___28 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___28;

struct vm_operations_struct___28 {
	void (*open)(struct vm_area_struct___31 *);
	void (*close)(struct vm_area_struct___31 *);
	int (*may_split)(struct vm_area_struct___31 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___31 *);
	int (*mprotect)(struct vm_area_struct___31 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___28 *);
	vm_fault_t (*huge_fault)(struct vm_fault___28 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___28 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___31 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___28 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___28 *);
	int (*access)(struct vm_area_struct___31 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___31 *);
	int (*set_policy)(struct vm_area_struct___31 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___31 *, long unsigned int);
	struct page___30 * (*find_special_page)(struct vm_area_struct___31 *, long unsigned int);
};

struct core_thread___30 {
	struct task_struct___32 *task;
	struct core_thread___30 *next;
};

struct core_state___30 {
	atomic_t nr_threads;
	struct core_thread___30 dumper;
	struct completion startup;
};

struct linux_binprm___7;

struct coredump_params___6;

struct linux_binfmt___6 {
	struct list_head lh;
	struct module___27 *module;
	int (*load_binary)(struct linux_binprm___7 *);
	int (*load_shlib)(struct file___28 *);
	int (*core_dump)(struct coredump_params___6 *);
	long unsigned int min_coredump;
};

struct vm_fault___28 {
	const struct {
		struct vm_area_struct___31 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___30 *cow_page;
	struct page___30 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___30 prealloc_pte;
};

struct pglist_data___18;

struct lruvec___18 {
	struct list_head lists[5];
	spinlock_t lru_lock;
	long unsigned int anon_cost;
	long unsigned int file_cost;
	atomic_long_t nonresident_age;
	long unsigned int refaults[2];
	long unsigned int flags;
	struct pglist_data___18 *pgdat;
};

struct zone___18 {
	long unsigned int _watermark[3];
	long unsigned int watermark_boost;
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[5];
	int node;
	struct pglist_data___18 *zone_pgdat;
	struct per_cpu_pages *per_cpu_pageset;
	struct per_cpu_zonestat *per_cpu_zonestats;
	int pageset_high;
	int pageset_batch;
	long unsigned int zone_start_pfn;
	atomic_long_t managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int present_early_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	seqlock_t span_seqlock;
	int initialized;
	int: 32;
	struct zone_padding _pad1_;
	struct free_area free_area[11];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	long unsigned int compact_init_migrate_pfn;
	long unsigned int compact_init_free_pfn;
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	short: 16;
	struct zone_padding _pad3_;
	atomic_long_t vm_stat[11];
	atomic_long_t vm_numa_event[6];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___18 {
	struct zone___18 *zone;
	int zone_idx;
};

struct zonelist___18 {
	struct zoneref___18 _zonerefs[5121];
};

struct pglist_data___18 {
	struct zone___18 node_zones[5];
	struct zonelist___18 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___32 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_highest_zoneidx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_highest_zoneidx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___32 *kcompactd;
	bool proactive_compact_trigger;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct deferred_split deferred_split_queue;
	struct lruvec___18 __lruvec;
	long unsigned int flags;
	long: 64;
	struct zone_padding _pad2_;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[39];
};

struct upid___24 {
	int nr;
	struct pid_namespace___24 *ns;
};

struct pid_namespace___24 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___32 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___24 *parent;
	struct fs_pin *bacct;
	struct user_namespace___3 *user_ns;
	struct ucounts___3 *ucounts;
	int reboot;
	struct ns_common___3 ns;
};

struct pid___24 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___24 numbers[1];
};

typedef long unsigned int old_sigset_t;

struct tty_struct___6;

struct signal_struct___29 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___32 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___32 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper;
	unsigned int has_child_subreaper;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___24 *pids[4];
	struct pid___24 *tty_old_pgrp;
	int leader;
	struct tty_struct___6 *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___31 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct cgroup_namespace___22;

struct nsproxy___27 {
	atomic_t count;
	struct uts_namespace *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___24 *pid_ns_for_children;
	struct net *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___22 *cgroup_ns;
};

struct bio___18;

struct bio_list___18 {
	struct bio___18 *head;
	struct bio___18 *tail;
};

struct cgroup_subsys_state___22;

struct bdi_writeback___17 {
	struct backing_dev_info___17 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	atomic_t writeback_inodes;
	struct percpu_counter stat[4];
	long unsigned int congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	struct delayed_work bw_dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___22 *memcg_css;
	struct cgroup_subsys_state___22 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	struct list_head b_attached;
	struct list_head offline_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
};

struct device___30;

struct backing_dev_info___17 {
	u64 id;
	struct rb_node rb_node;
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___17 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct mutex cgwb_release_mutex;
	struct rw_semaphore wb_switch_rwsem;
	wait_queue_head_t wb_waitq;
	struct device___30 *dev;
	char dev_name[64];
	struct device___30 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___28 *debug_dir;
};

struct io_cq___18;

struct io_context___19 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	struct xarray icq_tree;
	struct io_cq___18 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct cgroup___22;

struct css_set___22 {
	struct cgroup_subsys_state___22 *subsys[14];
	refcount_t refcount;
	struct css_set___22 *dom_cset;
	struct cgroup___22 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___22 *mg_src_cgrp;
	struct cgroup___22 *mg_dst_cgrp;
	struct css_set___22 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___17 {
	struct pmu___17 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	int rotate_necessary;
	refcount_t refcount;
	struct task_struct___32 *task;
	u64 time;
	u64 timestamp;
	u64 timeoffset;
	struct perf_event_context___17 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

struct cgroup_subsys___22;

struct cgroup_subsys_state___22 {
	struct cgroup___22 *cgroup;
	struct cgroup_subsys___22 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___22 *parent;
};

struct kernfs_node___28;

struct cgroup_file___22 {
	struct kernfs_node___28 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct obj_cgroup___17;

struct mem_cgroup_per_node___17;

struct mem_cgroup___17 {
	struct cgroup_subsys_state___22 css;
	struct mem_cgroup_id id;
	struct page_counter memory;
	union {
		struct page_counter swap;
		struct page_counter memsw;
	};
	struct page_counter kmem;
	struct page_counter tcpmem;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool oom_group;
	bool oom_lock;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___22 events_file;
	struct cgroup_file___22 events_local_file;
	struct cgroup_file___22 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	struct memcg_vmstats vmstats;
	atomic_long_t memory_events[8];
	atomic_long_t memory_events_local[8];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct obj_cgroup___17 *objcg;
	struct list_head objcg_list;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad2_;
	atomic_t moving_account;
	struct task_struct___32 *move_lock_task;
	struct memcg_vmstats_percpu *vmstats_percpu;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct memcg_cgwb_frn cgwb_frn[4];
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct deferred_split deferred_split_queue;
	struct mem_cgroup_per_node___17 *nodeinfo[0];
	long: 64;
};

struct kset___27;

struct kobj_type___27;

struct kobject___28 {
	const char *name;
	struct list_head entry;
	struct kobject___28 *parent;
	struct kset___27 *kset;
	struct kobj_type___27 *ktype;
	struct kernfs_node___28 *sd;
	struct kref kref;
	unsigned int state_initialized;
	unsigned int state_in_sysfs;
	unsigned int state_add_uevent_sent;
	unsigned int state_remove_uevent_sent;
	unsigned int uevent_suppress;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct blk_integrity_profile___18;

struct blk_integrity___18 {
	const struct blk_integrity_profile___18 *profile;
	unsigned char flags;
	unsigned char tuple_size;
	unsigned char interval_exp;
	unsigned char tag_size;
};

struct bio_set___18 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	struct bio_alloc_cache *cache;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	unsigned int back_pad;
	spinlock_t rescue_lock;
	struct bio_list___18 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	struct hlist_node cpuhp_dead;
};

struct request___18;

struct elevator_queue___18;

struct gendisk___18;

struct blkcg_gq___17;

struct request_queue___18 {
	struct request___18 *last_merge;
	struct elevator_queue___18 *elevator;
	struct percpu_ref q_usage_counter;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	const struct blk_mq_ops *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx **queue_hw_ctx;
	unsigned int nr_hw_queues;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	spinlock_t queue_lock;
	struct gendisk___18 *disk;
	struct kobject___28 kobj;
	struct kobject___28 *mq_kobj;
	struct blk_integrity___18 integrity;
	struct device___30 *dev;
	enum rpm_status rpm_status;
	long unsigned int nr_requests;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_keyslot_manager *ksm;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	atomic_t nr_active_requests_shared_sbitmap;
	struct sbitmap_queue sched_bitmap_tags;
	struct sbitmap_queue sched_breserved_tags;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___17 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int required_elevator_features;
	unsigned int nr_zones;
	long unsigned int *conv_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int max_open_zones;
	unsigned int max_active_zones;
	int node;
	struct mutex debugfs_mutex;
	struct blk_trace *blk_trace;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	struct mutex sysfs_dir_lock;
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	int mq_freeze_depth;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct mutex mq_freeze_lock;
	struct blk_mq_tag_set *tag_set;
	struct list_head tag_set_list;
	struct bio_set___18 bio_split;
	struct dentry___28 *debugfs_dir;
	struct dentry___28 *sched_debugfs_dir;
	struct dentry___28 *rqos_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	u64 write_hints[5];
};

struct vm_struct___25 {
	struct vm_struct___25 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___30 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct psi_group___22 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___32 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___22;

struct cgroup_rstat_cpu___22;

struct cgroup___22 {
	struct cgroup_subsys_state___22 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___28 *kn;
	struct cgroup_file___22 procs_file;
	struct cgroup_file___22 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___22 *subsys[14];
	struct cgroup_root___22 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___22 *dom_cgrp;
	struct cgroup___22 *old_dom_cgrp;
	struct cgroup_rstat_cpu___22 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___22 psi;
	struct cgroup_bpf___3 bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

enum siginfo_layout {
	SIL_KILL = 0,
	SIL_TIMER = 1,
	SIL_POLL = 2,
	SIL_FAULT = 3,
	SIL_FAULT_TRAPNO = 4,
	SIL_FAULT_MCEERR = 5,
	SIL_FAULT_BNDERR = 6,
	SIL_FAULT_PKUERR = 7,
	SIL_FAULT_PERF_EVENT = 8,
	SIL_CHLD = 9,
	SIL_RT = 10,
	SIL_SYS = 11,
};

struct tty_driver___6;

struct tty_operations___6;

struct tty_ldisc___6;

struct tty_port___6;

struct tty_struct___6 {
	int magic;
	struct kref kref;
	struct device___30 *dev;
	struct tty_driver___6 *driver;
	const struct tty_operations___6 *ops;
	int index;
	struct ld_semaphore ldisc_sem;
	struct tty_ldisc___6 *ldisc;
	struct mutex atomic_write_lock;
	struct mutex legacy_mutex;
	struct mutex throttle_mutex;
	struct rw_semaphore termios_rwsem;
	struct mutex winsize_mutex;
	struct ktermios termios;
	struct ktermios termios_locked;
	char name[64];
	long unsigned int flags;
	int count;
	struct winsize winsize;
	struct {
		spinlock_t lock;
		bool stopped;
		bool tco_stopped;
		long unsigned int unused[0];
	} flow;
	struct {
		spinlock_t lock;
		struct pid___24 *pgrp;
		struct pid___24 *session;
		unsigned char pktstatus;
		bool packet;
		long unsigned int unused[0];
	} ctrl;
	int hw_stopped;
	unsigned int receive_room;
	int flow_change;
	struct tty_struct___6 *link;
	struct fasync_struct___28 *fasync;
	wait_queue_head_t write_wait;
	wait_queue_head_t read_wait;
	struct work_struct hangup_work;
	void *disc_data;
	void *driver_data;
	spinlock_t files_lock;
	struct list_head tty_files;
	int closing;
	unsigned char *write_buf;
	int write_cnt;
	struct work_struct SAK_work;
	struct tty_port___6 *port;
};

struct fd {
	struct file___28 *file;
	unsigned int flags;
};

struct dentry_operations___28;

struct dentry___28 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___28 *d_parent;
	struct qstr d_name;
	struct inode___28 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___28 *d_op;
	struct super_block___28 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___28;

struct cdev___13;

struct inode___28 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___28 *i_op;
	struct super_block___28 *i_sb;
	struct address_space___28 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___17 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	long: 64;
	long: 64;
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___28 *i_fop;
		void (*free_inode)(struct inode___28 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___28 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct cdev___13 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___28 {
	int (*d_revalidate)(struct dentry___28 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___28 *, unsigned int);
	int (*d_hash)(const struct dentry___28 *, struct qstr *);
	int (*d_compare)(const struct dentry___28 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___28 *);
	int (*d_init)(struct dentry___28 *);
	void (*d_release)(struct dentry___28 *);
	void (*d_prune)(struct dentry___28 *);
	void (*d_iput)(struct dentry___28 *, struct inode___28 *);
	char * (*d_dname)(struct dentry___28 *, char *, int);
	struct vfsmount___28 * (*d_automount)(struct path___28 *);
	int (*d_manage)(const struct path___28 *, bool);
	struct dentry___28 * (*d_real)(struct dentry___28 *, const struct inode___28 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___28;

struct mem_dqinfo___28 {
	struct quota_format_type___28 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___28;

struct quota_info___28 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___28 *files[3];
	struct mem_dqinfo___28 info[3];
	const struct quota_format_ops___28 *ops[3];
};

struct rcuwait___28 {
	struct task_struct___32 *task;
};

struct percpu_rw_semaphore___28 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___28 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___28 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___28 rw_sem[3];
};

struct shrink_control___17;

struct shrinker___17 {
	long unsigned int (*count_objects)(struct shrinker___17 *, struct shrink_control___17 *);
	long unsigned int (*scan_objects)(struct shrinker___17 *, struct shrink_control___17 *);
	long int batch;
	int seeks;
	unsigned int flags;
	struct list_head list;
	int id;
	atomic_long_t *nr_deferred;
};

struct super_operations___28;

struct dquot_operations___28;

struct quotactl_ops___28;

struct block_device___18;

struct super_block___28 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___28 *s_type;
	const struct super_operations___28 *s_op;
	const struct dquot_operations___28 *dq_op;
	const struct quotactl_ops___28 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___28 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___18 *s_bdev;
	struct backing_dev_info___17 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___28 s_dquot;
	struct sb_writers___28 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___28 *s_d_op;
	int cleancache_poolid;
	struct shrinker___17 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___3 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___28 {
	struct dentry___28 *mnt_root;
	struct super_block___28 *mnt_sb;
	int mnt_flags;
	struct user_namespace___3 *mnt_userns;
};

struct shrink_control___17 {
	gfp_t gfp_mask;
	int nid;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	struct mem_cgroup___17 *memcg;
};

struct io_cq___18 {
	struct request_queue___18 *q;
	struct io_context___19 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct kiocb___28 {
	struct file___28 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___28 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___15 *ki_waitq;
	};
};

struct iattr___28 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___28 *ia_file;
};

struct dquot___28 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___28 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___28 {
	int qf_fmt_id;
	const struct quota_format_ops___28 *qf_ops;
	struct module___27 *qf_owner;
	struct quota_format_type___28 *qf_next;
};

struct quota_format_ops___28 {
	int (*check_quota_file)(struct super_block___28 *, int);
	int (*read_file_info)(struct super_block___28 *, int);
	int (*write_file_info)(struct super_block___28 *, int);
	int (*free_file_info)(struct super_block___28 *, int);
	int (*read_dqblk)(struct dquot___28 *);
	int (*commit_dqblk)(struct dquot___28 *);
	int (*release_dqblk)(struct dquot___28 *);
	int (*get_next_id)(struct super_block___28 *, struct kqid *);
};

struct dquot_operations___28 {
	int (*write_dquot)(struct dquot___28 *);
	struct dquot___28 * (*alloc_dquot)(struct super_block___28 *, int);
	void (*destroy_dquot)(struct dquot___28 *);
	int (*acquire_dquot)(struct dquot___28 *);
	int (*release_dquot)(struct dquot___28 *);
	int (*mark_dirty)(struct dquot___28 *);
	int (*write_info)(struct super_block___28 *, int);
	qsize_t * (*get_reserved_space)(struct inode___28 *);
	int (*get_projid)(struct inode___28 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___28 *, qsize_t *);
	int (*get_next_id)(struct super_block___28 *, struct kqid *);
};

struct quotactl_ops___28 {
	int (*quota_on)(struct super_block___28 *, int, int, const struct path___28 *);
	int (*quota_off)(struct super_block___28 *, int);
	int (*quota_enable)(struct super_block___28 *, unsigned int);
	int (*quota_disable)(struct super_block___28 *, unsigned int);
	int (*quota_sync)(struct super_block___28 *, int);
	int (*set_info)(struct super_block___28 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___28 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___28 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___28 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___28 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___28 *, unsigned int);
};

struct module_kobject___27 {
	struct kobject___28 kobj;
	struct module___27 *mod;
	struct kobject___28 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___27 {
	struct module___27 *mod;
	struct latch_tree_node node;
};

struct module_layout___27 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___27 mtn;
};

struct module_attribute___27;

struct kernel_param___27;

struct module___27 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___27 mkobj;
	struct module_attribute___27 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___28 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___27 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___27 core_layout;
	struct module_layout___27 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map___20 *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___17 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	int num_static_call_sites;
	struct static_call_site *static_call_sites;
	bool klp;
	bool klp_alive;
	struct klp_modinfo *klp_info;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct writeback_control___17;

struct address_space_operations___28 {
	int (*writepage)(struct page___30 *, struct writeback_control___17 *);
	int (*readpage)(struct file___28 *, struct page___30 *);
	int (*writepages)(struct address_space___28 *, struct writeback_control___17 *);
	int (*set_page_dirty)(struct page___30 *);
	int (*readpages)(struct file___28 *, struct address_space___28 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control *);
	int (*write_begin)(struct file___28 *, struct address_space___28 *, loff_t, unsigned int, unsigned int, struct page___30 **, void **);
	int (*write_end)(struct file___28 *, struct address_space___28 *, loff_t, unsigned int, unsigned int, struct page___30 *, void *);
	sector_t (*bmap)(struct address_space___28 *, sector_t);
	void (*invalidatepage)(struct page___30 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___30 *, gfp_t);
	void (*freepage)(struct page___30 *);
	ssize_t (*direct_IO)(struct kiocb___28 *, struct iov_iter___22 *);
	int (*migratepage)(struct address_space___28 *, struct page___30 *, struct page___30 *, enum migrate_mode);
	bool (*isolate_page)(struct page___30 *, isolate_mode_t);
	void (*putback_page)(struct page___30 *);
	int (*launder_page)(struct page___30 *);
	int (*is_partially_uptodate)(struct page___30 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___30 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___28 *, struct page___30 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___28 *, sector_t *);
	void (*swap_deactivate)(struct file___28 *);
};

struct writeback_control___17 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate;
	unsigned int for_background;
	unsigned int tagged_writepages;
	unsigned int for_reclaim;
	unsigned int range_cyclic;
	unsigned int for_sync;
	unsigned int no_cgroup_owner;
	unsigned int punt_to_cgroup;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bdi_writeback___17 *wb;
	struct inode___28 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
};

struct bio_vec___22;

struct iov_iter___22 {
	u8 iter_type;
	bool data_source;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___22 *bvec;
		struct xarray *xarray;
		struct pipe_inode_info *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			unsigned int head;
			unsigned int start_head;
		};
		loff_t xarray_start;
	};
};

struct cdev___13 {
	struct kobject___28 kobj;
	struct module___27 *owner;
	const struct file_operations___28 *ops;
	struct list_head list;
	dev_t dev;
	unsigned int count;
};

struct inode_operations___28 {
	struct dentry___28 * (*lookup)(struct inode___28 *, struct dentry___28 *, unsigned int);
	const char * (*get_link)(struct dentry___28 *, struct inode___28 *, struct delayed_call *);
	int (*permission)(struct user_namespace___3 *, struct inode___28 *, int);
	struct posix_acl * (*get_acl)(struct inode___28 *, int, bool);
	int (*readlink)(struct dentry___28 *, char *, int);
	int (*create)(struct user_namespace___3 *, struct inode___28 *, struct dentry___28 *, umode_t, bool);
	int (*link)(struct dentry___28 *, struct inode___28 *, struct dentry___28 *);
	int (*unlink)(struct inode___28 *, struct dentry___28 *);
	int (*symlink)(struct user_namespace___3 *, struct inode___28 *, struct dentry___28 *, const char *);
	int (*mkdir)(struct user_namespace___3 *, struct inode___28 *, struct dentry___28 *, umode_t);
	int (*rmdir)(struct inode___28 *, struct dentry___28 *);
	int (*mknod)(struct user_namespace___3 *, struct inode___28 *, struct dentry___28 *, umode_t, dev_t);
	int (*rename)(struct user_namespace___3 *, struct inode___28 *, struct dentry___28 *, struct inode___28 *, struct dentry___28 *, unsigned int);
	int (*setattr)(struct user_namespace___3 *, struct dentry___28 *, struct iattr___28 *);
	int (*getattr)(struct user_namespace___3 *, const struct path___28 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___28 *, char *, size_t);
	int (*fiemap)(struct inode___28 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___28 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___28 *, struct dentry___28 *, struct file___28 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace___3 *, struct inode___28 *, struct dentry___28 *, umode_t);
	int (*set_acl)(struct user_namespace___3 *, struct inode___28 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace___3 *, struct dentry___28 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___28 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___28 {
	void (*fl_copy_lock)(struct file_lock___28 *, struct file_lock___28 *);
	void (*fl_release_private)(struct file_lock___28 *);
};

struct lock_manager_operations___28;

struct file_lock___28 {
	struct file_lock___28 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___28 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___28 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___28 *fl_ops;
	const struct lock_manager_operations___28 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___28 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___28 *);
	int (*lm_grant)(struct file_lock___28 *, int);
	bool (*lm_break)(struct file_lock___28 *);
	int (*lm_change)(struct file_lock___28 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___28 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___28 *);
};

struct fasync_struct___28 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___28 *fa_next;
	struct file___28 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___28 {
	struct inode___28 * (*alloc_inode)(struct super_block___28 *);
	void (*destroy_inode)(struct inode___28 *);
	void (*free_inode)(struct inode___28 *);
	void (*dirty_inode)(struct inode___28 *, int);
	int (*write_inode)(struct inode___28 *, struct writeback_control___17 *);
	int (*drop_inode)(struct inode___28 *);
	void (*evict_inode)(struct inode___28 *);
	void (*put_super)(struct super_block___28 *);
	int (*sync_fs)(struct super_block___28 *, int);
	int (*freeze_super)(struct super_block___28 *);
	int (*freeze_fs)(struct super_block___28 *);
	int (*thaw_super)(struct super_block___28 *);
	int (*unfreeze_fs)(struct super_block___28 *);
	int (*statfs)(struct dentry___28 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___28 *, int *, char *);
	void (*umount_begin)(struct super_block___28 *);
	int (*show_options)(struct seq_file___26 *, struct dentry___28 *);
	int (*show_devname)(struct seq_file___26 *, struct dentry___28 *);
	int (*show_path)(struct seq_file___26 *, struct dentry___28 *);
	int (*show_stats)(struct seq_file___26 *, struct dentry___28 *);
	ssize_t (*quota_read)(struct super_block___28 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___28 *, int, const char *, size_t, loff_t);
	struct dquot___28 ** (*get_dquots)(struct inode___28 *);
	long int (*nr_cached_objects)(struct super_block___28 *, struct shrink_control___17 *);
	long int (*free_cached_objects)(struct super_block___28 *, struct shrink_control___17 *);
	struct file___28 * (*real_loop)(struct file___28 *);
};

struct wakeup_source___30;

struct dev_pm_info___30 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___30 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___30 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___30;

struct bus_type___30;

struct device_driver___30;

struct dev_pm_domain___30;

struct fwnode_handle___27;

struct class___30;

struct attribute_group___28;

struct device___30 {
	struct kobject___28 kobj;
	struct device___30 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___30 *type;
	struct bus_type___30 *bus;
	struct device_driver___30 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___30 power;
	struct dev_pm_domain___30 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node *of_node;
	struct fwnode_handle___27 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___30 *class;
	const struct attribute_group___28 **groups;
	void (*release)(struct device___30 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct block_device___18 {
	sector_t bd_start_sect;
	struct disk_stats *bd_stats;
	long unsigned int bd_stamp;
	bool bd_read_only;
	dev_t bd_dev;
	int bd_openers;
	struct inode___28 *bd_inode;
	struct super_block___28 *bd_super;
	void *bd_claiming;
	struct device___30 bd_device;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct kobject___28 *bd_holder_dir;
	u8 bd_partno;
	spinlock_t bd_size_lock;
	struct gendisk___18 *bd_disk;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	struct super_block___28 *bd_fsfreeze_sb;
	struct partition_meta_info *bd_meta_info;
};

typedef void (*poll_queue_proc___20)(struct file___28 *, wait_queue_head_t *, struct poll_table_struct___20 *);

struct poll_table_struct___20 {
	poll_queue_proc___20 _qproc;
	__poll_t _key;
};

struct seq_file___26 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___26 *op;
	int poll_event;
	const struct file___28 *file;
	void *private;
};

typedef void bio_end_io_t___18(struct bio___18 *);

struct bio_vec___22 {
	struct page___30 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___18;

struct bio___18 {
	struct bio___18 *bi_next;
	struct block_device___18 *bi_bdev;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	atomic_t __bi_remaining;
	struct bvec_iter bi_iter;
	bio_end_io_t___18 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___17 *bi_blkg;
	struct bio_issue bi_issue;
	u64 bi_iocost_cost;
	struct bio_crypt_ctx *bi_crypt_context;
	union {
		struct bio_integrity_payload___18 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___22 *bi_io_vec;
	struct bio_set___18 *bi_pool;
	struct bio_vec___22 bi_inline_vecs[0];
};

struct kernfs_root___28;

struct kernfs_elem_dir___28 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___28 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___28;

struct kernfs_root___28 {
	struct kernfs_node___28 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___28 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___28 {
	struct kernfs_node___28 *target_kn;
};

struct kernfs_ops___28;

struct kernfs_elem_attr___28 {
	const struct kernfs_ops___28 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___28 *notify_next;
};

struct kernfs_node___28 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___28 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___28 dir;
		struct kernfs_elem_symlink___28 symlink;
		struct kernfs_elem_attr___28 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___28;

struct kernfs_ops___28 {
	int (*open)(struct kernfs_open_file___28 *);
	void (*release)(struct kernfs_open_file___28 *);
	int (*seq_show)(struct seq_file___26 *, void *);
	void * (*seq_start)(struct seq_file___26 *, loff_t *);
	void * (*seq_next)(struct seq_file___26 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___26 *, void *);
	ssize_t (*read)(struct kernfs_open_file___28 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___28 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___28 *, struct poll_table_struct___20 *);
	int (*mmap)(struct kernfs_open_file___28 *, struct vm_area_struct___31 *);
};

struct kernfs_syscall_ops___28 {
	int (*show_options)(struct seq_file___26 *, struct kernfs_root___28 *);
	int (*mkdir)(struct kernfs_node___28 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___28 *);
	int (*rename)(struct kernfs_node___28 *, struct kernfs_node___28 *, const char *);
	int (*show_path)(struct seq_file___26 *, struct kernfs_node___28 *, struct kernfs_root___28 *);
};

struct kernfs_open_file___28 {
	struct kernfs_node___28 *kn;
	struct file___28 *file;
	struct seq_file___26 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped;
	bool released;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___28 *vm_ops;
};

struct bin_attribute___28;

struct attribute_group___28 {
	const char *name;
	umode_t (*is_visible)(struct kobject___28 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___28 *, struct bin_attribute___28 *, int);
	struct attribute **attrs;
	struct bin_attribute___28 **bin_attrs;
};

struct bin_attribute___28 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___28 * (*f_mapping)();
	ssize_t (*read)(struct file___28 *, struct kobject___28 *, struct bin_attribute___28 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___28 *, struct kobject___28 *, struct bin_attribute___28 *, char *, loff_t, size_t);
	int (*mmap)(struct file___28 *, struct kobject___28 *, struct bin_attribute___28 *, struct vm_area_struct___31 *);
};

struct sysfs_ops___27 {
	ssize_t (*show)(struct kobject___28 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___28 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___27;

struct kset___27 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___28 kobj;
	const struct kset_uevent_ops___27 *uevent_ops;
};

struct kobj_type___27 {
	void (*release)(struct kobject___28 *);
	const struct sysfs_ops___27 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___28 **default_groups;
	const struct kobj_ns_type_operations___2 * (*child_ns_type)(struct kobject___28 *);
	const void * (*namespace)(struct kobject___28 *);
	void (*get_ownership)(struct kobject___28 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___27 {
	int (* const filter)(struct kset___27 *, struct kobject___28 *);
	const char * (* const name)(struct kset___27 *, struct kobject___28 *);
	int (* const uevent)(struct kset___27 *, struct kobject___28 *, struct kobj_uevent_env *);
};

struct dev_pm_ops___30 {
	int (*prepare)(struct device___30 *);
	void (*complete)(struct device___30 *);
	int (*suspend)(struct device___30 *);
	int (*resume)(struct device___30 *);
	int (*freeze)(struct device___30 *);
	int (*thaw)(struct device___30 *);
	int (*poweroff)(struct device___30 *);
	int (*restore)(struct device___30 *);
	int (*suspend_late)(struct device___30 *);
	int (*resume_early)(struct device___30 *);
	int (*freeze_late)(struct device___30 *);
	int (*thaw_early)(struct device___30 *);
	int (*poweroff_late)(struct device___30 *);
	int (*restore_early)(struct device___30 *);
	int (*suspend_noirq)(struct device___30 *);
	int (*resume_noirq)(struct device___30 *);
	int (*freeze_noirq)(struct device___30 *);
	int (*thaw_noirq)(struct device___30 *);
	int (*poweroff_noirq)(struct device___30 *);
	int (*restore_noirq)(struct device___30 *);
	int (*runtime_suspend)(struct device___30 *);
	int (*runtime_resume)(struct device___30 *);
	int (*runtime_idle)(struct device___30 *);
};

struct wakeup_source___30 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___30 *dev;
	bool active;
	bool autosleep_enabled;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___30 {
	struct dev_pm_ops___30 ops;
	int (*start)(struct device___30 *);
	void (*detach)(struct device___30 *, bool);
	int (*activate)(struct device___30 *);
	void (*sync)(struct device___30 *);
	void (*dismiss)(struct device___30 *);
};

struct bus_type___30 {
	const char *name;
	const char *dev_name;
	struct device___30 *dev_root;
	const struct attribute_group___28 **bus_groups;
	const struct attribute_group___28 **dev_groups;
	const struct attribute_group___28 **drv_groups;
	int (*match)(struct device___30 *, struct device_driver___30 *);
	int (*uevent)(struct device___30 *, struct kobj_uevent_env *);
	int (*probe)(struct device___30 *);
	void (*sync_state)(struct device___30 *);
	void (*remove)(struct device___30 *);
	void (*shutdown)(struct device___30 *);
	int (*online)(struct device___30 *);
	int (*offline)(struct device___30 *);
	int (*suspend)(struct device___30 *, pm_message_t);
	int (*resume)(struct device___30 *);
	int (*num_vf)(struct device___30 *);
	int (*dma_configure)(struct device___30 *);
	const struct dev_pm_ops___30 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___30 {
	const char *name;
	struct bus_type___30 *bus;
	struct module___27 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___30 *);
	void (*sync_state)(struct device___30 *);
	int (*remove)(struct device___30 *);
	void (*shutdown)(struct device___30 *);
	int (*suspend)(struct device___30 *, pm_message_t);
	int (*resume)(struct device___30 *);
	const struct attribute_group___28 **groups;
	const struct attribute_group___28 **dev_groups;
	const struct dev_pm_ops___30 *pm;
	void (*coredump)(struct device___30 *);
	struct driver_private *p;
};

struct device_type___30 {
	const char *name;
	const struct attribute_group___28 **groups;
	int (*uevent)(struct device___30 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___30 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___30 *);
	const struct dev_pm_ops___30 *pm;
};

struct class___30 {
	const char *name;
	struct module___27 *owner;
	const struct attribute_group___28 **class_groups;
	const struct attribute_group___28 **dev_groups;
	struct kobject___28 *dev_kobj;
	int (*dev_uevent)(struct device___30 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___30 *, umode_t *);
	void (*class_release)(struct class___30 *);
	void (*dev_release)(struct device___30 *);
	int (*shutdown_pre)(struct device___30 *);
	const struct kobj_ns_type_operations___2 *ns_type;
	const void * (*namespace)(struct device___30 *);
	void (*get_ownership)(struct device___30 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___30 *pm;
	struct subsys_private *p;
};

struct fwnode_operations___27;

struct fwnode_handle___27 {
	struct fwnode_handle___27 *secondary;
	const struct fwnode_operations___27 *ops;
	struct device___30 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct tty_operations___6 {
	struct tty_struct___6 * (*lookup)(struct tty_driver___6 *, struct file___28 *, int);
	int (*install)(struct tty_driver___6 *, struct tty_struct___6 *);
	void (*remove)(struct tty_driver___6 *, struct tty_struct___6 *);
	int (*open)(struct tty_struct___6 *, struct file___28 *);
	void (*close)(struct tty_struct___6 *, struct file___28 *);
	void (*shutdown)(struct tty_struct___6 *);
	void (*cleanup)(struct tty_struct___6 *);
	int (*write)(struct tty_struct___6 *, const unsigned char *, int);
	int (*put_char)(struct tty_struct___6 *, unsigned char);
	void (*flush_chars)(struct tty_struct___6 *);
	unsigned int (*write_room)(struct tty_struct___6 *);
	unsigned int (*chars_in_buffer)(struct tty_struct___6 *);
	int (*ioctl)(struct tty_struct___6 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct tty_struct___6 *, unsigned int, long unsigned int);
	void (*set_termios)(struct tty_struct___6 *, struct ktermios *);
	void (*throttle)(struct tty_struct___6 *);
	void (*unthrottle)(struct tty_struct___6 *);
	void (*stop)(struct tty_struct___6 *);
	void (*start)(struct tty_struct___6 *);
	void (*hangup)(struct tty_struct___6 *);
	int (*break_ctl)(struct tty_struct___6 *, int);
	void (*flush_buffer)(struct tty_struct___6 *);
	void (*set_ldisc)(struct tty_struct___6 *);
	void (*wait_until_sent)(struct tty_struct___6 *, int);
	void (*send_xchar)(struct tty_struct___6 *, char);
	int (*tiocmget)(struct tty_struct___6 *);
	int (*tiocmset)(struct tty_struct___6 *, unsigned int, unsigned int);
	int (*resize)(struct tty_struct___6 *, struct winsize *);
	int (*get_icount)(struct tty_struct___6 *, struct serial_icounter_struct *);
	int (*get_serial)(struct tty_struct___6 *, struct serial_struct *);
	int (*set_serial)(struct tty_struct___6 *, struct serial_struct *);
	void (*show_fdinfo)(struct tty_struct___6 *, struct seq_file___26 *);
	int (*poll_init)(struct tty_driver___6 *, int, char *);
	int (*poll_get_char)(struct tty_driver___6 *, int);
	void (*poll_put_char)(struct tty_driver___6 *, int, char);
	int (*proc_show)(struct seq_file___26 *, void *);
};

struct tty_driver___6 {
	int magic;
	struct kref kref;
	struct cdev___13 **cdevs;
	struct module___27 *owner;
	const char *driver_name;
	const char *name;
	int name_base;
	int major;
	int minor_start;
	unsigned int num;
	short int type;
	short int subtype;
	struct ktermios init_termios;
	long unsigned int flags;
	struct proc_dir_entry *proc_entry;
	struct tty_driver___6 *other;
	struct tty_struct___6 **ttys;
	struct tty_port___6 **ports;
	struct ktermios **termios;
	void *driver_state;
	const struct tty_operations___6 *ops;
	struct list_head tty_drivers;
};

struct tty_port_operations___6;

struct tty_port_client_operations___6;

struct tty_port___6 {
	struct tty_bufhead buf;
	struct tty_struct___6 *tty;
	struct tty_struct___6 *itty;
	const struct tty_port_operations___6 *ops;
	const struct tty_port_client_operations___6 *client_ops;
	spinlock_t lock;
	int blocked_open;
	int count;
	wait_queue_head_t open_wait;
	wait_queue_head_t delta_msr_wait;
	long unsigned int flags;
	long unsigned int iflags;
	unsigned char console;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct mutex mutex;
	struct mutex buf_mutex;
	unsigned char *xmit_buf;
	unsigned int close_delay;
	unsigned int closing_wait;
	int drain_delay;
	struct kref kref;
	void *client_data;
};

struct tty_ldisc_ops___6 {
	char *name;
	int num;
	int flags;
	int (*open)(struct tty_struct___6 *);
	void (*close)(struct tty_struct___6 *);
	void (*flush_buffer)(struct tty_struct___6 *);
	ssize_t (*read)(struct tty_struct___6 *, struct file___28 *, unsigned char *, size_t, void **, long unsigned int);
	ssize_t (*write)(struct tty_struct___6 *, struct file___28 *, const unsigned char *, size_t);
	int (*ioctl)(struct tty_struct___6 *, struct file___28 *, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct tty_struct___6 *, struct file___28 *, unsigned int, long unsigned int);
	void (*set_termios)(struct tty_struct___6 *, struct ktermios *);
	__poll_t (*poll)(struct tty_struct___6 *, struct file___28 *, struct poll_table_struct___20 *);
	int (*hangup)(struct tty_struct___6 *);
	void (*receive_buf)(struct tty_struct___6 *, const unsigned char *, const char *, int);
	void (*write_wakeup)(struct tty_struct___6 *);
	void (*dcd_change)(struct tty_struct___6 *, unsigned int);
	int (*receive_buf2)(struct tty_struct___6 *, const unsigned char *, const char *, int);
	struct module___27 *owner;
};

struct tty_ldisc___6 {
	struct tty_ldisc_ops___6 *ops;
	struct tty_struct___6 *tty;
};

struct tty_port_operations___6 {
	int (*carrier_raised)(struct tty_port___6 *);
	void (*dtr_rts)(struct tty_port___6 *, int);
	void (*shutdown)(struct tty_port___6 *);
	int (*activate)(struct tty_port___6 *, struct tty_struct___6 *);
	void (*destruct)(struct tty_port___6 *);
};

struct tty_port_client_operations___6 {
	int (*receive_buf)(struct tty_port___6 *, const unsigned char *, const unsigned char *, size_t);
	void (*write_wakeup)(struct tty_port___6 *);
};

struct linux_binprm___7 {
	struct vm_area_struct___31 *vma;
	long unsigned int vma_pages;
	struct mm_struct___31 *mm;
	long unsigned int p;
	long unsigned int argmin;
	unsigned int have_execfd;
	unsigned int execfd_creds;
	unsigned int secureexec;
	unsigned int point_of_no_return;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct file___28 *executable;
	struct file___28 *interpreter;
	struct file___28 *file;
	struct cred *cred;
	int unsafe;
	unsigned int per_clear;
	int argc;
	int envc;
	const char *filename;
	const char *interp;
	const char *fdpath;
	unsigned int interp_flags;
	int execfd;
	long unsigned int loader;
	long unsigned int exec;
	struct rlimit rlim_stack;
	char buf[256];
};

struct coredump_params___6 {
	const kernel_siginfo_t *siginfo;
	struct pt_regs *regs;
	struct file___28 *file;
	long unsigned int limit;
	long unsigned int mm_flags;
	loff_t written;
	loff_t pos;
	loff_t to_skip;
};

struct dev_pagemap_ops___28 {
	void (*page_free)(struct page___30 *);
	void (*kill)(struct dev_pagemap___28 *);
	void (*cleanup)(struct dev_pagemap___28 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___28 *);
};

struct cgroup_namespace___22 {
	struct ns_common___3 ns;
	struct user_namespace___3 *user_ns;
	struct ucounts___3 *ucounts;
	struct css_set___22 *root_cset;
};

struct perf_cpu_context___17;

struct perf_output_handle___17;

struct pmu___17 {
	struct list_head entry;
	struct module___27 *module;
	struct device___30 *dev;
	const struct attribute_group___28 **attr_groups;
	const struct attribute_group___28 **attr_update;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___17 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___17 *);
	void (*pmu_disable)(struct pmu___17 *);
	int (*event_init)(struct perf_event___17 *);
	void (*event_mapped)(struct perf_event___17 *, struct mm_struct___31 *);
	void (*event_unmapped)(struct perf_event___17 *, struct mm_struct___31 *);
	int (*add)(struct perf_event___17 *, int);
	void (*del)(struct perf_event___17 *, int);
	void (*start)(struct perf_event___17 *, int);
	void (*stop)(struct perf_event___17 *, int);
	void (*read)(struct perf_event___17 *);
	void (*start_txn)(struct pmu___17 *, unsigned int);
	int (*commit_txn)(struct pmu___17 *);
	void (*cancel_txn)(struct pmu___17 *);
	int (*event_idx)(struct perf_event___17 *);
	void (*sched_task)(struct perf_event_context___17 *, bool);
	struct kmem_cache *task_ctx_cache;
	void (*swap_task_ctx)(struct perf_event_context___17 *, struct perf_event_context___17 *);
	void * (*setup_aux)(struct perf_event___17 *, void **, int, bool);
	void (*free_aux)(void *);
	long int (*snapshot_aux)(struct perf_event___17 *, struct perf_output_handle___17 *, long unsigned int);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___17 *);
	int (*aux_output_match)(struct perf_event___17 *);
	int (*filter_match)(struct perf_event___17 *);
	int (*check_period)(struct perf_event___17 *, u64);
};

struct kernel_param_ops___27 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___27 *);
	int (*get)(char *, const struct kernel_param___27 *);
	void (*free)(void *);
};

struct kparam_array___27;

struct kernel_param___27 {
	const char *name;
	struct module___27 *mod;
	const struct kernel_param_ops___27 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___27 *arr;
	};
};

struct kparam_array___27 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___27 *ops;
	void *elem;
};

struct module_attribute___27 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___27 *, struct module_kobject___27 *, char *);
	ssize_t (*store)(struct module_attribute___27 *, struct module_kobject___27 *, const char *, size_t);
	void (*setup)(struct module___27 *, const char *);
	int (*test)(struct module___27 *);
	void (*free)(struct module___27 *);
};

struct trace_event_class___17;

struct trace_event_call___17 {
	struct list_head list;
	struct trace_event_class___17 *class;
	union {
		char *name;
		struct tracepoint___20 *tp;
	};
	struct trace_event event;
	char *print_fmt;
	struct event_filter *filter;
	union {
		void *module;
		atomic_t refcnt;
	};
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
	struct bpf_prog_array___3 *prog_array;
	int (*perf_perm)(struct trace_event_call___17 *, struct perf_event___17 *);
};

typedef u32 compat_old_sigset_t;

struct compat_sigaction {
	compat_uptr_t sa_handler;
	compat_ulong_t sa_flags;
	compat_uptr_t sa_restorer;
	compat_sigset_t sa_mask;
};

struct compat_old_sigaction {
	compat_uptr_t sa_handler;
	compat_old_sigset_t sa_mask;
	compat_ulong_t sa_flags;
	compat_uptr_t sa_restorer;
};

struct cftype___22;

struct cgroup_subsys___22 {
	struct cgroup_subsys_state___22 * (*css_alloc)(struct cgroup_subsys_state___22 *);
	int (*css_online)(struct cgroup_subsys_state___22 *);
	void (*css_offline)(struct cgroup_subsys_state___22 *);
	void (*css_released)(struct cgroup_subsys_state___22 *);
	void (*css_free)(struct cgroup_subsys_state___22 *);
	void (*css_reset)(struct cgroup_subsys_state___22 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___22 *, int);
	int (*css_extra_stat_show)(struct seq_file___26 *, struct cgroup_subsys_state___22 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___32 *, struct css_set___22 *);
	void (*cancel_fork)(struct task_struct___32 *, struct css_set___22 *);
	void (*fork)(struct task_struct___32 *);
	void (*exit)(struct task_struct___32 *);
	void (*release)(struct task_struct___32 *);
	void (*bind)(struct cgroup_subsys_state___22 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___22 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___22 *dfl_cftypes;
	struct cftype___22 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___22 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___22 *updated_children;
	struct cgroup___22 *updated_next;
};

struct cgroup_root___22 {
	struct kernfs_root___28 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___22 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___22 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___22 *ss;
	struct list_head node;
	struct kernfs_ops___28 *kf_ops;
	int (*open)(struct kernfs_open_file___28 *);
	void (*release)(struct kernfs_open_file___28 *);
	u64 (*read_u64)(struct cgroup_subsys_state___22 *, struct cftype___22 *);
	s64 (*read_s64)(struct cgroup_subsys_state___22 *, struct cftype___22 *);
	int (*seq_show)(struct seq_file___26 *, void *);
	void * (*seq_start)(struct seq_file___26 *, loff_t *);
	void * (*seq_next)(struct seq_file___26 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___26 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___22 *, struct cftype___22 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___22 *, struct cftype___22 *, s64);
	ssize_t (*write)(struct kernfs_open_file___28 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___28 *, struct poll_table_struct___20 *);
};

struct perf_cpu_context___17 {
	struct perf_event_context___17 ctx;
	struct perf_event_context___17 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___17 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
	int heap_size;
	struct perf_event___17 **heap;
	struct perf_event___17 *heap_default[2];
};

struct perf_output_handle___17 {
	struct perf_event___17 *event;
	struct perf_buffer *rb;
	long unsigned int wakeup;
	long unsigned int size;
	u64 aux_flags;
	union {
		void *addr;
		long unsigned int head;
	};
	int page;
};

struct perf_cgroup___17 {
	struct cgroup_subsys_state___22 css;
	struct perf_cgroup_info *info;
};

struct trace_event_fields___17 {
	const char *type;
	union {
		struct {
			const char *name;
			const int size;
			const int align;
			const int is_signed;
			const int filter_type;
		};
		int (*define_fields)(struct trace_event_call___17 *);
	};
};

struct trace_event_class___17 {
	const char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct trace_event_call___17 *, enum trace_reg, void *);
	struct trace_event_fields___17 *fields_array;
	struct list_head * (*get_fields)(struct trace_event_call___17 *);
	struct list_head fields;
	int (*raw_init)(struct trace_event_call___17 *);
};

struct trace_event_file___10;

struct trace_event_buffer___10 {
	struct trace_buffer *buffer;
	struct ring_buffer_event *event;
	struct trace_event_file___10 *trace_file;
	void *entry;
	unsigned int trace_ctx;
	struct pt_regs *regs;
};

struct trace_event_file___10 {
	struct list_head list;
	struct trace_event_call___17 *event_call;
	struct event_filter *filter;
	struct dentry___28 *dir;
	struct trace_array *tr;
	struct trace_subsystem_dir *system;
	struct list_head triggers;
	long unsigned int flags;
	atomic_t sm_ref;
	atomic_t tm_ref;
};

struct syscall_metadata___5 {
	const char *name;
	int syscall_nr;
	int nb_args;
	const char **types;
	const char **args;
	struct list_head enter_fields;
	struct trace_event_call___17 *enter_event;
	struct trace_event_call___17 *exit_event;
};

struct block_device_operations___18;

struct gendisk___18 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	short unsigned int events;
	short unsigned int event_flags;
	struct xarray part_tbl;
	struct block_device___18 *part0;
	const struct block_device_operations___18 *fops;
	struct request_queue___18 *queue;
	void *private_data;
	int flags;
	long unsigned int state;
	struct mutex open_mutex;
	unsigned int open_partitions;
	struct backing_dev_info___17 *bdi;
	struct kobject___28 *slave_dir;
	struct list_head slave_bdevs;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___28 integrity_kobj;
	struct cdrom_device_info *cdi;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	u64 diskseq;
};

struct bio_integrity_payload___18 {
	struct bio___18 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___22 *bip_vec;
	struct bio_vec___22 bip_inline_vecs[0];
};

struct blkcg___17;

struct blkg_policy_data___17;

struct blkcg_gq___17 {
	struct request_queue___18 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___17 *blkcg;
	struct blkcg_gq___17 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_iostat_set *iostat_cpu;
	struct blkg_iostat_set iostat;
	struct blkg_policy_data___17 *pd[6];
	spinlock_t async_bio_lock;
	struct bio_list___18 async_bios;
	struct work_struct async_bio_work;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
	struct callback_head callback_head;
};

typedef void integrity_prepare_fn___18(struct request___18 *);

typedef void integrity_complete_fn___18(struct request___18 *, unsigned int);

struct blk_integrity_profile___18 {
	integrity_processing_fn *generate_fn;
	integrity_processing_fn *verify_fn;
	integrity_prepare_fn___18 *prepare_fn;
	integrity_complete_fn___18 *complete_fn;
	const char *name;
};

struct block_device_operations___18 {
	blk_qc_t (*submit_bio)(struct bio___18 *);
	int (*open)(struct block_device___18 *, fmode_t);
	void (*release)(struct gendisk___18 *, fmode_t);
	int (*rw_page)(struct block_device___18 *, sector_t, struct page___30 *, unsigned int);
	int (*ioctl)(struct block_device___18 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___18 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___18 *, unsigned int);
	void (*unlock_native_capacity)(struct gendisk___18 *);
	int (*getgeo)(struct block_device___18 *, struct hd_geometry *);
	int (*set_read_only)(struct block_device___18 *, bool);
	void (*swap_slot_free_notify)(struct block_device___18 *, long unsigned int);
	int (*report_zones)(struct gendisk___18 *, sector_t, unsigned int, report_zones_cb, void *);
	char * (*devnode)(struct gendisk___18 *, umode_t *);
	struct module___27 *owner;
	const struct pr_ops *pr_ops;
	int (*alternative_gpt_sector)(struct gendisk___18 *, sector_t *);
};

struct fwnode_reference_args___27;

struct fwnode_endpoint___27;

struct fwnode_operations___27 {
	struct fwnode_handle___27 * (*get)(struct fwnode_handle___27 *);
	void (*put)(struct fwnode_handle___27 *);
	bool (*device_is_available)(const struct fwnode_handle___27 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___27 *, const struct device___30 *);
	bool (*property_present)(const struct fwnode_handle___27 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___27 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___27 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___27 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___27 *);
	struct fwnode_handle___27 * (*get_parent)(const struct fwnode_handle___27 *);
	struct fwnode_handle___27 * (*get_next_child_node)(const struct fwnode_handle___27 *, struct fwnode_handle___27 *);
	struct fwnode_handle___27 * (*get_named_child_node)(const struct fwnode_handle___27 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___27 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___27 *);
	struct fwnode_handle___27 * (*graph_get_next_endpoint)(const struct fwnode_handle___27 *, struct fwnode_handle___27 *);
	struct fwnode_handle___27 * (*graph_get_remote_endpoint)(const struct fwnode_handle___27 *);
	struct fwnode_handle___27 * (*graph_get_port_parent)(struct fwnode_handle___27 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___27 *, struct fwnode_endpoint___27 *);
	int (*add_links)(struct fwnode_handle___27 *);
};

struct fwnode_endpoint___27 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___27 *local_fwnode;
};

struct fwnode_reference_args___27 {
	struct fwnode_handle___27 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

typedef void rq_end_io_fn___18(struct request___18 *, blk_status_t);

struct request___18 {
	struct request_queue___18 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int tag;
	int internal_tag;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___18 *bio;
	struct bio___18 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct llist_node ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___22 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___18 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___18 *saved_end_io;
		} flush;
	};
	struct gendisk___18 *rq_disk;
	struct block_device___18 *part;
	u64 alloc_time_ns;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int stats_sectors;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	struct bio_crypt_ctx *crypt_ctx;
	struct blk_ksm_keyslot *crypt_keyslot;
	short unsigned int write_hint;
	short unsigned int ioprio;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___18 *end_io;
	void *end_io_data;
};

struct elevator_type___18;

struct elevator_mq_ops___18 {
	int (*init_sched)(struct request_queue___18 *, struct elevator_type___18 *);
	void (*exit_sched)(struct elevator_queue___18 *);
	int (*init_hctx)(struct blk_mq_hw_ctx *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx *, unsigned int);
	void (*depth_updated)(struct blk_mq_hw_ctx *);
	bool (*allow_merge)(struct request_queue___18 *, struct request___18 *, struct bio___18 *);
	bool (*bio_merge)(struct request_queue___18 *, struct bio___18 *, unsigned int);
	int (*request_merge)(struct request_queue___18 *, struct request___18 **, struct bio___18 *);
	void (*request_merged)(struct request_queue___18 *, struct request___18 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___18 *, struct request___18 *, struct request___18 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___18 *);
	void (*finish_request)(struct request___18 *);
	void (*insert_requests)(struct blk_mq_hw_ctx *, struct list_head *, bool);
	struct request___18 * (*dispatch_request)(struct blk_mq_hw_ctx *);
	bool (*has_work)(struct blk_mq_hw_ctx *);
	void (*completed_request)(struct request___18 *, u64);
	void (*requeue_request)(struct request___18 *);
	struct request___18 * (*former_request)(struct request_queue___18 *, struct request___18 *);
	struct request___18 * (*next_request)(struct request_queue___18 *, struct request___18 *);
	void (*init_icq)(struct io_cq___18 *);
	void (*exit_icq)(struct io_cq___18 *);
};

struct elv_fs_entry___18;

struct elevator_type___18 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___18 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___18 *elevator_attrs;
	const char *elevator_name;
	const char *elevator_alias;
	const unsigned int elevator_features;
	struct module___27 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
};

struct elevator_queue___18 {
	struct elevator_type___18 *type;
	void *elevator_data;
	struct kobject___28 kobj;
	struct mutex sysfs_lock;
	unsigned int registered;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hlist_head hash[64];
};

struct elv_fs_entry___18 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___18 *, char *);
	ssize_t (*store)(struct elevator_queue___18 *, const char *, size_t);
};

struct blkcg_policy_data___17;

struct blkcg___17 {
	struct cgroup_subsys_state___22 css;
	spinlock_t lock;
	refcount_t online_pin;
	struct xarray blkg_tree;
	struct blkcg_gq___17 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___17 *cpd[6];
	struct list_head all_blkcgs_node;
	char fc_app_id[129];
	struct list_head cgwb_list;
};

struct blkcg_policy_data___17 {
	struct blkcg___17 *blkcg;
	int plid;
};

struct blkg_policy_data___17 {
	struct blkcg_gq___17 *blkg;
	int plid;
};

struct mem_cgroup_reclaim_iter___17 {
	struct mem_cgroup___17 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___17 {
	struct lruvec___18 lruvec;
	struct lruvec_stats_percpu *lruvec_stats_percpu;
	struct lruvec_stats lruvec_stats;
	long unsigned int lru_zone_size[25];
	struct mem_cgroup_reclaim_iter___17 iter;
	struct shrinker_info *shrinker_info;
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	struct mem_cgroup___17 *memcg;
};

struct obj_cgroup___17 {
	struct percpu_ref refcnt;
	struct mem_cgroup___17 *memcg;
	atomic_t nr_charged_bytes;
	union {
		struct list_head list;
		struct callback_head rcu;
	};
};

enum {
	TRACE_SIGNAL_DELIVERED = 0,
	TRACE_SIGNAL_IGNORED = 1,
	TRACE_SIGNAL_ALREADY_PENDING = 2,
	TRACE_SIGNAL_OVERFLOW_FAIL = 3,
	TRACE_SIGNAL_LOSE_INFO = 4,
};

struct trace_event_raw_signal_generate {
	struct trace_entry ent;
	int sig;
	int errno;
	int code;
	char comm[16];
	pid_t pid;
	int group;
	int result;
	char __data[0];
};

struct trace_event_raw_signal_deliver {
	struct trace_entry ent;
	int sig;
	int errno;
	int code;
	long unsigned int sa_handler;
	long unsigned int sa_flags;
	char __data[0];
};

struct trace_event_data_offsets_signal_generate {};

struct trace_event_data_offsets_signal_deliver {};

typedef void (*btf_trace_signal_generate)(void *, int, struct kernel_siginfo *, struct task_struct___32 *, int, int);

typedef void (*btf_trace_signal_deliver)(void *, int, struct kernel_siginfo *, struct k_sigaction *);

enum sig_handler {
	HANDLER_CURRENT = 0,
	HANDLER_SIG_DFL = 1,
	HANDLER_EXIT = 2,
};

struct dentry___29;

struct super_block___29;

struct module___28;

struct file_system_type___29 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___29 * (*mount)(struct file_system_type___29 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___29 *);
	struct module___28 *owner;
	struct file_system_type___29 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct sysinfo {
	__kernel_long_t uptime;
	__kernel_ulong_t loads[3];
	__kernel_ulong_t totalram;
	__kernel_ulong_t freeram;
	__kernel_ulong_t sharedram;
	__kernel_ulong_t bufferram;
	__kernel_ulong_t totalswap;
	__kernel_ulong_t freeswap;
	__u16 procs;
	__u16 pad;
	__kernel_ulong_t totalhigh;
	__kernel_ulong_t freehigh;
	__u32 mem_unit;
	char _f[0];
};

struct file___29;

struct kiocb___29;

struct iov_iter___23;

struct poll_table_struct___21;

struct vm_area_struct___32;

struct inode___29;

struct file_lock___29;

struct page___31;

struct seq_file___27;

struct file_operations___29 {
	struct module___28 *owner;
	loff_t (*llseek)(struct file___29 *, loff_t, int);
	ssize_t (*read)(struct file___29 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___29 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___29 *, struct iov_iter___23 *);
	ssize_t (*write_iter)(struct kiocb___29 *, struct iov_iter___23 *);
	int (*iopoll)(struct kiocb___29 *, bool);
	int (*iterate)(struct file___29 *, struct dir_context *);
	int (*iterate_shared)(struct file___29 *, struct dir_context *);
	__poll_t (*poll)(struct file___29 *, struct poll_table_struct___21 *);
	long int (*unlocked_ioctl)(struct file___29 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___29 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___29 *, struct vm_area_struct___32 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___29 *, struct file___29 *);
	int (*flush)(struct file___29 *, fl_owner_t);
	int (*release)(struct inode___29 *, struct file___29 *);
	int (*fsync)(struct file___29 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___29 *, int);
	int (*lock)(struct file___29 *, int, struct file_lock___29 *);
	ssize_t (*sendpage)(struct file___29 *, struct page___31 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___29 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___29 *, long unsigned int);
	int (*flock)(struct file___29 *, int, struct file_lock___29 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___29 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___29 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___29 *, long int, struct file_lock___29 **, void **);
	long int (*fallocate)(struct file___29 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___27 *, struct file___29 *);
	ssize_t (*copy_file_range)(struct file___29 *, loff_t, struct file___29 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___29 *, loff_t, struct file___29 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___29 *, loff_t, loff_t, int);
};

struct static_call_mod___21 {
	struct static_call_mod___21 *next;
	struct module___28 *mod;
	struct static_call_site *sites;
};

struct static_call_key___21 {
	void *func;
	union {
		long unsigned int type;
		struct static_call_mod___21 *mods;
		struct static_call_site *sites;
	};
};

struct vmacache___31 {
	u64 seqnum;
	struct vm_area_struct___32 *vmas[4];
};

struct page_frag___31 {
	struct page___31 *page;
	__u32 offset;
	__u32 size;
};

struct perf_event___18;

struct thread_struct___19 {
	struct desc_struct tls_array[3];
	long unsigned int sp;
	short unsigned int es;
	short unsigned int ds;
	short unsigned int fsindex;
	short unsigned int gsindex;
	long unsigned int fsbase;
	long unsigned int gsbase;
	struct perf_event___18 *ptrace_bps[4];
	long unsigned int virtual_dr6;
	long unsigned int ptrace_dr7;
	long unsigned int cr2;
	long unsigned int trap_nr;
	long unsigned int error_code;
	struct io_bitmap *io_bitmap;
	long unsigned int iopl_emul;
	unsigned int iopl_warn: 1;
	unsigned int sig_on_uaccess_err: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u32 pkru;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct fpu fpu;
};

struct mm_struct___32;

struct pid___25;

struct nsproxy___28;

struct signal_struct___30;

struct bio_list___19;

struct backing_dev_info___18;

struct io_context___20;

struct css_set___23;

struct perf_event_context___18;

struct mem_cgroup___18;

struct request_queue___19;

struct vm_struct___26;

struct task_struct___33 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___33 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___32 *mm;
	struct mm_struct___32 *active_mm;
	struct vmacache___31 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int restore_sigmask: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___33 *real_parent;
	struct task_struct___33 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___33 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___25 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	struct posix_cputimers_work posix_cputimers_work;
	const struct cred *ptracer_cred;
	const struct cred *real_cred;
	const struct cred *cred;
	struct key *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___28 *nsproxy;
	struct signal_struct___30 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___33 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___19 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___18 *backing_dev_info;
	struct io_context___20 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___23 *cgroups;
	struct list_head cg_list;
	u32 closid;
	u32 rmid;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___18 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	long: 64;
	long: 64;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___31 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___18 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___18 *active_memcg;
	struct request_queue___19 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___33 *oom_reaper_list;
	struct vm_struct___26 *stack_vm_area;
	refcount_t stack_refcount;
	int patch_state;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	void *mce_vaddr;
	__u64 mce_kflags;
	u64 mce_addr;
	__u64 mce_ripv: 1;
	__u64 mce_whole_page: 1;
	__u64 __mce_reserved: 62;
	long: 2;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct callback_head mce_kill_me;
	int mce_count;
	struct llist_head kretprobe_instances;
	struct callback_head l1d_flush_kill;
	long: 64;
	struct thread_struct___19 thread;
};

typedef struct page___31 *pgtable_t___31;

struct address_space___29;

struct dev_pagemap___29;

struct page___31 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___29 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___8 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___31 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___31 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___32 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___29 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct pv_cpu_ops___25 {
	void (*io_delay)();
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	void (*write_cr4)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___19 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(long unsigned int);
	void (*invalidate_io_bitmap)();
	void (*update_io_bitmap)();
	void (*wbinvd)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int);
	void (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_msr_safe)(unsigned int, int *);
	int (*write_msr_safe)(unsigned int, unsigned int, unsigned int);
	u64 (*read_pmc)(int);
	void (*start_context_switch)(struct task_struct___33 *);
	void (*end_context_switch)(struct task_struct___33 *);
};

struct pv_mmu_ops___26 {
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_one_user)(long unsigned int);
	void (*flush_tlb_multi)(const struct cpumask *, const struct flush_tlb_info___3 *);
	void (*tlb_remove_table)(struct mmu_gather *, void *);
	void (*exit_mmap)(struct mm_struct___32 *);
	struct paravirt_callee_save read_cr2;
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___32 *, struct mm_struct___32 *);
	void (*dup_mmap)(struct mm_struct___32 *, struct mm_struct___32 *);
	int (*pgd_alloc)(struct mm_struct___32 *);
	void (*pgd_free)(struct mm_struct___32 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___32 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___32 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___32 *, long unsigned int);
	void (*alloc_p4d)(struct mm_struct___32 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*release_p4d)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	pte_t (*ptep_modify_prot_start)(struct vm_area_struct___32 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct vm_area_struct___32 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_p4d)(p4d_t *, p4d_t);
	struct paravirt_callee_save p4d_val;
	struct paravirt_callee_save make_p4d;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

struct linux_binfmt___7;

struct core_state___31;

struct mm_struct___32 {
	struct {
		struct vm_area_struct___32 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___29 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int mmap_compat_base;
		long unsigned int mmap_compat_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[48];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___7 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___31 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___33 *owner;
		struct user_namespace___3 *user_ns;
		struct file___29 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		bool tlb_flush_batched;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct vm_operations_struct___29;

struct vm_area_struct___32 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___32 *vm_next;
	struct vm_area_struct___32 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___32 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___29 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___29 *vm_file;
	struct file___29 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct paravirt_patch_template___26 {
	struct pv_cpu_ops___25 cpu;
	struct pv_irq_ops irq;
	struct pv_mmu_ops___26 mmu;
	struct pv_lock_ops lock;
};

struct tracepoint___21 {
	const char *name;
	struct static_key key;
	struct static_call_key___21 *static_call_key;
	void *static_call_tramp;
	void *iterator;
	int (*regfunc)();
	void (*unregfunc)();
	struct tracepoint_func *funcs;
};

struct bpf_raw_event_map___21 {
	struct tracepoint___21 *tp;
	void *bpf_func;
	u32 num_args;
	u32 writable_size;
	long: 64;
};

enum {
	PER_LINUX = 0,
	PER_LINUX_32BIT = 8388608,
	PER_LINUX_FDPIC = 524288,
	PER_SVR4 = 68157441,
	PER_SVR3 = 83886082,
	PER_SCOSVR3 = 117440515,
	PER_OSR5 = 100663299,
	PER_WYSEV386 = 83886084,
	PER_ISCR4 = 67108869,
	PER_BSD = 6,
	PER_SUNOS = 67108870,
	PER_XENIX = 83886087,
	PER_LINUX32 = 8,
	PER_LINUX32_3GB = 134217736,
	PER_IRIX32 = 67108873,
	PER_IRIXN32 = 67108874,
	PER_IRIX64 = 67108875,
	PER_RISCOS = 12,
	PER_SOLARIS = 67108877,
	PER_UW7 = 68157454,
	PER_OSF4 = 15,
	PER_HPUX = 16,
	PER_MASK = 255,
};

struct seq_operations___27 {
	void * (*start)(struct seq_file___27 *, loff_t *);
	void (*stop)(struct seq_file___27 *, void *);
	void * (*next)(struct seq_file___27 *, void *, loff_t *);
	int (*show)(struct seq_file___27 *, void *);
};

struct hw_perf_event___18 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___33 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	union {
		struct {
			u64 last_period;
			local64_t period_left;
		};
		struct {
			u64 saved_metric;
			u64 saved_slots;
		};
	};
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___18)(struct perf_event___18 *, struct perf_sample_data *, struct pt_regs *);

struct pmu___18;

struct fasync_struct___29;

struct pid_namespace___25;

struct trace_event_call___18;

struct perf_cgroup___18;

struct perf_event___18 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___18 *group_leader;
	struct pmu___18 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___18 hw;
	struct perf_event_context___18 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___18 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___33 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct perf_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___29 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	long unsigned int pending_addr;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	struct perf_addr_filter_range *addr_filter_ranges;
	long unsigned int addr_filters_gen;
	struct perf_event___18 *aux_event;
	void (*destroy)(struct perf_event___18 *);
	struct callback_head callback_head;
	struct pid_namespace___25 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___18 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___18 orig_overflow_handler;
	struct bpf_prog *prog;
	u64 bpf_cookie;
	struct trace_event_call___18 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___18 *cgrp;
	void *security;
	struct list_head sb_list;
};

struct address_space_operations___29;

struct address_space___29 {
	struct inode___29 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___29 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct dev_pagemap_ops___29;

struct dev_pagemap___29 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___29 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vfsmount___29;

struct path___29 {
	struct vfsmount___29 *mnt;
	struct dentry___29 *dentry;
};

struct fown_struct___25 {
	rwlock_t lock;
	struct pid___25 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___29 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	long: 64;
	long: 64;
	struct path___29 f_path;
	struct inode___29 *f_inode;
	const struct file_operations___29 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___25 f_owner;
	const struct cred *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___29 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___29;

struct vm_operations_struct___29 {
	void (*open)(struct vm_area_struct___32 *);
	void (*close)(struct vm_area_struct___32 *);
	int (*may_split)(struct vm_area_struct___32 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___32 *);
	int (*mprotect)(struct vm_area_struct___32 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___29 *);
	vm_fault_t (*huge_fault)(struct vm_fault___29 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___29 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___32 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___29 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___29 *);
	int (*access)(struct vm_area_struct___32 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___32 *);
	int (*set_policy)(struct vm_area_struct___32 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___32 *, long unsigned int);
	struct page___31 * (*find_special_page)(struct vm_area_struct___32 *, long unsigned int);
};

struct core_thread___31 {
	struct task_struct___33 *task;
	struct core_thread___31 *next;
};

struct core_state___31 {
	atomic_t nr_threads;
	struct core_thread___31 dumper;
	struct completion startup;
};

struct linux_binprm___8;

struct coredump_params___7;

struct linux_binfmt___7 {
	struct list_head lh;
	struct module___28 *module;
	int (*load_binary)(struct linux_binprm___8 *);
	int (*load_shlib)(struct file___29 *);
	int (*core_dump)(struct coredump_params___7 *);
	long unsigned int min_coredump;
};

struct vm_fault___29 {
	const struct {
		struct vm_area_struct___32 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___31 *cow_page;
	struct page___31 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___31 prealloc_pte;
};

struct pglist_data___19;

struct lruvec___19 {
	struct list_head lists[5];
	spinlock_t lru_lock;
	long unsigned int anon_cost;
	long unsigned int file_cost;
	atomic_long_t nonresident_age;
	long unsigned int refaults[2];
	long unsigned int flags;
	struct pglist_data___19 *pgdat;
};

struct zone___19 {
	long unsigned int _watermark[3];
	long unsigned int watermark_boost;
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[5];
	int node;
	struct pglist_data___19 *zone_pgdat;
	struct per_cpu_pages *per_cpu_pageset;
	struct per_cpu_zonestat *per_cpu_zonestats;
	int pageset_high;
	int pageset_batch;
	long unsigned int zone_start_pfn;
	atomic_long_t managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int present_early_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	seqlock_t span_seqlock;
	int initialized;
	int: 32;
	struct zone_padding _pad1_;
	struct free_area free_area[11];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	long unsigned int compact_init_migrate_pfn;
	long unsigned int compact_init_free_pfn;
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	short: 16;
	struct zone_padding _pad3_;
	atomic_long_t vm_stat[11];
	atomic_long_t vm_numa_event[6];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___19 {
	struct zone___19 *zone;
	int zone_idx;
};

struct zonelist___19 {
	struct zoneref___19 _zonerefs[5121];
};

struct pglist_data___19 {
	struct zone___19 node_zones[5];
	struct zonelist___19 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___33 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_highest_zoneidx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_highest_zoneidx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___33 *kcompactd;
	bool proactive_compact_trigger;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct deferred_split deferred_split_queue;
	struct lruvec___19 __lruvec;
	long unsigned int flags;
	long: 64;
	struct zone_padding _pad2_;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[39];
};

struct shrink_control___18 {
	gfp_t gfp_mask;
	int nid;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	struct mem_cgroup___18 *memcg;
};

struct cgroup___23;

struct cgroup_subsys___23;

struct cgroup_subsys_state___23 {
	struct cgroup___23 *cgroup;
	struct cgroup_subsys___23 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___23 *parent;
};

struct kernfs_node___29;

struct cgroup_file___23 {
	struct kernfs_node___29 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct obj_cgroup___18;

struct mem_cgroup_per_node___18;

struct mem_cgroup___18 {
	struct cgroup_subsys_state___23 css;
	struct mem_cgroup_id id;
	struct page_counter memory;
	union {
		struct page_counter swap;
		struct page_counter memsw;
	};
	struct page_counter kmem;
	struct page_counter tcpmem;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool oom_group;
	bool oom_lock;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___23 events_file;
	struct cgroup_file___23 events_local_file;
	struct cgroup_file___23 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	struct memcg_vmstats vmstats;
	atomic_long_t memory_events[8];
	atomic_long_t memory_events_local[8];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct obj_cgroup___18 *objcg;
	struct list_head objcg_list;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad2_;
	atomic_t moving_account;
	struct task_struct___33 *move_lock_task;
	struct memcg_vmstats_percpu *vmstats_percpu;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct memcg_cgwb_frn cgwb_frn[4];
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct deferred_split deferred_split_queue;
	struct mem_cgroup_per_node___18 *nodeinfo[0];
	long: 64;
};

struct shrinker___18 {
	long unsigned int (*count_objects)(struct shrinker___18 *, struct shrink_control___18 *);
	long unsigned int (*scan_objects)(struct shrinker___18 *, struct shrink_control___18 *);
	long int batch;
	int seeks;
	unsigned int flags;
	struct list_head list;
	int id;
	atomic_long_t *nr_deferred;
};

struct rlimit64 {
	__u64 rlim_cur;
	__u64 rlim_max;
};

struct dev_pagemap_ops___29 {
	void (*page_free)(struct page___31 *);
	void (*kill)(struct dev_pagemap___29 *);
	void (*cleanup)(struct dev_pagemap___29 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___29 *);
};

struct upid___25 {
	int nr;
	struct pid_namespace___25 *ns;
};

struct pid_namespace___25 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___33 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___25 *parent;
	struct fs_pin *bacct;
	struct user_namespace___3 *user_ns;
	struct ucounts___3 *ucounts;
	int reboot;
	struct ns_common___3 ns;
};

struct pid___25 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___25 numbers[1];
};

struct tty_struct___7;

struct signal_struct___30 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___33 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___33 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper;
	unsigned int has_child_subreaper;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___25 *pids[4];
	struct pid___25 *tty_old_pgrp;
	int leader;
	struct tty_struct___7 *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___32 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct fs_struct {
	int users;
	spinlock_t lock;
	seqcount_spinlock_t seq;
	int umask;
	int in_exec;
	struct path___29 root;
	struct path___29 pwd;
};

struct time_namespace___2;

struct cgroup_namespace___23;

struct nsproxy___28 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___25 *pid_ns_for_children;
	struct net *net_ns;
	struct time_namespace___2 *time_ns;
	struct time_namespace___2 *time_ns_for_children;
	struct cgroup_namespace___23 *cgroup_ns;
};

struct bio___19;

struct bio_list___19 {
	struct bio___19 *head;
	struct bio___19 *tail;
};

struct bdi_writeback___18 {
	struct backing_dev_info___18 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	atomic_t writeback_inodes;
	struct percpu_counter stat[4];
	long unsigned int congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	struct delayed_work bw_dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___23 *memcg_css;
	struct cgroup_subsys_state___23 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	struct list_head b_attached;
	struct list_head offline_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
};

struct device___31;

struct backing_dev_info___18 {
	u64 id;
	struct rb_node rb_node;
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___18 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct mutex cgwb_release_mutex;
	struct rw_semaphore wb_switch_rwsem;
	wait_queue_head_t wb_waitq;
	struct device___31 *dev;
	char dev_name[64];
	struct device___31 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___29 *debug_dir;
};

struct io_cq___19;

struct io_context___20 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	struct xarray icq_tree;
	struct io_cq___19 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct css_set___23 {
	struct cgroup_subsys_state___23 *subsys[14];
	refcount_t refcount;
	struct css_set___23 *dom_cset;
	struct cgroup___23 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___23 *mg_src_cgrp;
	struct cgroup___23 *mg_dst_cgrp;
	struct css_set___23 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___18 {
	struct pmu___18 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	int rotate_necessary;
	refcount_t refcount;
	struct task_struct___33 *task;
	u64 time;
	u64 timestamp;
	u64 timeoffset;
	struct perf_event_context___18 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

struct kset___28;

struct kobj_type___28;

struct kobject___29 {
	const char *name;
	struct list_head entry;
	struct kobject___29 *parent;
	struct kset___28 *kset;
	struct kobj_type___28 *ktype;
	struct kernfs_node___29 *sd;
	struct kref kref;
	unsigned int state_initialized;
	unsigned int state_in_sysfs;
	unsigned int state_add_uevent_sent;
	unsigned int state_remove_uevent_sent;
	unsigned int uevent_suppress;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct blk_integrity_profile___19;

struct blk_integrity___19 {
	const struct blk_integrity_profile___19 *profile;
	unsigned char flags;
	unsigned char tuple_size;
	unsigned char interval_exp;
	unsigned char tag_size;
};

struct bio_set___19 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	struct bio_alloc_cache *cache;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	unsigned int back_pad;
	spinlock_t rescue_lock;
	struct bio_list___19 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	struct hlist_node cpuhp_dead;
};

struct request___19;

struct elevator_queue___19;

struct gendisk___19;

struct blkcg_gq___18;

struct request_queue___19 {
	struct request___19 *last_merge;
	struct elevator_queue___19 *elevator;
	struct percpu_ref q_usage_counter;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	const struct blk_mq_ops *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx **queue_hw_ctx;
	unsigned int nr_hw_queues;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	spinlock_t queue_lock;
	struct gendisk___19 *disk;
	struct kobject___29 kobj;
	struct kobject___29 *mq_kobj;
	struct blk_integrity___19 integrity;
	struct device___31 *dev;
	enum rpm_status rpm_status;
	long unsigned int nr_requests;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_keyslot_manager *ksm;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	atomic_t nr_active_requests_shared_sbitmap;
	struct sbitmap_queue sched_bitmap_tags;
	struct sbitmap_queue sched_breserved_tags;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___18 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int required_elevator_features;
	unsigned int nr_zones;
	long unsigned int *conv_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int max_open_zones;
	unsigned int max_active_zones;
	int node;
	struct mutex debugfs_mutex;
	struct blk_trace *blk_trace;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	struct mutex sysfs_dir_lock;
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	int mq_freeze_depth;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct mutex mq_freeze_lock;
	struct blk_mq_tag_set *tag_set;
	struct list_head tag_set_list;
	struct bio_set___19 bio_split;
	struct dentry___29 *debugfs_dir;
	struct dentry___29 *sched_debugfs_dir;
	struct dentry___29 *rqos_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	u64 write_hints[5];
};

struct vm_struct___26 {
	struct vm_struct___26 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___31 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct dentry_operations___29;

struct dentry___29 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___29 *d_parent;
	struct qstr d_name;
	struct inode___29 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___29 *d_op;
	struct super_block___29 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___29;

struct cdev___14;

struct inode___29 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___29 *i_op;
	struct super_block___29 *i_sb;
	struct address_space___29 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___18 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	long: 64;
	long: 64;
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___29 *i_fop;
		void (*free_inode)(struct inode___29 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___29 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct cdev___14 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___29 {
	int (*d_revalidate)(struct dentry___29 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___29 *, unsigned int);
	int (*d_hash)(const struct dentry___29 *, struct qstr *);
	int (*d_compare)(const struct dentry___29 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___29 *);
	int (*d_init)(struct dentry___29 *);
	void (*d_release)(struct dentry___29 *);
	void (*d_prune)(struct dentry___29 *);
	void (*d_iput)(struct dentry___29 *, struct inode___29 *);
	char * (*d_dname)(struct dentry___29 *, char *, int);
	struct vfsmount___29 * (*d_automount)(struct path___29 *);
	int (*d_manage)(const struct path___29 *, bool);
	struct dentry___29 * (*d_real)(struct dentry___29 *, const struct inode___29 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___29;

struct mem_dqinfo___29 {
	struct quota_format_type___29 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___29;

struct quota_info___29 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___29 *files[3];
	struct mem_dqinfo___29 info[3];
	const struct quota_format_ops___29 *ops[3];
};

struct rcuwait___29 {
	struct task_struct___33 *task;
};

struct percpu_rw_semaphore___29 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___29 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___29 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___29 rw_sem[3];
};

struct super_operations___29;

struct dquot_operations___29;

struct quotactl_ops___29;

struct block_device___19;

struct super_block___29 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___29 *s_type;
	const struct super_operations___29 *s_op;
	const struct dquot_operations___29 *dq_op;
	const struct quotactl_ops___29 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___29 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___19 *s_bdev;
	struct backing_dev_info___18 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___29 s_dquot;
	struct sb_writers___29 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___29 *s_d_op;
	int cleancache_poolid;
	struct shrinker___18 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___3 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___29 {
	struct dentry___29 *mnt_root;
	struct super_block___29 *mnt_sb;
	int mnt_flags;
	struct user_namespace___3 *mnt_userns;
};

struct psi_group___23 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___33 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___23;

struct cgroup_rstat_cpu___23;

struct cgroup___23 {
	struct cgroup_subsys_state___23 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___29 *kn;
	struct cgroup_file___23 procs_file;
	struct cgroup_file___23 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___23 *subsys[14];
	struct cgroup_root___23 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___23 *dom_cgrp;
	struct cgroup___23 *old_dom_cgrp;
	struct cgroup_rstat_cpu___23 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___23 psi;
	struct cgroup_bpf___3 bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct tty_driver___7;

struct tty_operations___7;

struct tty_ldisc___7;

struct tty_port___7;

struct tty_struct___7 {
	int magic;
	struct kref kref;
	struct device___31 *dev;
	struct tty_driver___7 *driver;
	const struct tty_operations___7 *ops;
	int index;
	struct ld_semaphore ldisc_sem;
	struct tty_ldisc___7 *ldisc;
	struct mutex atomic_write_lock;
	struct mutex legacy_mutex;
	struct mutex throttle_mutex;
	struct rw_semaphore termios_rwsem;
	struct mutex winsize_mutex;
	struct ktermios termios;
	struct ktermios termios_locked;
	char name[64];
	long unsigned int flags;
	int count;
	struct winsize winsize;
	struct {
		spinlock_t lock;
		bool stopped;
		bool tco_stopped;
		long unsigned int unused[0];
	} flow;
	struct {
		spinlock_t lock;
		struct pid___25 *pgrp;
		struct pid___25 *session;
		unsigned char pktstatus;
		bool packet;
		long unsigned int unused[0];
	} ctrl;
	int hw_stopped;
	unsigned int receive_room;
	int flow_change;
	struct tty_struct___7 *link;
	struct fasync_struct___29 *fasync;
	wait_queue_head_t write_wait;
	wait_queue_head_t read_wait;
	struct work_struct hangup_work;
	void *disc_data;
	void *driver_data;
	spinlock_t files_lock;
	struct list_head tty_files;
	int closing;
	unsigned char *write_buf;
	int write_cnt;
	struct work_struct SAK_work;
	struct tty_port___7 *port;
};

typedef int (*proc_visitor___2)(struct task_struct___33 *, void *);

struct io_cq___19 {
	struct request_queue___19 *q;
	struct io_context___20 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct wait_page_queue___16;

struct kiocb___29 {
	struct file___29 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___29 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___16 *ki_waitq;
	};
};

struct iattr___29 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___29 *ia_file;
};

struct dquot___29 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___29 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___29 {
	int qf_fmt_id;
	const struct quota_format_ops___29 *qf_ops;
	struct module___28 *qf_owner;
	struct quota_format_type___29 *qf_next;
};

struct quota_format_ops___29 {
	int (*check_quota_file)(struct super_block___29 *, int);
	int (*read_file_info)(struct super_block___29 *, int);
	int (*write_file_info)(struct super_block___29 *, int);
	int (*free_file_info)(struct super_block___29 *, int);
	int (*read_dqblk)(struct dquot___29 *);
	int (*commit_dqblk)(struct dquot___29 *);
	int (*release_dqblk)(struct dquot___29 *);
	int (*get_next_id)(struct super_block___29 *, struct kqid *);
};

struct dquot_operations___29 {
	int (*write_dquot)(struct dquot___29 *);
	struct dquot___29 * (*alloc_dquot)(struct super_block___29 *, int);
	void (*destroy_dquot)(struct dquot___29 *);
	int (*acquire_dquot)(struct dquot___29 *);
	int (*release_dquot)(struct dquot___29 *);
	int (*mark_dirty)(struct dquot___29 *);
	int (*write_info)(struct super_block___29 *, int);
	qsize_t * (*get_reserved_space)(struct inode___29 *);
	int (*get_projid)(struct inode___29 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___29 *, qsize_t *);
	int (*get_next_id)(struct super_block___29 *, struct kqid *);
};

struct quotactl_ops___29 {
	int (*quota_on)(struct super_block___29 *, int, int, const struct path___29 *);
	int (*quota_off)(struct super_block___29 *, int);
	int (*quota_enable)(struct super_block___29 *, unsigned int);
	int (*quota_disable)(struct super_block___29 *, unsigned int);
	int (*quota_sync)(struct super_block___29 *, int);
	int (*set_info)(struct super_block___29 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___29 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___29 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___29 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___29 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___29 *, unsigned int);
};

struct module_kobject___28 {
	struct kobject___29 kobj;
	struct module___28 *mod;
	struct kobject___29 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___28 {
	struct module___28 *mod;
	struct latch_tree_node node;
};

struct module_layout___28 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___28 mtn;
};

struct module_attribute___28;

struct kernel_param___28;

struct module___28 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___28 mkobj;
	struct module_attribute___28 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___29 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___28 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___28 core_layout;
	struct module_layout___28 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map___21 *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___18 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	int num_static_call_sites;
	struct static_call_site *static_call_sites;
	bool klp;
	bool klp_alive;
	struct klp_modinfo *klp_info;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct wait_page_queue___16 {
	struct page___31 *page;
	int bit_nr;
	wait_queue_entry_t wait;
};

struct writeback_control___18;

struct readahead_control___16;

struct swap_info_struct___12;

struct address_space_operations___29 {
	int (*writepage)(struct page___31 *, struct writeback_control___18 *);
	int (*readpage)(struct file___29 *, struct page___31 *);
	int (*writepages)(struct address_space___29 *, struct writeback_control___18 *);
	int (*set_page_dirty)(struct page___31 *);
	int (*readpages)(struct file___29 *, struct address_space___29 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___16 *);
	int (*write_begin)(struct file___29 *, struct address_space___29 *, loff_t, unsigned int, unsigned int, struct page___31 **, void **);
	int (*write_end)(struct file___29 *, struct address_space___29 *, loff_t, unsigned int, unsigned int, struct page___31 *, void *);
	sector_t (*bmap)(struct address_space___29 *, sector_t);
	void (*invalidatepage)(struct page___31 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___31 *, gfp_t);
	void (*freepage)(struct page___31 *);
	ssize_t (*direct_IO)(struct kiocb___29 *, struct iov_iter___23 *);
	int (*migratepage)(struct address_space___29 *, struct page___31 *, struct page___31 *, enum migrate_mode);
	bool (*isolate_page)(struct page___31 *, isolate_mode_t);
	void (*putback_page)(struct page___31 *);
	int (*launder_page)(struct page___31 *);
	int (*is_partially_uptodate)(struct page___31 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___31 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___29 *, struct page___31 *);
	int (*swap_activate)(struct swap_info_struct___12 *, struct file___29 *, sector_t *);
	void (*swap_deactivate)(struct file___29 *);
};

struct writeback_control___18 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate;
	unsigned int for_background;
	unsigned int tagged_writepages;
	unsigned int for_reclaim;
	unsigned int range_cyclic;
	unsigned int for_sync;
	unsigned int no_cgroup_owner;
	unsigned int punt_to_cgroup;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bdi_writeback___18 *wb;
	struct inode___29 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
};

struct readahead_control___16 {
	struct file___29 *file;
	struct address_space___29 *mapping;
	struct file_ra_state *ra;
	long unsigned int _index;
	unsigned int _nr_pages;
	unsigned int _batch_count;
};

struct bio_vec___23;

struct iov_iter___23 {
	u8 iter_type;
	bool data_source;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___23 *bvec;
		struct xarray *xarray;
		struct pipe_inode_info *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			unsigned int head;
			unsigned int start_head;
		};
		loff_t xarray_start;
	};
};

struct swap_info_struct___12 {
	struct percpu_ref users;
	long unsigned int flags;
	short int prio;
	struct plist_node list;
	signed char type;
	unsigned int max;
	unsigned char *swap_map;
	struct swap_cluster_info *cluster_info;
	struct swap_cluster_list free_clusters;
	unsigned int lowest_bit;
	unsigned int highest_bit;
	unsigned int pages;
	unsigned int inuse_pages;
	unsigned int cluster_next;
	unsigned int cluster_nr;
	unsigned int *cluster_next_cpu;
	struct percpu_cluster *percpu_cluster;
	struct rb_root swap_extent_root;
	struct block_device___19 *bdev;
	struct file___29 *swap_file;
	unsigned int old_block_size;
	struct completion comp;
	long unsigned int *frontswap_map;
	atomic_t frontswap_pages;
	spinlock_t lock;
	spinlock_t cont_lock;
	struct work_struct discard_work;
	struct swap_cluster_list discard_clusters;
	struct plist_node avail_lists[0];
};

struct cdev___14 {
	struct kobject___29 kobj;
	struct module___28 *owner;
	const struct file_operations___29 *ops;
	struct list_head list;
	dev_t dev;
	unsigned int count;
};

struct inode_operations___29 {
	struct dentry___29 * (*lookup)(struct inode___29 *, struct dentry___29 *, unsigned int);
	const char * (*get_link)(struct dentry___29 *, struct inode___29 *, struct delayed_call *);
	int (*permission)(struct user_namespace___3 *, struct inode___29 *, int);
	struct posix_acl * (*get_acl)(struct inode___29 *, int, bool);
	int (*readlink)(struct dentry___29 *, char *, int);
	int (*create)(struct user_namespace___3 *, struct inode___29 *, struct dentry___29 *, umode_t, bool);
	int (*link)(struct dentry___29 *, struct inode___29 *, struct dentry___29 *);
	int (*unlink)(struct inode___29 *, struct dentry___29 *);
	int (*symlink)(struct user_namespace___3 *, struct inode___29 *, struct dentry___29 *, const char *);
	int (*mkdir)(struct user_namespace___3 *, struct inode___29 *, struct dentry___29 *, umode_t);
	int (*rmdir)(struct inode___29 *, struct dentry___29 *);
	int (*mknod)(struct user_namespace___3 *, struct inode___29 *, struct dentry___29 *, umode_t, dev_t);
	int (*rename)(struct user_namespace___3 *, struct inode___29 *, struct dentry___29 *, struct inode___29 *, struct dentry___29 *, unsigned int);
	int (*setattr)(struct user_namespace___3 *, struct dentry___29 *, struct iattr___29 *);
	int (*getattr)(struct user_namespace___3 *, const struct path___29 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___29 *, char *, size_t);
	int (*fiemap)(struct inode___29 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___29 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___29 *, struct dentry___29 *, struct file___29 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace___3 *, struct inode___29 *, struct dentry___29 *, umode_t);
	int (*set_acl)(struct user_namespace___3 *, struct inode___29 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace___3 *, struct dentry___29 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___29 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___29 {
	void (*fl_copy_lock)(struct file_lock___29 *, struct file_lock___29 *);
	void (*fl_release_private)(struct file_lock___29 *);
};

struct lock_manager_operations___29;

struct file_lock___29 {
	struct file_lock___29 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___29 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___29 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___29 *fl_ops;
	const struct lock_manager_operations___29 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___29 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___29 *);
	int (*lm_grant)(struct file_lock___29 *, int);
	bool (*lm_break)(struct file_lock___29 *);
	int (*lm_change)(struct file_lock___29 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___29 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___29 *);
};

struct fasync_struct___29 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___29 *fa_next;
	struct file___29 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___29 {
	struct inode___29 * (*alloc_inode)(struct super_block___29 *);
	void (*destroy_inode)(struct inode___29 *);
	void (*free_inode)(struct inode___29 *);
	void (*dirty_inode)(struct inode___29 *, int);
	int (*write_inode)(struct inode___29 *, struct writeback_control___18 *);
	int (*drop_inode)(struct inode___29 *);
	void (*evict_inode)(struct inode___29 *);
	void (*put_super)(struct super_block___29 *);
	int (*sync_fs)(struct super_block___29 *, int);
	int (*freeze_super)(struct super_block___29 *);
	int (*freeze_fs)(struct super_block___29 *);
	int (*thaw_super)(struct super_block___29 *);
	int (*unfreeze_fs)(struct super_block___29 *);
	int (*statfs)(struct dentry___29 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___29 *, int *, char *);
	void (*umount_begin)(struct super_block___29 *);
	int (*show_options)(struct seq_file___27 *, struct dentry___29 *);
	int (*show_devname)(struct seq_file___27 *, struct dentry___29 *);
	int (*show_path)(struct seq_file___27 *, struct dentry___29 *);
	int (*show_stats)(struct seq_file___27 *, struct dentry___29 *);
	ssize_t (*quota_read)(struct super_block___29 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___29 *, int, const char *, size_t, loff_t);
	struct dquot___29 ** (*get_dquots)(struct inode___29 *);
	long int (*nr_cached_objects)(struct super_block___29 *, struct shrink_control___18 *);
	long int (*free_cached_objects)(struct super_block___29 *, struct shrink_control___18 *);
	struct file___29 * (*real_loop)(struct file___29 *);
};

struct wakeup_source___31;

struct dev_pm_info___31 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___31 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___31 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___31;

struct bus_type___31;

struct device_driver___31;

struct dev_pm_domain___31;

struct fwnode_handle___28;

struct class___31;

struct attribute_group___29;

struct device___31 {
	struct kobject___29 kobj;
	struct device___31 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___31 *type;
	struct bus_type___31 *bus;
	struct device_driver___31 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___31 power;
	struct dev_pm_domain___31 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node *of_node;
	struct fwnode_handle___28 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___31 *class;
	const struct attribute_group___29 **groups;
	void (*release)(struct device___31 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct block_device___19 {
	sector_t bd_start_sect;
	struct disk_stats *bd_stats;
	long unsigned int bd_stamp;
	bool bd_read_only;
	dev_t bd_dev;
	int bd_openers;
	struct inode___29 *bd_inode;
	struct super_block___29 *bd_super;
	void *bd_claiming;
	struct device___31 bd_device;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct kobject___29 *bd_holder_dir;
	u8 bd_partno;
	spinlock_t bd_size_lock;
	struct gendisk___19 *bd_disk;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	struct super_block___29 *bd_fsfreeze_sb;
	struct partition_meta_info *bd_meta_info;
};

typedef void (*poll_queue_proc___21)(struct file___29 *, wait_queue_head_t *, struct poll_table_struct___21 *);

struct poll_table_struct___21 {
	poll_queue_proc___21 _qproc;
	__poll_t _key;
};

struct seq_file___27 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___27 *op;
	int poll_event;
	const struct file___29 *file;
	void *private;
};

typedef void bio_end_io_t___19(struct bio___19 *);

struct bio_vec___23 {
	struct page___31 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___19;

struct bio___19 {
	struct bio___19 *bi_next;
	struct block_device___19 *bi_bdev;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	atomic_t __bi_remaining;
	struct bvec_iter bi_iter;
	bio_end_io_t___19 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___18 *bi_blkg;
	struct bio_issue bi_issue;
	u64 bi_iocost_cost;
	struct bio_crypt_ctx *bi_crypt_context;
	union {
		struct bio_integrity_payload___19 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___23 *bi_io_vec;
	struct bio_set___19 *bi_pool;
	struct bio_vec___23 bi_inline_vecs[0];
};

struct time_namespace___2 {
	struct user_namespace___3 *user_ns;
	struct ucounts___3 *ucounts;
	struct ns_common___3 ns;
	struct timens_offsets offsets;
	struct page___31 *vvar_page;
	bool frozen_offsets;
};

struct cgroup_namespace___23 {
	struct ns_common___3 ns;
	struct user_namespace___3 *user_ns;
	struct ucounts___3 *ucounts;
	struct css_set___23 *root_cset;
};

struct oldold_utsname {
	char sysname[9];
	char nodename[9];
	char release[9];
	char version[9];
	char machine[9];
};

struct old_utsname {
	char sysname[65];
	char nodename[65];
	char release[65];
	char version[65];
	char machine[65];
};

enum uts_proc {
	UTS_PROC_OSTYPE = 0,
	UTS_PROC_OSRELEASE = 1,
	UTS_PROC_VERSION = 2,
	UTS_PROC_HOSTNAME = 3,
	UTS_PROC_DOMAINNAME = 4,
};

struct prctl_mm_map {
	__u64 start_code;
	__u64 end_code;
	__u64 start_data;
	__u64 end_data;
	__u64 start_brk;
	__u64 brk;
	__u64 start_stack;
	__u64 arg_start;
	__u64 arg_end;
	__u64 env_start;
	__u64 env_end;
	__u64 *auxv;
	__u32 auxv_size;
	__u32 exe_fd;
};

struct perf_cpu_context___18;

struct perf_output_handle___18;

struct pmu___18 {
	struct list_head entry;
	struct module___28 *module;
	struct device___31 *dev;
	const struct attribute_group___29 **attr_groups;
	const struct attribute_group___29 **attr_update;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___18 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___18 *);
	void (*pmu_disable)(struct pmu___18 *);
	int (*event_init)(struct perf_event___18 *);
	void (*event_mapped)(struct perf_event___18 *, struct mm_struct___32 *);
	void (*event_unmapped)(struct perf_event___18 *, struct mm_struct___32 *);
	int (*add)(struct perf_event___18 *, int);
	void (*del)(struct perf_event___18 *, int);
	void (*start)(struct perf_event___18 *, int);
	void (*stop)(struct perf_event___18 *, int);
	void (*read)(struct perf_event___18 *);
	void (*start_txn)(struct pmu___18 *, unsigned int);
	int (*commit_txn)(struct pmu___18 *);
	void (*cancel_txn)(struct pmu___18 *);
	int (*event_idx)(struct perf_event___18 *);
	void (*sched_task)(struct perf_event_context___18 *, bool);
	struct kmem_cache *task_ctx_cache;
	void (*swap_task_ctx)(struct perf_event_context___18 *, struct perf_event_context___18 *);
	void * (*setup_aux)(struct perf_event___18 *, void **, int, bool);
	void (*free_aux)(void *);
	long int (*snapshot_aux)(struct perf_event___18 *, struct perf_output_handle___18 *, long unsigned int);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___18 *);
	int (*aux_output_match)(struct perf_event___18 *);
	int (*filter_match)(struct perf_event___18 *);
	int (*check_period)(struct perf_event___18 *, u64);
};

struct kernfs_root___29;

struct kernfs_elem_dir___29 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___29 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___29;

struct kernfs_root___29 {
	struct kernfs_node___29 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___29 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___29 {
	struct kernfs_node___29 *target_kn;
};

struct kernfs_ops___29;

struct kernfs_elem_attr___29 {
	const struct kernfs_ops___29 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___29 *notify_next;
};

struct kernfs_node___29 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___29 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___29 dir;
		struct kernfs_elem_symlink___29 symlink;
		struct kernfs_elem_attr___29 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___29;

struct kernfs_ops___29 {
	int (*open)(struct kernfs_open_file___29 *);
	void (*release)(struct kernfs_open_file___29 *);
	int (*seq_show)(struct seq_file___27 *, void *);
	void * (*seq_start)(struct seq_file___27 *, loff_t *);
	void * (*seq_next)(struct seq_file___27 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___27 *, void *);
	ssize_t (*read)(struct kernfs_open_file___29 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___29 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___29 *, struct poll_table_struct___21 *);
	int (*mmap)(struct kernfs_open_file___29 *, struct vm_area_struct___32 *);
};

struct kernfs_syscall_ops___29 {
	int (*show_options)(struct seq_file___27 *, struct kernfs_root___29 *);
	int (*mkdir)(struct kernfs_node___29 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___29 *);
	int (*rename)(struct kernfs_node___29 *, struct kernfs_node___29 *, const char *);
	int (*show_path)(struct seq_file___27 *, struct kernfs_node___29 *, struct kernfs_root___29 *);
};

struct kernfs_open_file___29 {
	struct kernfs_node___29 *kn;
	struct file___29 *file;
	struct seq_file___27 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped;
	bool released;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___29 *vm_ops;
};

struct bin_attribute___29;

struct attribute_group___29 {
	const char *name;
	umode_t (*is_visible)(struct kobject___29 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___29 *, struct bin_attribute___29 *, int);
	struct attribute **attrs;
	struct bin_attribute___29 **bin_attrs;
};

struct bin_attribute___29 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___29 * (*f_mapping)();
	ssize_t (*read)(struct file___29 *, struct kobject___29 *, struct bin_attribute___29 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___29 *, struct kobject___29 *, struct bin_attribute___29 *, char *, loff_t, size_t);
	int (*mmap)(struct file___29 *, struct kobject___29 *, struct bin_attribute___29 *, struct vm_area_struct___32 *);
};

struct sysfs_ops___28 {
	ssize_t (*show)(struct kobject___29 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___29 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___28;

struct kset___28 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___29 kobj;
	const struct kset_uevent_ops___28 *uevent_ops;
};

struct kobj_type___28 {
	void (*release)(struct kobject___29 *);
	const struct sysfs_ops___28 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___29 **default_groups;
	const struct kobj_ns_type_operations___2 * (*child_ns_type)(struct kobject___29 *);
	const void * (*namespace)(struct kobject___29 *);
	void (*get_ownership)(struct kobject___29 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___28 {
	int (* const filter)(struct kset___28 *, struct kobject___29 *);
	const char * (* const name)(struct kset___28 *, struct kobject___29 *);
	int (* const uevent)(struct kset___28 *, struct kobject___29 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___28 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___28 *);
	int (*get)(char *, const struct kernel_param___28 *);
	void (*free)(void *);
};

struct kparam_array___28;

struct kernel_param___28 {
	const char *name;
	struct module___28 *mod;
	const struct kernel_param_ops___28 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___28 *arr;
	};
};

struct kparam_array___28 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___28 *ops;
	void *elem;
};

struct module_attribute___28 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___28 *, struct module_kobject___28 *, char *);
	ssize_t (*store)(struct module_attribute___28 *, struct module_kobject___28 *, const char *, size_t);
	void (*setup)(struct module___28 *, const char *);
	int (*test)(struct module___28 *);
	void (*free)(struct module___28 *);
};

struct trace_event_class___18;

struct trace_event_call___18 {
	struct list_head list;
	struct trace_event_class___18 *class;
	union {
		char *name;
		struct tracepoint___21 *tp;
	};
	struct trace_event event;
	char *print_fmt;
	struct event_filter *filter;
	union {
		void *module;
		atomic_t refcnt;
	};
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
	struct bpf_prog_array___3 *prog_array;
	int (*perf_perm)(struct trace_event_call___18 *, struct perf_event___18 *);
};

struct compat_tms {
	compat_clock_t tms_utime;
	compat_clock_t tms_stime;
	compat_clock_t tms_cutime;
	compat_clock_t tms_cstime;
};

struct compat_rlimit {
	compat_ulong_t rlim_cur;
	compat_ulong_t rlim_max;
};

struct dev_pm_ops___31 {
	int (*prepare)(struct device___31 *);
	void (*complete)(struct device___31 *);
	int (*suspend)(struct device___31 *);
	int (*resume)(struct device___31 *);
	int (*freeze)(struct device___31 *);
	int (*thaw)(struct device___31 *);
	int (*poweroff)(struct device___31 *);
	int (*restore)(struct device___31 *);
	int (*suspend_late)(struct device___31 *);
	int (*resume_early)(struct device___31 *);
	int (*freeze_late)(struct device___31 *);
	int (*thaw_early)(struct device___31 *);
	int (*poweroff_late)(struct device___31 *);
	int (*restore_early)(struct device___31 *);
	int (*suspend_noirq)(struct device___31 *);
	int (*resume_noirq)(struct device___31 *);
	int (*freeze_noirq)(struct device___31 *);
	int (*thaw_noirq)(struct device___31 *);
	int (*poweroff_noirq)(struct device___31 *);
	int (*restore_noirq)(struct device___31 *);
	int (*runtime_suspend)(struct device___31 *);
	int (*runtime_resume)(struct device___31 *);
	int (*runtime_idle)(struct device___31 *);
};

struct wakeup_source___31 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___31 *dev;
	bool active;
	bool autosleep_enabled;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___31 {
	struct dev_pm_ops___31 ops;
	int (*start)(struct device___31 *);
	void (*detach)(struct device___31 *, bool);
	int (*activate)(struct device___31 *);
	void (*sync)(struct device___31 *);
	void (*dismiss)(struct device___31 *);
};

struct bus_type___31 {
	const char *name;
	const char *dev_name;
	struct device___31 *dev_root;
	const struct attribute_group___29 **bus_groups;
	const struct attribute_group___29 **dev_groups;
	const struct attribute_group___29 **drv_groups;
	int (*match)(struct device___31 *, struct device_driver___31 *);
	int (*uevent)(struct device___31 *, struct kobj_uevent_env *);
	int (*probe)(struct device___31 *);
	void (*sync_state)(struct device___31 *);
	void (*remove)(struct device___31 *);
	void (*shutdown)(struct device___31 *);
	int (*online)(struct device___31 *);
	int (*offline)(struct device___31 *);
	int (*suspend)(struct device___31 *, pm_message_t);
	int (*resume)(struct device___31 *);
	int (*num_vf)(struct device___31 *);
	int (*dma_configure)(struct device___31 *);
	const struct dev_pm_ops___31 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___31 {
	const char *name;
	struct bus_type___31 *bus;
	struct module___28 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___31 *);
	void (*sync_state)(struct device___31 *);
	int (*remove)(struct device___31 *);
	void (*shutdown)(struct device___31 *);
	int (*suspend)(struct device___31 *, pm_message_t);
	int (*resume)(struct device___31 *);
	const struct attribute_group___29 **groups;
	const struct attribute_group___29 **dev_groups;
	const struct dev_pm_ops___31 *pm;
	void (*coredump)(struct device___31 *);
	struct driver_private *p;
};

struct device_type___31 {
	const char *name;
	const struct attribute_group___29 **groups;
	int (*uevent)(struct device___31 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___31 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___31 *);
	const struct dev_pm_ops___31 *pm;
};

struct class___31 {
	const char *name;
	struct module___28 *owner;
	const struct attribute_group___29 **class_groups;
	const struct attribute_group___29 **dev_groups;
	struct kobject___29 *dev_kobj;
	int (*dev_uevent)(struct device___31 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___31 *, umode_t *);
	void (*class_release)(struct class___31 *);
	void (*dev_release)(struct device___31 *);
	int (*shutdown_pre)(struct device___31 *);
	const struct kobj_ns_type_operations___2 *ns_type;
	const void * (*namespace)(struct device___31 *);
	void (*get_ownership)(struct device___31 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___31 *pm;
	struct subsys_private *p;
};

struct fwnode_operations___28;

struct fwnode_handle___28 {
	struct fwnode_handle___28 *secondary;
	const struct fwnode_operations___28 *ops;
	struct device___31 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct fd___2 {
	struct file___29 *file;
	unsigned int flags;
};

struct cftype___23;

struct cgroup_subsys___23 {
	struct cgroup_subsys_state___23 * (*css_alloc)(struct cgroup_subsys_state___23 *);
	int (*css_online)(struct cgroup_subsys_state___23 *);
	void (*css_offline)(struct cgroup_subsys_state___23 *);
	void (*css_released)(struct cgroup_subsys_state___23 *);
	void (*css_free)(struct cgroup_subsys_state___23 *);
	void (*css_reset)(struct cgroup_subsys_state___23 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___23 *, int);
	int (*css_extra_stat_show)(struct seq_file___27 *, struct cgroup_subsys_state___23 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___33 *, struct css_set___23 *);
	void (*cancel_fork)(struct task_struct___33 *, struct css_set___23 *);
	void (*fork)(struct task_struct___33 *);
	void (*exit)(struct task_struct___33 *);
	void (*release)(struct task_struct___33 *);
	void (*bind)(struct cgroup_subsys_state___23 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___23 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___23 *dfl_cftypes;
	struct cftype___23 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___23 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___23 *updated_children;
	struct cgroup___23 *updated_next;
};

struct cgroup_root___23 {
	struct kernfs_root___29 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___23 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___23 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___23 *ss;
	struct list_head node;
	struct kernfs_ops___29 *kf_ops;
	int (*open)(struct kernfs_open_file___29 *);
	void (*release)(struct kernfs_open_file___29 *);
	u64 (*read_u64)(struct cgroup_subsys_state___23 *, struct cftype___23 *);
	s64 (*read_s64)(struct cgroup_subsys_state___23 *, struct cftype___23 *);
	int (*seq_show)(struct seq_file___27 *, void *);
	void * (*seq_start)(struct seq_file___27 *, loff_t *);
	void * (*seq_next)(struct seq_file___27 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___27 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___23 *, struct cftype___23 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___23 *, struct cftype___23 *, s64);
	ssize_t (*write)(struct kernfs_open_file___29 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___29 *, struct poll_table_struct___21 *);
};

struct perf_cpu_context___18 {
	struct perf_event_context___18 ctx;
	struct perf_event_context___18 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___18 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
	int heap_size;
	struct perf_event___18 **heap;
	struct perf_event___18 *heap_default[2];
};

struct perf_output_handle___18 {
	struct perf_event___18 *event;
	struct perf_buffer *rb;
	long unsigned int wakeup;
	long unsigned int size;
	u64 aux_flags;
	union {
		void *addr;
		long unsigned int head;
	};
	int page;
};

struct perf_cgroup___18 {
	struct cgroup_subsys_state___23 css;
	struct perf_cgroup_info *info;
};

struct tms {
	__kernel_clock_t tms_utime;
	__kernel_clock_t tms_stime;
	__kernel_clock_t tms_cutime;
	__kernel_clock_t tms_cstime;
};

struct block_device_operations___19;

struct gendisk___19 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	short unsigned int events;
	short unsigned int event_flags;
	struct xarray part_tbl;
	struct block_device___19 *part0;
	const struct block_device_operations___19 *fops;
	struct request_queue___19 *queue;
	void *private_data;
	int flags;
	long unsigned int state;
	struct mutex open_mutex;
	unsigned int open_partitions;
	struct backing_dev_info___18 *bdi;
	struct kobject___29 *slave_dir;
	struct list_head slave_bdevs;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___29 integrity_kobj;
	struct cdrom_device_info *cdi;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	u64 diskseq;
};

struct bio_integrity_payload___19 {
	struct bio___19 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___23 *bip_vec;
	struct bio_vec___23 bip_inline_vecs[0];
};

struct blkcg___18;

struct blkg_policy_data___18;

struct blkcg_gq___18 {
	struct request_queue___19 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___18 *blkcg;
	struct blkcg_gq___18 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_iostat_set *iostat_cpu;
	struct blkg_iostat_set iostat;
	struct blkg_policy_data___18 *pd[6];
	spinlock_t async_bio_lock;
	struct bio_list___19 async_bios;
	struct work_struct async_bio_work;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
	struct callback_head callback_head;
};

typedef void integrity_prepare_fn___19(struct request___19 *);

typedef void integrity_complete_fn___19(struct request___19 *, unsigned int);

struct blk_integrity_profile___19 {
	integrity_processing_fn *generate_fn;
	integrity_processing_fn *verify_fn;
	integrity_prepare_fn___19 *prepare_fn;
	integrity_complete_fn___19 *complete_fn;
	const char *name;
};

struct block_device_operations___19 {
	blk_qc_t (*submit_bio)(struct bio___19 *);
	int (*open)(struct block_device___19 *, fmode_t);
	void (*release)(struct gendisk___19 *, fmode_t);
	int (*rw_page)(struct block_device___19 *, sector_t, struct page___31 *, unsigned int);
	int (*ioctl)(struct block_device___19 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___19 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___19 *, unsigned int);
	void (*unlock_native_capacity)(struct gendisk___19 *);
	int (*getgeo)(struct block_device___19 *, struct hd_geometry *);
	int (*set_read_only)(struct block_device___19 *, bool);
	void (*swap_slot_free_notify)(struct block_device___19 *, long unsigned int);
	int (*report_zones)(struct gendisk___19 *, sector_t, unsigned int, report_zones_cb, void *);
	char * (*devnode)(struct gendisk___19 *, umode_t *);
	struct module___28 *owner;
	const struct pr_ops *pr_ops;
	int (*alternative_gpt_sector)(struct gendisk___19 *, sector_t *);
};

struct fwnode_reference_args___28;

struct fwnode_endpoint___28;

struct fwnode_operations___28 {
	struct fwnode_handle___28 * (*get)(struct fwnode_handle___28 *);
	void (*put)(struct fwnode_handle___28 *);
	bool (*device_is_available)(const struct fwnode_handle___28 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___28 *, const struct device___31 *);
	bool (*property_present)(const struct fwnode_handle___28 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___28 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___28 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___28 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___28 *);
	struct fwnode_handle___28 * (*get_parent)(const struct fwnode_handle___28 *);
	struct fwnode_handle___28 * (*get_next_child_node)(const struct fwnode_handle___28 *, struct fwnode_handle___28 *);
	struct fwnode_handle___28 * (*get_named_child_node)(const struct fwnode_handle___28 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___28 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___28 *);
	struct fwnode_handle___28 * (*graph_get_next_endpoint)(const struct fwnode_handle___28 *, struct fwnode_handle___28 *);
	struct fwnode_handle___28 * (*graph_get_remote_endpoint)(const struct fwnode_handle___28 *);
	struct fwnode_handle___28 * (*graph_get_port_parent)(struct fwnode_handle___28 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___28 *, struct fwnode_endpoint___28 *);
	int (*add_links)(struct fwnode_handle___28 *);
};

struct fwnode_endpoint___28 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___28 *local_fwnode;
};

struct fwnode_reference_args___28 {
	struct fwnode_handle___28 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

typedef void rq_end_io_fn___19(struct request___19 *, blk_status_t);

struct request___19 {
	struct request_queue___19 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int tag;
	int internal_tag;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___19 *bio;
	struct bio___19 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct llist_node ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___23 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___19 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___19 *saved_end_io;
		} flush;
	};
	struct gendisk___19 *rq_disk;
	struct block_device___19 *part;
	u64 alloc_time_ns;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int stats_sectors;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	struct bio_crypt_ctx *crypt_ctx;
	struct blk_ksm_keyslot *crypt_keyslot;
	short unsigned int write_hint;
	short unsigned int ioprio;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___19 *end_io;
	void *end_io_data;
};

struct elevator_type___19;

struct elevator_mq_ops___19 {
	int (*init_sched)(struct request_queue___19 *, struct elevator_type___19 *);
	void (*exit_sched)(struct elevator_queue___19 *);
	int (*init_hctx)(struct blk_mq_hw_ctx *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx *, unsigned int);
	void (*depth_updated)(struct blk_mq_hw_ctx *);
	bool (*allow_merge)(struct request_queue___19 *, struct request___19 *, struct bio___19 *);
	bool (*bio_merge)(struct request_queue___19 *, struct bio___19 *, unsigned int);
	int (*request_merge)(struct request_queue___19 *, struct request___19 **, struct bio___19 *);
	void (*request_merged)(struct request_queue___19 *, struct request___19 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___19 *, struct request___19 *, struct request___19 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___19 *);
	void (*finish_request)(struct request___19 *);
	void (*insert_requests)(struct blk_mq_hw_ctx *, struct list_head *, bool);
	struct request___19 * (*dispatch_request)(struct blk_mq_hw_ctx *);
	bool (*has_work)(struct blk_mq_hw_ctx *);
	void (*completed_request)(struct request___19 *, u64);
	void (*requeue_request)(struct request___19 *);
	struct request___19 * (*former_request)(struct request_queue___19 *, struct request___19 *);
	struct request___19 * (*next_request)(struct request_queue___19 *, struct request___19 *);
	void (*init_icq)(struct io_cq___19 *);
	void (*exit_icq)(struct io_cq___19 *);
};

struct elv_fs_entry___19;

struct elevator_type___19 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___19 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___19 *elevator_attrs;
	const char *elevator_name;
	const char *elevator_alias;
	const unsigned int elevator_features;
	struct module___28 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
};

struct elevator_queue___19 {
	struct elevator_type___19 *type;
	void *elevator_data;
	struct kobject___29 kobj;
	struct mutex sysfs_lock;
	unsigned int registered;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hlist_head hash[64];
};

struct elv_fs_entry___19 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___19 *, char *);
	ssize_t (*store)(struct elevator_queue___19 *, const char *, size_t);
};

struct blkcg_policy_data___18;

struct blkcg___18 {
	struct cgroup_subsys_state___23 css;
	spinlock_t lock;
	refcount_t online_pin;
	struct xarray blkg_tree;
	struct blkcg_gq___18 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___18 *cpd[6];
	struct list_head all_blkcgs_node;
	char fc_app_id[129];
	struct list_head cgwb_list;
};

struct blkcg_policy_data___18 {
	struct blkcg___18 *blkcg;
	int plid;
};

struct blkg_policy_data___18 {
	struct blkcg_gq___18 *blkg;
	int plid;
};

struct mem_cgroup_reclaim_iter___18 {
	struct mem_cgroup___18 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___18 {
	struct lruvec___19 lruvec;
	struct lruvec_stats_percpu *lruvec_stats_percpu;
	struct lruvec_stats lruvec_stats;
	long unsigned int lru_zone_size[25];
	struct mem_cgroup_reclaim_iter___18 iter;
	struct shrinker_info *shrinker_info;
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	struct mem_cgroup___18 *memcg;
};

struct obj_cgroup___18 {
	struct percpu_ref refcnt;
	struct mem_cgroup___18 *memcg;
	atomic_t nr_charged_bytes;
	union {
		struct list_head list;
		struct callback_head rcu;
	};
};

struct tty_operations___7 {
	struct tty_struct___7 * (*lookup)(struct tty_driver___7 *, struct file___29 *, int);
	int (*install)(struct tty_driver___7 *, struct tty_struct___7 *);
	void (*remove)(struct tty_driver___7 *, struct tty_struct___7 *);
	int (*open)(struct tty_struct___7 *, struct file___29 *);
	void (*close)(struct tty_struct___7 *, struct file___29 *);
	void (*shutdown)(struct tty_struct___7 *);
	void (*cleanup)(struct tty_struct___7 *);
	int (*write)(struct tty_struct___7 *, const unsigned char *, int);
	int (*put_char)(struct tty_struct___7 *, unsigned char);
	void (*flush_chars)(struct tty_struct___7 *);
	unsigned int (*write_room)(struct tty_struct___7 *);
	unsigned int (*chars_in_buffer)(struct tty_struct___7 *);
	int (*ioctl)(struct tty_struct___7 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct tty_struct___7 *, unsigned int, long unsigned int);
	void (*set_termios)(struct tty_struct___7 *, struct ktermios *);
	void (*throttle)(struct tty_struct___7 *);
	void (*unthrottle)(struct tty_struct___7 *);
	void (*stop)(struct tty_struct___7 *);
	void (*start)(struct tty_struct___7 *);
	void (*hangup)(struct tty_struct___7 *);
	int (*break_ctl)(struct tty_struct___7 *, int);
	void (*flush_buffer)(struct tty_struct___7 *);
	void (*set_ldisc)(struct tty_struct___7 *);
	void (*wait_until_sent)(struct tty_struct___7 *, int);
	void (*send_xchar)(struct tty_struct___7 *, char);
	int (*tiocmget)(struct tty_struct___7 *);
	int (*tiocmset)(struct tty_struct___7 *, unsigned int, unsigned int);
	int (*resize)(struct tty_struct___7 *, struct winsize *);
	int (*get_icount)(struct tty_struct___7 *, struct serial_icounter_struct *);
	int (*get_serial)(struct tty_struct___7 *, struct serial_struct *);
	int (*set_serial)(struct tty_struct___7 *, struct serial_struct *);
	void (*show_fdinfo)(struct tty_struct___7 *, struct seq_file___27 *);
	int (*poll_init)(struct tty_driver___7 *, int, char *);
	int (*poll_get_char)(struct tty_driver___7 *, int);
	void (*poll_put_char)(struct tty_driver___7 *, int, char);
	int (*proc_show)(struct seq_file___27 *, void *);
};

struct tty_driver___7 {
	int magic;
	struct kref kref;
	struct cdev___14 **cdevs;
	struct module___28 *owner;
	const char *driver_name;
	const char *name;
	int name_base;
	int major;
	int minor_start;
	unsigned int num;
	short int type;
	short int subtype;
	struct ktermios init_termios;
	long unsigned int flags;
	struct proc_dir_entry *proc_entry;
	struct tty_driver___7 *other;
	struct tty_struct___7 **ttys;
	struct tty_port___7 **ports;
	struct ktermios **termios;
	void *driver_state;
	const struct tty_operations___7 *ops;
	struct list_head tty_drivers;
};

struct tty_port_operations___7;

struct tty_port_client_operations___7;

struct tty_port___7 {
	struct tty_bufhead buf;
	struct tty_struct___7 *tty;
	struct tty_struct___7 *itty;
	const struct tty_port_operations___7 *ops;
	const struct tty_port_client_operations___7 *client_ops;
	spinlock_t lock;
	int blocked_open;
	int count;
	wait_queue_head_t open_wait;
	wait_queue_head_t delta_msr_wait;
	long unsigned int flags;
	long unsigned int iflags;
	unsigned char console;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct mutex mutex;
	struct mutex buf_mutex;
	unsigned char *xmit_buf;
	unsigned int close_delay;
	unsigned int closing_wait;
	int drain_delay;
	struct kref kref;
	void *client_data;
};

struct tty_ldisc_ops___7 {
	char *name;
	int num;
	int flags;
	int (*open)(struct tty_struct___7 *);
	void (*close)(struct tty_struct___7 *);
	void (*flush_buffer)(struct tty_struct___7 *);
	ssize_t (*read)(struct tty_struct___7 *, struct file___29 *, unsigned char *, size_t, void **, long unsigned int);
	ssize_t (*write)(struct tty_struct___7 *, struct file___29 *, const unsigned char *, size_t);
	int (*ioctl)(struct tty_struct___7 *, struct file___29 *, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct tty_struct___7 *, struct file___29 *, unsigned int, long unsigned int);
	void (*set_termios)(struct tty_struct___7 *, struct ktermios *);
	__poll_t (*poll)(struct tty_struct___7 *, struct file___29 *, struct poll_table_struct___21 *);
	int (*hangup)(struct tty_struct___7 *);
	void (*receive_buf)(struct tty_struct___7 *, const unsigned char *, const char *, int);
	void (*write_wakeup)(struct tty_struct___7 *);
	void (*dcd_change)(struct tty_struct___7 *, unsigned int);
	int (*receive_buf2)(struct tty_struct___7 *, const unsigned char *, const char *, int);
	struct module___28 *owner;
};

struct tty_ldisc___7 {
	struct tty_ldisc_ops___7 *ops;
	struct tty_struct___7 *tty;
};

struct tty_port_operations___7 {
	int (*carrier_raised)(struct tty_port___7 *);
	void (*dtr_rts)(struct tty_port___7 *, int);
	void (*shutdown)(struct tty_port___7 *);
	int (*activate)(struct tty_port___7 *, struct tty_struct___7 *);
	void (*destruct)(struct tty_port___7 *);
};

struct tty_port_client_operations___7 {
	int (*receive_buf)(struct tty_port___7 *, const unsigned char *, const unsigned char *, size_t);
	void (*write_wakeup)(struct tty_port___7 *);
};

struct getcpu_cache {
	long unsigned int blob[16];
};

struct trace_event_fields___18 {
	const char *type;
	union {
		struct {
			const char *name;
			const int size;
			const int align;
			const int is_signed;
			const int filter_type;
		};
		int (*define_fields)(struct trace_event_call___18 *);
	};
};

struct trace_event_class___18 {
	const char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct trace_event_call___18 *, enum trace_reg, void *);
	struct trace_event_fields___18 *fields_array;
	struct list_head * (*get_fields)(struct trace_event_call___18 *);
	struct list_head fields;
	int (*raw_init)(struct trace_event_call___18 *);
};

struct syscall_metadata___6 {
	const char *name;
	int syscall_nr;
	int nb_args;
	const char **types;
	const char **args;
	struct list_head enter_fields;
	struct trace_event_call___18 *enter_event;
	struct trace_event_call___18 *exit_event;
};

struct linux_binprm___8 {
	struct vm_area_struct___32 *vma;
	long unsigned int vma_pages;
	struct mm_struct___32 *mm;
	long unsigned int p;
	long unsigned int argmin;
	unsigned int have_execfd;
	unsigned int execfd_creds;
	unsigned int secureexec;
	unsigned int point_of_no_return;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct file___29 *executable;
	struct file___29 *interpreter;
	struct file___29 *file;
	struct cred *cred;
	int unsafe;
	unsigned int per_clear;
	int argc;
	int envc;
	const char *filename;
	const char *interp;
	const char *fdpath;
	unsigned int interp_flags;
	int execfd;
	long unsigned int loader;
	long unsigned int exec;
	struct rlimit rlim_stack;
	char buf[256];
};

struct coredump_params___7 {
	const kernel_siginfo_t *siginfo;
	struct pt_regs *regs;
	struct file___29 *file;
	long unsigned int limit;
	long unsigned int mm_flags;
	loff_t written;
	loff_t pos;
	loff_t to_skip;
};

struct compat_sysinfo {
	s32 uptime;
	u32 loads[3];
	u32 totalram;
	u32 freeram;
	u32 sharedram;
	u32 bufferram;
	u32 totalswap;
	u32 freeswap;
	u16 procs;
	u16 pad;
	u32 totalhigh;
	u32 freehigh;
	u32 mem_unit;
	char _f[8];
};

struct fdtable___3 {
	unsigned int max_fds;
	struct file___29 **fd;
	long unsigned int *close_on_exec;
	long unsigned int *open_fds;
	long unsigned int *full_fds_bits;
	struct callback_head rcu;
};

struct files_struct {
	atomic_t count;
	bool resize_in_progress;
	wait_queue_head_t resize_wait;
	struct fdtable___3 *fdt;
	struct fdtable___3 fdtab;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t file_lock;
	unsigned int next_fd;
	long unsigned int close_on_exec_init[1];
	long unsigned int open_fds_init[1];
	long unsigned int full_fds_bits_init[1];
	struct file___29 *fd_array[64];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct wq_flusher;

struct worker;

struct workqueue_attrs;

struct pool_workqueue;

struct wq_device;

struct workqueue_struct {
	struct list_head pwqs;
	struct list_head list;
	struct mutex mutex;
	int work_color;
	int flush_color;
	atomic_t nr_pwqs_to_flush;
	struct wq_flusher *first_flusher;
	struct list_head flusher_queue;
	struct list_head flusher_overflow;
	struct list_head maydays;
	struct worker *rescuer;
	int nr_drainers;
	int saved_max_active;
	struct workqueue_attrs *unbound_attrs;
	struct pool_workqueue *dfl_pwq;
	struct wq_device *wq_dev;
	char name[24];
	struct callback_head rcu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int flags;
	struct pool_workqueue *cpu_pwqs;
	struct pool_workqueue *numa_pwq_tbl[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct workqueue_attrs {
	int nice;
	cpumask_var_t cpumask;
	bool no_numa;
};

struct execute_work {
	struct work_struct work;
};

enum {
	WQ_UNBOUND = 2,
	WQ_FREEZABLE = 4,
	WQ_MEM_RECLAIM = 8,
	WQ_HIGHPRI = 16,
	WQ_CPU_INTENSIVE = 32,
	WQ_SYSFS = 64,
	WQ_POWER_EFFICIENT = 128,
	__WQ_DRAINING = 65536,
	__WQ_ORDERED = 131072,
	__WQ_LEGACY = 262144,
	__WQ_ORDERED_EXPLICIT = 524288,
	WQ_MAX_ACTIVE = 512,
	WQ_MAX_UNBOUND_PER_CPU = 4,
	WQ_DFL_ACTIVE = 256,
};

enum xa_lock_type {
	XA_LOCK_IRQ = 1,
	XA_LOCK_BH = 2,
};

struct ida {
	struct xarray xa;
};

struct device_attribute___7 {
	struct attribute attr;
	ssize_t (*show)(struct device___3 *, struct device_attribute___7 *, char *);
	ssize_t (*store)(struct device___3 *, struct device_attribute___7 *, const char *, size_t);
};

struct __una_u32 {
	u32 x;
};

struct worker_pool;

struct worker {
	union {
		struct list_head entry;
		struct hlist_node hentry;
	};
	struct work_struct *current_work;
	work_func_t current_func;
	struct pool_workqueue *current_pwq;
	unsigned int current_color;
	struct list_head scheduled;
	struct task_struct___10 *task;
	struct worker_pool *pool;
	struct list_head node;
	long unsigned int last_active;
	unsigned int flags;
	int id;
	int sleeping;
	char desc[24];
	struct workqueue_struct *rescue_wq;
	work_func_t last_func;
};

struct pool_workqueue {
	struct worker_pool *pool;
	struct workqueue_struct *wq;
	int work_color;
	int flush_color;
	int refcnt;
	int nr_in_flight[16];
	int nr_active;
	int max_active;
	struct list_head inactive_works;
	struct list_head pwqs_node;
	struct list_head mayday_node;
	struct work_struct unbound_release_work;
	struct callback_head rcu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct worker_pool {
	raw_spinlock_t lock;
	int cpu;
	int node;
	int id;
	unsigned int flags;
	long unsigned int watchdog_ts;
	struct list_head worklist;
	int nr_workers;
	int nr_idle;
	struct list_head idle_list;
	struct timer_list idle_timer;
	struct timer_list mayday_timer;
	struct hlist_head busy_hash[64];
	struct worker *manager;
	struct list_head workers;
	struct completion *detach_completion;
	struct ida worker_ida;
	struct workqueue_attrs *attrs;
	struct hlist_node hash_node;
	int refcnt;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	atomic_t nr_running;
	struct callback_head rcu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

enum {
	POOL_MANAGER_ACTIVE = 1,
	POOL_DISASSOCIATED = 4,
	WORKER_DIE = 2,
	WORKER_IDLE = 4,
	WORKER_PREP = 8,
	WORKER_CPU_INTENSIVE = 64,
	WORKER_UNBOUND = 128,
	WORKER_REBOUND = 256,
	WORKER_NOT_RUNNING = 456,
	NR_STD_WORKER_POOLS = 2,
	UNBOUND_POOL_HASH_ORDER = 6,
	BUSY_WORKER_HASH_ORDER = 6,
	MAX_IDLE_WORKERS_RATIO = 4,
	IDLE_WORKER_TIMEOUT = 75000,
	MAYDAY_INITIAL_TIMEOUT = 2,
	MAYDAY_INTERVAL = 25,
	CREATE_COOLDOWN = 250,
	RESCUER_NICE_LEVEL = 4294967276,
	HIGHPRI_NICE_LEVEL = 4294967276,
	WQ_NAME_LEN = 24,
};

struct wq_flusher {
	struct list_head list;
	int flush_color;
	struct completion done;
};

struct wq_device {
	struct workqueue_struct *wq;
	struct device___3 dev;
};

struct trace_event_raw_workqueue_queue_work {
	struct trace_entry ent;
	void *work;
	void *function;
	u32 __data_loc_workqueue;
	unsigned int req_cpu;
	unsigned int cpu;
	char __data[0];
};

struct trace_event_raw_workqueue_activate_work {
	struct trace_entry ent;
	void *work;
	char __data[0];
};

struct trace_event_raw_workqueue_execute_start {
	struct trace_entry ent;
	void *work;
	void *function;
	char __data[0];
};

struct trace_event_raw_workqueue_execute_end {
	struct trace_entry ent;
	void *work;
	void *function;
	char __data[0];
};

struct trace_event_data_offsets_workqueue_queue_work {
	u32 workqueue;
};

struct trace_event_data_offsets_workqueue_activate_work {};

struct trace_event_data_offsets_workqueue_execute_start {};

struct trace_event_data_offsets_workqueue_execute_end {};

typedef void (*btf_trace_workqueue_queue_work)(void *, unsigned int, struct pool_workqueue *, struct work_struct *);

typedef void (*btf_trace_workqueue_activate_work)(void *, struct work_struct *);

typedef void (*btf_trace_workqueue_execute_start)(void *, struct work_struct *);

typedef void (*btf_trace_workqueue_execute_end)(void *, struct work_struct *, work_func_t);

struct wq_barrier {
	struct work_struct work;
	struct completion done;
	struct task_struct___10 *task;
};

struct cwt_wait {
	wait_queue_entry_t wait;
	struct work_struct *work;
};

struct apply_wqattrs_ctx {
	struct workqueue_struct *wq;
	struct workqueue_attrs *attrs;
	struct list_head list;
	struct pool_workqueue *dfl_pwq;
	struct pool_workqueue *pwq_tbl[0];
};

struct work_for_cpu {
	struct work_struct work;
	long int (*fn)(void *);
	void *arg;
	long int ret;
};

struct dentry___30;

struct super_block___30;

struct module___29;

struct file_system_type___30 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___30 * (*mount)(struct file_system_type___30 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___30 *);
	struct module___29 *owner;
	struct file_system_type___30 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___30;

struct kiocb___30;

struct iov_iter___24;

struct poll_table_struct___22;

struct vm_area_struct___33;

struct inode___30;

struct file_lock___30;

struct page___32;

struct pipe_inode_info___9;

struct seq_file___28;

struct file_operations___30 {
	struct module___29 *owner;
	loff_t (*llseek)(struct file___30 *, loff_t, int);
	ssize_t (*read)(struct file___30 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___30 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___30 *, struct iov_iter___24 *);
	ssize_t (*write_iter)(struct kiocb___30 *, struct iov_iter___24 *);
	int (*iopoll)(struct kiocb___30 *, bool);
	int (*iterate)(struct file___30 *, struct dir_context *);
	int (*iterate_shared)(struct file___30 *, struct dir_context *);
	__poll_t (*poll)(struct file___30 *, struct poll_table_struct___22 *);
	long int (*unlocked_ioctl)(struct file___30 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___30 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___30 *, struct vm_area_struct___33 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___30 *, struct file___30 *);
	int (*flush)(struct file___30 *, fl_owner_t);
	int (*release)(struct inode___30 *, struct file___30 *);
	int (*fsync)(struct file___30 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___30 *, int);
	int (*lock)(struct file___30 *, int, struct file_lock___30 *);
	ssize_t (*sendpage)(struct file___30 *, struct page___32 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___30 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___30 *, long unsigned int);
	int (*flock)(struct file___30 *, int, struct file_lock___30 *);
	ssize_t (*splice_write)(struct pipe_inode_info___9 *, struct file___30 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___30 *, loff_t *, struct pipe_inode_info___9 *, size_t, unsigned int);
	int (*setlease)(struct file___30 *, long int, struct file_lock___30 **, void **);
	long int (*fallocate)(struct file___30 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___28 *, struct file___30 *);
	ssize_t (*copy_file_range)(struct file___30 *, loff_t, struct file___30 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___30 *, loff_t, struct file___30 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___30 *, loff_t, loff_t, int);
};

struct static_call_mod___22 {
	struct static_call_mod___22 *next;
	struct module___29 *mod;
	struct static_call_site *sites;
};

struct static_call_key___22 {
	void *func;
	union {
		long unsigned int type;
		struct static_call_mod___22 *mods;
		struct static_call_site *sites;
	};
};

struct vmacache___32 {
	u64 seqnum;
	struct vm_area_struct___33 *vmas[4];
};

struct page_frag___32 {
	struct page___32 *page;
	__u32 offset;
	__u32 size;
};

struct perf_event___19;

struct thread_struct___20 {
	struct desc_struct tls_array[3];
	long unsigned int sp;
	short unsigned int es;
	short unsigned int ds;
	short unsigned int fsindex;
	short unsigned int gsindex;
	long unsigned int fsbase;
	long unsigned int gsbase;
	struct perf_event___19 *ptrace_bps[4];
	long unsigned int virtual_dr6;
	long unsigned int ptrace_dr7;
	long unsigned int cr2;
	long unsigned int trap_nr;
	long unsigned int error_code;
	struct io_bitmap *io_bitmap;
	long unsigned int iopl_emul;
	unsigned int iopl_warn: 1;
	unsigned int sig_on_uaccess_err: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u32 pkru;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct fpu fpu;
};

struct mm_struct___33;

struct pid___26;

struct cred___3;

struct nsproxy___29;

struct signal_struct___31;

struct bio_list___20;

struct backing_dev_info___19;

struct css_set___24;

struct perf_event_context___19;

struct mem_cgroup___19;

struct request_queue___20;

struct vm_struct___27;

struct task_struct___34 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___34 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___33 *mm;
	struct mm_struct___33 *active_mm;
	struct vmacache___32 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int restore_sigmask: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___34 *real_parent;
	struct task_struct___34 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___34 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___26 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	struct posix_cputimers_work posix_cputimers_work;
	const struct cred___3 *ptracer_cred;
	const struct cred___3 *real_cred;
	const struct cred___3 *cred;
	struct key *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___29 *nsproxy;
	struct signal_struct___31 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___34 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___20 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___19 *backing_dev_info;
	struct io_context___2 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___24 *cgroups;
	struct list_head cg_list;
	u32 closid;
	u32 rmid;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___19 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	struct pipe_inode_info___9 *splice_pipe;
	struct page_frag___32 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___19 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___19 *active_memcg;
	struct request_queue___20 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___34 *oom_reaper_list;
	struct vm_struct___27 *stack_vm_area;
	refcount_t stack_refcount;
	int patch_state;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	void *mce_vaddr;
	__u64 mce_kflags;
	u64 mce_addr;
	__u64 mce_ripv: 1;
	__u64 mce_whole_page: 1;
	__u64 __mce_reserved: 62;
	long: 2;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct callback_head mce_kill_me;
	int mce_count;
	struct llist_head kretprobe_instances;
	struct callback_head l1d_flush_kill;
	long: 64;
	struct thread_struct___20 thread;
};

typedef struct page___32 *pgtable_t___32;

struct address_space___30;

struct page_pool___9;

struct dev_pagemap___30;

struct page___32 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___30 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___9 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___32 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___32 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___33 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___30 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct pv_cpu_ops___26 {
	void (*io_delay)();
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	void (*write_cr4)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___20 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(long unsigned int);
	void (*invalidate_io_bitmap)();
	void (*update_io_bitmap)();
	void (*wbinvd)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int);
	void (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_msr_safe)(unsigned int, int *);
	int (*write_msr_safe)(unsigned int, unsigned int, unsigned int);
	u64 (*read_pmc)(int);
	void (*start_context_switch)(struct task_struct___34 *);
	void (*end_context_switch)(struct task_struct___34 *);
};

struct pv_mmu_ops___27 {
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_one_user)(long unsigned int);
	void (*flush_tlb_multi)(const struct cpumask *, const struct flush_tlb_info___3 *);
	void (*tlb_remove_table)(struct mmu_gather *, void *);
	void (*exit_mmap)(struct mm_struct___33 *);
	struct paravirt_callee_save read_cr2;
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___33 *, struct mm_struct___33 *);
	void (*dup_mmap)(struct mm_struct___33 *, struct mm_struct___33 *);
	int (*pgd_alloc)(struct mm_struct___33 *);
	void (*pgd_free)(struct mm_struct___33 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___33 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___33 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___33 *, long unsigned int);
	void (*alloc_p4d)(struct mm_struct___33 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*release_p4d)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	pte_t (*ptep_modify_prot_start)(struct vm_area_struct___33 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct vm_area_struct___33 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_p4d)(p4d_t *, p4d_t);
	struct paravirt_callee_save p4d_val;
	struct paravirt_callee_save make_p4d;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

struct core_state___32;

struct user_namespace___4;

struct mm_struct___33 {
	struct {
		struct vm_area_struct___33 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___30 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int mmap_compat_base;
		long unsigned int mmap_compat_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[48];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___32 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___34 *owner;
		struct user_namespace___4 *user_ns;
		struct file___30 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		bool tlb_flush_batched;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct vm_operations_struct___30;

struct vm_area_struct___33 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___33 *vm_next;
	struct vm_area_struct___33 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___33 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___30 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___30 *vm_file;
	struct file___30 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct paravirt_patch_template___27 {
	struct pv_cpu_ops___26 cpu;
	struct pv_irq_ops irq;
	struct pv_mmu_ops___27 mmu;
	struct pv_lock_ops lock;
};

struct tracepoint___22 {
	const char *name;
	struct static_key key;
	struct static_call_key___22 *static_call_key;
	void *static_call_tramp;
	void *iterator;
	int (*regfunc)();
	void (*unregfunc)();
	struct tracepoint_func *funcs;
};

struct bpf_raw_event_map___22 {
	struct tracepoint___22 *tp;
	void *bpf_func;
	u32 num_args;
	u32 writable_size;
	long: 64;
};

struct seq_operations___28 {
	void * (*start)(struct seq_file___28 *, loff_t *);
	void (*stop)(struct seq_file___28 *, void *);
	void * (*next)(struct seq_file___28 *, void *, loff_t *);
	int (*show)(struct seq_file___28 *, void *);
};

struct hw_perf_event___19 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___34 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	union {
		struct {
			u64 last_period;
			local64_t period_left;
		};
		struct {
			u64 saved_metric;
			u64 saved_slots;
		};
	};
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___19)(struct perf_event___19 *, struct perf_sample_data *, struct pt_regs *);

struct pmu___19;

struct fasync_struct___30;

struct pid_namespace___26;

struct bpf_prog___4;

struct trace_event_call___19;

struct perf_cgroup___19;

struct perf_event___19 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___19 *group_leader;
	struct pmu___19 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___19 hw;
	struct perf_event_context___19 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___19 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___34 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct perf_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___30 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	long unsigned int pending_addr;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	struct perf_addr_filter_range *addr_filter_ranges;
	long unsigned int addr_filters_gen;
	struct perf_event___19 *aux_event;
	void (*destroy)(struct perf_event___19 *);
	struct callback_head callback_head;
	struct pid_namespace___26 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___19 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___19 orig_overflow_handler;
	struct bpf_prog___4 *prog;
	u64 bpf_cookie;
	struct trace_event_call___19 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___19 *cgrp;
	void *security;
	struct list_head sb_list;
};

struct address_space_operations___30;

struct address_space___30 {
	struct inode___30 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___30 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct device___32;

struct page_pool_params___9 {
	unsigned int flags;
	unsigned int order;
	unsigned int pool_size;
	int nid;
	struct device___32 *dev;
	enum dma_data_direction dma_dir;
	unsigned int max_len;
	unsigned int offset;
};

struct pp_alloc_cache___9 {
	u32 count;
	struct page___32 *cache[128];
};

struct page_pool___9 {
	struct page_pool_params___9 p;
	struct delayed_work release_dw;
	void (*disconnect)(void *);
	long unsigned int defer_start;
	long unsigned int defer_warn;
	u32 pages_state_hold_cnt;
	unsigned int frag_offset;
	struct page___32 *frag_page;
	long int frag_users;
	long: 64;
	long: 64;
	struct pp_alloc_cache___9 alloc;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct ptr_ring ring;
	atomic_t pages_state_release_cnt;
	refcount_t user_cnt;
	u64 destroy_cnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pagemap_ops___30;

struct dev_pagemap___30 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___30 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vfsmount___30;

struct path___30 {
	struct vfsmount___30 *mnt;
	struct dentry___30 *dentry;
};

struct fown_struct___26 {
	rwlock_t lock;
	struct pid___26 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___30 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___30 f_path;
	struct inode___30 *f_inode;
	const struct file_operations___30 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___26 f_owner;
	const struct cred___3 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___30 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___30;

struct vm_operations_struct___30 {
	void (*open)(struct vm_area_struct___33 *);
	void (*close)(struct vm_area_struct___33 *);
	int (*may_split)(struct vm_area_struct___33 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___33 *);
	int (*mprotect)(struct vm_area_struct___33 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___30 *);
	vm_fault_t (*huge_fault)(struct vm_fault___30 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___30 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___33 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___30 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___30 *);
	int (*access)(struct vm_area_struct___33 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___33 *);
	int (*set_policy)(struct vm_area_struct___33 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___33 *, long unsigned int);
	struct page___32 * (*find_special_page)(struct vm_area_struct___33 *, long unsigned int);
};

struct core_thread___32 {
	struct task_struct___34 *task;
	struct core_thread___32 *next;
};

struct core_state___32 {
	atomic_t nr_threads;
	struct core_thread___32 dumper;
	struct completion startup;
};

struct proc_ns_operations___4;

struct ns_common___4 {
	atomic_long_t stashed;
	const struct proc_ns_operations___4 *ops;
	unsigned int inum;
	refcount_t count;
};

struct ucounts___4;

struct user_namespace___4 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	struct user_namespace___4 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___4 ns;
	long unsigned int flags;
	bool parent_could_setfcap;
	struct list_head keyring_name_list;
	struct key *user_keyring_register;
	struct rw_semaphore keyring_sem;
	struct key *persistent_keyring_register;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___4 *ucounts;
	long int ucount_max[16];
};

struct vm_fault___30 {
	const struct {
		struct vm_area_struct___33 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___32 *cow_page;
	struct page___32 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___32 prealloc_pte;
};

struct pglist_data___20;

struct lruvec___20 {
	struct list_head lists[5];
	spinlock_t lru_lock;
	long unsigned int anon_cost;
	long unsigned int file_cost;
	atomic_long_t nonresident_age;
	long unsigned int refaults[2];
	long unsigned int flags;
	struct pglist_data___20 *pgdat;
};

struct zone___20 {
	long unsigned int _watermark[3];
	long unsigned int watermark_boost;
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[5];
	int node;
	struct pglist_data___20 *zone_pgdat;
	struct per_cpu_pages *per_cpu_pageset;
	struct per_cpu_zonestat *per_cpu_zonestats;
	int pageset_high;
	int pageset_batch;
	long unsigned int zone_start_pfn;
	atomic_long_t managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int present_early_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	seqlock_t span_seqlock;
	int initialized;
	int: 32;
	struct zone_padding _pad1_;
	struct free_area free_area[11];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	long unsigned int compact_init_migrate_pfn;
	long unsigned int compact_init_free_pfn;
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	short: 16;
	struct zone_padding _pad3_;
	atomic_long_t vm_stat[11];
	atomic_long_t vm_numa_event[6];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___20 {
	struct zone___20 *zone;
	int zone_idx;
};

struct zonelist___20 {
	struct zoneref___20 _zonerefs[5121];
};

struct pglist_data___20 {
	struct zone___20 node_zones[5];
	struct zonelist___20 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___34 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_highest_zoneidx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_highest_zoneidx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___34 *kcompactd;
	bool proactive_compact_trigger;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct deferred_split deferred_split_queue;
	struct lruvec___20 __lruvec;
	long unsigned int flags;
	long: 64;
	struct zone_padding _pad2_;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[39];
};

struct shrink_control___19 {
	gfp_t gfp_mask;
	int nid;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	struct mem_cgroup___19 *memcg;
};

struct cgroup___24;

struct cgroup_subsys___24;

struct cgroup_subsys_state___24 {
	struct cgroup___24 *cgroup;
	struct cgroup_subsys___24 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___24 *parent;
};

struct kernfs_node___30;

struct cgroup_file___24 {
	struct kernfs_node___30 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct obj_cgroup___19;

struct mem_cgroup_per_node___19;

struct mem_cgroup___19 {
	struct cgroup_subsys_state___24 css;
	struct mem_cgroup_id id;
	struct page_counter memory;
	union {
		struct page_counter swap;
		struct page_counter memsw;
	};
	struct page_counter kmem;
	struct page_counter tcpmem;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool oom_group;
	bool oom_lock;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___24 events_file;
	struct cgroup_file___24 events_local_file;
	struct cgroup_file___24 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	struct memcg_vmstats vmstats;
	atomic_long_t memory_events[8];
	atomic_long_t memory_events_local[8];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct obj_cgroup___19 *objcg;
	struct list_head objcg_list;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad2_;
	atomic_t moving_account;
	struct task_struct___34 *move_lock_task;
	struct memcg_vmstats_percpu *vmstats_percpu;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct memcg_cgwb_frn cgwb_frn[4];
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct deferred_split deferred_split_queue;
	struct mem_cgroup_per_node___19 *nodeinfo[0];
	long: 64;
};

struct shrinker___19 {
	long unsigned int (*count_objects)(struct shrinker___19 *, struct shrink_control___19 *);
	long unsigned int (*scan_objects)(struct shrinker___19 *, struct shrink_control___19 *);
	long int batch;
	int seeks;
	unsigned int flags;
	struct list_head list;
	int id;
	atomic_long_t *nr_deferred;
};

struct dev_pagemap_ops___30 {
	void (*page_free)(struct page___32 *);
	void (*kill)(struct dev_pagemap___30 *);
	void (*cleanup)(struct dev_pagemap___30 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___30 *);
};

struct upid___26 {
	int nr;
	struct pid_namespace___26 *ns;
};

struct pid_namespace___26 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___34 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___26 *parent;
	struct fs_pin *bacct;
	struct user_namespace___4 *user_ns;
	struct ucounts___4 *ucounts;
	int reboot;
	struct ns_common___4 ns;
};

struct pid___26 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___26 numbers[1];
};

struct ucounts___4 {
	struct hlist_node node;
	struct user_namespace___4 *ns;
	kuid_t uid;
	atomic_t count;
	atomic_long_t ucount[16];
};

struct signal_struct___31 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___34 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___34 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper;
	unsigned int has_child_subreaper;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___26 *pids[4];
	struct pid___26 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___33 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct cred___3 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key *session_keyring;
	struct key *process_keyring;
	struct key *thread_keyring;
	struct key *request_key_auth;
	void *security;
	struct user_struct *user;
	struct user_namespace___4 *user_ns;
	struct ucounts___4 *ucounts;
	struct group_info *group_info;
	union {
		int non_rcu;
		struct callback_head rcu;
	};
};

struct uts_namespace___3;

struct net___5;

struct cgroup_namespace___24;

struct nsproxy___29 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___26 *pid_ns_for_children;
	struct net___5 *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___24 *cgroup_ns;
};

struct bio___20;

struct bio_list___20 {
	struct bio___20 *head;
	struct bio___20 *tail;
};

struct bdi_writeback___19 {
	struct backing_dev_info___19 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	atomic_t writeback_inodes;
	struct percpu_counter stat[4];
	long unsigned int congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	struct delayed_work bw_dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___24 *memcg_css;
	struct cgroup_subsys_state___24 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	struct list_head b_attached;
	struct list_head offline_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
};

struct backing_dev_info___19 {
	u64 id;
	struct rb_node rb_node;
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___19 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct mutex cgwb_release_mutex;
	struct rw_semaphore wb_switch_rwsem;
	wait_queue_head_t wb_waitq;
	struct device___32 *dev;
	char dev_name[64];
	struct device___32 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___30 *debug_dir;
};

struct io_cq___20;

struct io_context___2 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	struct xarray icq_tree;
	struct io_cq___20 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct css_set___24 {
	struct cgroup_subsys_state___24 *subsys[14];
	refcount_t refcount;
	struct css_set___24 *dom_cset;
	struct cgroup___24 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___24 *mg_src_cgrp;
	struct cgroup___24 *mg_dst_cgrp;
	struct css_set___24 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___19 {
	struct pmu___19 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	int rotate_necessary;
	refcount_t refcount;
	struct task_struct___34 *task;
	u64 time;
	u64 timestamp;
	u64 timeoffset;
	struct perf_event_context___19 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

struct pipe_buffer___9;

struct pipe_inode_info___9 {
	struct mutex mutex;
	wait_queue_head_t rd_wait;
	wait_queue_head_t wr_wait;
	unsigned int head;
	unsigned int tail;
	unsigned int max_usage;
	unsigned int ring_size;
	bool note_loss;
	unsigned int nr_accounted;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int r_counter;
	unsigned int w_counter;
	unsigned int poll_usage;
	struct page___32 *tmp_page;
	struct fasync_struct___30 *fasync_readers;
	struct fasync_struct___30 *fasync_writers;
	struct pipe_buffer___9 *bufs;
	struct user_struct *user;
	struct watch_queue *watch_queue;
};

struct kset___29;

struct kobj_type___29;

struct kobject___30 {
	const char *name;
	struct list_head entry;
	struct kobject___30 *parent;
	struct kset___29 *kset;
	struct kobj_type___29 *ktype;
	struct kernfs_node___30 *sd;
	struct kref kref;
	unsigned int state_initialized;
	unsigned int state_in_sysfs;
	unsigned int state_add_uevent_sent;
	unsigned int state_remove_uevent_sent;
	unsigned int uevent_suppress;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct blk_integrity_profile___20;

struct blk_integrity___20 {
	const struct blk_integrity_profile___20 *profile;
	unsigned char flags;
	unsigned char tuple_size;
	unsigned char interval_exp;
	unsigned char tag_size;
};

struct bio_set___20 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	struct bio_alloc_cache *cache;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	unsigned int back_pad;
	spinlock_t rescue_lock;
	struct bio_list___20 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	struct hlist_node cpuhp_dead;
};

struct request___20;

struct elevator_queue___20;

struct gendisk___20;

struct blkcg_gq___19;

struct request_queue___20 {
	struct request___20 *last_merge;
	struct elevator_queue___20 *elevator;
	struct percpu_ref q_usage_counter;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	const struct blk_mq_ops *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx **queue_hw_ctx;
	unsigned int nr_hw_queues;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	spinlock_t queue_lock;
	struct gendisk___20 *disk;
	struct kobject___30 kobj;
	struct kobject___30 *mq_kobj;
	struct blk_integrity___20 integrity;
	struct device___32 *dev;
	enum rpm_status rpm_status;
	long unsigned int nr_requests;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_keyslot_manager *ksm;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	atomic_t nr_active_requests_shared_sbitmap;
	struct sbitmap_queue sched_bitmap_tags;
	struct sbitmap_queue sched_breserved_tags;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___19 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int required_elevator_features;
	unsigned int nr_zones;
	long unsigned int *conv_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int max_open_zones;
	unsigned int max_active_zones;
	int node;
	struct mutex debugfs_mutex;
	struct blk_trace *blk_trace;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	struct mutex sysfs_dir_lock;
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	int mq_freeze_depth;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct mutex mq_freeze_lock;
	struct blk_mq_tag_set *tag_set;
	struct list_head tag_set_list;
	struct bio_set___20 bio_split;
	struct dentry___30 *debugfs_dir;
	struct dentry___30 *sched_debugfs_dir;
	struct dentry___30 *rqos_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	u64 write_hints[5];
};

struct vm_struct___27 {
	struct vm_struct___27 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___32 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct dentry_operations___30;

struct dentry___30 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___30 *d_parent;
	struct qstr d_name;
	struct inode___30 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___30 *d_op;
	struct super_block___30 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___30;

struct inode___30 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___30 *i_op;
	struct super_block___30 *i_sb;
	struct address_space___30 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___19 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___30 *i_fop;
		void (*free_inode)(struct inode___30 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___30 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___9 *i_pipe;
		struct cdev *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___30 {
	int (*d_revalidate)(struct dentry___30 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___30 *, unsigned int);
	int (*d_hash)(const struct dentry___30 *, struct qstr *);
	int (*d_compare)(const struct dentry___30 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___30 *);
	int (*d_init)(struct dentry___30 *);
	void (*d_release)(struct dentry___30 *);
	void (*d_prune)(struct dentry___30 *);
	void (*d_iput)(struct dentry___30 *, struct inode___30 *);
	char * (*d_dname)(struct dentry___30 *, char *, int);
	struct vfsmount___30 * (*d_automount)(struct path___30 *);
	int (*d_manage)(const struct path___30 *, bool);
	struct dentry___30 * (*d_real)(struct dentry___30 *, const struct inode___30 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___30;

struct mem_dqinfo___30 {
	struct quota_format_type___30 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___30;

struct quota_info___30 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___30 *files[3];
	struct mem_dqinfo___30 info[3];
	const struct quota_format_ops___30 *ops[3];
};

struct rcuwait___30 {
	struct task_struct___34 *task;
};

struct percpu_rw_semaphore___30 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___30 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___30 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___30 rw_sem[3];
};

struct super_operations___30;

struct dquot_operations___30;

struct quotactl_ops___30;

struct block_device___20;

struct super_block___30 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___30 *s_type;
	const struct super_operations___30 *s_op;
	const struct dquot_operations___30 *dq_op;
	const struct quotactl_ops___30 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___30 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___20 *s_bdev;
	struct backing_dev_info___19 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___30 s_dquot;
	struct sb_writers___30 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___30 *s_d_op;
	int cleancache_poolid;
	struct shrinker___19 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___4 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___30 {
	struct dentry___30 *mnt_root;
	struct super_block___30 *mnt_sb;
	int mnt_flags;
	struct user_namespace___4 *mnt_userns;
};

struct psi_group___24 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___34 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct bpf_prog_array___4;

struct cgroup_bpf___4 {
	struct bpf_prog_array___4 *effective[23];
	struct list_head progs[23];
	u32 flags[23];
	struct list_head storages;
	struct bpf_prog_array___4 *inactive;
	struct percpu_ref refcnt;
	struct work_struct release_work;
};

struct cgroup_root___24;

struct cgroup_rstat_cpu___24;

struct cgroup___24 {
	struct cgroup_subsys_state___24 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___30 *kn;
	struct cgroup_file___24 procs_file;
	struct cgroup_file___24 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___24 *subsys[14];
	struct cgroup_root___24 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___24 *dom_cgrp;
	struct cgroup___24 *old_dom_cgrp;
	struct cgroup_rstat_cpu___24 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___24 psi;
	struct cgroup_bpf___4 bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct io_cq___20 {
	struct request_queue___20 *q;
	struct io_context___2 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct kiocb___30 {
	struct file___30 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___30 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___16 *ki_waitq;
	};
};

struct iattr___30 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___30 *ia_file;
};

struct dquot___30 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___30 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___30 {
	int qf_fmt_id;
	const struct quota_format_ops___30 *qf_ops;
	struct module___29 *qf_owner;
	struct quota_format_type___30 *qf_next;
};

struct quota_format_ops___30 {
	int (*check_quota_file)(struct super_block___30 *, int);
	int (*read_file_info)(struct super_block___30 *, int);
	int (*write_file_info)(struct super_block___30 *, int);
	int (*free_file_info)(struct super_block___30 *, int);
	int (*read_dqblk)(struct dquot___30 *);
	int (*commit_dqblk)(struct dquot___30 *);
	int (*release_dqblk)(struct dquot___30 *);
	int (*get_next_id)(struct super_block___30 *, struct kqid *);
};

struct dquot_operations___30 {
	int (*write_dquot)(struct dquot___30 *);
	struct dquot___30 * (*alloc_dquot)(struct super_block___30 *, int);
	void (*destroy_dquot)(struct dquot___30 *);
	int (*acquire_dquot)(struct dquot___30 *);
	int (*release_dquot)(struct dquot___30 *);
	int (*mark_dirty)(struct dquot___30 *);
	int (*write_info)(struct super_block___30 *, int);
	qsize_t * (*get_reserved_space)(struct inode___30 *);
	int (*get_projid)(struct inode___30 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___30 *, qsize_t *);
	int (*get_next_id)(struct super_block___30 *, struct kqid *);
};

struct quotactl_ops___30 {
	int (*quota_on)(struct super_block___30 *, int, int, const struct path___30 *);
	int (*quota_off)(struct super_block___30 *, int);
	int (*quota_enable)(struct super_block___30 *, unsigned int);
	int (*quota_disable)(struct super_block___30 *, unsigned int);
	int (*quota_sync)(struct super_block___30 *, int);
	int (*set_info)(struct super_block___30 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___30 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___30 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___30 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___30 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___30 *, unsigned int);
};

struct module_kobject___29 {
	struct kobject___30 kobj;
	struct module___29 *mod;
	struct kobject___30 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___29 {
	struct module___29 *mod;
	struct latch_tree_node node;
};

struct module_layout___29 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___29 mtn;
};

struct module_attribute___29;

struct kernel_param___29;

struct module___29 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___29 mkobj;
	struct module_attribute___29 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___30 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___29 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___29 core_layout;
	struct module_layout___29 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map___22 *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___19 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	int num_static_call_sites;
	struct static_call_site *static_call_sites;
	bool klp;
	bool klp_alive;
	struct klp_modinfo *klp_info;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct writeback_control___19;

struct address_space_operations___30 {
	int (*writepage)(struct page___32 *, struct writeback_control___19 *);
	int (*readpage)(struct file___30 *, struct page___32 *);
	int (*writepages)(struct address_space___30 *, struct writeback_control___19 *);
	int (*set_page_dirty)(struct page___32 *);
	int (*readpages)(struct file___30 *, struct address_space___30 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control *);
	int (*write_begin)(struct file___30 *, struct address_space___30 *, loff_t, unsigned int, unsigned int, struct page___32 **, void **);
	int (*write_end)(struct file___30 *, struct address_space___30 *, loff_t, unsigned int, unsigned int, struct page___32 *, void *);
	sector_t (*bmap)(struct address_space___30 *, sector_t);
	void (*invalidatepage)(struct page___32 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___32 *, gfp_t);
	void (*freepage)(struct page___32 *);
	ssize_t (*direct_IO)(struct kiocb___30 *, struct iov_iter___24 *);
	int (*migratepage)(struct address_space___30 *, struct page___32 *, struct page___32 *, enum migrate_mode);
	bool (*isolate_page)(struct page___32 *, isolate_mode_t);
	void (*putback_page)(struct page___32 *);
	int (*launder_page)(struct page___32 *);
	int (*is_partially_uptodate)(struct page___32 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___32 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___30 *, struct page___32 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___30 *, sector_t *);
	void (*swap_deactivate)(struct file___30 *);
};

struct writeback_control___19 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate;
	unsigned int for_background;
	unsigned int tagged_writepages;
	unsigned int for_reclaim;
	unsigned int range_cyclic;
	unsigned int for_sync;
	unsigned int no_cgroup_owner;
	unsigned int punt_to_cgroup;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bdi_writeback___19 *wb;
	struct inode___30 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
};

struct bio_vec___24;

struct iov_iter___24 {
	u8 iter_type;
	bool data_source;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___24 *bvec;
		struct xarray *xarray;
		struct pipe_inode_info___9 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			unsigned int head;
			unsigned int start_head;
		};
		loff_t xarray_start;
	};
};

struct inode_operations___30 {
	struct dentry___30 * (*lookup)(struct inode___30 *, struct dentry___30 *, unsigned int);
	const char * (*get_link)(struct dentry___30 *, struct inode___30 *, struct delayed_call *);
	int (*permission)(struct user_namespace___4 *, struct inode___30 *, int);
	struct posix_acl * (*get_acl)(struct inode___30 *, int, bool);
	int (*readlink)(struct dentry___30 *, char *, int);
	int (*create)(struct user_namespace___4 *, struct inode___30 *, struct dentry___30 *, umode_t, bool);
	int (*link)(struct dentry___30 *, struct inode___30 *, struct dentry___30 *);
	int (*unlink)(struct inode___30 *, struct dentry___30 *);
	int (*symlink)(struct user_namespace___4 *, struct inode___30 *, struct dentry___30 *, const char *);
	int (*mkdir)(struct user_namespace___4 *, struct inode___30 *, struct dentry___30 *, umode_t);
	int (*rmdir)(struct inode___30 *, struct dentry___30 *);
	int (*mknod)(struct user_namespace___4 *, struct inode___30 *, struct dentry___30 *, umode_t, dev_t);
	int (*rename)(struct user_namespace___4 *, struct inode___30 *, struct dentry___30 *, struct inode___30 *, struct dentry___30 *, unsigned int);
	int (*setattr)(struct user_namespace___4 *, struct dentry___30 *, struct iattr___30 *);
	int (*getattr)(struct user_namespace___4 *, const struct path___30 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___30 *, char *, size_t);
	int (*fiemap)(struct inode___30 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___30 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___30 *, struct dentry___30 *, struct file___30 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace___4 *, struct inode___30 *, struct dentry___30 *, umode_t);
	int (*set_acl)(struct user_namespace___4 *, struct inode___30 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace___4 *, struct dentry___30 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___30 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___30 {
	void (*fl_copy_lock)(struct file_lock___30 *, struct file_lock___30 *);
	void (*fl_release_private)(struct file_lock___30 *);
};

struct lock_manager_operations___30;

struct file_lock___30 {
	struct file_lock___30 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___30 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___30 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___30 *fl_ops;
	const struct lock_manager_operations___30 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___30 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___30 *);
	int (*lm_grant)(struct file_lock___30 *, int);
	bool (*lm_break)(struct file_lock___30 *);
	int (*lm_change)(struct file_lock___30 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___30 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___30 *);
};

struct fasync_struct___30 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___30 *fa_next;
	struct file___30 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___30 {
	struct inode___30 * (*alloc_inode)(struct super_block___30 *);
	void (*destroy_inode)(struct inode___30 *);
	void (*free_inode)(struct inode___30 *);
	void (*dirty_inode)(struct inode___30 *, int);
	int (*write_inode)(struct inode___30 *, struct writeback_control___19 *);
	int (*drop_inode)(struct inode___30 *);
	void (*evict_inode)(struct inode___30 *);
	void (*put_super)(struct super_block___30 *);
	int (*sync_fs)(struct super_block___30 *, int);
	int (*freeze_super)(struct super_block___30 *);
	int (*freeze_fs)(struct super_block___30 *);
	int (*thaw_super)(struct super_block___30 *);
	int (*unfreeze_fs)(struct super_block___30 *);
	int (*statfs)(struct dentry___30 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___30 *, int *, char *);
	void (*umount_begin)(struct super_block___30 *);
	int (*show_options)(struct seq_file___28 *, struct dentry___30 *);
	int (*show_devname)(struct seq_file___28 *, struct dentry___30 *);
	int (*show_path)(struct seq_file___28 *, struct dentry___30 *);
	int (*show_stats)(struct seq_file___28 *, struct dentry___30 *);
	ssize_t (*quota_read)(struct super_block___30 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___30 *, int, const char *, size_t, loff_t);
	struct dquot___30 ** (*get_dquots)(struct inode___30 *);
	long int (*nr_cached_objects)(struct super_block___30 *, struct shrink_control___19 *);
	long int (*free_cached_objects)(struct super_block___30 *, struct shrink_control___19 *);
	struct file___30 * (*real_loop)(struct file___30 *);
};

struct wakeup_source___32;

struct dev_pm_info___32 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___32 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___32 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___32;

struct bus_type___32;

struct device_driver___32;

struct dev_pm_domain___32;

struct fwnode_handle___29;

struct class___32;

struct attribute_group___30;

struct device___32 {
	struct kobject___30 kobj;
	struct device___32 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___32 *type;
	struct bus_type___32 *bus;
	struct device_driver___32 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___32 power;
	struct dev_pm_domain___32 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node *of_node;
	struct fwnode_handle___29 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___32 *class;
	const struct attribute_group___30 **groups;
	void (*release)(struct device___32 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct block_device___20 {
	sector_t bd_start_sect;
	struct disk_stats *bd_stats;
	long unsigned int bd_stamp;
	bool bd_read_only;
	dev_t bd_dev;
	int bd_openers;
	struct inode___30 *bd_inode;
	struct super_block___30 *bd_super;
	void *bd_claiming;
	struct device___32 bd_device;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct kobject___30 *bd_holder_dir;
	u8 bd_partno;
	spinlock_t bd_size_lock;
	struct gendisk___20 *bd_disk;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	struct super_block___30 *bd_fsfreeze_sb;
	struct partition_meta_info *bd_meta_info;
};

typedef void (*poll_queue_proc___22)(struct file___30 *, wait_queue_head_t *, struct poll_table_struct___22 *);

struct poll_table_struct___22 {
	poll_queue_proc___22 _qproc;
	__poll_t _key;
};

struct seq_file___28 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___28 *op;
	int poll_event;
	const struct file___30 *file;
	void *private;
};

typedef void bio_end_io_t___20(struct bio___20 *);

struct bio_vec___24 {
	struct page___32 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___20;

struct bio___20 {
	struct bio___20 *bi_next;
	struct block_device___20 *bi_bdev;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	atomic_t __bi_remaining;
	struct bvec_iter bi_iter;
	bio_end_io_t___20 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___19 *bi_blkg;
	struct bio_issue bi_issue;
	u64 bi_iocost_cost;
	struct bio_crypt_ctx *bi_crypt_context;
	union {
		struct bio_integrity_payload___20 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___24 *bi_io_vec;
	struct bio_set___20 *bi_pool;
	struct bio_vec___24 bi_inline_vecs[0];
};

struct fwnode_operations___29;

struct fwnode_handle___29 {
	struct fwnode_handle___29 *secondary;
	const struct fwnode_operations___29 *ops;
	struct device___32 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct fwnode_reference_args___29;

struct fwnode_endpoint___29;

struct fwnode_operations___29 {
	struct fwnode_handle___29 * (*get)(struct fwnode_handle___29 *);
	void (*put)(struct fwnode_handle___29 *);
	bool (*device_is_available)(const struct fwnode_handle___29 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___29 *, const struct device___32 *);
	bool (*property_present)(const struct fwnode_handle___29 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___29 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___29 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___29 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___29 *);
	struct fwnode_handle___29 * (*get_parent)(const struct fwnode_handle___29 *);
	struct fwnode_handle___29 * (*get_next_child_node)(const struct fwnode_handle___29 *, struct fwnode_handle___29 *);
	struct fwnode_handle___29 * (*get_named_child_node)(const struct fwnode_handle___29 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___29 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___29 *);
	struct fwnode_handle___29 * (*graph_get_next_endpoint)(const struct fwnode_handle___29 *, struct fwnode_handle___29 *);
	struct fwnode_handle___29 * (*graph_get_remote_endpoint)(const struct fwnode_handle___29 *);
	struct fwnode_handle___29 * (*graph_get_port_parent)(struct fwnode_handle___29 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___29 *, struct fwnode_endpoint___29 *);
	int (*add_links)(struct fwnode_handle___29 *);
};

struct fwnode_endpoint___29 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___29 *local_fwnode;
};

struct fwnode_reference_args___29 {
	struct fwnode_handle___29 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct uts_namespace___3 {
	struct new_utsname name;
	struct user_namespace___4 *user_ns;
	struct ucounts___4 *ucounts;
	struct ns_common___4 ns;
};

struct fib_rules_ops___3;

struct sock___3;

struct fqdir___5;

struct fib_notifier_ops___3;

struct netns_ipv4___5 {
	struct inet_timewait_death_row tcp_death_row;
	struct ctl_table_header *forw_hdr;
	struct ctl_table_header *frags_hdr;
	struct ctl_table_header *ipv4_hdr;
	struct ctl_table_header *route_hdr;
	struct ctl_table_header *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct ip_ra_chain *ra_chain;
	struct mutex ra_mutex;
	struct fib_rules_ops___3 *rules_ops;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	unsigned int fib_rules_require_fldissect;
	bool fib_has_custom_rules;
	bool fib_has_custom_local_routes;
	bool fib_offload_disabled;
	atomic_t fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	struct sock___3 *fibnl;
	struct sock___3 **icmp_sk;
	struct sock___3 *mc_autojoin_sk;
	struct inet_peer_base *peers;
	struct sock___3 **tcp_sk;
	struct fqdir___5 *fqdir;
	u8 sysctl_icmp_echo_ignore_all;
	u8 sysctl_icmp_echo_enable_probe;
	u8 sysctl_icmp_echo_ignore_broadcasts;
	u8 sysctl_icmp_ignore_bogus_error_responses;
	u8 sysctl_icmp_errors_use_inbound_ifaddr;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	struct local_ports ip_local_ports;
	u8 sysctl_tcp_ecn;
	u8 sysctl_tcp_ecn_fallback;
	u8 sysctl_ip_default_ttl;
	u8 sysctl_ip_no_pmtu_disc;
	u8 sysctl_ip_fwd_use_pmtu;
	u8 sysctl_ip_fwd_update_priority;
	u8 sysctl_ip_nonlocal_bind;
	u8 sysctl_ip_autobind_reuse;
	u8 sysctl_ip_dynaddr;
	u8 sysctl_ip_early_demux;
	u8 sysctl_raw_l3mdev_accept;
	u8 sysctl_tcp_early_demux;
	u8 sysctl_udp_early_demux;
	u8 sysctl_nexthop_compat_mode;
	u8 sysctl_fwmark_reflect;
	u8 sysctl_tcp_fwmark_accept;
	u8 sysctl_tcp_l3mdev_accept;
	u8 sysctl_tcp_mtu_probing;
	int sysctl_tcp_mtu_probe_floor;
	int sysctl_tcp_base_mss;
	int sysctl_tcp_min_snd_mss;
	int sysctl_tcp_probe_threshold;
	u32 sysctl_tcp_probe_interval;
	int sysctl_tcp_keepalive_time;
	int sysctl_tcp_keepalive_intvl;
	u8 sysctl_tcp_keepalive_probes;
	u8 sysctl_tcp_syn_retries;
	u8 sysctl_tcp_synack_retries;
	u8 sysctl_tcp_syncookies;
	u8 sysctl_tcp_migrate_req;
	int sysctl_tcp_reordering;
	u8 sysctl_tcp_retries1;
	u8 sysctl_tcp_retries2;
	u8 sysctl_tcp_orphan_retries;
	u8 sysctl_tcp_tw_reuse;
	int sysctl_tcp_fin_timeout;
	unsigned int sysctl_tcp_notsent_lowat;
	u8 sysctl_tcp_sack;
	u8 sysctl_tcp_window_scaling;
	u8 sysctl_tcp_timestamps;
	u8 sysctl_tcp_early_retrans;
	u8 sysctl_tcp_recovery;
	u8 sysctl_tcp_thin_linear_timeouts;
	u8 sysctl_tcp_slow_start_after_idle;
	u8 sysctl_tcp_retrans_collapse;
	u8 sysctl_tcp_stdurg;
	u8 sysctl_tcp_rfc1337;
	u8 sysctl_tcp_abort_on_overflow;
	u8 sysctl_tcp_fack;
	int sysctl_tcp_max_reordering;
	int sysctl_tcp_adv_win_scale;
	u8 sysctl_tcp_dsack;
	u8 sysctl_tcp_app_win;
	u8 sysctl_tcp_frto;
	u8 sysctl_tcp_nometrics_save;
	u8 sysctl_tcp_no_ssthresh_metrics_save;
	u8 sysctl_tcp_moderate_rcvbuf;
	u8 sysctl_tcp_tso_win_divisor;
	u8 sysctl_tcp_workaround_signed_windows;
	int sysctl_tcp_limit_output_bytes;
	int sysctl_tcp_challenge_ack_limit;
	int sysctl_tcp_min_rtt_wlen;
	u8 sysctl_tcp_min_tso_segs;
	u8 sysctl_tcp_autocorking;
	u8 sysctl_tcp_reflect_tos;
	u8 sysctl_tcp_comp_sack_nr;
	int sysctl_tcp_invalid_ratelimit;
	int sysctl_tcp_pacing_ss_ratio;
	int sysctl_tcp_pacing_ca_ratio;
	int sysctl_tcp_wmem[3];
	int sysctl_tcp_rmem[3];
	long unsigned int sysctl_tcp_comp_sack_delay_ns;
	long unsigned int sysctl_tcp_comp_sack_slack_ns;
	int sysctl_max_syn_backlog;
	int sysctl_tcp_fastopen;
	const struct tcp_congestion_ops *tcp_congestion_control;
	struct tcp_fastopen_context *tcp_fastopen_ctx;
	unsigned int sysctl_tcp_fastopen_blackhole_timeout;
	atomic_t tfo_active_disable_times;
	long unsigned int tfo_active_disable_stamp;
	int sysctl_udp_wmem_min;
	int sysctl_udp_rmem_min;
	u8 sysctl_fib_notify_on_flag_change;
	u8 sysctl_udp_l3mdev_accept;
	u8 sysctl_igmp_llm_reports;
	int sysctl_igmp_max_memberships;
	int sysctl_igmp_max_msf;
	int sysctl_igmp_qrv;
	struct ping_group_range ping_group_range;
	atomic_t dev_addr_genid;
	long unsigned int *sysctl_local_reserved_ports;
	int sysctl_ip_prot_sock;
	struct list_head mr_tables;
	struct fib_rules_ops___3 *mr_rules_ops;
	u32 sysctl_fib_multipath_hash_fields;
	u8 sysctl_fib_multipath_use_neigh;
	u8 sysctl_fib_multipath_hash_policy;
	struct fib_notifier_ops___3 *notifier_ops;
	unsigned int fib_seq;
	struct fib_notifier_ops___3 *ipmr_notifier_ops;
	unsigned int ipmr_seq;
	atomic_t rt_genid;
	siphash_key_t ip_id_key;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dst_entry___3;

struct net_device___4;

struct sk_buff___5;

struct neighbour___3;

struct dst_ops___5 {
	short unsigned int family;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___5 *);
	struct dst_entry___3 * (*check)(struct dst_entry___3 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___3 *);
	unsigned int (*mtu)(const struct dst_entry___3 *);
	u32 * (*cow_metrics)(struct dst_entry___3 *, long unsigned int);
	void (*destroy)(struct dst_entry___3 *);
	void (*ifdown)(struct dst_entry___3 *, struct net_device___4 *, int);
	struct dst_entry___3 * (*negative_advice)(struct dst_entry___3 *);
	void (*link_failure)(struct sk_buff___5 *);
	void (*update_pmtu)(struct dst_entry___3 *, struct sock___3 *, struct sk_buff___5 *, u32, bool);
	void (*redirect)(struct dst_entry___3 *, struct sock___3 *, struct sk_buff___5 *);
	int (*local_out)(struct net___5 *, struct sock___3 *, struct sk_buff___5 *);
	struct neighbour___3 * (*neigh_lookup)(const struct dst_entry___3 *, struct sk_buff___5 *, const void *);
	void (*confirm_neigh)(const struct dst_entry___3 *, const void *);
	struct kmem_cache *kmem_cachep;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv6___5 {
	struct dst_ops___5 ip6_dst_ops;
	struct netns_sysctl_ipv6 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	struct fqdir___5 *fqdir;
	struct fib6_info *fib6_null_entry;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	struct list_head fib6_walkers;
	rwlock_t fib6_walker_lock;
	spinlock_t fib6_gc_lock;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	unsigned char flowlabel_has_excl;
	bool fib6_has_custom_rules;
	unsigned int fib6_rules_require_fldissect;
	unsigned int fib6_routes_require_src;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops___3 *fib6_rules_ops;
	struct sock___3 **icmp_sk;
	struct sock___3 *ndisc_sk;
	struct sock___3 *tcp_sk;
	struct sock___3 *igmp_sk;
	struct sock___3 *mc_autojoin_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops___3 *mr6_rules_ops;
	atomic_t dev_addr_genid;
	atomic_t fib6_sernum;
	struct seg6_pernet_data *seg6_data;
	struct fib_notifier_ops___3 *notifier_ops;
	struct fib_notifier_ops___3 *ip6mr_notifier_ops;
	unsigned int ipmr_seq;
	struct {
		struct hlist_head head;
		spinlock_t lock;
		u32 seq;
	} ip6addrlbl_table;
	struct ioam6_pernet_data *ioam6_data;
};

struct netns_ieee802154_lowpan___5 {
	struct netns_sysctl_lowpan sysctl;
	struct fqdir___5 *fqdir;
};

struct netns_sctp___3 {
	struct sctp_mib *sctp_statistics;
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header *sysctl_header;
	struct sock___3 *ctl_sock;
	struct sock___3 *udp4_sock;
	struct sock___3 *udp6_sock;
	int udp_port;
	int encap_port;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	unsigned int probe_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int ps_retrans;
	int pf_enable;
	int pf_expose;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int reconf_enable;
	int auth_enable;
	int intl_enable;
	int ecn_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct sk_buff_head___4 {
	struct sk_buff___5 *next;
	struct sk_buff___5 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct netns_bpf___4 {
	struct bpf_prog_array___4 *run_array[2];
	struct bpf_prog___4 *progs[2];
	struct list_head links[2];
};

struct netns_xfrm___5 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	struct hlist_head *state_byseq;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[3];
	struct xfrm_policy_hash policy_bydst[3];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct xfrm_policy_hthresh policy_hthresh;
	struct list_head inexact_bins;
	struct sock___3 *nlsk;
	struct sock___3 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	u8 policy_default;
	struct ctl_table_header *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___5 xfrm4_dst_ops;
	struct dst_ops___5 xfrm6_dst_ops;
	spinlock_t xfrm_state_lock;
	seqcount_spinlock_t xfrm_state_hash_generation;
	seqcount_spinlock_t xfrm_policy_hash_generation;
	spinlock_t xfrm_policy_lock;
	struct mutex xfrm_cfg_mutex;
	long: 64;
	long: 64;
};

struct net___5 {
	refcount_t passive;
	spinlock_t rules_mod_lock;
	unsigned int dev_unreg_count;
	unsigned int dev_base_seq;
	int ifindex;
	spinlock_t nsid_lock;
	atomic_t fnhe_genid;
	struct list_head list;
	struct list_head exit_list;
	struct llist_node cleanup_list;
	struct key_tag *key_domain;
	struct user_namespace___4 *user_ns;
	struct ucounts___4 *ucounts;
	struct idr netns_ids;
	struct ns_common___4 ns;
	struct list_head dev_base_head;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set sysctls;
	struct sock___3 *rtnl;
	struct sock___3 *genl_sock;
	struct uevent_sock *uevent_sock;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	struct raw_notifier_head netdev_chain;
	u32 hash_mix;
	struct net_device___4 *loopback_dev;
	struct list_head rules_ops;
	struct netns_core core;
	struct netns_mib mib;
	struct netns_packet packet;
	struct netns_unix unx;
	struct netns_nexthop nexthop;
	struct netns_ipv4___5 ipv4;
	struct netns_ipv6___5 ipv6;
	struct netns_ieee802154_lowpan___5 ieee802154_lowpan;
	struct netns_sctp___3 sctp;
	struct netns_nf nf;
	struct netns_ct ct;
	struct netns_nftables nft;
	struct sk_buff_head___4 wext_nlevents;
	struct net_generic *gen;
	struct netns_bpf___4 bpf;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_xfrm___5 xfrm;
	u64 net_cookie;
	struct netns_ipvs *ipvs;
	struct netns_mpls mpls;
	struct netns_can can;
	struct netns_xdp xdp;
	struct netns_mctp mctp;
	struct sock___3 *crypto_nlsk;
	struct sock___3 *diag_nlsk;
	struct netns_smc smc;
	long: 64;
};

struct cgroup_namespace___24 {
	struct ns_common___4 ns;
	struct user_namespace___4 *user_ns;
	struct ucounts___4 *ucounts;
	struct css_set___24 *root_cset;
};

struct nsset___3 {
	unsigned int flags;
	struct nsproxy___29 *nsproxy;
	struct fs_struct *fs;
	const struct cred___3 *cred;
};

struct proc_ns_operations___4 {
	const char *name;
	const char *real_ns_name;
	int type;
	struct ns_common___4 * (*get)(struct task_struct___34 *);
	void (*put)(struct ns_common___4 *);
	int (*install)(struct nsset___3 *, struct ns_common___4 *);
	struct user_namespace___4 * (*owner)(struct ns_common___4 *);
	struct ns_common___4 * (*get_parent)(struct ns_common___4 *);
};

struct kernfs_root___30;

struct kernfs_elem_dir___30 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___30 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___30;

struct kernfs_root___30 {
	struct kernfs_node___30 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___30 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___30 {
	struct kernfs_node___30 *target_kn;
};

struct kernfs_ops___30;

struct kernfs_elem_attr___30 {
	const struct kernfs_ops___30 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___30 *notify_next;
};

struct kernfs_node___30 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___30 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___30 dir;
		struct kernfs_elem_symlink___30 symlink;
		struct kernfs_elem_attr___30 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___30;

struct kernfs_ops___30 {
	int (*open)(struct kernfs_open_file___30 *);
	void (*release)(struct kernfs_open_file___30 *);
	int (*seq_show)(struct seq_file___28 *, void *);
	void * (*seq_start)(struct seq_file___28 *, loff_t *);
	void * (*seq_next)(struct seq_file___28 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___28 *, void *);
	ssize_t (*read)(struct kernfs_open_file___30 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___30 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___30 *, struct poll_table_struct___22 *);
	int (*mmap)(struct kernfs_open_file___30 *, struct vm_area_struct___33 *);
};

struct kernfs_syscall_ops___30 {
	int (*show_options)(struct seq_file___28 *, struct kernfs_root___30 *);
	int (*mkdir)(struct kernfs_node___30 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___30 *);
	int (*rename)(struct kernfs_node___30 *, struct kernfs_node___30 *, const char *);
	int (*show_path)(struct seq_file___28 *, struct kernfs_node___30 *, struct kernfs_root___30 *);
};

struct kernfs_open_file___30 {
	struct kernfs_node___30 *kn;
	struct file___30 *file;
	struct seq_file___28 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped;
	bool released;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___30 *vm_ops;
};

struct kobj_ns_type_operations___3 {
	enum kobj_ns_type type;
	bool (*current_may_mount)();
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___3 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

typedef struct {
	struct net___5 *net;
} possible_net_t___4;

struct proto___3;

struct sock_common___3 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 1;
	unsigned char skc_ipv6only: 1;
	unsigned char skc_net_refcnt: 1;
	long: 31;
	long: 64;
	long: 64;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_node skc_portaddr_node;
	};
	struct proto___3 *skc_prot;
	possible_net_t___4 skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	atomic64_t skc_cookie;
	union {
		long unsigned int skc_flags;
		struct sock___3 *skc_listener;
		struct inet_timewait_death_row *skc_tw_dr;
	};
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	short unsigned int skc_tx_queue_mapping;
	short unsigned int skc_rx_queue_mapping;
	union {
		int skc_incoming_cpu;
		u32 skc_rcv_wnd;
		u32 skc_tw_rcv_nxt;
	};
	refcount_t skc_refcnt;
	int skc_dontcopy_end[0];
	union {
		u32 skc_rxhash;
		u32 skc_window_clamp;
		u32 skc_tw_snd_nxt;
	};
};

struct sock_cgroup_data___3 {
	struct cgroup___24 *cgroup;
	u32 classid;
	u16 prioidx;
};

struct sk_filter___3;

struct socket_wq___3;

struct socket___3;

struct sock___3 {
	struct sock_common___3 __sk_common;
	socket_lock_t sk_lock;
	atomic_t sk_drops;
	int sk_rcvlowat;
	struct sk_buff_head___4 sk_error_queue;
	struct sk_buff___5 *sk_rx_skb_cache;
	struct sk_buff_head___4 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___5 *head;
		struct sk_buff___5 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	unsigned int sk_ll_usec;
	unsigned int sk_napi_id;
	int sk_rcvbuf;
	struct sk_filter___3 *sk_filter;
	union {
		struct socket_wq___3 *sk_wq;
		struct socket_wq___3 *sk_wq_raw;
	};
	struct xfrm_policy *sk_policy[2];
	struct dst_entry___3 *sk_rx_dst;
	int sk_rx_dst_ifindex;
	u32 sk_rx_dst_cookie;
	struct dst_entry___3 *sk_dst_cache;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	int sk_wmem_queued;
	refcount_t sk_wmem_alloc;
	long unsigned int sk_tsq_flags;
	union {
		struct sk_buff___5 *sk_send_head;
		struct rb_root tcp_rtx_queue;
	};
	struct sk_buff___5 *sk_tx_skb_cache;
	struct sk_buff_head___4 sk_write_queue;
	__s32 sk_peek_off;
	int sk_write_pending;
	__u32 sk_dst_pending_confirm;
	u32 sk_pacing_status;
	long int sk_sndtimeo;
	struct timer_list sk_timer;
	__u32 sk_priority;
	__u32 sk_mark;
	long unsigned int sk_pacing_rate;
	long unsigned int sk_max_pacing_rate;
	struct page_frag___32 sk_frag;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	netdev_features_t sk_route_forced_caps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	gfp_t sk_allocation;
	__u32 sk_txhash;
	u8 sk_padding: 1;
	u8 sk_kern_sock: 1;
	u8 sk_no_check_tx: 1;
	u8 sk_no_check_rx: 1;
	u8 sk_userlocks: 4;
	long: 4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u8 sk_pacing_shift;
	u16 sk_type;
	u16 sk_protocol;
	u16 sk_gso_max_segs;
	long unsigned int sk_lingertime;
	struct proto___3 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	u32 sk_ack_backlog;
	u32 sk_max_ack_backlog;
	kuid_t sk_uid;
	u8 sk_prefer_busy_poll;
	u16 sk_busy_poll_budget;
	spinlock_t sk_peer_lock;
	struct pid___26 *sk_peer_pid;
	const struct cred___3 *sk_peer_cred;
	long int sk_rcvtimeo;
	ktime_t sk_stamp;
	u16 sk_tsflags;
	int sk_bind_phc;
	u8 sk_shutdown;
	atomic_t sk_tskey;
	atomic_t sk_zckey;
	u8 sk_clockid;
	u8 sk_txtime_deadline_mode: 1;
	u8 sk_txtime_report_errors: 1;
	u8 sk_txtime_unused: 6;
	long: 58;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct socket___3 *sk_socket;
	void *sk_user_data;
	void *sk_security;
	struct sock_cgroup_data___3 sk_cgrp_data;
	struct mem_cgroup___19 *sk_memcg;
	void (*sk_state_change)(struct sock___3 *);
	void (*sk_data_ready)(struct sock___3 *);
	void (*sk_write_space)(struct sock___3 *);
	void (*sk_error_report)(struct sock___3 *);
	int (*sk_backlog_rcv)(struct sock___3 *, struct sk_buff___5 *);
	struct sk_buff___5 * (*sk_validate_xmit_skb)(struct sock___3 *, struct net_device___4 *, struct sk_buff___5 *);
	void (*sk_destruct)(struct sock___3 *);
	struct sock_reuseport *sk_reuseport_cb;
	struct bpf_local_storage *sk_bpf_storage;
	struct callback_head sk_rcu;
};

struct bin_attribute___30;

struct attribute_group___30 {
	const char *name;
	umode_t (*is_visible)(struct kobject___30 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___30 *, struct bin_attribute___30 *, int);
	struct attribute **attrs;
	struct bin_attribute___30 **bin_attrs;
};

struct bin_attribute___30 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___30 * (*f_mapping)();
	ssize_t (*read)(struct file___30 *, struct kobject___30 *, struct bin_attribute___30 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___30 *, struct kobject___30 *, struct bin_attribute___30 *, char *, loff_t, size_t);
	int (*mmap)(struct file___30 *, struct kobject___30 *, struct bin_attribute___30 *, struct vm_area_struct___33 *);
};

struct sysfs_ops___29 {
	ssize_t (*show)(struct kobject___30 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___30 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___29;

struct kset___29 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___30 kobj;
	const struct kset_uevent_ops___29 *uevent_ops;
};

struct kobj_type___29 {
	void (*release)(struct kobject___30 *);
	const struct sysfs_ops___29 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___30 **default_groups;
	const struct kobj_ns_type_operations___3 * (*child_ns_type)(struct kobject___30 *);
	const void * (*namespace)(struct kobject___30 *);
	void (*get_ownership)(struct kobject___30 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___29 {
	int (* const filter)(struct kset___29 *, struct kobject___30 *);
	const char * (* const name)(struct kset___29 *, struct kobject___30 *);
	int (* const uevent)(struct kset___29 *, struct kobject___30 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___29 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___29 *);
	int (*get)(char *, const struct kernel_param___29 *);
	void (*free)(void *);
};

struct kparam_array___29;

struct kernel_param___29 {
	const char *name;
	struct module___29 *mod;
	const struct kernel_param_ops___29 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___29 *arr;
	};
};

struct kparam_array___29 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___29 *ops;
	void *elem;
};

struct module_attribute___29 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___29 *, struct module_kobject___29 *, char *);
	ssize_t (*store)(struct module_attribute___29 *, struct module_kobject___29 *, const char *, size_t);
	void (*setup)(struct module___29 *, const char *);
	int (*test)(struct module___29 *);
	void (*free)(struct module___29 *);
};

struct trace_event_class___19;

struct trace_event_call___19 {
	struct list_head list;
	struct trace_event_class___19 *class;
	union {
		char *name;
		struct tracepoint___22 *tp;
	};
	struct trace_event event;
	char *print_fmt;
	struct event_filter *filter;
	union {
		void *module;
		atomic_t refcnt;
	};
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
	struct bpf_prog_array___4 *prog_array;
	int (*perf_perm)(struct trace_event_call___19 *, struct perf_event___19 *);
};

struct msghdr___3 {
	void *msg_name;
	int msg_namelen;
	struct iov_iter___24 msg_iter;
	union {
		void *msg_control;
		void *msg_control_user;
	};
	bool msg_control_is_user;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__kernel_size_t msg_controllen;
	unsigned int msg_flags;
	struct kiocb___30 *msg_iocb;
};

struct sk_buff___5 {
	union {
		struct {
			struct sk_buff___5 *next;
			struct sk_buff___5 *prev;
			union {
				struct net_device___4 *dev;
				long unsigned int dev_scratch;
			};
		};
		struct rb_node rbnode;
		struct list_head list;
	};
	union {
		struct sock___3 *sk;
		int ip_defrag_offset;
	};
	union {
		ktime_t tstamp;
		u64 skb_mstamp_ns;
	};
	char cb[48];
	union {
		struct {
			long unsigned int _skb_refdst;
			void (*destructor)(struct sk_buff___5 *);
		};
		struct list_head tcp_tsorted_anchor;
		long unsigned int _sk_redir;
	};
	long unsigned int _nfct;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	__u16 queue_mapping;
	__u8 __cloned_offset[0];
	__u8 cloned: 1;
	__u8 nohdr: 1;
	__u8 fclone: 2;
	__u8 peeked: 1;
	__u8 head_frag: 1;
	__u8 pfmemalloc: 1;
	__u8 pp_recycle: 1;
	long: 55;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 active_extensions;
	__u32 headers_start[0];
	__u8 __pkt_type_offset[0];
	__u8 pkt_type: 3;
	__u8 ignore_df: 1;
	__u8 nf_trace: 1;
	__u8 ip_summed: 2;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 sw_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	long: 15;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 __pkt_vlan_present_offset[0];
	__u8 vlan_present: 1;
	__u8 csum_complete_sw: 1;
	__u8 csum_level: 2;
	__u8 csum_not_inet: 1;
	__u8 dst_pending_confirm: 1;
	__u8 ndisc_nodetype: 2;
	__u8 ipvs_property: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	__u8 offload_fwd_mark: 1;
	__u8 offload_l3_fwd_mark: 1;
	__u8 tc_skip_classify: 1;
	__u8 tc_at_ingress: 1;
	__u8 redirected: 1;
	__u8 from_ingress: 1;
	__u8 decrypted: 1;
	__u8 slow_gro: 1;
	long: 47;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u16 tc_index;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	int skb_iif;
	__u32 hash;
	__be16 vlan_proto;
	__u16 vlan_tci;
	union {
		unsigned int napi_id;
		unsigned int sender_cpu;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__be16 protocol;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	__u32 headers_end[0];
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	refcount_t users;
	struct skb_ext *extensions;
};

struct inet_frags___5;

struct fqdir___5 {
	long int high_thresh;
	long int low_thresh;
	int timeout;
	int max_dist;
	struct inet_frags___5 *f;
	struct net___5 *net;
	bool dead;
	long: 56;
	long: 64;
	long: 64;
	struct rhashtable rhashtable;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	atomic_long_t mem;
	struct work_struct destroy_work;
	struct llist_node free_list;
	long: 64;
	long: 64;
};

struct inet_frag_queue___5;

struct inet_frags___5 {
	unsigned int qsize;
	void (*constructor)(struct inet_frag_queue___5 *, const void *);
	void (*destructor)(struct inet_frag_queue___5 *);
	void (*frag_expire)(struct timer_list *);
	struct kmem_cache *frags_cachep;
	const char *frags_cache_name;
	struct rhashtable_params rhash_params;
	refcount_t refcnt;
	struct completion completion;
};

struct inet_frag_queue___5 {
	struct rhash_head node;
	union {
		struct frag_v4_compare_key v4;
		struct frag_v6_compare_key v6;
	} key;
	struct timer_list timer;
	spinlock_t lock;
	refcount_t refcnt;
	struct rb_root rb_fragments;
	struct sk_buff___5 *fragments_tail;
	struct sk_buff___5 *last_run_head;
	ktime_t stamp;
	int len;
	int meat;
	__u8 flags;
	u16 max_size;
	struct fqdir___5 *fqdir;
	struct callback_head rcu;
};

struct fib_rule___3;

struct fib_lookup_arg___3;

struct fib_rules_ops___3 {
	int family;
	struct list_head list;
	int rule_size;
	int addr_size;
	int unresolved_rules;
	int nr_goto_rules;
	unsigned int fib_rules_seq;
	int (*action)(struct fib_rule___3 *, struct flowi *, int, struct fib_lookup_arg___3 *);
	bool (*suppress)(struct fib_rule___3 *, int, struct fib_lookup_arg___3 *);
	int (*match)(struct fib_rule___3 *, struct flowi *, int);
	int (*configure)(struct fib_rule___3 *, struct sk_buff___5 *, struct fib_rule_hdr *, struct nlattr **, struct netlink_ext_ack *);
	int (*delete)(struct fib_rule___3 *);
	int (*compare)(struct fib_rule___3 *, struct fib_rule_hdr *, struct nlattr **);
	int (*fill)(struct fib_rule___3 *, struct sk_buff___5 *, struct fib_rule_hdr *);
	size_t (*nlmsg_payload)(struct fib_rule___3 *);
	void (*flush_cache)(struct fib_rules_ops___3 *);
	int nlgroup;
	const struct nla_policy *policy;
	struct list_head rules_list;
	struct module___29 *owner;
	struct net___5 *fro_net;
	struct callback_head rcu;
};

struct fib_notifier_ops___3 {
	int family;
	struct list_head list;
	unsigned int (*fib_seq_read)(struct net___5 *);
	int (*fib_dump)(struct net___5 *, struct notifier_block *, struct netlink_ext_ack *);
	struct module___29 *owner;
	struct callback_head rcu;
};

struct dst_entry___3 {
	struct net_device___4 *dev;
	struct dst_ops___5 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct xfrm_state *xfrm;
	int (*input)(struct sk_buff___5 *);
	int (*output)(struct net___5 *, struct sock___3 *, struct sk_buff___5 *);
	short unsigned int flags;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	struct lwtunnel_state *lwtstate;
	struct callback_head callback_head;
	short int error;
	short int __pad;
	__u32 tclassid;
};

typedef rx_handler_result_t rx_handler_func_t___4(struct sk_buff___5 **);

struct bpf_xdp_entity___4 {
	struct bpf_prog___4 *prog;
	struct bpf_xdp_link *link;
};

struct netdev_name_node___4;

struct net_device_ops___4;

struct l3mdev_ops___4;

struct xfrmdev_ops___4;

struct header_ops___4;

struct netdev_rx_queue___4;

struct mini_Qdisc___4;

struct netdev_queue___4;

struct Qdisc___4;

struct rtnl_link_ops___4;

struct dcbnl_rtnl_ops___4;

struct net_device___4 {
	char name[16];
	struct netdev_name_node___4 *name_node;
	struct dev_ifalias *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head close_list;
	struct list_head ptype_all;
	struct list_head ptype_specific;
	struct {
		struct list_head upper;
		struct list_head lower;
	} adj_list;
	unsigned int flags;
	unsigned int priv_flags;
	const struct net_device_ops___4 *netdev_ops;
	int ifindex;
	short unsigned int gflags;
	short unsigned int hard_header_len;
	unsigned int mtu;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	netdev_features_t gso_partial_features;
	unsigned int min_mtu;
	unsigned int max_mtu;
	short unsigned int type;
	unsigned char min_header_len;
	unsigned char name_assign_type;
	int group;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	atomic_long_t tx_dropped;
	atomic_long_t rx_nohandler;
	atomic_t carrier_up_count;
	atomic_t carrier_down_count;
	const struct iw_handler_def *wireless_handlers;
	struct iw_public_data *wireless_data;
	const struct ethtool_ops *ethtool_ops;
	const struct l3mdev_ops___4 *l3mdev_ops;
	const struct ndisc_ops___2 *ndisc_ops;
	const struct xfrmdev_ops___4 *xfrmdev_ops;
	const struct tlsdev_ops *tlsdev_ops;
	const struct header_ops___4 *header_ops;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	unsigned char upper_level;
	unsigned char lower_level;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	short unsigned int padded;
	spinlock_t addr_list_lock;
	int irq;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___29 *queues_kset;
	unsigned int promiscuity;
	unsigned int allmulti;
	bool uc_promisc;
	struct vlan_info *vlan_info;
	struct dsa_port *dsa_ptr;
	struct tipc_bearer *tipc_ptr;
	void *atalk_ptr;
	struct in_device *ip_ptr;
	struct dn_dev *dn_ptr;
	struct inet6_dev___2 *ip6_ptr;
	void *ax25_ptr;
	struct wireless_dev *ieee80211_ptr;
	struct wpan_dev *ieee802154_ptr;
	struct mpls_dev *mpls_ptr;
	struct mctp_dev *mctp_ptr;
	unsigned char *dev_addr;
	struct netdev_rx_queue___4 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	struct bpf_prog___4 *xdp_prog;
	long unsigned int gro_flush_timeout;
	int napi_defer_hard_irqs;
	rx_handler_func_t___4 *rx_handler;
	void *rx_handler_data;
	struct mini_Qdisc___4 *miniq_ingress;
	struct netdev_queue___4 *ingress_queue;
	struct nf_hook_entries *nf_hooks_ingress;
	unsigned char broadcast[32];
	struct cpu_rmap *rx_cpu_rmap;
	struct hlist_node index_hlist;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___4 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc___4 *qdisc;
	unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	struct xdp_dev_bulk_queue *xdp_bulkq;
	struct xps_dev_maps *xps_maps[2];
	struct mini_Qdisc___4 *miniq_egress;
	struct hlist_head qdisc_hash[16];
	struct timer_list watchdog_timer;
	int watchdog_timeo;
	u32 proto_down_reason;
	struct list_head todo_list;
	int *pcpu_refcnt;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___4 = 0,
		NETREG_REGISTERED___4 = 1,
		NETREG_UNREGISTERING___4 = 2,
		NETREG_UNREGISTERED___4 = 3,
		NETREG_RELEASED___4 = 4,
		NETREG_DUMMY___4 = 5,
	} reg_state: 8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___4 = 0,
		RTNL_LINK_INITIALIZING___4 = 1,
	} rtnl_link_state: 16;
	long: 16;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	bool needs_free_netdev;
	void (*priv_destructor)(struct net_device___4 *);
	struct netpoll_info *npinfo;
	possible_net_t___4 nd_net;
	void *ml_priv;
	enum netdev_ml_priv_type ml_priv_type;
	union {
		struct pcpu_lstats *lstats;
		struct pcpu_sw_netstats *tstats;
		struct pcpu_dstats *dstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___32 dev;
	const struct attribute_group___30 *sysfs_groups[4];
	const struct attribute_group___30 *sysfs_rx_queue_group;
	const struct rtnl_link_ops___4 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___4 *dcbnl_ops;
	s16 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	unsigned int fcoe_ddp_xid;
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct sfp_bus *sfp_bus;
	struct lock_class_key *qdisc_tx_busylock;
	struct lock_class_key *qdisc_running_key;
	bool proto_down;
	unsigned int wol_enabled: 1;
	unsigned int threaded: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct list_head net_notifier_list;
	const struct macsec_ops *macsec_ops;
	const struct udp_tunnel_nic_info *udp_tunnel_nic_info;
	struct udp_tunnel_nic *udp_tunnel_nic;
	struct bpf_xdp_entity___4 xdp_state[3];
	long: 64;
	long: 64;
	long: 64;
};

struct neigh_table___3;

struct neigh_parms___4;

struct neigh_ops___3;

struct neighbour___3 {
	struct neighbour___3 *next;
	struct neigh_table___3 *tbl;
	struct neigh_parms___4 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	refcount_t refcnt;
	unsigned int arp_queue_len_bytes;
	struct sk_buff_head___4 arp_queue;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	u8 protocol;
	seqlock_t ha_lock;
	int: 32;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___3 *, struct sk_buff___5 *);
	const struct neigh_ops___3 *ops;
	struct list_head gc_list;
	struct callback_head rcu;
	struct net_device___4 *dev;
	u8 primary_key[0];
};

struct bpf_prog_array_item___4 {
	struct bpf_prog___4 *prog;
	union {
		struct bpf_cgroup_storage *cgroup_storage[2];
		u64 bpf_cookie;
	};
};

struct bpf_prog_array___4 {
	struct callback_head rcu;
	struct bpf_prog_array_item___4 items[0];
};

struct bpf_prog_aux___4;

struct bpf_prog___4 {
	u16 pages;
	u16 jited: 1;
	u16 jit_requested: 1;
	u16 gpl_compatible: 1;
	u16 cb_access: 1;
	u16 dst_needed: 1;
	u16 blinded: 1;
	u16 is_func: 1;
	u16 kprobe_override: 1;
	u16 has_callchain_buf: 1;
	u16 enforce_expected_attach_type: 1;
	u16 call_get_stack: 1;
	u16 call_get_func_ip: 1;
	enum bpf_prog_type type;
	enum bpf_attach_type expected_attach_type;
	u32 len;
	u32 jited_len;
	u8 tag[8];
	struct bpf_prog_stats *stats;
	int *active;
	unsigned int (*bpf_func)(const void *, const struct bpf_insn *);
	struct bpf_prog_aux___4 *aux;
	struct sock_fprog_kern *orig_prog;
	struct sock_filter insns[0];
	struct bpf_insn insnsi[0];
};

struct socket_wq___3 {
	wait_queue_head_t wait;
	struct fasync_struct___30 *fasync_list;
	long unsigned int flags;
	struct callback_head rcu;
	long: 64;
};

struct proto_ops___3;

struct socket___3 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct file___30 *file;
	struct sock___3 *sk;
	const struct proto_ops___3 *ops;
	long: 64;
	long: 64;
	long: 64;
	struct socket_wq___3 wq;
};

typedef int (*sk_read_actor_t___3)(read_descriptor_t *, struct sk_buff___5 *, unsigned int, size_t);

struct proto_ops___3 {
	int family;
	struct module___29 *owner;
	int (*release)(struct socket___3 *);
	int (*bind)(struct socket___3 *, struct sockaddr *, int);
	int (*connect)(struct socket___3 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___3 *, struct socket___3 *);
	int (*accept)(struct socket___3 *, struct socket___3 *, int, bool);
	int (*getname)(struct socket___3 *, struct sockaddr *, int);
	__poll_t (*poll)(struct file___30 *, struct socket___3 *, struct poll_table_struct___22 *);
	int (*ioctl)(struct socket___3 *, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct socket___3 *, unsigned int, long unsigned int);
	int (*gettstamp)(struct socket___3 *, void *, bool, bool);
	int (*listen)(struct socket___3 *, int);
	int (*shutdown)(struct socket___3 *, int);
	int (*setsockopt)(struct socket___3 *, int, int, sockptr_t, unsigned int);
	int (*getsockopt)(struct socket___3 *, int, int, char *, int *);
	void (*show_fdinfo)(struct seq_file___28 *, struct socket___3 *);
	int (*sendmsg)(struct socket___3 *, struct msghdr___3 *, size_t);
	int (*recvmsg)(struct socket___3 *, struct msghdr___3 *, size_t, int);
	int (*mmap)(struct file___30 *, struct socket___3 *, struct vm_area_struct___33 *);
	ssize_t (*sendpage)(struct socket___3 *, struct page___32 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___3 *, loff_t *, struct pipe_inode_info___9 *, size_t, unsigned int);
	int (*set_peek_off)(struct sock___3 *, int);
	int (*peek_len)(struct socket___3 *);
	int (*read_sock)(struct sock___3 *, read_descriptor_t *, sk_read_actor_t___3);
	int (*sendpage_locked)(struct sock___3 *, struct page___32 *, int, size_t, int);
	int (*sendmsg_locked)(struct sock___3 *, struct msghdr___3 *, size_t);
	int (*set_rcvlowat)(struct sock___3 *, int);
};

struct dev_pm_ops___32 {
	int (*prepare)(struct device___32 *);
	void (*complete)(struct device___32 *);
	int (*suspend)(struct device___32 *);
	int (*resume)(struct device___32 *);
	int (*freeze)(struct device___32 *);
	int (*thaw)(struct device___32 *);
	int (*poweroff)(struct device___32 *);
	int (*restore)(struct device___32 *);
	int (*suspend_late)(struct device___32 *);
	int (*resume_early)(struct device___32 *);
	int (*freeze_late)(struct device___32 *);
	int (*thaw_early)(struct device___32 *);
	int (*poweroff_late)(struct device___32 *);
	int (*restore_early)(struct device___32 *);
	int (*suspend_noirq)(struct device___32 *);
	int (*resume_noirq)(struct device___32 *);
	int (*freeze_noirq)(struct device___32 *);
	int (*thaw_noirq)(struct device___32 *);
	int (*poweroff_noirq)(struct device___32 *);
	int (*restore_noirq)(struct device___32 *);
	int (*runtime_suspend)(struct device___32 *);
	int (*runtime_resume)(struct device___32 *);
	int (*runtime_idle)(struct device___32 *);
};

struct wakeup_source___32 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___32 *dev;
	bool active;
	bool autosleep_enabled;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___32 {
	struct dev_pm_ops___32 ops;
	int (*start)(struct device___32 *);
	void (*detach)(struct device___32 *, bool);
	int (*activate)(struct device___32 *);
	void (*sync)(struct device___32 *);
	void (*dismiss)(struct device___32 *);
};

struct bus_type___32 {
	const char *name;
	const char *dev_name;
	struct device___32 *dev_root;
	const struct attribute_group___30 **bus_groups;
	const struct attribute_group___30 **dev_groups;
	const struct attribute_group___30 **drv_groups;
	int (*match)(struct device___32 *, struct device_driver___32 *);
	int (*uevent)(struct device___32 *, struct kobj_uevent_env *);
	int (*probe)(struct device___32 *);
	void (*sync_state)(struct device___32 *);
	void (*remove)(struct device___32 *);
	void (*shutdown)(struct device___32 *);
	int (*online)(struct device___32 *);
	int (*offline)(struct device___32 *);
	int (*suspend)(struct device___32 *, pm_message_t);
	int (*resume)(struct device___32 *);
	int (*num_vf)(struct device___32 *);
	int (*dma_configure)(struct device___32 *);
	const struct dev_pm_ops___32 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___32 {
	const char *name;
	struct bus_type___32 *bus;
	struct module___29 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___32 *);
	void (*sync_state)(struct device___32 *);
	int (*remove)(struct device___32 *);
	void (*shutdown)(struct device___32 *);
	int (*suspend)(struct device___32 *, pm_message_t);
	int (*resume)(struct device___32 *);
	const struct attribute_group___30 **groups;
	const struct attribute_group___30 **dev_groups;
	const struct dev_pm_ops___32 *pm;
	void (*coredump)(struct device___32 *);
	struct driver_private *p;
};

struct device_type___32 {
	const char *name;
	const struct attribute_group___30 **groups;
	int (*uevent)(struct device___32 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___32 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___32 *);
	const struct dev_pm_ops___32 *pm;
};

struct class___32 {
	const char *name;
	struct module___29 *owner;
	const struct attribute_group___30 **class_groups;
	const struct attribute_group___30 **dev_groups;
	struct kobject___30 *dev_kobj;
	int (*dev_uevent)(struct device___32 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___32 *, umode_t *);
	void (*class_release)(struct class___32 *);
	void (*dev_release)(struct device___32 *);
	int (*shutdown_pre)(struct device___32 *);
	const struct kobj_ns_type_operations___3 *ns_type;
	const void * (*namespace)(struct device___32 *);
	void (*get_ownership)(struct device___32 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___32 *pm;
	struct subsys_private *p;
};

struct pipe_buf_operations___9;

struct pipe_buffer___9 {
	struct page___32 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___9 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___9 {
	int (*confirm)(struct pipe_inode_info___9 *, struct pipe_buffer___9 *);
	void (*release)(struct pipe_inode_info___9 *, struct pipe_buffer___9 *);
	bool (*try_steal)(struct pipe_inode_info___9 *, struct pipe_buffer___9 *);
	bool (*get)(struct pipe_inode_info___9 *, struct pipe_buffer___9 *);
};

struct perf_cpu_context___19;

struct perf_output_handle___19;

struct pmu___19 {
	struct list_head entry;
	struct module___29 *module;
	struct device___32 *dev;
	const struct attribute_group___30 **attr_groups;
	const struct attribute_group___30 **attr_update;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___19 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___19 *);
	void (*pmu_disable)(struct pmu___19 *);
	int (*event_init)(struct perf_event___19 *);
	void (*event_mapped)(struct perf_event___19 *, struct mm_struct___33 *);
	void (*event_unmapped)(struct perf_event___19 *, struct mm_struct___33 *);
	int (*add)(struct perf_event___19 *, int);
	void (*del)(struct perf_event___19 *, int);
	void (*start)(struct perf_event___19 *, int);
	void (*stop)(struct perf_event___19 *, int);
	void (*read)(struct perf_event___19 *);
	void (*start_txn)(struct pmu___19 *, unsigned int);
	int (*commit_txn)(struct pmu___19 *);
	void (*cancel_txn)(struct pmu___19 *);
	int (*event_idx)(struct perf_event___19 *);
	void (*sched_task)(struct perf_event_context___19 *, bool);
	struct kmem_cache *task_ctx_cache;
	void (*swap_task_ctx)(struct perf_event_context___19 *, struct perf_event_context___19 *);
	void * (*setup_aux)(struct perf_event___19 *, void **, int, bool);
	void (*free_aux)(void *);
	long int (*snapshot_aux)(struct perf_event___19 *, struct perf_output_handle___19 *, long unsigned int);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___19 *);
	int (*aux_output_match)(struct perf_event___19 *);
	int (*filter_match)(struct perf_event___19 *);
	int (*check_period)(struct perf_event___19 *, u64);
};

struct fd___3 {
	struct file___30 *file;
	unsigned int flags;
};

struct bpf_iter_aux_info___4;

typedef int (*bpf_iter_init_seq_priv_t___4)(void *, struct bpf_iter_aux_info___4 *);

struct bpf_map___4;

struct bpf_iter_aux_info___4 {
	struct bpf_map___4 *map;
};

struct bpf_iter_seq_info___4 {
	const struct seq_operations___28 *seq_ops;
	bpf_iter_init_seq_priv_t___4 init_seq_private;
	bpf_iter_fini_seq_priv_t fini_seq_private;
	u32 seq_priv_size;
};

struct bpf_map_ops___4 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___4 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___4 *, struct file___30 *);
	void (*map_free)(struct bpf_map___4 *);
	int (*map_get_next_key)(struct bpf_map___4 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___4 *);
	void * (*map_lookup_elem_sys_only)(struct bpf_map___4 *, void *);
	int (*map_lookup_batch)(struct bpf_map___4 *, const union bpf_attr *, union bpf_attr *);
	int (*map_lookup_and_delete_elem)(struct bpf_map___4 *, void *, void *, u64);
	int (*map_lookup_and_delete_batch)(struct bpf_map___4 *, const union bpf_attr *, union bpf_attr *);
	int (*map_update_batch)(struct bpf_map___4 *, const union bpf_attr *, union bpf_attr *);
	int (*map_delete_batch)(struct bpf_map___4 *, const union bpf_attr *, union bpf_attr *);
	void * (*map_lookup_elem)(struct bpf_map___4 *, void *);
	int (*map_update_elem)(struct bpf_map___4 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___4 *, void *);
	int (*map_push_elem)(struct bpf_map___4 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___4 *, void *);
	int (*map_peek_elem)(struct bpf_map___4 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___4 *, struct file___30 *, int);
	void (*map_fd_put_ptr)(void *);
	int (*map_gen_lookup)(struct bpf_map___4 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___4 *, void *, struct seq_file___28 *);
	int (*map_check_btf)(const struct bpf_map___4 *, const struct btf *, const struct btf_type *, const struct btf_type *);
	int (*map_poke_track)(struct bpf_map___4 *, struct bpf_prog_aux___4 *);
	void (*map_poke_untrack)(struct bpf_map___4 *, struct bpf_prog_aux___4 *);
	void (*map_poke_run)(struct bpf_map___4 *, u32, struct bpf_prog___4 *, struct bpf_prog___4 *);
	int (*map_direct_value_addr)(const struct bpf_map___4 *, u64 *, u32);
	int (*map_direct_value_meta)(const struct bpf_map___4 *, u64, u32 *);
	int (*map_mmap)(struct bpf_map___4 *, struct vm_area_struct___33 *);
	__poll_t (*map_poll)(struct bpf_map___4 *, struct file___30 *, struct poll_table_struct___22 *);
	int (*map_local_storage_charge)(struct bpf_local_storage_map *, void *, u32);
	void (*map_local_storage_uncharge)(struct bpf_local_storage_map *, void *, u32);
	struct bpf_local_storage ** (*map_owner_storage_ptr)(void *);
	int (*map_redirect)(struct bpf_map___4 *, u32, u64);
	bool (*map_meta_equal)(const struct bpf_map___4 *, const struct bpf_map___4 *);
	int (*map_set_for_each_callback_args)(struct bpf_verifier_env *, struct bpf_func_state *, struct bpf_func_state *);
	int (*map_for_each_callback)(struct bpf_map___4 *, void *, void *, u64);
	const char * const map_btf_name;
	int *map_btf_id;
	const struct bpf_iter_seq_info___4 *iter_seq_info;
};

struct bpf_map___4 {
	const struct bpf_map_ops___4 *ops;
	struct bpf_map___4 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	int spin_lock_off;
	int timer_off;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	struct mem_cgroup___19 *memcg;
	char name[16];
	u32 btf_vmlinux_value_type_id;
	bool bypass_spec_v1;
	bool frozen;
	long: 16;
	long: 64;
	long: 64;
	atomic64_t refcnt;
	atomic64_t usercnt;
	struct work_struct work;
	struct mutex freeze_mutex;
	atomic64_t writecnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_trampoline___4;

struct bpf_jit_poke_descriptor___4;

struct bpf_prog_ops___4;

struct btf_mod_pair___4;

struct bpf_prog_offload___4;

struct bpf_prog_aux___4 {
	atomic64_t refcnt;
	u32 used_map_cnt;
	u32 used_btf_cnt;
	u32 max_ctx_offset;
	u32 max_pkt_offset;
	u32 max_tp_access;
	u32 stack_depth;
	u32 id;
	u32 func_cnt;
	u32 func_idx;
	u32 attach_btf_id;
	u32 ctx_arg_info_size;
	u32 max_rdonly_access;
	u32 max_rdwr_access;
	struct btf *attach_btf;
	const struct bpf_ctx_arg_aux *ctx_arg_info;
	struct mutex dst_mutex;
	struct bpf_prog___4 *dst_prog;
	struct bpf_trampoline___4 *dst_trampoline;
	enum bpf_prog_type saved_dst_prog_type;
	enum bpf_attach_type saved_dst_attach_type;
	bool verifier_zext;
	bool offload_requested;
	bool attach_btf_trace;
	bool func_proto_unreliable;
	bool sleepable;
	bool tail_call_reachable;
	struct hlist_node tramp_hlist;
	const struct btf_type *attach_func_proto;
	const char *attach_func_name;
	struct bpf_prog___4 **func;
	void *jit_data;
	struct bpf_jit_poke_descriptor___4 *poke_tab;
	struct bpf_kfunc_desc_tab *kfunc_tab;
	u32 size_poke_tab;
	struct bpf_ksym ksym;
	const struct bpf_prog_ops___4 *ops;
	struct bpf_map___4 **used_maps;
	struct mutex used_maps_mutex;
	struct btf_mod_pair___4 *used_btfs;
	struct bpf_prog___4 *prog;
	struct user_struct *user;
	u64 load_time;
	struct bpf_map___4 *cgroup_storage[2];
	char name[16];
	void *security;
	struct bpf_prog_offload___4 *offload;
	struct btf *btf;
	struct bpf_func_info *func_info;
	struct bpf_func_info_aux *func_info_aux;
	struct bpf_line_info *linfo;
	void **jited_linfo;
	u32 func_info_cnt;
	u32 nr_linfo;
	u32 linfo_idx;
	u32 num_exentries;
	struct exception_table_entry *extable;
	union {
		struct work_struct work;
		struct callback_head rcu;
	};
};

struct bpf_offloaded_map___4;

struct bpf_map_dev_ops___4 {
	int (*map_get_next_key)(struct bpf_offloaded_map___4 *, void *, void *);
	int (*map_lookup_elem)(struct bpf_offloaded_map___4 *, void *, void *);
	int (*map_update_elem)(struct bpf_offloaded_map___4 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_offloaded_map___4 *, void *);
};

struct bpf_offloaded_map___4 {
	struct bpf_map___4 map;
	struct net_device___4 *netdev;
	const struct bpf_map_dev_ops___4 *dev_ops;
	void *dev_priv;
	struct list_head offloads;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_prog_ops___4 {
	int (*test_run)(struct bpf_prog___4 *, const union bpf_attr *, union bpf_attr *);
};

struct bpf_prog_offload___4 {
	struct bpf_prog___4 *prog;
	struct net_device___4 *netdev;
	struct bpf_offload_dev *offdev;
	void *dev_priv;
	struct list_head offloads;
	bool dev_state;
	bool opt_failed;
	void *jited_image;
	u32 jited_len;
};

struct bpf_trampoline___4 {
	struct hlist_node hlist;
	struct mutex mutex;
	refcount_t refcnt;
	u64 key;
	struct {
		struct btf_func_model model;
		void *addr;
		bool ftrace_managed;
	} func;
	struct bpf_prog___4 *extension_prog;
	struct hlist_head progs_hlist[3];
	int progs_cnt[3];
	struct bpf_tramp_image *cur_image;
	u64 selector;
	struct module___29 *mod;
};

struct bpf_jit_poke_descriptor___4 {
	void *tailcall_target;
	void *tailcall_bypass;
	void *bypass_addr;
	void *aux;
	union {
		struct {
			struct bpf_map___4 *map;
			u32 key;
		} tail_call;
	};
	bool tailcall_target_stable;
	u8 adj_off;
	u16 reason;
	u32 insn_idx;
};

struct btf_mod_pair___4 {
	struct btf *btf;
	struct module___29 *module;
};

struct cftype___24;

struct cgroup_subsys___24 {
	struct cgroup_subsys_state___24 * (*css_alloc)(struct cgroup_subsys_state___24 *);
	int (*css_online)(struct cgroup_subsys_state___24 *);
	void (*css_offline)(struct cgroup_subsys_state___24 *);
	void (*css_released)(struct cgroup_subsys_state___24 *);
	void (*css_free)(struct cgroup_subsys_state___24 *);
	void (*css_reset)(struct cgroup_subsys_state___24 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___24 *, int);
	int (*css_extra_stat_show)(struct seq_file___28 *, struct cgroup_subsys_state___24 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___34 *, struct css_set___24 *);
	void (*cancel_fork)(struct task_struct___34 *, struct css_set___24 *);
	void (*fork)(struct task_struct___34 *);
	void (*exit)(struct task_struct___34 *);
	void (*release)(struct task_struct___34 *);
	void (*bind)(struct cgroup_subsys_state___24 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___24 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___24 *dfl_cftypes;
	struct cftype___24 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___24 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___24 *updated_children;
	struct cgroup___24 *updated_next;
};

struct cgroup_root___24 {
	struct kernfs_root___30 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___24 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___24 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___24 *ss;
	struct list_head node;
	struct kernfs_ops___30 *kf_ops;
	int (*open)(struct kernfs_open_file___30 *);
	void (*release)(struct kernfs_open_file___30 *);
	u64 (*read_u64)(struct cgroup_subsys_state___24 *, struct cftype___24 *);
	s64 (*read_s64)(struct cgroup_subsys_state___24 *, struct cftype___24 *);
	int (*seq_show)(struct seq_file___28 *, void *);
	void * (*seq_start)(struct seq_file___28 *, loff_t *);
	void * (*seq_next)(struct seq_file___28 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___28 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___24 *, struct cftype___24 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___24 *, struct cftype___24 *, s64);
	ssize_t (*write)(struct kernfs_open_file___30 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___30 *, struct poll_table_struct___22 *);
};

struct perf_cpu_context___19 {
	struct perf_event_context___19 ctx;
	struct perf_event_context___19 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___19 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
	int heap_size;
	struct perf_event___19 **heap;
	struct perf_event___19 *heap_default[2];
};

struct perf_output_handle___19 {
	struct perf_event___19 *event;
	struct perf_buffer *rb;
	long unsigned int wakeup;
	long unsigned int size;
	u64 aux_flags;
	union {
		void *addr;
		long unsigned int head;
	};
	int page;
};

struct perf_cgroup___19 {
	struct cgroup_subsys_state___24 css;
	struct perf_cgroup_info *info;
};

struct trace_event_fields___19 {
	const char *type;
	union {
		struct {
			const char *name;
			const int size;
			const int align;
			const int is_signed;
			const int filter_type;
		};
		int (*define_fields)(struct trace_event_call___19 *);
	};
};

struct trace_event_class___19 {
	const char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct trace_event_call___19 *, enum trace_reg, void *);
	struct trace_event_fields___19 *fields_array;
	struct list_head * (*get_fields)(struct trace_event_call___19 *);
	struct list_head fields;
	int (*raw_init)(struct trace_event_call___19 *);
};

struct syscall_metadata___7 {
	const char *name;
	int syscall_nr;
	int nb_args;
	const char **types;
	const char **args;
	struct list_head enter_fields;
	struct trace_event_call___19 *enter_event;
	struct trace_event_call___19 *exit_event;
};

struct dcbnl_rtnl_ops___4 {
	int (*ieee_getets)(struct net_device___4 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___4 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___4 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___4 *, struct ieee_maxrate *);
	int (*ieee_getqcn)(struct net_device___4 *, struct ieee_qcn *);
	int (*ieee_setqcn)(struct net_device___4 *, struct ieee_qcn *);
	int (*ieee_getqcnstats)(struct net_device___4 *, struct ieee_qcn_stats *);
	int (*ieee_getpfc)(struct net_device___4 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___4 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___4 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___4 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___4 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___4 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___4 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___4 *);
	u8 (*setstate)(struct net_device___4 *, u8);
	void (*getpermhwaddr)(struct net_device___4 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___4 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___4 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___4 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___4 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___4 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___4 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___4 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___4 *, int, u8 *);
	void (*setpfccfg)(struct net_device___4 *, int, u8);
	void (*getpfccfg)(struct net_device___4 *, int, u8 *);
	u8 (*setall)(struct net_device___4 *);
	u8 (*getcap)(struct net_device___4 *, int, u8 *);
	int (*getnumtcs)(struct net_device___4 *, int, u8 *);
	int (*setnumtcs)(struct net_device___4 *, int, u8);
	u8 (*getpfcstate)(struct net_device___4 *);
	void (*setpfcstate)(struct net_device___4 *, u8);
	void (*getbcncfg)(struct net_device___4 *, int, u32 *);
	void (*setbcncfg)(struct net_device___4 *, int, u32);
	void (*getbcnrp)(struct net_device___4 *, int, u8 *);
	void (*setbcnrp)(struct net_device___4 *, int, u8);
	int (*setapp)(struct net_device___4 *, u8, u16, u8);
	int (*getapp)(struct net_device___4 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___4 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___4 *, int, u8);
	u8 (*getdcbx)(struct net_device___4 *);
	u8 (*setdcbx)(struct net_device___4 *, u8);
	int (*peer_getappinfo)(struct net_device___4 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___4 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___4 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___4 *, struct cee_pfc *);
	int (*dcbnl_getbuffer)(struct net_device___4 *, struct dcbnl_buffer *);
	int (*dcbnl_setbuffer)(struct net_device___4 *, struct dcbnl_buffer *);
};

struct xdp_rxq_info___4 {
	struct net_device___4 *dev;
	u32 queue_index;
	u32 reg_state;
	struct xdp_mem_info mem;
	unsigned int napi_id;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct xdp_txq_info___4 {
	struct net_device___4 *dev;
};

struct xdp_buff___4 {
	void *data;
	void *data_end;
	void *data_meta;
	void *data_hard_start;
	struct xdp_rxq_info___4 *rxq;
	struct xdp_txq_info___4 *txq;
	u32 frame_sz;
};

struct xdp_frame___4 {
	void *data;
	u16 len;
	u16 headroom;
	u32 metasize: 8;
	u32 frame_sz: 24;
	long: 40;
	long: 64;
	struct xdp_mem_info mem;
	struct net_device___4 *dev_rx;
};

struct netlink_callback___4 {
	struct sk_buff___5 *skb;
	const struct nlmsghdr *nlh;
	int (*dump)(struct sk_buff___5 *, struct netlink_callback___4 *);
	int (*done)(struct netlink_callback___4 *);
	void *data;
	struct module___29 *module;
	struct netlink_ext_ack *extack;
	u16 family;
	u16 answer_flags;
	u32 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	bool strict_check;
	union {
		u8 ctx[48];
		long int args[6];
	};
};

struct header_ops___4 {
	int (*create)(struct sk_buff___5 *, struct net_device___4 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___5 *, unsigned char *);
	int (*cache)(const struct neighbour___3 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___4 *, const unsigned char *);
	bool (*validate)(const char *, unsigned int);
	__be16 (*parse_protocol)(const struct sk_buff___5 *);
};

struct netdev_queue___4 {
	struct net_device___4 *dev;
	struct Qdisc___4 *qdisc;
	struct Qdisc___4 *qdisc_sleeping;
	struct kobject___30 kobj;
	int numa_node;
	long unsigned int tx_maxrate;
	long unsigned int trans_timeout;
	struct net_device___4 *sb_dev;
	struct xsk_buff_pool *pool;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
};

struct qdisc_skb_head___4 {
	struct sk_buff___5 *head;
	struct sk_buff___5 *tail;
	__u32 qlen;
	spinlock_t lock;
};

struct Qdisc_ops___4;

struct Qdisc___4 {
	int (*enqueue)(struct sk_buff___5 *, struct Qdisc___4 *, struct sk_buff___5 **);
	struct sk_buff___5 * (*dequeue)(struct Qdisc___4 *);
	unsigned int flags;
	u32 limit;
	const struct Qdisc_ops___4 *ops;
	struct qdisc_size_table *stab;
	struct hlist_node hash;
	u32 handle;
	u32 parent;
	struct netdev_queue___4 *dev_queue;
	struct net_rate_estimator *rate_est;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	int pad;
	refcount_t refcnt;
	long: 64;
	long: 64;
	long: 64;
	struct sk_buff_head___4 gso_skb;
	struct qdisc_skb_head___4 q;
	struct gnet_stats_basic_packed bstats;
	seqcount_t running;
	struct gnet_stats_queue qstats;
	long unsigned int state;
	struct Qdisc___4 *next_sched;
	struct sk_buff_head___4 skb_bad_txq;
	spinlock_t busylock;
	spinlock_t seqlock;
	struct callback_head rcu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long int privdata[0];
};

struct netdev_rx_queue___4 {
	struct xdp_rxq_info___4 xdp_rxq;
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___30 kobj;
	struct net_device___4 *dev;
	struct xsk_buff_pool *pool;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct net_device_path___4 {
	enum net_device_path_type type;
	const struct net_device___4 *dev;
	union {
		struct {
			u16 id;
			__be16 proto;
			u8 h_dest[6];
		} encap;
		struct {
			enum {
				DEV_PATH_BR_VLAN_KEEP___4 = 0,
				DEV_PATH_BR_VLAN_TAG___4 = 1,
				DEV_PATH_BR_VLAN_UNTAG___4 = 2,
				DEV_PATH_BR_VLAN_UNTAG_HW___4 = 3,
			} vlan_mode;
			u16 vlan_id;
			__be16 vlan_proto;
		} bridge;
		struct {
			int port;
			u16 proto;
		} dsa;
	};
};

struct net_device_path_ctx___4 {
	const struct net_device___4 *dev;
	const u8 *daddr;
	int num_vlans;
	struct {
		u16 id;
		__be16 proto;
	} vlan[2];
};

struct netdev_bpf___4 {
	enum bpf_netdev_command command;
	union {
		struct {
			u32 flags;
			struct bpf_prog___4 *prog;
			struct netlink_ext_ack *extack;
		};
		struct {
			struct bpf_offloaded_map___4 *offmap;
		};
		struct {
			struct xsk_buff_pool *pool;
			u16 queue_id;
		} xsk;
	};
};

struct xfrmdev_ops___4 {
	int (*xdo_dev_state_add)(struct xfrm_state *);
	void (*xdo_dev_state_delete)(struct xfrm_state *);
	void (*xdo_dev_state_free)(struct xfrm_state *);
	bool (*xdo_dev_offload_ok)(struct sk_buff___5 *, struct xfrm_state *);
	void (*xdo_dev_state_advance_esn)(struct xfrm_state *);
};

struct netdev_name_node___4 {
	struct hlist_node hlist;
	struct list_head list;
	struct net_device___4 *dev;
	const char *name;
};

struct net_device_ops___4 {
	int (*ndo_init)(struct net_device___4 *);
	void (*ndo_uninit)(struct net_device___4 *);
	int (*ndo_open)(struct net_device___4 *);
	int (*ndo_stop)(struct net_device___4 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___5 *, struct net_device___4 *);
	netdev_features_t (*ndo_features_check)(struct sk_buff___5 *, struct net_device___4 *, netdev_features_t);
	u16 (*ndo_select_queue)(struct net_device___4 *, struct sk_buff___5 *, struct net_device___4 *);
	void (*ndo_change_rx_flags)(struct net_device___4 *, int);
	void (*ndo_set_rx_mode)(struct net_device___4 *);
	int (*ndo_set_mac_address)(struct net_device___4 *, void *);
	int (*ndo_validate_addr)(struct net_device___4 *);
	int (*ndo_do_ioctl)(struct net_device___4 *, struct ifreq *, int);
	int (*ndo_eth_ioctl)(struct net_device___4 *, struct ifreq *, int);
	int (*ndo_siocbond)(struct net_device___4 *, struct ifreq *, int);
	int (*ndo_siocwandev)(struct net_device___4 *, struct if_settings *);
	int (*ndo_siocdevprivate)(struct net_device___4 *, struct ifreq *, void *, int);
	int (*ndo_set_config)(struct net_device___4 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___4 *, int);
	int (*ndo_neigh_setup)(struct net_device___4 *, struct neigh_parms___4 *);
	void (*ndo_tx_timeout)(struct net_device___4 *, unsigned int);
	void (*ndo_get_stats64)(struct net_device___4 *, struct rtnl_link_stats64 *);
	bool (*ndo_has_offload_stats)(const struct net_device___4 *, int);
	int (*ndo_get_offload_stats)(int, const struct net_device___4 *, void *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___4 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___4 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___4 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___4 *);
	int (*ndo_netpoll_setup)(struct net_device___4 *, struct netpoll_info *);
	void (*ndo_netpoll_cleanup)(struct net_device___4 *);
	int (*ndo_set_vf_mac)(struct net_device___4 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___4 *, int, u16, u8, __be16);
	int (*ndo_set_vf_rate)(struct net_device___4 *, int, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___4 *, int, bool);
	int (*ndo_set_vf_trust)(struct net_device___4 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___4 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___4 *, int, int);
	int (*ndo_get_vf_stats)(struct net_device___4 *, int, struct ifla_vf_stats *);
	int (*ndo_set_vf_port)(struct net_device___4 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___4 *, int, struct sk_buff___5 *);
	int (*ndo_get_vf_guid)(struct net_device___4 *, int, struct ifla_vf_guid *, struct ifla_vf_guid *);
	int (*ndo_set_vf_guid)(struct net_device___4 *, int, u64, int);
	int (*ndo_set_vf_rss_query_en)(struct net_device___4 *, int, bool);
	int (*ndo_setup_tc)(struct net_device___4 *, enum tc_setup_type, void *);
	int (*ndo_fcoe_enable)(struct net_device___4 *);
	int (*ndo_fcoe_disable)(struct net_device___4 *);
	int (*ndo_fcoe_ddp_setup)(struct net_device___4 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_ddp_done)(struct net_device___4 *, u16);
	int (*ndo_fcoe_ddp_target)(struct net_device___4 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_get_hbainfo)(struct net_device___4 *, struct netdev_fcoe_hbainfo *);
	int (*ndo_fcoe_get_wwn)(struct net_device___4 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___4 *, const struct sk_buff___5 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___4 *, struct net_device___4 *, struct netlink_ext_ack *);
	int (*ndo_del_slave)(struct net_device___4 *, struct net_device___4 *);
	struct net_device___4 * (*ndo_get_xmit_slave)(struct net_device___4 *, struct sk_buff___5 *, bool);
	struct net_device___4 * (*ndo_sk_get_lower_dev)(struct net_device___4 *, struct sock___3 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___4 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___4 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct net_device___4 *, struct neighbour___3 *);
	void (*ndo_neigh_destroy)(struct net_device___4 *, struct neighbour___3 *);
	int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___4 *, const unsigned char *, u16, u16, struct netlink_ext_ack *);
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___4 *, const unsigned char *, u16);
	int (*ndo_fdb_dump)(struct sk_buff___5 *, struct netlink_callback___4 *, struct net_device___4 *, struct net_device___4 *, int *);
	int (*ndo_fdb_get)(struct sk_buff___5 *, struct nlattr **, struct net_device___4 *, const unsigned char *, u16, u32, u32, struct netlink_ext_ack *);
	int (*ndo_bridge_setlink)(struct net_device___4 *, struct nlmsghdr *, u16, struct netlink_ext_ack *);
	int (*ndo_bridge_getlink)(struct sk_buff___5 *, u32, u32, struct net_device___4 *, u32, int);
	int (*ndo_bridge_dellink)(struct net_device___4 *, struct nlmsghdr *, u16);
	int (*ndo_change_carrier)(struct net_device___4 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___4 *, struct netdev_phys_item_id *);
	int (*ndo_get_port_parent_id)(struct net_device___4 *, struct netdev_phys_item_id *);
	int (*ndo_get_phys_port_name)(struct net_device___4 *, char *, size_t);
	void * (*ndo_dfwd_add_station)(struct net_device___4 *, struct net_device___4 *);
	void (*ndo_dfwd_del_station)(struct net_device___4 *, void *);
	int (*ndo_set_tx_maxrate)(struct net_device___4 *, int, u32);
	int (*ndo_get_iflink)(const struct net_device___4 *);
	int (*ndo_change_proto_down)(struct net_device___4 *, bool);
	int (*ndo_fill_metadata_dst)(struct net_device___4 *, struct sk_buff___5 *);
	void (*ndo_set_rx_headroom)(struct net_device___4 *, int);
	int (*ndo_bpf)(struct net_device___4 *, struct netdev_bpf___4 *);
	int (*ndo_xdp_xmit)(struct net_device___4 *, int, struct xdp_frame___4 **, u32);
	struct net_device___4 * (*ndo_xdp_get_xmit_slave)(struct net_device___4 *, struct xdp_buff___4 *);
	int (*ndo_xsk_wakeup)(struct net_device___4 *, u32, u32);
	struct devlink_port * (*ndo_get_devlink_port)(struct net_device___4 *);
	int (*ndo_tunnel_ctl)(struct net_device___4 *, struct ip_tunnel_parm *, int);
	struct net_device___4 * (*ndo_get_peer_dev)(struct net_device___4 *);
	int (*ndo_fill_forward_path)(struct net_device_path_ctx___4 *, struct net_device_path___4 *);
};

struct neigh_parms___4 {
	possible_net_t___4 net;
	struct net_device___4 *dev;
	struct list_head list;
	int (*neigh_setup)(struct neighbour___3 *);
	struct neigh_table___3 *tbl;
	void *sysctl_table;
	int dead;
	refcount_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[13];
	long unsigned int data_state[1];
};

struct l3mdev_ops___4 {
	u32 (*l3mdev_fib_table)(const struct net_device___4 *);
	struct sk_buff___5 * (*l3mdev_l3_rcv)(struct net_device___4 *, struct sk_buff___5 *, u16);
	struct sk_buff___5 * (*l3mdev_l3_out)(struct net_device___4 *, struct sock___3 *, struct sk_buff___5 *, u16);
	struct dst_entry___3 * (*l3mdev_link_scope_lookup)(const struct net_device___4 *, struct flowi6 *);
};

struct tcf_proto___4;

struct tcf_block___4;

struct mini_Qdisc___4 {
	struct tcf_proto___4 *filter_list;
	struct tcf_block___4 *block;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	struct callback_head rcu;
};

struct rtnl_link_ops___4 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	struct net_device___4 * (*alloc)(struct nlattr **, const char *, unsigned char, unsigned int, unsigned int);
	void (*setup)(struct net_device___4 *);
	bool netns_refund;
	unsigned int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*newlink)(struct net___5 *, struct net_device___4 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*changelink)(struct net_device___4 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	void (*dellink)(struct net_device___4 *, struct list_head *);
	size_t (*get_size)(const struct net_device___4 *);
	int (*fill_info)(struct sk_buff___5 *, const struct net_device___4 *);
	size_t (*get_xstats_size)(const struct net_device___4 *);
	int (*fill_xstats)(struct sk_buff___5 *, const struct net_device___4 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	unsigned int slave_maxtype;
	const struct nla_policy *slave_policy;
	int (*slave_changelink)(struct net_device___4 *, struct net_device___4 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	size_t (*get_slave_size)(const struct net_device___4 *, const struct net_device___4 *);
	int (*fill_slave_info)(struct sk_buff___5 *, const struct net_device___4 *, const struct net_device___4 *);
	struct net___5 * (*get_link_net)(const struct net_device___4 *);
	size_t (*get_linkxstats_size)(const struct net_device___4 *, int);
	int (*fill_linkxstats)(struct sk_buff___5 *, const struct net_device___4 *, int *, int);
};

struct block_device_operations___20;

struct gendisk___20 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	short unsigned int events;
	short unsigned int event_flags;
	struct xarray part_tbl;
	struct block_device___20 *part0;
	const struct block_device_operations___20 *fops;
	struct request_queue___20 *queue;
	void *private_data;
	int flags;
	long unsigned int state;
	struct mutex open_mutex;
	unsigned int open_partitions;
	struct backing_dev_info___19 *bdi;
	struct kobject___30 *slave_dir;
	struct list_head slave_bdevs;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___30 integrity_kobj;
	struct cdrom_device_info *cdi;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	u64 diskseq;
};

struct bio_integrity_payload___20 {
	struct bio___20 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___24 *bip_vec;
	struct bio_vec___24 bip_inline_vecs[0];
};

struct blkcg___19;

struct blkg_policy_data___19;

struct blkcg_gq___19 {
	struct request_queue___20 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___19 *blkcg;
	struct blkcg_gq___19 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_iostat_set *iostat_cpu;
	struct blkg_iostat_set iostat;
	struct blkg_policy_data___19 *pd[6];
	spinlock_t async_bio_lock;
	struct bio_list___20 async_bios;
	struct work_struct async_bio_work;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
	struct callback_head callback_head;
};

typedef void integrity_prepare_fn___20(struct request___20 *);

typedef void integrity_complete_fn___20(struct request___20 *, unsigned int);

struct blk_integrity_profile___20 {
	integrity_processing_fn *generate_fn;
	integrity_processing_fn *verify_fn;
	integrity_prepare_fn___20 *prepare_fn;
	integrity_complete_fn___20 *complete_fn;
	const char *name;
};

struct block_device_operations___20 {
	blk_qc_t (*submit_bio)(struct bio___20 *);
	int (*open)(struct block_device___20 *, fmode_t);
	void (*release)(struct gendisk___20 *, fmode_t);
	int (*rw_page)(struct block_device___20 *, sector_t, struct page___32 *, unsigned int);
	int (*ioctl)(struct block_device___20 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___20 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___20 *, unsigned int);
	void (*unlock_native_capacity)(struct gendisk___20 *);
	int (*getgeo)(struct block_device___20 *, struct hd_geometry *);
	int (*set_read_only)(struct block_device___20 *, bool);
	void (*swap_slot_free_notify)(struct block_device___20 *, long unsigned int);
	int (*report_zones)(struct gendisk___20 *, sector_t, unsigned int, report_zones_cb, void *);
	char * (*devnode)(struct gendisk___20 *, umode_t *);
	struct module___29 *owner;
	const struct pr_ops *pr_ops;
	int (*alternative_gpt_sector)(struct gendisk___20 *, sector_t *);
};

typedef void rq_end_io_fn___20(struct request___20 *, blk_status_t);

struct request___20 {
	struct request_queue___20 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int tag;
	int internal_tag;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___20 *bio;
	struct bio___20 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct llist_node ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___24 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___20 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___20 *saved_end_io;
		} flush;
	};
	struct gendisk___20 *rq_disk;
	struct block_device___20 *part;
	u64 alloc_time_ns;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int stats_sectors;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	struct bio_crypt_ctx *crypt_ctx;
	struct blk_ksm_keyslot *crypt_keyslot;
	short unsigned int write_hint;
	short unsigned int ioprio;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___20 *end_io;
	void *end_io_data;
};

struct elevator_type___20;

struct elevator_mq_ops___20 {
	int (*init_sched)(struct request_queue___20 *, struct elevator_type___20 *);
	void (*exit_sched)(struct elevator_queue___20 *);
	int (*init_hctx)(struct blk_mq_hw_ctx *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx *, unsigned int);
	void (*depth_updated)(struct blk_mq_hw_ctx *);
	bool (*allow_merge)(struct request_queue___20 *, struct request___20 *, struct bio___20 *);
	bool (*bio_merge)(struct request_queue___20 *, struct bio___20 *, unsigned int);
	int (*request_merge)(struct request_queue___20 *, struct request___20 **, struct bio___20 *);
	void (*request_merged)(struct request_queue___20 *, struct request___20 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___20 *, struct request___20 *, struct request___20 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___20 *);
	void (*finish_request)(struct request___20 *);
	void (*insert_requests)(struct blk_mq_hw_ctx *, struct list_head *, bool);
	struct request___20 * (*dispatch_request)(struct blk_mq_hw_ctx *);
	bool (*has_work)(struct blk_mq_hw_ctx *);
	void (*completed_request)(struct request___20 *, u64);
	void (*requeue_request)(struct request___20 *);
	struct request___20 * (*former_request)(struct request_queue___20 *, struct request___20 *);
	struct request___20 * (*next_request)(struct request_queue___20 *, struct request___20 *);
	void (*init_icq)(struct io_cq___20 *);
	void (*exit_icq)(struct io_cq___20 *);
};

struct elv_fs_entry___20;

struct elevator_type___20 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___20 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___20 *elevator_attrs;
	const char *elevator_name;
	const char *elevator_alias;
	const unsigned int elevator_features;
	struct module___29 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
};

struct elevator_queue___20 {
	struct elevator_type___20 *type;
	void *elevator_data;
	struct kobject___30 kobj;
	struct mutex sysfs_lock;
	unsigned int registered: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hlist_head hash[64];
};

struct elv_fs_entry___20 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___20 *, char *);
	ssize_t (*store)(struct elevator_queue___20 *, const char *, size_t);
};

struct blkcg_policy_data___19;

struct blkcg___19 {
	struct cgroup_subsys_state___24 css;
	spinlock_t lock;
	refcount_t online_pin;
	struct xarray blkg_tree;
	struct blkcg_gq___19 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___19 *cpd[6];
	struct list_head all_blkcgs_node;
	char fc_app_id[129];
	struct list_head cgwb_list;
};

struct blkcg_policy_data___19 {
	struct blkcg___19 *blkcg;
	int plid;
};

struct blkg_policy_data___19 {
	struct blkcg_gq___19 *blkg;
	int plid;
};

struct mem_cgroup_reclaim_iter___19 {
	struct mem_cgroup___19 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___19 {
	struct lruvec___20 lruvec;
	struct lruvec_stats_percpu *lruvec_stats_percpu;
	struct lruvec_stats lruvec_stats;
	long unsigned int lru_zone_size[25];
	struct mem_cgroup_reclaim_iter___19 iter;
	struct shrinker_info *shrinker_info;
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	struct mem_cgroup___19 *memcg;
};

struct obj_cgroup___19 {
	struct percpu_ref refcnt;
	struct mem_cgroup___19 *memcg;
	atomic_t nr_charged_bytes;
	union {
		struct list_head list;
		struct callback_head rcu;
	};
};

struct gnet_dump___4 {
	spinlock_t *lock;
	struct sk_buff___5 *skb;
	struct nlattr *tail;
	int compat_tc_stats;
	int compat_xstats;
	int padattr;
	void *xstats;
	int xstats_len;
	struct tc_stats tc_stats;
};

struct Qdisc_class_ops___4;

struct Qdisc_ops___4 {
	struct Qdisc_ops___4 *next;
	const struct Qdisc_class_ops___4 *cl_ops;
	char id[16];
	int priv_size;
	unsigned int static_flags;
	int (*enqueue)(struct sk_buff___5 *, struct Qdisc___4 *, struct sk_buff___5 **);
	struct sk_buff___5 * (*dequeue)(struct Qdisc___4 *);
	struct sk_buff___5 * (*peek)(struct Qdisc___4 *);
	int (*init)(struct Qdisc___4 *, struct nlattr *, struct netlink_ext_ack *);
	void (*reset)(struct Qdisc___4 *);
	void (*destroy)(struct Qdisc___4 *);
	int (*change)(struct Qdisc___4 *, struct nlattr *, struct netlink_ext_ack *);
	void (*attach)(struct Qdisc___4 *);
	int (*change_tx_queue_len)(struct Qdisc___4 *, unsigned int);
	void (*change_real_num_tx)(struct Qdisc___4 *, unsigned int);
	int (*dump)(struct Qdisc___4 *, struct sk_buff___5 *);
	int (*dump_stats)(struct Qdisc___4 *, struct gnet_dump___4 *);
	void (*ingress_block_set)(struct Qdisc___4 *, u32);
	void (*egress_block_set)(struct Qdisc___4 *, u32);
	u32 (*ingress_block_get)(struct Qdisc___4 *);
	u32 (*egress_block_get)(struct Qdisc___4 *);
	struct module___29 *owner;
};

struct Qdisc_class_ops___4 {
	unsigned int flags;
	struct netdev_queue___4 * (*select_queue)(struct Qdisc___4 *, struct tcmsg *);
	int (*graft)(struct Qdisc___4 *, long unsigned int, struct Qdisc___4 *, struct Qdisc___4 **, struct netlink_ext_ack *);
	struct Qdisc___4 * (*leaf)(struct Qdisc___4 *, long unsigned int);
	void (*qlen_notify)(struct Qdisc___4 *, long unsigned int);
	long unsigned int (*find)(struct Qdisc___4 *, u32);
	int (*change)(struct Qdisc___4 *, u32, u32, struct nlattr **, long unsigned int *, struct netlink_ext_ack *);
	int (*delete)(struct Qdisc___4 *, long unsigned int, struct netlink_ext_ack *);
	void (*walk)(struct Qdisc___4 *, struct qdisc_walker *);
	struct tcf_block___4 * (*tcf_block)(struct Qdisc___4 *, long unsigned int, struct netlink_ext_ack *);
	long unsigned int (*bind_tcf)(struct Qdisc___4 *, long unsigned int, u32);
	void (*unbind_tcf)(struct Qdisc___4 *, long unsigned int);
	int (*dump)(struct Qdisc___4 *, long unsigned int, struct sk_buff___5 *, struct tcmsg *);
	int (*dump_stats)(struct Qdisc___4 *, long unsigned int, struct gnet_dump___4 *);
};

struct tcf_chain___4;

struct tcf_block___4 {
	struct mutex lock;
	struct list_head chain_list;
	u32 index;
	u32 classid;
	refcount_t refcnt;
	struct net___5 *net;
	struct Qdisc___4 *q;
	struct rw_semaphore cb_lock;
	struct flow_block flow_block;
	struct list_head owner_list;
	bool keep_dst;
	atomic_t offloadcnt;
	unsigned int nooffloaddevcnt;
	unsigned int lockeddevcnt;
	struct {
		struct tcf_chain___4 *chain;
		struct list_head filter_chain_list;
	} chain0;
	struct callback_head rcu;
	struct hlist_head proto_destroy_ht[128];
	struct mutex proto_destroy_lock;
};

struct tcf_result___4;

struct tcf_proto_ops___4;

struct tcf_proto___4 {
	struct tcf_proto___4 *next;
	void *root;
	int (*classify)(struct sk_buff___5 *, const struct tcf_proto___4 *, struct tcf_result___4 *);
	__be16 protocol;
	u32 prio;
	void *data;
	const struct tcf_proto_ops___4 *ops;
	struct tcf_chain___4 *chain;
	spinlock_t lock;
	bool deleting;
	refcount_t refcnt;
	struct callback_head rcu;
	struct hlist_node destroy_ht_node;
};

struct tcf_result___4 {
	union {
		struct {
			long unsigned int class;
			u32 classid;
		};
		const struct tcf_proto___4 *goto_tp;
		struct {
			bool ingress;
			struct gnet_stats_queue *qstats;
		};
	};
};

struct tcf_proto_ops___4 {
	struct list_head head;
	char kind[16];
	int (*classify)(struct sk_buff___5 *, const struct tcf_proto___4 *, struct tcf_result___4 *);
	int (*init)(struct tcf_proto___4 *);
	void (*destroy)(struct tcf_proto___4 *, bool, struct netlink_ext_ack *);
	void * (*get)(struct tcf_proto___4 *, u32);
	void (*put)(struct tcf_proto___4 *, void *);
	int (*change)(struct net___5 *, struct sk_buff___5 *, struct tcf_proto___4 *, long unsigned int, u32, struct nlattr **, void **, u32, struct netlink_ext_ack *);
	int (*delete)(struct tcf_proto___4 *, void *, bool *, bool, struct netlink_ext_ack *);
	bool (*delete_empty)(struct tcf_proto___4 *);
	void (*walk)(struct tcf_proto___4 *, struct tcf_walker *, bool);
	int (*reoffload)(struct tcf_proto___4 *, bool, flow_setup_cb_t *, void *, struct netlink_ext_ack *);
	void (*hw_add)(struct tcf_proto___4 *, void *);
	void (*hw_del)(struct tcf_proto___4 *, void *);
	void (*bind_class)(void *, u32, long unsigned int, void *, long unsigned int);
	void * (*tmplt_create)(struct net___5 *, struct tcf_chain___4 *, struct nlattr **, struct netlink_ext_ack *);
	void (*tmplt_destroy)(void *);
	int (*dump)(struct net___5 *, struct tcf_proto___4 *, void *, struct sk_buff___5 *, struct tcmsg *, bool);
	int (*terse_dump)(struct net___5 *, struct tcf_proto___4 *, void *, struct sk_buff___5 *, struct tcmsg *, bool);
	int (*tmplt_dump)(struct sk_buff___5 *, struct net___5 *, void *);
	struct module___29 *owner;
	int flags;
};

struct tcf_chain___4 {
	struct mutex filter_chain_lock;
	struct tcf_proto___4 *filter_chain;
	struct list_head list;
	struct tcf_block___4 *block;
	u32 index;
	unsigned int refcnt;
	unsigned int action_refcnt;
	bool explicitly_created;
	bool flushing;
	const struct tcf_proto_ops___4 *tmplt_ops;
	void *tmplt_priv;
	struct callback_head rcu;
};

struct sk_filter___3 {
	refcount_t refcnt;
	struct callback_head rcu;
	struct bpf_prog___4 *prog;
};

struct pneigh_entry___3;

struct neigh_hash_table___3;

struct neigh_table___3 {
	int family;
	unsigned int entry_size;
	unsigned int key_len;
	__be16 protocol;
	__u32 (*hash)(const void *, const struct net_device___4 *, __u32 *);
	bool (*key_eq)(const struct neighbour___3 *, const void *);
	int (*constructor)(struct neighbour___3 *);
	int (*pconstructor)(struct pneigh_entry___3 *);
	void (*pdestructor)(struct pneigh_entry___3 *);
	void (*proxy_redo)(struct sk_buff___5 *);
	int (*is_multicast)(const void *);
	bool (*allow_add)(const struct net_device___4 *, struct netlink_ext_ack *);
	char *id;
	struct neigh_parms___4 parms;
	struct list_head parms_list;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___4 proxy_queue;
	atomic_t entries;
	atomic_t gc_entries;
	struct list_head gc_list;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___3 *nht;
	struct pneigh_entry___3 **phash_buckets;
};

struct neigh_ops___3 {
	int family;
	void (*solicit)(struct neighbour___3 *, struct sk_buff___5 *);
	void (*error_report)(struct neighbour___3 *, struct sk_buff___5 *);
	int (*output)(struct neighbour___3 *, struct sk_buff___5 *);
	int (*connected_output)(struct neighbour___3 *, struct sk_buff___5 *);
};

struct pneigh_entry___3 {
	struct pneigh_entry___3 *next;
	possible_net_t___4 net;
	struct net_device___4 *dev;
	u8 flags;
	u8 protocol;
	u8 key[0];
};

struct neigh_hash_table___3 {
	struct neighbour___3 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct fib_rule___3 {
	struct list_head list;
	int iifindex;
	int oifindex;
	u32 mark;
	u32 mark_mask;
	u32 flags;
	u32 table;
	u8 action;
	u8 l3mdev;
	u8 proto;
	u8 ip_proto;
	u32 target;
	__be64 tun_id;
	struct fib_rule___3 *ctarget;
	struct net___5 *fr_net;
	refcount_t refcnt;
	u32 pref;
	int suppress_ifgroup;
	int suppress_prefixlen;
	char iifname[16];
	char oifname[16];
	struct fib_kuid_range uid_range;
	struct fib_rule_port_range sport_range;
	struct fib_rule_port_range dport_range;
	struct callback_head rcu;
};

struct fib_lookup_arg___3 {
	void *lookup_ptr;
	const void *lookup_data;
	void *result;
	struct fib_rule___3 *rule;
	u32 table;
	int flags;
};

struct request_sock_ops___3;

struct timewait_sock_ops___3;

struct proto___3 {
	void (*close)(struct sock___3 *, long int);
	int (*pre_connect)(struct sock___3 *, struct sockaddr *, int);
	int (*connect)(struct sock___3 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___3 *, int);
	struct sock___3 * (*accept)(struct sock___3 *, int, int *, bool);
	int (*ioctl)(struct sock___3 *, int, long unsigned int);
	int (*init)(struct sock___3 *);
	void (*destroy)(struct sock___3 *);
	void (*shutdown)(struct sock___3 *, int);
	int (*setsockopt)(struct sock___3 *, int, int, sockptr_t, unsigned int);
	int (*getsockopt)(struct sock___3 *, int, int, char *, int *);
	void (*keepalive)(struct sock___3 *, int);
	int (*compat_ioctl)(struct sock___3 *, unsigned int, long unsigned int);
	int (*sendmsg)(struct sock___3 *, struct msghdr___3 *, size_t);
	int (*recvmsg)(struct sock___3 *, struct msghdr___3 *, size_t, int, int, int *);
	int (*sendpage)(struct sock___3 *, struct page___32 *, int, size_t, int);
	int (*bind)(struct sock___3 *, struct sockaddr *, int);
	int (*bind_add)(struct sock___3 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___3 *, struct sk_buff___5 *);
	bool (*bpf_bypass_getsockopt)(int, int);
	void (*release_cb)(struct sock___3 *);
	int (*hash)(struct sock___3 *);
	void (*unhash)(struct sock___3 *);
	void (*rehash)(struct sock___3 *);
	int (*get_port)(struct sock___3 *, short unsigned int);
	int (*psock_update_sk_prot)(struct sock___3 *, struct sk_psock *, bool);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___3 *, int);
	bool (*sock_is_readable)(struct sock___3 *);
	void (*enter_memory_pressure)(struct sock___3 *);
	void (*leave_memory_pressure)(struct sock___3 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	long unsigned int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	u32 sysctl_wmem_offset;
	u32 sysctl_rmem_offset;
	int max_header;
	bool no_autobind;
	struct kmem_cache *slab;
	unsigned int obj_size;
	slab_flags_t slab_flags;
	unsigned int useroffset;
	unsigned int usersize;
	unsigned int *orphan_count;
	struct request_sock_ops___3 *rsk_prot;
	struct timewait_sock_ops___3 *twsk_prot;
	union {
		struct inet_hashinfo *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
		struct smc_hashinfo *smc_hash;
	} h;
	struct module___29 *owner;
	char name[32];
	struct list_head node;
	int (*diag_destroy)(struct sock___3 *, int);
};

typedef void (*task_work_func_t)(struct callback_head *);

enum {
	KERNEL_PARAM_OPS_FL_NOARG = 1,
};

enum {
	KERNEL_PARAM_FL_UNSAFE = 1,
	KERNEL_PARAM_FL_HWPARAM = 2,
};

struct param_attribute {
	struct module_attribute___24 mattr;
	const struct kernel_param___24 *param;
};

struct module_param_attrs {
	unsigned int num;
	struct attribute_group___25 grp;
	struct param_attribute attrs[0];
};

struct module_version_attribute {
	struct module_attribute___24 mattr;
	const char *module_name;
	const char *version;
};

struct kmalloced_param {
	struct list_head list;
	char val[0];
};

struct sched_param {
	int sched_priority;
};

struct flush_tlb_info___12;

struct pv_mmu_ops___28 {
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_one_user)(long unsigned int);
	void (*flush_tlb_multi)(const struct cpumask *, const struct flush_tlb_info___12 *);
	void (*tlb_remove_table)(struct mmu_gather *, void *);
	void (*exit_mmap)(struct mm_struct___32 *);
	struct paravirt_callee_save read_cr2;
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___32 *, struct mm_struct___32 *);
	void (*dup_mmap)(struct mm_struct___32 *, struct mm_struct___32 *);
	int (*pgd_alloc)(struct mm_struct___32 *);
	void (*pgd_free)(struct mm_struct___32 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___32 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___32 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___32 *, long unsigned int);
	void (*alloc_p4d)(struct mm_struct___32 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*release_p4d)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	pte_t (*ptep_modify_prot_start)(struct vm_area_struct___32 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct vm_area_struct___32 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_p4d)(p4d_t *, p4d_t);
	struct paravirt_callee_save p4d_val;
	struct paravirt_callee_save make_p4d;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

struct flush_tlb_info___12 {
	struct mm_struct___32 *mm;
	long unsigned int start;
	long unsigned int end;
	u64 new_tlb_gen;
	unsigned int initiating_cpu;
	u8 stride_shift;
	u8 freed_tables;
};

struct paravirt_patch_template___28 {
	struct pv_cpu_ops___25 cpu;
	struct pv_irq_ops irq;
	struct pv_mmu_ops___28 mmu;
	struct pv_lock_ops lock;
};

enum {
	__PERCPU_REF_ATOMIC = 1,
	__PERCPU_REF_DEAD = 2,
	__PERCPU_REF_ATOMIC_DEAD = 3,
	__PERCPU_REF_FLAG_BITS = 2,
};

struct kthread_work;

typedef void (*kthread_work_func_t)(struct kthread_work *);

struct kthread_worker;

struct kthread_work {
	struct list_head node;
	kthread_work_func_t func;
	struct kthread_worker *worker;
	int canceling;
};

enum {
	KTW_FREEZABLE = 1,
};

struct kthread_worker {
	unsigned int flags;
	raw_spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___33 *task;
	struct kthread_work *current_work;
};

struct kthread_delayed_work {
	struct kthread_work work;
	struct timer_list timer;
};

enum {
	CSS_NO_REF = 1,
	CSS_ONLINE = 2,
	CSS_RELEASED = 4,
	CSS_VISIBLE = 8,
	CSS_DYING = 16,
};

struct kthread_create_info {
	int (*threadfn)(void *);
	void *data;
	int node;
	struct task_struct___33 *result;
	struct completion *done;
	struct list_head list;
};

struct kthread {
	long unsigned int flags;
	unsigned int cpu;
	int (*threadfn)(void *);
	void *data;
	mm_segment_t oldfs;
	struct completion parked;
	struct completion exited;
	struct cgroup_subsys_state___23 *blkcg_css;
};

enum KTHREAD_BITS {
	KTHREAD_IS_PER_CPU = 0,
	KTHREAD_SHOULD_STOP = 1,
	KTHREAD_SHOULD_PARK = 2,
};

struct kthread_flush_work {
	struct kthread_work work;
	struct completion done;
};

struct pt_regs___2;

struct dentry___31;

struct super_block___31;

struct module___30;

struct file_system_type___31 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___31 * (*mount)(struct file_system_type___31 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___31 *);
	struct module___30 *owner;
	struct file_system_type___31 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___31;

struct kiocb___31;

struct iov_iter___25;

struct poll_table_struct___23;

struct vm_area_struct___34;

struct inode___31;

struct file_lock___31;

struct page___33;

struct pipe_inode_info___10;

struct seq_file___29;

struct file_operations___31 {
	struct module___30 *owner;
	loff_t (*llseek)(struct file___31 *, loff_t, int);
	ssize_t (*read)(struct file___31 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___31 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___31 *, struct iov_iter___25 *);
	ssize_t (*write_iter)(struct kiocb___31 *, struct iov_iter___25 *);
	int (*iopoll)(struct kiocb___31 *, bool);
	int (*iterate)(struct file___31 *, struct dir_context *);
	int (*iterate_shared)(struct file___31 *, struct dir_context *);
	__poll_t (*poll)(struct file___31 *, struct poll_table_struct___23 *);
	long int (*unlocked_ioctl)(struct file___31 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___31 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___31 *, struct vm_area_struct___34 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___31 *, struct file___31 *);
	int (*flush)(struct file___31 *, fl_owner_t);
	int (*release)(struct inode___31 *, struct file___31 *);
	int (*fsync)(struct file___31 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___31 *, int);
	int (*lock)(struct file___31 *, int, struct file_lock___31 *);
	ssize_t (*sendpage)(struct file___31 *, struct page___33 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___31 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___31 *, long unsigned int);
	int (*flock)(struct file___31 *, int, struct file_lock___31 *);
	ssize_t (*splice_write)(struct pipe_inode_info___10 *, struct file___31 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___31 *, loff_t *, struct pipe_inode_info___10 *, size_t, unsigned int);
	int (*setlease)(struct file___31 *, long int, struct file_lock___31 **, void **);
	long int (*fallocate)(struct file___31 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___29 *, struct file___31 *);
	ssize_t (*copy_file_range)(struct file___31 *, loff_t, struct file___31 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___31 *, loff_t, struct file___31 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___31 *, loff_t, loff_t, int);
};

struct static_call_mod___23 {
	struct static_call_mod___23 *next;
	struct module___30 *mod;
	struct static_call_site *sites;
};

struct static_call_key___23 {
	void *func;
	union {
		long unsigned int type;
		struct static_call_mod___23 *mods;
		struct static_call_site *sites;
	};
};

struct vmacache___33 {
	u64 seqnum;
	struct vm_area_struct___34 *vmas[4];
};

struct page_frag___33 {
	struct page___33 *page;
	__u32 offset;
	__u32 size;
};

struct perf_event___20;

struct thread_struct___21 {
	struct desc_struct tls_array[3];
	long unsigned int sp;
	short unsigned int es;
	short unsigned int ds;
	short unsigned int fsindex;
	short unsigned int gsindex;
	long unsigned int fsbase;
	long unsigned int gsbase;
	struct perf_event___20 *ptrace_bps[4];
	long unsigned int virtual_dr6;
	long unsigned int ptrace_dr7;
	long unsigned int cr2;
	long unsigned int trap_nr;
	long unsigned int error_code;
	struct io_bitmap *io_bitmap;
	long unsigned int iopl_emul;
	unsigned int iopl_warn: 1;
	unsigned int sig_on_uaccess_err: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u32 pkru;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct fpu fpu;
};

struct mm_struct___34;

struct pid___27;

struct fs_struct___5;

struct nsproxy___30;

struct css_set___25;

struct perf_event_context___20;

struct vm_struct___28;

struct task_struct___35 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___35 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___34 *mm;
	struct mm_struct___34 *active_mm;
	struct vmacache___33 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int restore_sigmask: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___35 *real_parent;
	struct task_struct___35 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___35 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___27 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	struct posix_cputimers_work posix_cputimers_work;
	const struct cred___2 *ptracer_cred;
	const struct cred___2 *real_cred;
	const struct cred___2 *cred;
	struct key *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct___5 *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___30 *nsproxy;
	struct signal_struct___3 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___35 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context___2 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___25 *cgroups;
	struct list_head cg_list;
	u32 closid;
	u32 rmid;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___20 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	struct pipe_inode_info___10 *splice_pipe;
	struct page_frag___33 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup *active_memcg;
	struct request_queue *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___35 *oom_reaper_list;
	struct vm_struct___28 *stack_vm_area;
	refcount_t stack_refcount;
	int patch_state;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	void *mce_vaddr;
	__u64 mce_kflags;
	u64 mce_addr;
	__u64 mce_ripv: 1;
	__u64 mce_whole_page: 1;
	__u64 __mce_reserved: 62;
	long: 2;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct callback_head mce_kill_me;
	int mce_count;
	struct llist_head kretprobe_instances;
	struct callback_head l1d_flush_kill;
	long: 64;
	struct thread_struct___21 thread;
};

typedef struct page___33 *pgtable_t___33;

struct address_space___31;

struct page_pool___10;

struct dev_pagemap___31;

struct page___33 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___31 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___10 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___33 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___33 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___34 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___31 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct pv_cpu_ops___27 {
	void (*io_delay)();
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	void (*write_cr4)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___21 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(long unsigned int);
	void (*invalidate_io_bitmap)();
	void (*update_io_bitmap)();
	void (*wbinvd)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int);
	void (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_msr_safe)(unsigned int, int *);
	int (*write_msr_safe)(unsigned int, unsigned int, unsigned int);
	u64 (*read_pmc)(int);
	void (*start_context_switch)(struct task_struct___35 *);
	void (*end_context_switch)(struct task_struct___35 *);
};

struct pv_mmu_ops___29 {
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_one_user)(long unsigned int);
	void (*flush_tlb_multi)(const struct cpumask *, const struct flush_tlb_info___3 *);
	void (*tlb_remove_table)(struct mmu_gather *, void *);
	void (*exit_mmap)(struct mm_struct___34 *);
	struct paravirt_callee_save read_cr2;
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___34 *, struct mm_struct___34 *);
	void (*dup_mmap)(struct mm_struct___34 *, struct mm_struct___34 *);
	int (*pgd_alloc)(struct mm_struct___34 *);
	void (*pgd_free)(struct mm_struct___34 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___34 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___34 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___34 *, long unsigned int);
	void (*alloc_p4d)(struct mm_struct___34 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*release_p4d)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	pte_t (*ptep_modify_prot_start)(struct vm_area_struct___34 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct vm_area_struct___34 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_p4d)(p4d_t *, p4d_t);
	struct paravirt_callee_save p4d_val;
	struct paravirt_callee_save make_p4d;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

struct core_state___33;

struct mm_struct___34 {
	struct {
		struct vm_area_struct___34 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___31 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int mmap_compat_base;
		long unsigned int mmap_compat_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[48];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___33 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___35 *owner;
		struct user_namespace___2 *user_ns;
		struct file___31 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		bool tlb_flush_batched;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct vm_operations_struct___31;

struct vm_area_struct___34 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___34 *vm_next;
	struct vm_area_struct___34 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___34 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___31 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___31 *vm_file;
	struct file___31 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct paravirt_patch_template___29 {
	struct pv_cpu_ops___27 cpu;
	struct pv_irq_ops irq;
	struct pv_mmu_ops___29 mmu;
	struct pv_lock_ops lock;
};

struct tracepoint___23 {
	const char *name;
	struct static_key key;
	struct static_call_key___23 *static_call_key;
	void *static_call_tramp;
	void *iterator;
	int (*regfunc)();
	void (*unregfunc)();
	struct tracepoint_func *funcs;
};

struct bpf_raw_event_map___23 {
	struct tracepoint___23 *tp;
	void *bpf_func;
	u32 num_args;
	u32 writable_size;
	long: 64;
};

struct seq_operations___29 {
	void * (*start)(struct seq_file___29 *, loff_t *);
	void (*stop)(struct seq_file___29 *, void *);
	void * (*next)(struct seq_file___29 *, void *, loff_t *);
	int (*show)(struct seq_file___29 *, void *);
};

struct hw_perf_event___20 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___35 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	union {
		struct {
			u64 last_period;
			local64_t period_left;
		};
		struct {
			u64 saved_metric;
			u64 saved_slots;
		};
	};
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___20)(struct perf_event___20 *, struct perf_sample_data *, struct pt_regs *);

struct pmu___20;

struct fasync_struct___31;

struct pid_namespace___27;

struct trace_event_call___20;

struct perf_cgroup___20;

struct perf_event___20 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___20 *group_leader;
	struct pmu___20 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___20 hw;
	struct perf_event_context___20 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___20 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___35 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct perf_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___31 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	long unsigned int pending_addr;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	struct perf_addr_filter_range *addr_filter_ranges;
	long unsigned int addr_filters_gen;
	struct perf_event___20 *aux_event;
	void (*destroy)(struct perf_event___20 *);
	struct callback_head callback_head;
	struct pid_namespace___27 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___20 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___20 orig_overflow_handler;
	struct bpf_prog *prog;
	u64 bpf_cookie;
	struct trace_event_call___20 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___20 *cgrp;
	void *security;
	struct list_head sb_list;
};

struct address_space_operations___31;

struct address_space___31 {
	struct inode___31 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___31 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct device___33;

struct page_pool_params___10 {
	unsigned int flags;
	unsigned int order;
	unsigned int pool_size;
	int nid;
	struct device___33 *dev;
	enum dma_data_direction dma_dir;
	unsigned int max_len;
	unsigned int offset;
};

struct pp_alloc_cache___10 {
	u32 count;
	struct page___33 *cache[128];
};

struct page_pool___10 {
	struct page_pool_params___10 p;
	struct delayed_work release_dw;
	void (*disconnect)(void *);
	long unsigned int defer_start;
	long unsigned int defer_warn;
	u32 pages_state_hold_cnt;
	unsigned int frag_offset;
	struct page___33 *frag_page;
	long int frag_users;
	long: 64;
	long: 64;
	struct pp_alloc_cache___10 alloc;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct ptr_ring ring;
	atomic_t pages_state_release_cnt;
	refcount_t user_cnt;
	u64 destroy_cnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pagemap_ops___31;

struct dev_pagemap___31 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___31 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vfsmount___31;

struct path___31 {
	struct vfsmount___31 *mnt;
	struct dentry___31 *dentry;
};

struct fown_struct___27 {
	rwlock_t lock;
	struct pid___27 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___31 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___31 f_path;
	struct inode___31 *f_inode;
	const struct file_operations___31 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___27 f_owner;
	const struct cred___2 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___31 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___31;

struct vm_operations_struct___31 {
	void (*open)(struct vm_area_struct___34 *);
	void (*close)(struct vm_area_struct___34 *);
	int (*may_split)(struct vm_area_struct___34 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___34 *);
	int (*mprotect)(struct vm_area_struct___34 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___31 *);
	vm_fault_t (*huge_fault)(struct vm_fault___31 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___31 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___34 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___31 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___31 *);
	int (*access)(struct vm_area_struct___34 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___34 *);
	int (*set_policy)(struct vm_area_struct___34 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___34 *, long unsigned int);
	struct page___33 * (*find_special_page)(struct vm_area_struct___34 *, long unsigned int);
};

struct core_thread___33 {
	struct task_struct___35 *task;
	struct core_thread___33 *next;
};

struct core_state___33 {
	atomic_t nr_threads;
	struct core_thread___33 dumper;
	struct completion startup;
};

struct proc_ns_operations___5;

struct ns_common___5 {
	atomic_long_t stashed;
	const struct proc_ns_operations___5 *ops;
	unsigned int inum;
	refcount_t count;
};

struct user_namespace___2 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	struct user_namespace___2 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___5 ns;
	long unsigned int flags;
	bool parent_could_setfcap;
	struct list_head keyring_name_list;
	struct key *user_keyring_register;
	struct rw_semaphore keyring_sem;
	struct key *persistent_keyring_register;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___2 *ucounts;
	long int ucount_max[16];
};

struct vm_fault___31 {
	const struct {
		struct vm_area_struct___34 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___33 *cow_page;
	struct page___33 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___33 prealloc_pte;
};

struct upid___27 {
	int nr;
	struct pid_namespace___27 *ns;
};

struct pid_namespace___27 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___35 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___27 *parent;
	struct fs_pin *bacct;
	struct user_namespace___2 *user_ns;
	struct ucounts___2 *ucounts;
	int reboot;
	struct ns_common___5 ns;
};

struct pid___27 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___27 numbers[1];
};

struct ucounts___2 {
	struct hlist_node node;
	struct user_namespace___2 *ns;
	kuid_t uid;
	atomic_t count;
	atomic_long_t ucount[16];
};

struct signal_struct___3 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___35 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___35 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper;
	unsigned int has_child_subreaper;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___27 *pids[4];
	struct pid___27 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___34 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct fs_struct___5 {
	int users;
	spinlock_t lock;
	seqcount_spinlock_t seq;
	int umask;
	int in_exec;
	struct path___31 root;
	struct path___31 pwd;
};

struct uts_namespace___4;

struct net___6;

struct time_namespace___3;

struct cgroup_namespace___25;

struct nsproxy___30 {
	atomic_t count;
	struct uts_namespace___4 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___27 *pid_ns_for_children;
	struct net___6 *net_ns;
	struct time_namespace___3 *time_ns;
	struct time_namespace___3 *time_ns_for_children;
	struct cgroup_namespace___25 *cgroup_ns;
};

struct cgroup_subsys_state___25;

struct cgroup___25;

struct css_set___25 {
	struct cgroup_subsys_state___25 *subsys[14];
	refcount_t refcount;
	struct css_set___25 *dom_cset;
	struct cgroup___25 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___25 *mg_src_cgrp;
	struct cgroup___25 *mg_dst_cgrp;
	struct css_set___25 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___20 {
	struct pmu___20 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	int rotate_necessary;
	refcount_t refcount;
	struct task_struct___35 *task;
	u64 time;
	u64 timestamp;
	u64 timeoffset;
	struct perf_event_context___20 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

struct pipe_buffer___10;

struct pipe_inode_info___10 {
	struct mutex mutex;
	wait_queue_head_t rd_wait;
	wait_queue_head_t wr_wait;
	unsigned int head;
	unsigned int tail;
	unsigned int max_usage;
	unsigned int ring_size;
	bool note_loss;
	unsigned int nr_accounted;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int r_counter;
	unsigned int w_counter;
	unsigned int poll_usage;
	struct page___33 *tmp_page;
	struct fasync_struct___31 *fasync_readers;
	struct fasync_struct___31 *fasync_writers;
	struct pipe_buffer___10 *bufs;
	struct user_struct *user;
	struct watch_queue *watch_queue;
};

struct vm_struct___28 {
	struct vm_struct___28 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___33 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct uts_namespace___4 {
	struct new_utsname name;
	struct user_namespace___2 *user_ns;
	struct ucounts___2 *ucounts;
	struct ns_common___5 ns;
};

struct ipc_ids {
	int in_use;
	short unsigned int seq;
	struct rw_semaphore rwsem;
	struct idr ipcs_idr;
	int max_idx;
	int last_idx;
	int next_id;
	struct rhashtable key_ht;
};

struct ipc_namespace {
	struct ipc_ids ids[3];
	int sem_ctls[4];
	int used_sems;
	unsigned int msg_ctlmax;
	unsigned int msg_ctlmnb;
	unsigned int msg_ctlmni;
	atomic_t msg_bytes;
	atomic_t msg_hdrs;
	size_t shm_ctlmax;
	size_t shm_ctlall;
	long unsigned int shm_tot;
	int shm_ctlmni;
	int shm_rmid_forced;
	struct notifier_block ipcns_nb;
	struct vfsmount___31 *mq_mnt;
	unsigned int mq_queues_count;
	unsigned int mq_queues_max;
	unsigned int mq_msg_max;
	unsigned int mq_msgsize_max;
	unsigned int mq_msg_default;
	unsigned int mq_msgsize_default;
	struct user_namespace___2 *user_ns;
	struct ucounts___2 *ucounts;
	struct llist_node mnt_llist;
	struct ns_common___5 ns;
};

struct fqdir___6;

struct netns_ipv4___6 {
	struct inet_timewait_death_row tcp_death_row;
	struct ctl_table_header *forw_hdr;
	struct ctl_table_header *frags_hdr;
	struct ctl_table_header *ipv4_hdr;
	struct ctl_table_header *route_hdr;
	struct ctl_table_header *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct ip_ra_chain *ra_chain;
	struct mutex ra_mutex;
	struct fib_rules_ops *rules_ops;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	unsigned int fib_rules_require_fldissect;
	bool fib_has_custom_rules;
	bool fib_has_custom_local_routes;
	bool fib_offload_disabled;
	atomic_t fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	struct sock *fibnl;
	struct sock **icmp_sk;
	struct sock *mc_autojoin_sk;
	struct inet_peer_base *peers;
	struct sock **tcp_sk;
	struct fqdir___6 *fqdir;
	u8 sysctl_icmp_echo_ignore_all;
	u8 sysctl_icmp_echo_enable_probe;
	u8 sysctl_icmp_echo_ignore_broadcasts;
	u8 sysctl_icmp_ignore_bogus_error_responses;
	u8 sysctl_icmp_errors_use_inbound_ifaddr;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	struct local_ports ip_local_ports;
	u8 sysctl_tcp_ecn;
	u8 sysctl_tcp_ecn_fallback;
	u8 sysctl_ip_default_ttl;
	u8 sysctl_ip_no_pmtu_disc;
	u8 sysctl_ip_fwd_use_pmtu;
	u8 sysctl_ip_fwd_update_priority;
	u8 sysctl_ip_nonlocal_bind;
	u8 sysctl_ip_autobind_reuse;
	u8 sysctl_ip_dynaddr;
	u8 sysctl_ip_early_demux;
	u8 sysctl_raw_l3mdev_accept;
	u8 sysctl_tcp_early_demux;
	u8 sysctl_udp_early_demux;
	u8 sysctl_nexthop_compat_mode;
	u8 sysctl_fwmark_reflect;
	u8 sysctl_tcp_fwmark_accept;
	u8 sysctl_tcp_l3mdev_accept;
	u8 sysctl_tcp_mtu_probing;
	int sysctl_tcp_mtu_probe_floor;
	int sysctl_tcp_base_mss;
	int sysctl_tcp_min_snd_mss;
	int sysctl_tcp_probe_threshold;
	u32 sysctl_tcp_probe_interval;
	int sysctl_tcp_keepalive_time;
	int sysctl_tcp_keepalive_intvl;
	u8 sysctl_tcp_keepalive_probes;
	u8 sysctl_tcp_syn_retries;
	u8 sysctl_tcp_synack_retries;
	u8 sysctl_tcp_syncookies;
	u8 sysctl_tcp_migrate_req;
	int sysctl_tcp_reordering;
	u8 sysctl_tcp_retries1;
	u8 sysctl_tcp_retries2;
	u8 sysctl_tcp_orphan_retries;
	u8 sysctl_tcp_tw_reuse;
	int sysctl_tcp_fin_timeout;
	unsigned int sysctl_tcp_notsent_lowat;
	u8 sysctl_tcp_sack;
	u8 sysctl_tcp_window_scaling;
	u8 sysctl_tcp_timestamps;
	u8 sysctl_tcp_early_retrans;
	u8 sysctl_tcp_recovery;
	u8 sysctl_tcp_thin_linear_timeouts;
	u8 sysctl_tcp_slow_start_after_idle;
	u8 sysctl_tcp_retrans_collapse;
	u8 sysctl_tcp_stdurg;
	u8 sysctl_tcp_rfc1337;
	u8 sysctl_tcp_abort_on_overflow;
	u8 sysctl_tcp_fack;
	int sysctl_tcp_max_reordering;
	int sysctl_tcp_adv_win_scale;
	u8 sysctl_tcp_dsack;
	u8 sysctl_tcp_app_win;
	u8 sysctl_tcp_frto;
	u8 sysctl_tcp_nometrics_save;
	u8 sysctl_tcp_no_ssthresh_metrics_save;
	u8 sysctl_tcp_moderate_rcvbuf;
	u8 sysctl_tcp_tso_win_divisor;
	u8 sysctl_tcp_workaround_signed_windows;
	int sysctl_tcp_limit_output_bytes;
	int sysctl_tcp_challenge_ack_limit;
	int sysctl_tcp_min_rtt_wlen;
	u8 sysctl_tcp_min_tso_segs;
	u8 sysctl_tcp_autocorking;
	u8 sysctl_tcp_reflect_tos;
	u8 sysctl_tcp_comp_sack_nr;
	int sysctl_tcp_invalid_ratelimit;
	int sysctl_tcp_pacing_ss_ratio;
	int sysctl_tcp_pacing_ca_ratio;
	int sysctl_tcp_wmem[3];
	int sysctl_tcp_rmem[3];
	long unsigned int sysctl_tcp_comp_sack_delay_ns;
	long unsigned int sysctl_tcp_comp_sack_slack_ns;
	int sysctl_max_syn_backlog;
	int sysctl_tcp_fastopen;
	const struct tcp_congestion_ops *tcp_congestion_control;
	struct tcp_fastopen_context *tcp_fastopen_ctx;
	unsigned int sysctl_tcp_fastopen_blackhole_timeout;
	atomic_t tfo_active_disable_times;
	long unsigned int tfo_active_disable_stamp;
	int sysctl_udp_wmem_min;
	int sysctl_udp_rmem_min;
	u8 sysctl_fib_notify_on_flag_change;
	u8 sysctl_udp_l3mdev_accept;
	u8 sysctl_igmp_llm_reports;
	int sysctl_igmp_max_memberships;
	int sysctl_igmp_max_msf;
	int sysctl_igmp_qrv;
	struct ping_group_range ping_group_range;
	atomic_t dev_addr_genid;
	long unsigned int *sysctl_local_reserved_ports;
	int sysctl_ip_prot_sock;
	struct list_head mr_tables;
	struct fib_rules_ops *mr_rules_ops;
	u32 sysctl_fib_multipath_hash_fields;
	u8 sysctl_fib_multipath_use_neigh;
	u8 sysctl_fib_multipath_hash_policy;
	struct fib_notifier_ops *notifier_ops;
	unsigned int fib_seq;
	struct fib_notifier_ops *ipmr_notifier_ops;
	unsigned int ipmr_seq;
	atomic_t rt_genid;
	siphash_key_t ip_id_key;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dst_ops___6 {
	short unsigned int family;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___6 *);
	struct dst_entry * (*check)(struct dst_entry *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry *);
	unsigned int (*mtu)(const struct dst_entry *);
	u32 * (*cow_metrics)(struct dst_entry *, long unsigned int);
	void (*destroy)(struct dst_entry *);
	void (*ifdown)(struct dst_entry *, struct net_device *, int);
	struct dst_entry * (*negative_advice)(struct dst_entry *);
	void (*link_failure)(struct sk_buff___5 *);
	void (*update_pmtu)(struct dst_entry *, struct sock *, struct sk_buff___5 *, u32, bool);
	void (*redirect)(struct dst_entry *, struct sock *, struct sk_buff___5 *);
	int (*local_out)(struct net___6 *, struct sock *, struct sk_buff___5 *);
	struct neighbour * (*neigh_lookup)(const struct dst_entry *, struct sk_buff___5 *, const void *);
	void (*confirm_neigh)(const struct dst_entry *, const void *);
	struct kmem_cache *kmem_cachep;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv6___6 {
	struct dst_ops___6 ip6_dst_ops;
	struct netns_sysctl_ipv6 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	struct fqdir___6 *fqdir;
	struct fib6_info *fib6_null_entry;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	struct list_head fib6_walkers;
	rwlock_t fib6_walker_lock;
	spinlock_t fib6_gc_lock;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	unsigned char flowlabel_has_excl;
	bool fib6_has_custom_rules;
	unsigned int fib6_rules_require_fldissect;
	unsigned int fib6_routes_require_src;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops *fib6_rules_ops;
	struct sock **icmp_sk;
	struct sock *ndisc_sk;
	struct sock *tcp_sk;
	struct sock *igmp_sk;
	struct sock *mc_autojoin_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops *mr6_rules_ops;
	atomic_t dev_addr_genid;
	atomic_t fib6_sernum;
	struct seg6_pernet_data *seg6_data;
	struct fib_notifier_ops *notifier_ops;
	struct fib_notifier_ops *ip6mr_notifier_ops;
	unsigned int ipmr_seq;
	struct {
		struct hlist_head head;
		spinlock_t lock;
		u32 seq;
	} ip6addrlbl_table;
	struct ioam6_pernet_data *ioam6_data;
};

struct netns_ieee802154_lowpan___6 {
	struct netns_sysctl_lowpan sysctl;
	struct fqdir___6 *fqdir;
};

struct netns_xfrm___6 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	struct hlist_head *state_byseq;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[3];
	struct xfrm_policy_hash policy_bydst[3];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct xfrm_policy_hthresh policy_hthresh;
	struct list_head inexact_bins;
	struct sock *nlsk;
	struct sock *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	u8 policy_default;
	struct ctl_table_header *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___6 xfrm4_dst_ops;
	struct dst_ops___6 xfrm6_dst_ops;
	spinlock_t xfrm_state_lock;
	seqcount_spinlock_t xfrm_state_hash_generation;
	seqcount_spinlock_t xfrm_policy_hash_generation;
	spinlock_t xfrm_policy_lock;
	struct mutex xfrm_cfg_mutex;
	long: 64;
	long: 64;
};

struct net___6 {
	refcount_t passive;
	spinlock_t rules_mod_lock;
	unsigned int dev_unreg_count;
	unsigned int dev_base_seq;
	int ifindex;
	spinlock_t nsid_lock;
	atomic_t fnhe_genid;
	struct list_head list;
	struct list_head exit_list;
	struct llist_node cleanup_list;
	struct key_tag *key_domain;
	struct user_namespace___2 *user_ns;
	struct ucounts___2 *ucounts;
	struct idr netns_ids;
	struct ns_common___5 ns;
	struct list_head dev_base_head;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set sysctls;
	struct sock *rtnl;
	struct sock *genl_sock;
	struct uevent_sock *uevent_sock;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	struct raw_notifier_head netdev_chain;
	u32 hash_mix;
	struct net_device *loopback_dev;
	struct list_head rules_ops;
	struct netns_core core;
	struct netns_mib mib;
	struct netns_packet packet;
	struct netns_unix unx;
	struct netns_nexthop nexthop;
	struct netns_ipv4___6 ipv4;
	struct netns_ipv6___6 ipv6;
	struct netns_ieee802154_lowpan___6 ieee802154_lowpan;
	struct netns_sctp___3 sctp;
	struct netns_nf nf;
	struct netns_ct ct;
	struct netns_nftables nft;
	struct sk_buff_head___4 wext_nlevents;
	struct net_generic *gen;
	struct netns_bpf___4 bpf;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_xfrm___6 xfrm;
	u64 net_cookie;
	struct netns_ipvs *ipvs;
	struct netns_mpls mpls;
	struct netns_can can;
	struct netns_xdp xdp;
	struct netns_mctp mctp;
	struct sock *crypto_nlsk;
	struct sock *diag_nlsk;
	struct netns_smc smc;
	long: 64;
};

struct time_namespace___3 {
	struct user_namespace___2 *user_ns;
	struct ucounts___2 *ucounts;
	struct ns_common___5 ns;
	struct timens_offsets offsets;
	struct page___33 *vvar_page;
	bool frozen_offsets;
};

struct cgroup_namespace___25 {
	struct ns_common___5 ns;
	struct user_namespace___2 *user_ns;
	struct ucounts___2 *ucounts;
	struct css_set___25 *root_cset;
};

struct nsset___4 {
	unsigned int flags;
	struct nsproxy___30 *nsproxy;
	struct fs_struct___5 *fs;
	const struct cred___2 *cred;
};

struct proc_ns_operations___5 {
	const char *name;
	const char *real_ns_name;
	int type;
	struct ns_common___5 * (*get)(struct task_struct___35 *);
	void (*put)(struct ns_common___5 *);
	int (*install)(struct nsset___4 *, struct ns_common___5 *);
	struct user_namespace___2 * (*owner)(struct ns_common___5 *);
	struct ns_common___5 * (*get_parent)(struct ns_common___5 *);
};

struct dev_pagemap_ops___31 {
	void (*page_free)(struct page___33 *);
	void (*kill)(struct dev_pagemap___31 *);
	void (*cleanup)(struct dev_pagemap___31 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___31 *);
};

struct dentry_operations___31;

struct dentry___31 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___31 *d_parent;
	struct qstr d_name;
	struct inode___31 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___31 *d_op;
	struct super_block___31 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___31;

struct inode___31 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___31 *i_op;
	struct super_block___31 *i_sb;
	struct address_space___31 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___31 *i_fop;
		void (*free_inode)(struct inode___31 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___31 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___10 *i_pipe;
		struct cdev *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___31 {
	int (*d_revalidate)(struct dentry___31 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___31 *, unsigned int);
	int (*d_hash)(const struct dentry___31 *, struct qstr *);
	int (*d_compare)(const struct dentry___31 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___31 *);
	int (*d_init)(struct dentry___31 *);
	void (*d_release)(struct dentry___31 *);
	void (*d_prune)(struct dentry___31 *);
	void (*d_iput)(struct dentry___31 *, struct inode___31 *);
	char * (*d_dname)(struct dentry___31 *, char *, int);
	struct vfsmount___31 * (*d_automount)(struct path___31 *);
	int (*d_manage)(const struct path___31 *, bool);
	struct dentry___31 * (*d_real)(struct dentry___31 *, const struct inode___31 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___31;

struct mem_dqinfo___31 {
	struct quota_format_type___31 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___31;

struct quota_info___31 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___31 *files[3];
	struct mem_dqinfo___31 info[3];
	const struct quota_format_ops___31 *ops[3];
};

struct rcuwait___31 {
	struct task_struct___35 *task;
};

struct percpu_rw_semaphore___31 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___31 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___31 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___31 rw_sem[3];
};

struct super_operations___31;

struct dquot_operations___31;

struct quotactl_ops___31;

struct super_block___31 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___31 *s_type;
	const struct super_operations___31 *s_op;
	const struct dquot_operations___31 *dq_op;
	const struct quotactl_ops___31 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___31 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device *s_bdev;
	struct backing_dev_info *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___31 s_dquot;
	struct sb_writers___31 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___31 *s_d_op;
	int cleancache_poolid;
	struct shrinker___19 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___2 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___31 {
	struct dentry___31 *mnt_root;
	struct super_block___31 *mnt_sb;
	int mnt_flags;
	struct user_namespace___2 *mnt_userns;
};

struct cgroup_subsys___25;

struct cgroup_subsys_state___25 {
	struct cgroup___25 *cgroup;
	struct cgroup_subsys___25 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___25 *parent;
};

struct kernfs_node___31;

struct cgroup_file___25 {
	struct kernfs_node___31 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct psi_group___25 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___35 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___25;

struct cgroup_rstat_cpu___25;

struct cgroup___25 {
	struct cgroup_subsys_state___25 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___31 *kn;
	struct cgroup_file___25 procs_file;
	struct cgroup_file___25 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___25 *subsys[14];
	struct cgroup_root___25 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___25 *dom_cgrp;
	struct cgroup___25 *old_dom_cgrp;
	struct cgroup_rstat_cpu___25 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___25 psi;
	struct cgroup_bpf___4 bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct kiocb___31 {
	struct file___31 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___31 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___16 *ki_waitq;
	};
};

struct iattr___31 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___31 *ia_file;
};

struct dquot___31 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___31 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___31 {
	int qf_fmt_id;
	const struct quota_format_ops___31 *qf_ops;
	struct module___30 *qf_owner;
	struct quota_format_type___31 *qf_next;
};

struct quota_format_ops___31 {
	int (*check_quota_file)(struct super_block___31 *, int);
	int (*read_file_info)(struct super_block___31 *, int);
	int (*write_file_info)(struct super_block___31 *, int);
	int (*free_file_info)(struct super_block___31 *, int);
	int (*read_dqblk)(struct dquot___31 *);
	int (*commit_dqblk)(struct dquot___31 *);
	int (*release_dqblk)(struct dquot___31 *);
	int (*get_next_id)(struct super_block___31 *, struct kqid *);
};

struct dquot_operations___31 {
	int (*write_dquot)(struct dquot___31 *);
	struct dquot___31 * (*alloc_dquot)(struct super_block___31 *, int);
	void (*destroy_dquot)(struct dquot___31 *);
	int (*acquire_dquot)(struct dquot___31 *);
	int (*release_dquot)(struct dquot___31 *);
	int (*mark_dirty)(struct dquot___31 *);
	int (*write_info)(struct super_block___31 *, int);
	qsize_t * (*get_reserved_space)(struct inode___31 *);
	int (*get_projid)(struct inode___31 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___31 *, qsize_t *);
	int (*get_next_id)(struct super_block___31 *, struct kqid *);
};

struct quotactl_ops___31 {
	int (*quota_on)(struct super_block___31 *, int, int, const struct path___31 *);
	int (*quota_off)(struct super_block___31 *, int);
	int (*quota_enable)(struct super_block___31 *, unsigned int);
	int (*quota_disable)(struct super_block___31 *, unsigned int);
	int (*quota_sync)(struct super_block___31 *, int);
	int (*set_info)(struct super_block___31 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___31 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___31 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___31 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___31 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___31 *, unsigned int);
};

struct kset___30;

struct kobj_type___30;

struct kobject___31 {
	const char *name;
	struct list_head entry;
	struct kobject___31 *parent;
	struct kset___30 *kset;
	struct kobj_type___30 *ktype;
	struct kernfs_node___31 *sd;
	struct kref kref;
	unsigned int state_initialized;
	unsigned int state_in_sysfs;
	unsigned int state_add_uevent_sent;
	unsigned int state_remove_uevent_sent;
	unsigned int uevent_suppress;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___30 {
	struct kobject___31 kobj;
	struct module___30 *mod;
	struct kobject___31 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___30 {
	struct module___30 *mod;
	struct latch_tree_node node;
};

struct module_layout___30 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___30 mtn;
};

struct module_attribute___30;

struct kernel_param___30;

struct module___30 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___30 mkobj;
	struct module_attribute___30 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___31 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___30 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___30 core_layout;
	struct module_layout___30 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map___23 *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___20 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	int num_static_call_sites;
	struct static_call_site *static_call_sites;
	bool klp;
	bool klp_alive;
	struct klp_modinfo *klp_info;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct address_space_operations___31 {
	int (*writepage)(struct page___33 *, struct writeback_control *);
	int (*readpage)(struct file___31 *, struct page___33 *);
	int (*writepages)(struct address_space___31 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___33 *);
	int (*readpages)(struct file___31 *, struct address_space___31 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control *);
	int (*write_begin)(struct file___31 *, struct address_space___31 *, loff_t, unsigned int, unsigned int, struct page___33 **, void **);
	int (*write_end)(struct file___31 *, struct address_space___31 *, loff_t, unsigned int, unsigned int, struct page___33 *, void *);
	sector_t (*bmap)(struct address_space___31 *, sector_t);
	void (*invalidatepage)(struct page___33 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___33 *, gfp_t);
	void (*freepage)(struct page___33 *);
	ssize_t (*direct_IO)(struct kiocb___31 *, struct iov_iter___25 *);
	int (*migratepage)(struct address_space___31 *, struct page___33 *, struct page___33 *, enum migrate_mode);
	bool (*isolate_page)(struct page___33 *, isolate_mode_t);
	void (*putback_page)(struct page___33 *);
	int (*launder_page)(struct page___33 *);
	int (*is_partially_uptodate)(struct page___33 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___33 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___31 *, struct page___33 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___31 *, sector_t *);
	void (*swap_deactivate)(struct file___31 *);
};

struct bio_vec___25;

struct iov_iter___25 {
	u8 iter_type;
	bool data_source;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___25 *bvec;
		struct xarray *xarray;
		struct pipe_inode_info___10 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			unsigned int head;
			unsigned int start_head;
		};
		loff_t xarray_start;
	};
};

struct inode_operations___31 {
	struct dentry___31 * (*lookup)(struct inode___31 *, struct dentry___31 *, unsigned int);
	const char * (*get_link)(struct dentry___31 *, struct inode___31 *, struct delayed_call *);
	int (*permission)(struct user_namespace___2 *, struct inode___31 *, int);
	struct posix_acl * (*get_acl)(struct inode___31 *, int, bool);
	int (*readlink)(struct dentry___31 *, char *, int);
	int (*create)(struct user_namespace___2 *, struct inode___31 *, struct dentry___31 *, umode_t, bool);
	int (*link)(struct dentry___31 *, struct inode___31 *, struct dentry___31 *);
	int (*unlink)(struct inode___31 *, struct dentry___31 *);
	int (*symlink)(struct user_namespace___2 *, struct inode___31 *, struct dentry___31 *, const char *);
	int (*mkdir)(struct user_namespace___2 *, struct inode___31 *, struct dentry___31 *, umode_t);
	int (*rmdir)(struct inode___31 *, struct dentry___31 *);
	int (*mknod)(struct user_namespace___2 *, struct inode___31 *, struct dentry___31 *, umode_t, dev_t);
	int (*rename)(struct user_namespace___2 *, struct inode___31 *, struct dentry___31 *, struct inode___31 *, struct dentry___31 *, unsigned int);
	int (*setattr)(struct user_namespace___2 *, struct dentry___31 *, struct iattr___31 *);
	int (*getattr)(struct user_namespace___2 *, const struct path___31 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___31 *, char *, size_t);
	int (*fiemap)(struct inode___31 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___31 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___31 *, struct dentry___31 *, struct file___31 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace___2 *, struct inode___31 *, struct dentry___31 *, umode_t);
	int (*set_acl)(struct user_namespace___2 *, struct inode___31 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace___2 *, struct dentry___31 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___31 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___31 {
	void (*fl_copy_lock)(struct file_lock___31 *, struct file_lock___31 *);
	void (*fl_release_private)(struct file_lock___31 *);
};

struct lock_manager_operations___31;

struct file_lock___31 {
	struct file_lock___31 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___31 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___31 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___31 *fl_ops;
	const struct lock_manager_operations___31 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___31 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___31 *);
	int (*lm_grant)(struct file_lock___31 *, int);
	bool (*lm_break)(struct file_lock___31 *);
	int (*lm_change)(struct file_lock___31 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___31 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___31 *);
};

struct fasync_struct___31 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___31 *fa_next;
	struct file___31 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___31 {
	struct inode___31 * (*alloc_inode)(struct super_block___31 *);
	void (*destroy_inode)(struct inode___31 *);
	void (*free_inode)(struct inode___31 *);
	void (*dirty_inode)(struct inode___31 *, int);
	int (*write_inode)(struct inode___31 *, struct writeback_control *);
	int (*drop_inode)(struct inode___31 *);
	void (*evict_inode)(struct inode___31 *);
	void (*put_super)(struct super_block___31 *);
	int (*sync_fs)(struct super_block___31 *, int);
	int (*freeze_super)(struct super_block___31 *);
	int (*freeze_fs)(struct super_block___31 *);
	int (*thaw_super)(struct super_block___31 *);
	int (*unfreeze_fs)(struct super_block___31 *);
	int (*statfs)(struct dentry___31 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___31 *, int *, char *);
	void (*umount_begin)(struct super_block___31 *);
	int (*show_options)(struct seq_file___29 *, struct dentry___31 *);
	int (*show_devname)(struct seq_file___29 *, struct dentry___31 *);
	int (*show_path)(struct seq_file___29 *, struct dentry___31 *);
	int (*show_stats)(struct seq_file___29 *, struct dentry___31 *);
	ssize_t (*quota_read)(struct super_block___31 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___31 *, int, const char *, size_t, loff_t);
	struct dquot___31 ** (*get_dquots)(struct inode___31 *);
	long int (*nr_cached_objects)(struct super_block___31 *, struct shrink_control___19 *);
	long int (*free_cached_objects)(struct super_block___31 *, struct shrink_control___19 *);
	struct file___31 * (*real_loop)(struct file___31 *);
};

typedef void (*poll_queue_proc___23)(struct file___31 *, wait_queue_head_t *, struct poll_table_struct___23 *);

struct poll_table_struct___23 {
	poll_queue_proc___23 _qproc;
	__poll_t _key;
};

struct seq_file___29 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___29 *op;
	int poll_event;
	const struct file___31 *file;
	void *private;
};

struct kernfs_root___31;

struct kernfs_elem_dir___31 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___31 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___31;

struct kernfs_root___31 {
	struct kernfs_node___31 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___31 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___31 {
	struct kernfs_node___31 *target_kn;
};

struct kernfs_ops___31;

struct kernfs_elem_attr___31 {
	const struct kernfs_ops___31 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___31 *notify_next;
};

struct kernfs_node___31 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___31 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___31 dir;
		struct kernfs_elem_symlink___31 symlink;
		struct kernfs_elem_attr___31 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___31;

struct kernfs_ops___31 {
	int (*open)(struct kernfs_open_file___31 *);
	void (*release)(struct kernfs_open_file___31 *);
	int (*seq_show)(struct seq_file___29 *, void *);
	void * (*seq_start)(struct seq_file___29 *, loff_t *);
	void * (*seq_next)(struct seq_file___29 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___29 *, void *);
	ssize_t (*read)(struct kernfs_open_file___31 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___31 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___31 *, struct poll_table_struct___23 *);
	int (*mmap)(struct kernfs_open_file___31 *, struct vm_area_struct___34 *);
};

struct kernfs_syscall_ops___31 {
	int (*show_options)(struct seq_file___29 *, struct kernfs_root___31 *);
	int (*mkdir)(struct kernfs_node___31 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___31 *);
	int (*rename)(struct kernfs_node___31 *, struct kernfs_node___31 *, const char *);
	int (*show_path)(struct seq_file___29 *, struct kernfs_node___31 *, struct kernfs_root___31 *);
};

struct kernfs_open_file___31 {
	struct kernfs_node___31 *kn;
	struct file___31 *file;
	struct seq_file___29 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped;
	bool released;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___31 *vm_ops;
};

struct bin_attribute___31;

struct attribute_group___31 {
	const char *name;
	umode_t (*is_visible)(struct kobject___31 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___31 *, struct bin_attribute___31 *, int);
	struct attribute **attrs;
	struct bin_attribute___31 **bin_attrs;
};

struct bin_attribute___31 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___31 * (*f_mapping)();
	ssize_t (*read)(struct file___31 *, struct kobject___31 *, struct bin_attribute___31 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___31 *, struct kobject___31 *, struct bin_attribute___31 *, char *, loff_t, size_t);
	int (*mmap)(struct file___31 *, struct kobject___31 *, struct bin_attribute___31 *, struct vm_area_struct___34 *);
};

struct sysfs_ops___30 {
	ssize_t (*show)(struct kobject___31 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___31 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___30;

struct kset___30 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___31 kobj;
	const struct kset_uevent_ops___30 *uevent_ops;
};

struct kobj_type___30 {
	void (*release)(struct kobject___31 *);
	const struct sysfs_ops___30 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___31 **default_groups;
	const struct kobj_ns_type_operations___3 * (*child_ns_type)(struct kobject___31 *);
	const void * (*namespace)(struct kobject___31 *);
	void (*get_ownership)(struct kobject___31 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___30 {
	int (* const filter)(struct kset___30 *, struct kobject___31 *);
	const char * (* const name)(struct kset___30 *, struct kobject___31 *);
	int (* const uevent)(struct kset___30 *, struct kobject___31 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___30 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___30 *);
	int (*get)(char *, const struct kernel_param___30 *);
	void (*free)(void *);
};

struct kparam_array___30;

struct kernel_param___30 {
	const char *name;
	struct module___30 *mod;
	const struct kernel_param_ops___30 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___30 *arr;
	};
};

struct kparam_array___30 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___30 *ops;
	void *elem;
};

struct module_attribute___30 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___30 *, struct module_kobject___30 *, char *);
	ssize_t (*store)(struct module_attribute___30 *, struct module_kobject___30 *, const char *, size_t);
	void (*setup)(struct module___30 *, const char *);
	int (*test)(struct module___30 *);
	void (*free)(struct module___30 *);
};

struct trace_event_class___20;

struct trace_event_call___20 {
	struct list_head list;
	struct trace_event_class___20 *class;
	union {
		char *name;
		struct tracepoint___23 *tp;
	};
	struct trace_event event;
	char *print_fmt;
	struct event_filter *filter;
	union {
		void *module;
		atomic_t refcnt;
	};
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
	struct bpf_prog_array___4 *prog_array;
	int (*perf_perm)(struct trace_event_call___20 *, struct perf_event___20 *);
};

struct bio_vec___25 {
	struct page___33 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct inet_frags___6;

struct fqdir___6 {
	long int high_thresh;
	long int low_thresh;
	int timeout;
	int max_dist;
	struct inet_frags___6 *f;
	struct net___6 *net;
	bool dead;
	long: 56;
	long: 64;
	long: 64;
	struct rhashtable rhashtable;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	atomic_long_t mem;
	struct work_struct destroy_work;
	struct llist_node free_list;
	long: 64;
	long: 64;
};

struct inet_frag_queue___6;

struct inet_frags___6 {
	unsigned int qsize;
	void (*constructor)(struct inet_frag_queue___6 *, const void *);
	void (*destructor)(struct inet_frag_queue___6 *);
	void (*frag_expire)(struct timer_list *);
	struct kmem_cache *frags_cachep;
	const char *frags_cache_name;
	struct rhashtable_params rhash_params;
	refcount_t refcnt;
	struct completion completion;
};

struct inet_frag_queue___6 {
	struct rhash_head node;
	union {
		struct frag_v4_compare_key v4;
		struct frag_v6_compare_key v6;
	} key;
	struct timer_list timer;
	spinlock_t lock;
	refcount_t refcnt;
	struct rb_root rb_fragments;
	struct sk_buff___5 *fragments_tail;
	struct sk_buff___5 *last_run_head;
	ktime_t stamp;
	int len;
	int meat;
	__u8 flags;
	u16 max_size;
	struct fqdir___6 *fqdir;
	struct callback_head rcu;
};

struct wakeup_source___33;

struct dev_pm_info___33 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___33 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___33 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___33;

struct bus_type___33;

struct device_driver___33;

struct dev_pm_domain___33;

struct fwnode_handle___30;

struct class___33;

struct device___33 {
	struct kobject___31 kobj;
	struct device___33 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___33 *type;
	struct bus_type___33 *bus;
	struct device_driver___33 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___33 power;
	struct dev_pm_domain___33 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node *of_node;
	struct fwnode_handle___30 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___33 *class;
	const struct attribute_group___31 **groups;
	void (*release)(struct device___33 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_ops___33 {
	int (*prepare)(struct device___33 *);
	void (*complete)(struct device___33 *);
	int (*suspend)(struct device___33 *);
	int (*resume)(struct device___33 *);
	int (*freeze)(struct device___33 *);
	int (*thaw)(struct device___33 *);
	int (*poweroff)(struct device___33 *);
	int (*restore)(struct device___33 *);
	int (*suspend_late)(struct device___33 *);
	int (*resume_early)(struct device___33 *);
	int (*freeze_late)(struct device___33 *);
	int (*thaw_early)(struct device___33 *);
	int (*poweroff_late)(struct device___33 *);
	int (*restore_early)(struct device___33 *);
	int (*suspend_noirq)(struct device___33 *);
	int (*resume_noirq)(struct device___33 *);
	int (*freeze_noirq)(struct device___33 *);
	int (*thaw_noirq)(struct device___33 *);
	int (*poweroff_noirq)(struct device___33 *);
	int (*restore_noirq)(struct device___33 *);
	int (*runtime_suspend)(struct device___33 *);
	int (*runtime_resume)(struct device___33 *);
	int (*runtime_idle)(struct device___33 *);
};

struct wakeup_source___33 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___33 *dev;
	bool active;
	bool autosleep_enabled;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___33 {
	struct dev_pm_ops___33 ops;
	int (*start)(struct device___33 *);
	void (*detach)(struct device___33 *, bool);
	int (*activate)(struct device___33 *);
	void (*sync)(struct device___33 *);
	void (*dismiss)(struct device___33 *);
};

struct bus_type___33 {
	const char *name;
	const char *dev_name;
	struct device___33 *dev_root;
	const struct attribute_group___31 **bus_groups;
	const struct attribute_group___31 **dev_groups;
	const struct attribute_group___31 **drv_groups;
	int (*match)(struct device___33 *, struct device_driver___33 *);
	int (*uevent)(struct device___33 *, struct kobj_uevent_env *);
	int (*probe)(struct device___33 *);
	void (*sync_state)(struct device___33 *);
	void (*remove)(struct device___33 *);
	void (*shutdown)(struct device___33 *);
	int (*online)(struct device___33 *);
	int (*offline)(struct device___33 *);
	int (*suspend)(struct device___33 *, pm_message_t);
	int (*resume)(struct device___33 *);
	int (*num_vf)(struct device___33 *);
	int (*dma_configure)(struct device___33 *);
	const struct dev_pm_ops___33 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___33 {
	const char *name;
	struct bus_type___33 *bus;
	struct module___30 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___33 *);
	void (*sync_state)(struct device___33 *);
	int (*remove)(struct device___33 *);
	void (*shutdown)(struct device___33 *);
	int (*suspend)(struct device___33 *, pm_message_t);
	int (*resume)(struct device___33 *);
	const struct attribute_group___31 **groups;
	const struct attribute_group___31 **dev_groups;
	const struct dev_pm_ops___33 *pm;
	void (*coredump)(struct device___33 *);
	struct driver_private *p;
};

struct device_type___33 {
	const char *name;
	const struct attribute_group___31 **groups;
	int (*uevent)(struct device___33 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___33 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___33 *);
	const struct dev_pm_ops___33 *pm;
};

struct class___33 {
	const char *name;
	struct module___30 *owner;
	const struct attribute_group___31 **class_groups;
	const struct attribute_group___31 **dev_groups;
	struct kobject___31 *dev_kobj;
	int (*dev_uevent)(struct device___33 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___33 *, umode_t *);
	void (*class_release)(struct class___33 *);
	void (*dev_release)(struct device___33 *);
	int (*shutdown_pre)(struct device___33 *);
	const struct kobj_ns_type_operations___3 *ns_type;
	const void * (*namespace)(struct device___33 *);
	void (*get_ownership)(struct device___33 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___33 *pm;
	struct subsys_private *p;
};

struct fwnode_operations___30;

struct fwnode_handle___30 {
	struct fwnode_handle___30 *secondary;
	const struct fwnode_operations___30 *ops;
	struct device___33 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct fwnode_reference_args___30;

struct fwnode_endpoint___30;

struct fwnode_operations___30 {
	struct fwnode_handle___30 * (*get)(struct fwnode_handle___30 *);
	void (*put)(struct fwnode_handle___30 *);
	bool (*device_is_available)(const struct fwnode_handle___30 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___30 *, const struct device___33 *);
	bool (*property_present)(const struct fwnode_handle___30 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___30 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___30 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___30 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___30 *);
	struct fwnode_handle___30 * (*get_parent)(const struct fwnode_handle___30 *);
	struct fwnode_handle___30 * (*get_next_child_node)(const struct fwnode_handle___30 *, struct fwnode_handle___30 *);
	struct fwnode_handle___30 * (*get_named_child_node)(const struct fwnode_handle___30 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___30 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___30 *);
	struct fwnode_handle___30 * (*graph_get_next_endpoint)(const struct fwnode_handle___30 *, struct fwnode_handle___30 *);
	struct fwnode_handle___30 * (*graph_get_remote_endpoint)(const struct fwnode_handle___30 *);
	struct fwnode_handle___30 * (*graph_get_port_parent)(struct fwnode_handle___30 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___30 *, struct fwnode_endpoint___30 *);
	int (*add_links)(struct fwnode_handle___30 *);
};

struct fwnode_endpoint___30 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___30 *local_fwnode;
};

struct fwnode_reference_args___30 {
	struct fwnode_handle___30 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct pipe_buf_operations___10;

struct pipe_buffer___10 {
	struct page___33 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___10 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___10 {
	int (*confirm)(struct pipe_inode_info___10 *, struct pipe_buffer___10 *);
	void (*release)(struct pipe_inode_info___10 *, struct pipe_buffer___10 *);
	bool (*try_steal)(struct pipe_inode_info___10 *, struct pipe_buffer___10 *);
	bool (*get)(struct pipe_inode_info___10 *, struct pipe_buffer___10 *);
};

struct perf_cpu_context___20;

struct perf_output_handle___20;

struct pmu___20 {
	struct list_head entry;
	struct module___30 *module;
	struct device___33 *dev;
	const struct attribute_group___31 **attr_groups;
	const struct attribute_group___31 **attr_update;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___20 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___20 *);
	void (*pmu_disable)(struct pmu___20 *);
	int (*event_init)(struct perf_event___20 *);
	void (*event_mapped)(struct perf_event___20 *, struct mm_struct___34 *);
	void (*event_unmapped)(struct perf_event___20 *, struct mm_struct___34 *);
	int (*add)(struct perf_event___20 *, int);
	void (*del)(struct perf_event___20 *, int);
	void (*start)(struct perf_event___20 *, int);
	void (*stop)(struct perf_event___20 *, int);
	void (*read)(struct perf_event___20 *);
	void (*start_txn)(struct pmu___20 *, unsigned int);
	int (*commit_txn)(struct pmu___20 *);
	void (*cancel_txn)(struct pmu___20 *);
	int (*event_idx)(struct perf_event___20 *);
	void (*sched_task)(struct perf_event_context___20 *, bool);
	struct kmem_cache *task_ctx_cache;
	void (*swap_task_ctx)(struct perf_event_context___20 *, struct perf_event_context___20 *);
	void * (*setup_aux)(struct perf_event___20 *, void **, int, bool);
	void (*free_aux)(void *);
	long int (*snapshot_aux)(struct perf_event___20 *, struct perf_output_handle___20 *, long unsigned int);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___20 *);
	int (*aux_output_match)(struct perf_event___20 *);
	int (*filter_match)(struct perf_event___20 *);
	int (*check_period)(struct perf_event___20 *, u64);
};

struct cftype___25;

struct cgroup_subsys___25 {
	struct cgroup_subsys_state___25 * (*css_alloc)(struct cgroup_subsys_state___25 *);
	int (*css_online)(struct cgroup_subsys_state___25 *);
	void (*css_offline)(struct cgroup_subsys_state___25 *);
	void (*css_released)(struct cgroup_subsys_state___25 *);
	void (*css_free)(struct cgroup_subsys_state___25 *);
	void (*css_reset)(struct cgroup_subsys_state___25 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___25 *, int);
	int (*css_extra_stat_show)(struct seq_file___29 *, struct cgroup_subsys_state___25 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___35 *, struct css_set___25 *);
	void (*cancel_fork)(struct task_struct___35 *, struct css_set___25 *);
	void (*fork)(struct task_struct___35 *);
	void (*exit)(struct task_struct___35 *);
	void (*release)(struct task_struct___35 *);
	void (*bind)(struct cgroup_subsys_state___25 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___25 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___25 *dfl_cftypes;
	struct cftype___25 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___25 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___25 *updated_children;
	struct cgroup___25 *updated_next;
};

struct cgroup_root___25 {
	struct kernfs_root___31 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___25 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___25 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___25 *ss;
	struct list_head node;
	struct kernfs_ops___31 *kf_ops;
	int (*open)(struct kernfs_open_file___31 *);
	void (*release)(struct kernfs_open_file___31 *);
	u64 (*read_u64)(struct cgroup_subsys_state___25 *, struct cftype___25 *);
	s64 (*read_s64)(struct cgroup_subsys_state___25 *, struct cftype___25 *);
	int (*seq_show)(struct seq_file___29 *, void *);
	void * (*seq_start)(struct seq_file___29 *, loff_t *);
	void * (*seq_next)(struct seq_file___29 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___29 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___25 *, struct cftype___25 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___25 *, struct cftype___25 *, s64);
	ssize_t (*write)(struct kernfs_open_file___31 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___31 *, struct poll_table_struct___23 *);
};

struct perf_cpu_context___20 {
	struct perf_event_context___20 ctx;
	struct perf_event_context___20 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___20 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
	int heap_size;
	struct perf_event___20 **heap;
	struct perf_event___20 *heap_default[2];
};

struct perf_output_handle___20 {
	struct perf_event___20 *event;
	struct perf_buffer *rb;
	long unsigned int wakeup;
	long unsigned int size;
	u64 aux_flags;
	union {
		void *addr;
		long unsigned int head;
	};
	int page;
};

struct perf_cgroup___20 {
	struct cgroup_subsys_state___25 css;
	struct perf_cgroup_info *info;
};

struct trace_event_fields___20 {
	const char *type;
	union {
		struct {
			const char *name;
			const int size;
			const int align;
			const int is_signed;
			const int filter_type;
		};
		int (*define_fields)(struct trace_event_call___20 *);
	};
};

struct trace_event_class___20 {
	const char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct trace_event_call___20 *, enum trace_reg, void *);
	struct trace_event_fields___20 *fields_array;
	struct list_head * (*get_fields)(struct trace_event_call___20 *);
	struct list_head fields;
	int (*raw_init)(struct trace_event_call___20 *);
};

struct syscall_metadata___8 {
	const char *name;
	int syscall_nr;
	int nb_args;
	const char **types;
	const char **args;
	struct list_head enter_fields;
	struct trace_event_call___20 *enter_event;
	struct trace_event_call___20 *exit_event;
};

struct srcu_node___2;

struct srcu_struct___2;

struct srcu_data___2 {
	long unsigned int srcu_lock_count[2];
	long unsigned int srcu_unlock_count[2];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t___2 lock;
	struct rcu_segcblist srcu_cblist;
	long unsigned int srcu_gp_seq_needed;
	long unsigned int srcu_gp_seq_needed_exp;
	bool srcu_cblist_invoking;
	struct timer_list delay_work;
	struct work_struct work;
	struct callback_head srcu_barrier_head;
	struct srcu_node___2 *mynode;
	long unsigned int grpmask;
	int cpu;
	struct srcu_struct___2 *ssp;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct srcu_node___2 {
	spinlock_t___2 lock;
	long unsigned int srcu_have_cbs[4];
	long unsigned int srcu_data_have_cbs[4];
	long unsigned int srcu_gp_seq_needed_exp;
	struct srcu_node___2 *srcu_parent;
	int grplo;
	int grphi;
};

struct srcu_struct___2 {
	struct srcu_node___2 node[521];
	struct srcu_node___2 *level[4];
	struct mutex___2 srcu_cb_mutex;
	spinlock_t___2 lock;
	struct mutex___2 srcu_gp_mutex;
	unsigned int srcu_idx;
	long unsigned int srcu_gp_seq;
	long unsigned int srcu_gp_seq_needed;
	long unsigned int srcu_gp_seq_needed_exp;
	long unsigned int srcu_last_gp_end;
	struct srcu_data___2 *sda;
	long unsigned int srcu_barrier_seq;
	struct mutex___2 srcu_barrier_mutex;
	struct completion___2 srcu_barrier_completion;
	atomic_t srcu_barrier_cpu_cnt;
	struct delayed_work work;
	struct lockdep_map dep_map;
};

struct atomic_notifier_head___2 {
	spinlock_t___2 lock;
	struct notifier_block *head;
};

struct srcu_notifier_head {
	struct mutex___2 mutex;
	struct srcu_struct___2 srcu;
	struct notifier_block *head;
};

struct kobj_attribute___3 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___29 *, struct kobj_attribute___3 *, char *);
	ssize_t (*store)(struct kobject___29 *, struct kobj_attribute___3 *, const char *, size_t);
};

struct lsmblob {
	u32 secid[4];
};

enum what {
	PROC_EVENT_NONE = 0,
	PROC_EVENT_FORK = 1,
	PROC_EVENT_EXEC = 2,
	PROC_EVENT_UID = 4,
	PROC_EVENT_GID = 64,
	PROC_EVENT_SID = 128,
	PROC_EVENT_PTRACE = 256,
	PROC_EVENT_COMM = 512,
	PROC_EVENT_COREDUMP = 1073741824,
	PROC_EVENT_EXIT = 2147483648,
};

enum reboot_mode___2 {
	REBOOT_UNDEFINED___2 = 4294967295,
	REBOOT_COLD___2 = 0,
	REBOOT_WARM___2 = 1,
	REBOOT_HARD___2 = 2,
	REBOOT_SOFT___2 = 3,
	REBOOT_GPIO___2 = 4,
};

typedef void (*dr_release_t___2)(struct device___31 *, void *);

struct pool_workqueue___2;

struct worker_pool___2;

struct worker___2 {
	union {
		struct list_head entry;
		struct hlist_node hentry;
	};
	struct work_struct *current_work;
	work_func_t current_func;
	struct pool_workqueue___2 *current_pwq;
	unsigned int current_color;
	struct list_head scheduled;
	struct task_struct___13 *task;
	struct worker_pool___2 *pool;
	struct list_head node;
	long unsigned int last_active;
	unsigned int flags;
	int id;
	int sleeping;
	char desc[24];
	struct workqueue_struct *rescue_wq;
	work_func_t last_func;
};

struct async_entry {
	struct list_head domain_list;
	struct list_head global_list;
	struct work_struct work;
	async_cookie_t cookie;
	async_func_t func;
	void *data;
	struct async_domain *domain;
};

struct smp_hotplug_thread___3 {
	struct task_struct___13 **store;
	struct list_head list;
	int (*thread_should_run)(unsigned int);
	void (*thread_fn)(unsigned int);
	void (*create)(unsigned int);
	void (*setup)(unsigned int);
	void (*cleanup)(unsigned int, bool);
	void (*park)(unsigned int);
	void (*unpark)(unsigned int);
	bool selfparking;
	const char *thread_comm;
};

struct smpboot_thread_data {
	unsigned int cpu;
	unsigned int status;
	struct smp_hotplug_thread___3 *ht;
};

enum {
	HP_THREAD_NONE = 0,
	HP_THREAD_ACTIVE = 1,
	HP_THREAD_PARKED = 2,
};

struct user_regset___4;

typedef int user_regset_active_fn___4(struct task_struct___13 *, const struct user_regset___4 *);

typedef int user_regset_get2_fn___4(struct task_struct___13 *, const struct user_regset___4 *, struct membuf);

typedef int user_regset_set_fn___4(struct task_struct___13 *, const struct user_regset___4 *, unsigned int, unsigned int, const void *, const void *);

typedef int user_regset_writeback_fn___4(struct task_struct___13 *, const struct user_regset___4 *, int);

struct user_regset___4 {
	user_regset_get2_fn___4 *regset_get;
	user_regset_set_fn___4 *set;
	user_regset_active_fn___4 *active;
	user_regset_writeback_fn___4 *writeback;
	unsigned int n;
	unsigned int size;
	unsigned int align;
	unsigned int bias;
	unsigned int core_note_type;
};

struct user_regset_view___3 {
	const char *name;
	const struct user_regset___4 *regsets;
	unsigned int n;
	u32 e_flags;
	u16 e_machine;
	u8 ei_osabi;
};

struct vfsmount___32;

struct dentry___32;

struct path___32 {
	struct vfsmount___32 *mnt;
	struct dentry___32 *dentry;
};

struct inode___32;

struct file_operations___32;

struct address_space___32;

struct file___32 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	long: 64;
	long: 64;
	struct path___32 f_path;
	struct inode___32 *f_inode;
	const struct file_operations___32 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___27 f_owner;
	const struct cred___2 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___32 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct fs_context___6;

struct fs_parameter_spec___4;

struct super_block___32;

struct module___31;

struct file_system_type___32 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context___6 *);
	const struct fs_parameter_spec___4 *parameters;
	struct dentry___32 * (*mount)(struct file_system_type___32 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___32 *);
	struct module___31 *owner;
	struct file_system_type___32 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct kiocb___32;

struct iov_iter___26;

struct vm_area_struct___35;

struct file_lock___32;

struct page___34;

struct pipe_inode_info___11;

struct seq_file___30;

struct file_operations___32 {
	struct module___31 *owner;
	loff_t (*llseek)(struct file___32 *, loff_t, int);
	ssize_t (*read)(struct file___32 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___32 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___32 *, struct iov_iter___26 *);
	ssize_t (*write_iter)(struct kiocb___32 *, struct iov_iter___26 *);
	int (*iopoll)(struct kiocb___32 *, bool);
	int (*iterate)(struct file___32 *, struct dir_context *);
	int (*iterate_shared)(struct file___32 *, struct dir_context *);
	__poll_t (*poll)(struct file___32 *, struct poll_table_struct *);
	long int (*unlocked_ioctl)(struct file___32 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___32 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___32 *, struct vm_area_struct___35 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___32 *, struct file___32 *);
	int (*flush)(struct file___32 *, fl_owner_t);
	int (*release)(struct inode___32 *, struct file___32 *);
	int (*fsync)(struct file___32 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___32 *, int);
	int (*lock)(struct file___32 *, int, struct file_lock___32 *);
	ssize_t (*sendpage)(struct file___32 *, struct page___34 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___32 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___32 *, long unsigned int);
	int (*flock)(struct file___32 *, int, struct file_lock___32 *);
	ssize_t (*splice_write)(struct pipe_inode_info___11 *, struct file___32 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___32 *, loff_t *, struct pipe_inode_info___11 *, size_t, unsigned int);
	int (*setlease)(struct file___32 *, long int, struct file_lock___32 **, void **);
	long int (*fallocate)(struct file___32 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___30 *, struct file___32 *);
	ssize_t (*copy_file_range)(struct file___32 *, loff_t, struct file___32 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___32 *, loff_t, struct file___32 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___32 *, loff_t, loff_t, int);
};

struct vmacache___34 {
	u64 seqnum;
	struct vm_area_struct___35 *vmas[4];
};

struct page_frag___34 {
	struct page___34 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___35;

struct fs_struct___6;

struct nsproxy___31;

struct signal_struct___32;

struct bio_list___21;

struct backing_dev_info___20;

struct io_context___21;

struct css_set___26;

struct mem_cgroup___20;

struct request_queue___21;

struct vm_struct___29;

struct task_struct___36 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___36 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___35 *mm;
	struct mm_struct___35 *active_mm;
	struct vmacache___34 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int restore_sigmask: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___36 *real_parent;
	struct task_struct___36 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___36 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___27 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	struct posix_cputimers_work posix_cputimers_work;
	const struct cred___2 *ptracer_cred;
	const struct cred___2 *real_cred;
	const struct cred___2 *cred;
	struct key *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct___6 *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___31 *nsproxy;
	struct signal_struct___32 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___36 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___21 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___20 *backing_dev_info;
	struct io_context___21 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___26 *cgroups;
	struct list_head cg_list;
	u32 closid;
	u32 rmid;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	long: 64;
	long: 64;
	struct pipe_inode_info___11 *splice_pipe;
	struct page_frag___34 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___20 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___20 *active_memcg;
	struct request_queue___21 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___36 *oom_reaper_list;
	struct vm_struct___29 *stack_vm_area;
	refcount_t stack_refcount;
	int patch_state;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	void *mce_vaddr;
	__u64 mce_kflags;
	u64 mce_addr;
	__u64 mce_ripv: 1;
	__u64 mce_whole_page: 1;
	__u64 __mce_reserved: 62;
	long: 2;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct callback_head mce_kill_me;
	int mce_count;
	struct llist_head kretprobe_instances;
	struct callback_head l1d_flush_kill;
	long: 64;
	struct thread_struct___21 thread;
};

typedef struct page___34 *pgtable_t___34;

struct dev_pagemap___32;

struct page___34 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___32 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___10 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___34 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___34 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___35 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___32 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct core_state___34;

struct mm_struct___35 {
	struct {
		struct vm_area_struct___35 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___32 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int mmap_compat_base;
		long unsigned int mmap_compat_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[48];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___34 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___36 *owner;
		struct user_namespace___2 *user_ns;
		struct file___32 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		bool tlb_flush_batched;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct vm_operations_struct___32;

struct vm_area_struct___35 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___35 *vm_next;
	struct vm_area_struct___35 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___35 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___32 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___32 *vm_file;
	struct file___32 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct seq_operations___30 {
	void * (*start)(struct seq_file___30 *, loff_t *);
	void (*stop)(struct seq_file___30 *, void *);
	void * (*next)(struct seq_file___30 *, void *, loff_t *);
	int (*show)(struct seq_file___30 *, void *);
};

struct address_space_operations___32;

struct address_space___32 {
	struct inode___32 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___32 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct dev_pagemap_ops___32;

struct dev_pagemap___32 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___32 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vm_fault___32;

struct vm_operations_struct___32 {
	void (*open)(struct vm_area_struct___35 *);
	void (*close)(struct vm_area_struct___35 *);
	int (*may_split)(struct vm_area_struct___35 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___35 *);
	int (*mprotect)(struct vm_area_struct___35 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___32 *);
	vm_fault_t (*huge_fault)(struct vm_fault___32 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___32 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___35 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___32 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___32 *);
	int (*access)(struct vm_area_struct___35 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___35 *);
	int (*set_policy)(struct vm_area_struct___35 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___35 *, long unsigned int);
	struct page___34 * (*find_special_page)(struct vm_area_struct___35 *, long unsigned int);
};

struct core_thread___34 {
	struct task_struct___36 *task;
	struct core_thread___34 *next;
};

struct core_state___34 {
	atomic_t nr_threads;
	struct core_thread___34 dumper;
	struct completion startup;
};

struct vm_fault___32 {
	const struct {
		struct vm_area_struct___35 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___34 *cow_page;
	struct page___34 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___34 prealloc_pte;
};

struct pglist_data___21;

struct lruvec___21 {
	struct list_head lists[5];
	spinlock_t lru_lock;
	long unsigned int anon_cost;
	long unsigned int file_cost;
	atomic_long_t nonresident_age;
	long unsigned int refaults[2];
	long unsigned int flags;
	struct pglist_data___21 *pgdat;
};

struct zone___21 {
	long unsigned int _watermark[3];
	long unsigned int watermark_boost;
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[5];
	int node;
	struct pglist_data___21 *zone_pgdat;
	struct per_cpu_pages *per_cpu_pageset;
	struct per_cpu_zonestat *per_cpu_zonestats;
	int pageset_high;
	int pageset_batch;
	long unsigned int zone_start_pfn;
	atomic_long_t managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int present_early_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	seqlock_t span_seqlock;
	int initialized;
	int: 32;
	struct zone_padding _pad1_;
	struct free_area free_area[11];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	long unsigned int compact_init_migrate_pfn;
	long unsigned int compact_init_free_pfn;
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	short: 16;
	struct zone_padding _pad3_;
	atomic_long_t vm_stat[11];
	atomic_long_t vm_numa_event[6];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___21 {
	struct zone___21 *zone;
	int zone_idx;
};

struct zonelist___21 {
	struct zoneref___21 _zonerefs[5121];
};

struct pglist_data___21 {
	struct zone___21 node_zones[5];
	struct zonelist___21 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___36 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_highest_zoneidx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_highest_zoneidx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___36 *kcompactd;
	bool proactive_compact_trigger;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct deferred_split deferred_split_queue;
	struct lruvec___21 __lruvec;
	long unsigned int flags;
	long: 64;
	struct zone_padding _pad2_;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[39];
};

struct signal_struct___32 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___36 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___36 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___27 *pids[4];
	struct pid___27 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___35 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct fs_struct___6 {
	int users;
	spinlock_t lock;
	seqcount_spinlock_t seq;
	int umask;
	int in_exec;
	struct path___32 root;
	struct path___32 pwd;
};

struct cgroup_namespace___26;

struct nsproxy___31 {
	atomic_t count;
	struct uts_namespace *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace *pid_ns_for_children;
	struct net *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___26 *cgroup_ns;
};

struct bio___21;

struct bio_list___21 {
	struct bio___21 *head;
	struct bio___21 *tail;
};

struct cgroup_subsys_state___26;

struct bdi_writeback___20 {
	struct backing_dev_info___20 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	atomic_t writeback_inodes;
	struct percpu_counter stat[4];
	long unsigned int congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	struct delayed_work bw_dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___26 *memcg_css;
	struct cgroup_subsys_state___26 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	struct list_head b_attached;
	struct list_head offline_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
};

struct device___34;

struct backing_dev_info___20 {
	u64 id;
	struct rb_node rb_node;
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___20 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct mutex cgwb_release_mutex;
	struct rw_semaphore wb_switch_rwsem;
	wait_queue_head_t wb_waitq;
	struct device___34 *dev;
	char dev_name[64];
	struct device___34 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___32 *debug_dir;
};

struct io_cq___21;

struct io_context___21 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	struct xarray icq_tree;
	struct io_cq___21 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct cgroup___26;

struct css_set___26 {
	struct cgroup_subsys_state___26 *subsys[14];
	refcount_t refcount;
	struct css_set___26 *dom_cset;
	struct cgroup___26 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___26 *mg_src_cgrp;
	struct cgroup___26 *mg_dst_cgrp;
	struct css_set___26 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct fasync_struct___32;

struct pipe_buffer___11;

struct pipe_inode_info___11 {
	struct mutex mutex;
	wait_queue_head_t rd_wait;
	wait_queue_head_t wr_wait;
	unsigned int head;
	unsigned int tail;
	unsigned int max_usage;
	unsigned int ring_size;
	bool note_loss;
	unsigned int nr_accounted;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int r_counter;
	unsigned int w_counter;
	unsigned int poll_usage;
	struct page___34 *tmp_page;
	struct fasync_struct___32 *fasync_readers;
	struct fasync_struct___32 *fasync_writers;
	struct pipe_buffer___11 *bufs;
	struct user_struct *user;
	struct watch_queue *watch_queue;
};

struct cgroup_subsys___26;

struct cgroup_subsys_state___26 {
	struct cgroup___26 *cgroup;
	struct cgroup_subsys___26 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___26 *parent;
};

struct kernfs_node___32;

struct cgroup_file___26 {
	struct kernfs_node___32 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct obj_cgroup___20;

struct mem_cgroup_per_node___20;

struct mem_cgroup___20 {
	struct cgroup_subsys_state___26 css;
	struct mem_cgroup_id id;
	struct page_counter memory;
	union {
		struct page_counter swap;
		struct page_counter memsw;
	};
	struct page_counter kmem;
	struct page_counter tcpmem;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool oom_group;
	bool oom_lock;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___26 events_file;
	struct cgroup_file___26 events_local_file;
	struct cgroup_file___26 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	struct memcg_vmstats vmstats;
	atomic_long_t memory_events[8];
	atomic_long_t memory_events_local[8];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct obj_cgroup___20 *objcg;
	struct list_head objcg_list;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad2_;
	atomic_t moving_account;
	struct task_struct___36 *move_lock_task;
	struct memcg_vmstats_percpu *vmstats_percpu;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct memcg_cgwb_frn cgwb_frn[4];
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct deferred_split deferred_split_queue;
	struct mem_cgroup_per_node___20 *nodeinfo[0];
	long: 64;
};

struct kset___31;

struct kobj_type___31;

struct kobject___32 {
	const char *name;
	struct list_head entry;
	struct kobject___32 *parent;
	struct kset___31 *kset;
	struct kobj_type___31 *ktype;
	struct kernfs_node___32 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct blk_integrity_profile___21;

struct blk_integrity___21 {
	const struct blk_integrity_profile___21 *profile;
	unsigned char flags;
	unsigned char tuple_size;
	unsigned char interval_exp;
	unsigned char tag_size;
};

struct bio_set___21 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	struct bio_alloc_cache *cache;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	unsigned int back_pad;
	spinlock_t rescue_lock;
	struct bio_list___21 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	struct hlist_node cpuhp_dead;
};

struct request___21;

struct elevator_queue___21;

struct gendisk___21;

struct blkcg_gq___20;

struct request_queue___21 {
	struct request___21 *last_merge;
	struct elevator_queue___21 *elevator;
	struct percpu_ref q_usage_counter;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	const struct blk_mq_ops *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx **queue_hw_ctx;
	unsigned int nr_hw_queues;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	spinlock_t queue_lock;
	struct gendisk___21 *disk;
	struct kobject___32 kobj;
	struct kobject___32 *mq_kobj;
	struct blk_integrity___21 integrity;
	struct device___34 *dev;
	enum rpm_status rpm_status;
	long unsigned int nr_requests;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_keyslot_manager *ksm;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	atomic_t nr_active_requests_shared_sbitmap;
	struct sbitmap_queue sched_bitmap_tags;
	struct sbitmap_queue sched_breserved_tags;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___20 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int required_elevator_features;
	unsigned int nr_zones;
	long unsigned int *conv_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int max_open_zones;
	unsigned int max_active_zones;
	int node;
	struct mutex debugfs_mutex;
	struct blk_trace *blk_trace;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	struct mutex sysfs_dir_lock;
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	int mq_freeze_depth;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct mutex mq_freeze_lock;
	struct blk_mq_tag_set *tag_set;
	struct list_head tag_set_list;
	struct bio_set___21 bio_split;
	struct dentry___32 *debugfs_dir;
	struct dentry___32 *sched_debugfs_dir;
	struct dentry___32 *rqos_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	u64 write_hints[5];
};

struct vm_struct___29 {
	struct vm_struct___29 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___34 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct dentry_operations___32;

struct dentry___32 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___32 *d_parent;
	struct qstr d_name;
	struct inode___32 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___32 *d_op;
	struct super_block___32 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___32;

struct inode___32 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___32 *i_op;
	struct super_block___32 *i_sb;
	struct address_space___32 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___20 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	long: 64;
	long: 64;
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___32 *i_fop;
		void (*free_inode)(struct inode___32 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___32 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___11 *i_pipe;
		struct cdev *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___32 {
	int (*d_revalidate)(struct dentry___32 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___32 *, unsigned int);
	int (*d_hash)(const struct dentry___32 *, struct qstr *);
	int (*d_compare)(const struct dentry___32 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___32 *);
	int (*d_init)(struct dentry___32 *);
	void (*d_release)(struct dentry___32 *);
	void (*d_prune)(struct dentry___32 *);
	void (*d_iput)(struct dentry___32 *, struct inode___32 *);
	char * (*d_dname)(struct dentry___32 *, char *, int);
	struct vfsmount___32 * (*d_automount)(struct path___32 *);
	int (*d_manage)(const struct path___32 *, bool);
	struct dentry___32 * (*d_real)(struct dentry___32 *, const struct inode___32 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___32;

struct mem_dqinfo___32 {
	struct quota_format_type___32 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___32;

struct quota_info___32 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___32 *files[3];
	struct mem_dqinfo___32 info[3];
	const struct quota_format_ops___32 *ops[3];
};

struct rcuwait___32 {
	struct task_struct___36 *task;
};

struct percpu_rw_semaphore___32 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___32 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___32 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___32 rw_sem[3];
};

struct shrink_control___20;

struct shrinker___20 {
	long unsigned int (*count_objects)(struct shrinker___20 *, struct shrink_control___20 *);
	long unsigned int (*scan_objects)(struct shrinker___20 *, struct shrink_control___20 *);
	long int batch;
	int seeks;
	unsigned int flags;
	struct list_head list;
	int id;
	atomic_long_t *nr_deferred;
};

struct super_operations___32;

struct dquot_operations___32;

struct quotactl_ops___32;

struct xattr_handler___4;

struct block_device___21;

struct super_block___32 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___32 *s_type;
	const struct super_operations___32 *s_op;
	const struct dquot_operations___32 *dq_op;
	const struct quotactl_ops___32 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___32 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___4 **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___21 *s_bdev;
	struct backing_dev_info___20 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___32 s_dquot;
	struct sb_writers___32 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___32 *s_d_op;
	int cleancache_poolid;
	struct shrinker___20 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___2 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___32 {
	struct dentry___32 *mnt_root;
	struct super_block___32 *mnt_sb;
	int mnt_flags;
	struct user_namespace___2 *mnt_userns;
};

struct shrink_control___20 {
	gfp_t gfp_mask;
	int nid;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	struct mem_cgroup___20 *memcg;
};

struct psi_group___26 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___36 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___26;

struct cgroup_rstat_cpu___26;

struct cgroup___26 {
	struct cgroup_subsys_state___26 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___32 *kn;
	struct cgroup_file___26 procs_file;
	struct cgroup_file___26 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___26 *subsys[14];
	struct cgroup_root___26 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___26 *dom_cgrp;
	struct cgroup___26 *old_dom_cgrp;
	struct cgroup_rstat_cpu___26 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___26 psi;
	struct cgroup_bpf___4 bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct io_cq___21 {
	struct request_queue___21 *q;
	struct io_context___21 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct wait_page_queue___17;

struct kiocb___32 {
	struct file___32 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___32 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___17 *ki_waitq;
	};
};

struct iattr___32 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___32 *ia_file;
};

struct dquot___32 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___32 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___32 {
	int qf_fmt_id;
	const struct quota_format_ops___32 *qf_ops;
	struct module___31 *qf_owner;
	struct quota_format_type___32 *qf_next;
};

struct quota_format_ops___32 {
	int (*check_quota_file)(struct super_block___32 *, int);
	int (*read_file_info)(struct super_block___32 *, int);
	int (*write_file_info)(struct super_block___32 *, int);
	int (*free_file_info)(struct super_block___32 *, int);
	int (*read_dqblk)(struct dquot___32 *);
	int (*commit_dqblk)(struct dquot___32 *);
	int (*release_dqblk)(struct dquot___32 *);
	int (*get_next_id)(struct super_block___32 *, struct kqid *);
};

struct dquot_operations___32 {
	int (*write_dquot)(struct dquot___32 *);
	struct dquot___32 * (*alloc_dquot)(struct super_block___32 *, int);
	void (*destroy_dquot)(struct dquot___32 *);
	int (*acquire_dquot)(struct dquot___32 *);
	int (*release_dquot)(struct dquot___32 *);
	int (*mark_dirty)(struct dquot___32 *);
	int (*write_info)(struct super_block___32 *, int);
	qsize_t * (*get_reserved_space)(struct inode___32 *);
	int (*get_projid)(struct inode___32 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___32 *, qsize_t *);
	int (*get_next_id)(struct super_block___32 *, struct kqid *);
};

struct quotactl_ops___32 {
	int (*quota_on)(struct super_block___32 *, int, int, const struct path___32 *);
	int (*quota_off)(struct super_block___32 *, int);
	int (*quota_enable)(struct super_block___32 *, unsigned int);
	int (*quota_disable)(struct super_block___32 *, unsigned int);
	int (*quota_sync)(struct super_block___32 *, int);
	int (*set_info)(struct super_block___32 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___32 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___32 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___32 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___32 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___32 *, unsigned int);
};

struct module_kobject___31 {
	struct kobject___32 kobj;
	struct module___31 *mod;
	struct kobject___32 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___31 {
	struct module___31 *mod;
	struct latch_tree_node node;
};

struct module_layout___31 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___31 mtn;
};

struct module_attribute___31;

struct kernel_param___31;

struct module___31 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___31 mkobj;
	struct module_attribute___31 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___32 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___31 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___31 core_layout;
	struct module_layout___31 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map___23 *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___4 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	int num_static_call_sites;
	struct static_call_site *static_call_sites;
	bool klp;
	bool klp_alive;
	struct klp_modinfo *klp_info;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct wait_page_queue___17 {
	struct page___34 *page;
	int bit_nr;
	wait_queue_entry_t wait;
};

struct writeback_control___20;

struct readahead_control___17;

struct swap_info_struct___13;

struct address_space_operations___32 {
	int (*writepage)(struct page___34 *, struct writeback_control___20 *);
	int (*readpage)(struct file___32 *, struct page___34 *);
	int (*writepages)(struct address_space___32 *, struct writeback_control___20 *);
	int (*set_page_dirty)(struct page___34 *);
	int (*readpages)(struct file___32 *, struct address_space___32 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___17 *);
	int (*write_begin)(struct file___32 *, struct address_space___32 *, loff_t, unsigned int, unsigned int, struct page___34 **, void **);
	int (*write_end)(struct file___32 *, struct address_space___32 *, loff_t, unsigned int, unsigned int, struct page___34 *, void *);
	sector_t (*bmap)(struct address_space___32 *, sector_t);
	void (*invalidatepage)(struct page___34 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___34 *, gfp_t);
	void (*freepage)(struct page___34 *);
	ssize_t (*direct_IO)(struct kiocb___32 *, struct iov_iter___26 *);
	int (*migratepage)(struct address_space___32 *, struct page___34 *, struct page___34 *, enum migrate_mode);
	bool (*isolate_page)(struct page___34 *, isolate_mode_t);
	void (*putback_page)(struct page___34 *);
	int (*launder_page)(struct page___34 *);
	int (*is_partially_uptodate)(struct page___34 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___34 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___32 *, struct page___34 *);
	int (*swap_activate)(struct swap_info_struct___13 *, struct file___32 *, sector_t *);
	void (*swap_deactivate)(struct file___32 *);
};

struct writeback_control___20 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	unsigned int no_cgroup_owner: 1;
	unsigned int punt_to_cgroup: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bdi_writeback___20 *wb;
	struct inode___32 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
};

struct readahead_control___17 {
	struct file___32 *file;
	struct address_space___32 *mapping;
	struct file_ra_state *ra;
	long unsigned int _index;
	unsigned int _nr_pages;
	unsigned int _batch_count;
};

struct bio_vec___26;

struct iov_iter___26 {
	u8 iter_type;
	bool data_source;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___26 *bvec;
		struct xarray *xarray;
		struct pipe_inode_info___11 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			unsigned int head;
			unsigned int start_head;
		};
		loff_t xarray_start;
	};
};

struct swap_info_struct___13 {
	struct percpu_ref users;
	long unsigned int flags;
	short int prio;
	struct plist_node list;
	signed char type;
	unsigned int max;
	unsigned char *swap_map;
	struct swap_cluster_info *cluster_info;
	struct swap_cluster_list free_clusters;
	unsigned int lowest_bit;
	unsigned int highest_bit;
	unsigned int pages;
	unsigned int inuse_pages;
	unsigned int cluster_next;
	unsigned int cluster_nr;
	unsigned int *cluster_next_cpu;
	struct percpu_cluster *percpu_cluster;
	struct rb_root swap_extent_root;
	struct block_device___21 *bdev;
	struct file___32 *swap_file;
	unsigned int old_block_size;
	struct completion comp;
	long unsigned int *frontswap_map;
	atomic_t frontswap_pages;
	spinlock_t lock;
	spinlock_t cont_lock;
	struct work_struct discard_work;
	struct swap_cluster_list discard_clusters;
	struct plist_node avail_lists[0];
};

struct inode_operations___32 {
	struct dentry___32 * (*lookup)(struct inode___32 *, struct dentry___32 *, unsigned int);
	const char * (*get_link)(struct dentry___32 *, struct inode___32 *, struct delayed_call *);
	int (*permission)(struct user_namespace___2 *, struct inode___32 *, int);
	struct posix_acl * (*get_acl)(struct inode___32 *, int, bool);
	int (*readlink)(struct dentry___32 *, char *, int);
	int (*create)(struct user_namespace___2 *, struct inode___32 *, struct dentry___32 *, umode_t, bool);
	int (*link)(struct dentry___32 *, struct inode___32 *, struct dentry___32 *);
	int (*unlink)(struct inode___32 *, struct dentry___32 *);
	int (*symlink)(struct user_namespace___2 *, struct inode___32 *, struct dentry___32 *, const char *);
	int (*mkdir)(struct user_namespace___2 *, struct inode___32 *, struct dentry___32 *, umode_t);
	int (*rmdir)(struct inode___32 *, struct dentry___32 *);
	int (*mknod)(struct user_namespace___2 *, struct inode___32 *, struct dentry___32 *, umode_t, dev_t);
	int (*rename)(struct user_namespace___2 *, struct inode___32 *, struct dentry___32 *, struct inode___32 *, struct dentry___32 *, unsigned int);
	int (*setattr)(struct user_namespace___2 *, struct dentry___32 *, struct iattr___32 *);
	int (*getattr)(struct user_namespace___2 *, const struct path___32 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___32 *, char *, size_t);
	int (*fiemap)(struct inode___32 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___32 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___32 *, struct dentry___32 *, struct file___32 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace___2 *, struct inode___32 *, struct dentry___32 *, umode_t);
	int (*set_acl)(struct user_namespace___2 *, struct inode___32 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace___2 *, struct dentry___32 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___32 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___32 {
	void (*fl_copy_lock)(struct file_lock___32 *, struct file_lock___32 *);
	void (*fl_release_private)(struct file_lock___32 *);
};

struct lock_manager_operations___32;

struct file_lock___32 {
	struct file_lock___32 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___32 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___32 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___32 *fl_ops;
	const struct lock_manager_operations___32 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___32 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___32 *);
	int (*lm_grant)(struct file_lock___32 *, int);
	bool (*lm_break)(struct file_lock___32 *);
	int (*lm_change)(struct file_lock___32 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___32 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___32 *);
};

struct fasync_struct___32 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___32 *fa_next;
	struct file___32 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___32 {
	struct inode___32 * (*alloc_inode)(struct super_block___32 *);
	void (*destroy_inode)(struct inode___32 *);
	void (*free_inode)(struct inode___32 *);
	void (*dirty_inode)(struct inode___32 *, int);
	int (*write_inode)(struct inode___32 *, struct writeback_control___20 *);
	int (*drop_inode)(struct inode___32 *);
	void (*evict_inode)(struct inode___32 *);
	void (*put_super)(struct super_block___32 *);
	int (*sync_fs)(struct super_block___32 *, int);
	int (*freeze_super)(struct super_block___32 *);
	int (*freeze_fs)(struct super_block___32 *);
	int (*thaw_super)(struct super_block___32 *);
	int (*unfreeze_fs)(struct super_block___32 *);
	int (*statfs)(struct dentry___32 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___32 *, int *, char *);
	void (*umount_begin)(struct super_block___32 *);
	int (*show_options)(struct seq_file___30 *, struct dentry___32 *);
	int (*show_devname)(struct seq_file___30 *, struct dentry___32 *);
	int (*show_path)(struct seq_file___30 *, struct dentry___32 *);
	int (*show_stats)(struct seq_file___30 *, struct dentry___32 *);
	ssize_t (*quota_read)(struct super_block___32 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___32 *, int, const char *, size_t, loff_t);
	struct dquot___32 ** (*get_dquots)(struct inode___32 *);
	long int (*nr_cached_objects)(struct super_block___32 *, struct shrink_control___20 *);
	long int (*free_cached_objects)(struct super_block___32 *, struct shrink_control___20 *);
	struct file___32 * (*real_loop)(struct file___32 *);
};

struct xattr_handler___4 {
	const char *name;
	const char *prefix;
	int flags;
	bool (*list)(struct dentry___32 *);
	int (*get)(const struct xattr_handler___4 *, struct dentry___32 *, struct inode___32 *, const char *, void *, size_t);
	int (*set)(const struct xattr_handler___4 *, struct user_namespace___2 *, struct dentry___32 *, struct inode___32 *, const char *, const void *, size_t, int);
};

struct wakeup_source___34;

struct dev_pm_info___34 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___34 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___34 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___34;

struct bus_type___34;

struct device_driver___34;

struct dev_pm_domain___34;

struct fwnode_handle___31;

struct class___34;

struct attribute_group___32;

struct device___34 {
	struct kobject___32 kobj;
	struct device___34 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___34 *type;
	struct bus_type___34 *bus;
	struct device_driver___34 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___34 power;
	struct dev_pm_domain___34 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node *of_node;
	struct fwnode_handle___31 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___34 *class;
	const struct attribute_group___32 **groups;
	void (*release)(struct device___34 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct block_device___21 {
	sector_t bd_start_sect;
	struct disk_stats *bd_stats;
	long unsigned int bd_stamp;
	bool bd_read_only;
	dev_t bd_dev;
	int bd_openers;
	struct inode___32 *bd_inode;
	struct super_block___32 *bd_super;
	void *bd_claiming;
	struct device___34 bd_device;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct kobject___32 *bd_holder_dir;
	u8 bd_partno;
	spinlock_t bd_size_lock;
	struct gendisk___21 *bd_disk;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	struct super_block___32 *bd_fsfreeze_sb;
	struct partition_meta_info *bd_meta_info;
};

struct seq_file___30 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___30 *op;
	int poll_event;
	const struct file___32 *file;
	void *private;
};

struct fc_log___5;

struct p_log___5 {
	const char *prefix;
	struct fc_log___5 *log;
};

struct fs_context_operations___6;

struct fs_context___6 {
	const struct fs_context_operations___6 *ops;
	struct mutex uapi_mutex;
	struct file_system_type___32 *fs_type;
	void *fs_private;
	void *sget_key;
	struct dentry___32 *root;
	struct user_namespace___2 *user_ns;
	struct net *net_ns;
	const struct cred___2 *cred;
	struct p_log___5 log;
	const char *source;
	void *security;
	void *s_fs_info;
	unsigned int sb_flags;
	unsigned int sb_flags_mask;
	unsigned int s_iflags;
	unsigned int lsm_flags;
	enum fs_context_purpose purpose: 8;
	enum fs_context_phase phase: 8;
	bool need_free: 1;
	bool global: 1;
	bool oldapi: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fs_parameter___6;

typedef int fs_param_type___4(struct p_log___5 *, const struct fs_parameter_spec___4 *, struct fs_parameter___6 *, struct fs_parse_result *);

struct fs_parameter_spec___4 {
	const char *name;
	fs_param_type___4 *type;
	u8 opt;
	short unsigned int flags;
	const void *data;
};

typedef void bio_end_io_t___21(struct bio___21 *);

struct bio_vec___26 {
	struct page___34 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___21;

struct bio___21 {
	struct bio___21 *bi_next;
	struct block_device___21 *bi_bdev;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	atomic_t __bi_remaining;
	struct bvec_iter bi_iter;
	bio_end_io_t___21 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___20 *bi_blkg;
	struct bio_issue bi_issue;
	u64 bi_iocost_cost;
	struct bio_crypt_ctx *bi_crypt_context;
	union {
		struct bio_integrity_payload___21 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___26 *bi_io_vec;
	struct bio_set___21 *bi_pool;
	struct bio_vec___26 bi_inline_vecs[0];
};

struct kernfs_root___32;

struct kernfs_elem_dir___32 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___32 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___32;

struct kernfs_root___32 {
	struct kernfs_node___32 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___32 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___32 {
	struct kernfs_node___32 *target_kn;
};

struct kernfs_ops___32;

struct kernfs_elem_attr___32 {
	const struct kernfs_ops___32 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___32 *notify_next;
};

struct kernfs_node___32 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___32 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___32 dir;
		struct kernfs_elem_symlink___32 symlink;
		struct kernfs_elem_attr___32 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___32;

struct kernfs_ops___32 {
	int (*open)(struct kernfs_open_file___32 *);
	void (*release)(struct kernfs_open_file___32 *);
	int (*seq_show)(struct seq_file___30 *, void *);
	void * (*seq_start)(struct seq_file___30 *, loff_t *);
	void * (*seq_next)(struct seq_file___30 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___30 *, void *);
	ssize_t (*read)(struct kernfs_open_file___32 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___32 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___32 *, struct poll_table_struct *);
	int (*mmap)(struct kernfs_open_file___32 *, struct vm_area_struct___35 *);
};

struct kernfs_syscall_ops___32 {
	int (*show_options)(struct seq_file___30 *, struct kernfs_root___32 *);
	int (*mkdir)(struct kernfs_node___32 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___32 *);
	int (*rename)(struct kernfs_node___32 *, struct kernfs_node___32 *, const char *);
	int (*show_path)(struct seq_file___30 *, struct kernfs_node___32 *, struct kernfs_root___32 *);
};

struct kernfs_open_file___32 {
	struct kernfs_node___32 *kn;
	struct file___32 *file;
	struct seq_file___30 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___32 *vm_ops;
};

struct cgroup_namespace___26 {
	struct ns_common___5 ns;
	struct user_namespace___2 *user_ns;
	struct ucounts___2 *ucounts;
	struct css_set___26 *root_cset;
};

struct bin_attribute___32;

struct attribute_group___32 {
	const char *name;
	umode_t (*is_visible)(struct kobject___32 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___32 *, struct bin_attribute___32 *, int);
	struct attribute **attrs;
	struct bin_attribute___32 **bin_attrs;
};

struct bin_attribute___32 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___32 * (*f_mapping)();
	ssize_t (*read)(struct file___32 *, struct kobject___32 *, struct bin_attribute___32 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___32 *, struct kobject___32 *, struct bin_attribute___32 *, char *, loff_t, size_t);
	int (*mmap)(struct file___32 *, struct kobject___32 *, struct bin_attribute___32 *, struct vm_area_struct___35 *);
};

struct sysfs_ops___31 {
	ssize_t (*show)(struct kobject___32 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___32 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___31;

struct kset___31 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___32 kobj;
	const struct kset_uevent_ops___31 *uevent_ops;
};

struct kobj_type___31 {
	void (*release)(struct kobject___32 *);
	const struct sysfs_ops___31 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___32 **default_groups;
	const struct kobj_ns_type_operations___3 * (*child_ns_type)(struct kobject___32 *);
	const void * (*namespace)(struct kobject___32 *);
	void (*get_ownership)(struct kobject___32 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___31 {
	int (* const filter)(struct kset___31 *, struct kobject___32 *);
	const char * (* const name)(struct kset___31 *, struct kobject___32 *);
	int (* const uevent)(struct kset___31 *, struct kobject___32 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___31 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___31 *);
	int (*get)(char *, const struct kernel_param___31 *);
	void (*free)(void *);
};

struct kparam_array___31;

struct kernel_param___31 {
	const char *name;
	struct module___31 *mod;
	const struct kernel_param_ops___31 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___31 *arr;
	};
};

struct kparam_array___31 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___31 *ops;
	void *elem;
};

struct module_attribute___31 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___31 *, struct module_kobject___31 *, char *);
	ssize_t (*store)(struct module_attribute___31 *, struct module_kobject___31 *, const char *, size_t);
	void (*setup)(struct module___31 *, const char *);
	int (*test)(struct module___31 *);
	void (*free)(struct module___31 *);
};

struct dev_pagemap_ops___32 {
	void (*page_free)(struct page___34 *);
	void (*kill)(struct dev_pagemap___32 *);
	void (*cleanup)(struct dev_pagemap___32 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___32 *);
};

struct cftype___26;

struct cgroup_subsys___26 {
	struct cgroup_subsys_state___26 * (*css_alloc)(struct cgroup_subsys_state___26 *);
	int (*css_online)(struct cgroup_subsys_state___26 *);
	void (*css_offline)(struct cgroup_subsys_state___26 *);
	void (*css_released)(struct cgroup_subsys_state___26 *);
	void (*css_free)(struct cgroup_subsys_state___26 *);
	void (*css_reset)(struct cgroup_subsys_state___26 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___26 *, int);
	int (*css_extra_stat_show)(struct seq_file___30 *, struct cgroup_subsys_state___26 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___36 *, struct css_set___26 *);
	void (*cancel_fork)(struct task_struct___36 *, struct css_set___26 *);
	void (*fork)(struct task_struct___36 *);
	void (*exit)(struct task_struct___36 *);
	void (*release)(struct task_struct___36 *);
	void (*bind)(struct cgroup_subsys_state___26 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___26 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___26 *dfl_cftypes;
	struct cftype___26 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___26 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___26 *updated_children;
	struct cgroup___26 *updated_next;
};

struct cgroup_root___26 {
	struct kernfs_root___32 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___26 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___26 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___26 *ss;
	struct list_head node;
	struct kernfs_ops___32 *kf_ops;
	int (*open)(struct kernfs_open_file___32 *);
	void (*release)(struct kernfs_open_file___32 *);
	u64 (*read_u64)(struct cgroup_subsys_state___26 *, struct cftype___26 *);
	s64 (*read_s64)(struct cgroup_subsys_state___26 *, struct cftype___26 *);
	int (*seq_show)(struct seq_file___30 *, void *);
	void * (*seq_start)(struct seq_file___30 *, loff_t *);
	void * (*seq_next)(struct seq_file___30 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___30 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___26 *, struct cftype___26 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___26 *, struct cftype___26 *, s64);
	ssize_t (*write)(struct kernfs_open_file___32 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___32 *, struct poll_table_struct *);
};

struct dev_pm_ops___34 {
	int (*prepare)(struct device___34 *);
	void (*complete)(struct device___34 *);
	int (*suspend)(struct device___34 *);
	int (*resume)(struct device___34 *);
	int (*freeze)(struct device___34 *);
	int (*thaw)(struct device___34 *);
	int (*poweroff)(struct device___34 *);
	int (*restore)(struct device___34 *);
	int (*suspend_late)(struct device___34 *);
	int (*resume_early)(struct device___34 *);
	int (*freeze_late)(struct device___34 *);
	int (*thaw_early)(struct device___34 *);
	int (*poweroff_late)(struct device___34 *);
	int (*restore_early)(struct device___34 *);
	int (*suspend_noirq)(struct device___34 *);
	int (*resume_noirq)(struct device___34 *);
	int (*freeze_noirq)(struct device___34 *);
	int (*thaw_noirq)(struct device___34 *);
	int (*poweroff_noirq)(struct device___34 *);
	int (*restore_noirq)(struct device___34 *);
	int (*runtime_suspend)(struct device___34 *);
	int (*runtime_resume)(struct device___34 *);
	int (*runtime_idle)(struct device___34 *);
};

struct wakeup_source___34 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___34 *dev;
	bool active: 1;
	bool autosleep_enabled: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___34 {
	struct dev_pm_ops___34 ops;
	int (*start)(struct device___34 *);
	void (*detach)(struct device___34 *, bool);
	int (*activate)(struct device___34 *);
	void (*sync)(struct device___34 *);
	void (*dismiss)(struct device___34 *);
};

struct bus_type___34 {
	const char *name;
	const char *dev_name;
	struct device___34 *dev_root;
	const struct attribute_group___32 **bus_groups;
	const struct attribute_group___32 **dev_groups;
	const struct attribute_group___32 **drv_groups;
	int (*match)(struct device___34 *, struct device_driver___34 *);
	int (*uevent)(struct device___34 *, struct kobj_uevent_env *);
	int (*probe)(struct device___34 *);
	void (*sync_state)(struct device___34 *);
	void (*remove)(struct device___34 *);
	void (*shutdown)(struct device___34 *);
	int (*online)(struct device___34 *);
	int (*offline)(struct device___34 *);
	int (*suspend)(struct device___34 *, pm_message_t);
	int (*resume)(struct device___34 *);
	int (*num_vf)(struct device___34 *);
	int (*dma_configure)(struct device___34 *);
	const struct dev_pm_ops___34 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___34 {
	const char *name;
	struct bus_type___34 *bus;
	struct module___31 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___34 *);
	void (*sync_state)(struct device___34 *);
	int (*remove)(struct device___34 *);
	void (*shutdown)(struct device___34 *);
	int (*suspend)(struct device___34 *, pm_message_t);
	int (*resume)(struct device___34 *);
	const struct attribute_group___32 **groups;
	const struct attribute_group___32 **dev_groups;
	const struct dev_pm_ops___34 *pm;
	void (*coredump)(struct device___34 *);
	struct driver_private *p;
};

struct device_type___34 {
	const char *name;
	const struct attribute_group___32 **groups;
	int (*uevent)(struct device___34 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___34 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___34 *);
	const struct dev_pm_ops___34 *pm;
};

struct class___34 {
	const char *name;
	struct module___31 *owner;
	const struct attribute_group___32 **class_groups;
	const struct attribute_group___32 **dev_groups;
	struct kobject___32 *dev_kobj;
	int (*dev_uevent)(struct device___34 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___34 *, umode_t *);
	void (*class_release)(struct class___34 *);
	void (*dev_release)(struct device___34 *);
	int (*shutdown_pre)(struct device___34 *);
	const struct kobj_ns_type_operations___3 *ns_type;
	const void * (*namespace)(struct device___34 *);
	void (*get_ownership)(struct device___34 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___34 *pm;
	struct subsys_private *p;
};

struct fwnode_operations___31;

struct fwnode_handle___31 {
	struct fwnode_handle___31 *secondary;
	const struct fwnode_operations___31 *ops;
	struct device___34 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct block_device_operations___21;

struct gendisk___21 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	short unsigned int events;
	short unsigned int event_flags;
	struct xarray part_tbl;
	struct block_device___21 *part0;
	const struct block_device_operations___21 *fops;
	struct request_queue___21 *queue;
	void *private_data;
	int flags;
	long unsigned int state;
	struct mutex open_mutex;
	unsigned int open_partitions;
	struct backing_dev_info___20 *bdi;
	struct kobject___32 *slave_dir;
	struct list_head slave_bdevs;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___32 integrity_kobj;
	struct cdrom_device_info *cdi;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	u64 diskseq;
};

struct bio_integrity_payload___21 {
	struct bio___21 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___26 *bip_vec;
	struct bio_vec___26 bip_inline_vecs[0];
};

struct blkcg___20;

struct blkg_policy_data___20;

struct blkcg_gq___20 {
	struct request_queue___21 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___20 *blkcg;
	struct blkcg_gq___20 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_iostat_set *iostat_cpu;
	struct blkg_iostat_set iostat;
	struct blkg_policy_data___20 *pd[6];
	spinlock_t async_bio_lock;
	struct bio_list___21 async_bios;
	struct work_struct async_bio_work;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
	struct callback_head callback_head;
};

typedef void integrity_prepare_fn___21(struct request___21 *);

typedef void integrity_complete_fn___21(struct request___21 *, unsigned int);

struct blk_integrity_profile___21 {
	integrity_processing_fn *generate_fn;
	integrity_processing_fn *verify_fn;
	integrity_prepare_fn___21 *prepare_fn;
	integrity_complete_fn___21 *complete_fn;
	const char *name;
};

struct block_device_operations___21 {
	blk_qc_t (*submit_bio)(struct bio___21 *);
	int (*open)(struct block_device___21 *, fmode_t);
	void (*release)(struct gendisk___21 *, fmode_t);
	int (*rw_page)(struct block_device___21 *, sector_t, struct page___34 *, unsigned int);
	int (*ioctl)(struct block_device___21 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___21 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___21 *, unsigned int);
	void (*unlock_native_capacity)(struct gendisk___21 *);
	int (*getgeo)(struct block_device___21 *, struct hd_geometry *);
	int (*set_read_only)(struct block_device___21 *, bool);
	void (*swap_slot_free_notify)(struct block_device___21 *, long unsigned int);
	int (*report_zones)(struct gendisk___21 *, sector_t, unsigned int, report_zones_cb, void *);
	char * (*devnode)(struct gendisk___21 *, umode_t *);
	struct module___31 *owner;
	const struct pr_ops *pr_ops;
	int (*alternative_gpt_sector)(struct gendisk___21 *, sector_t *);
};

struct fwnode_reference_args___31;

struct fwnode_endpoint___31;

struct fwnode_operations___31 {
	struct fwnode_handle___31 * (*get)(struct fwnode_handle___31 *);
	void (*put)(struct fwnode_handle___31 *);
	bool (*device_is_available)(const struct fwnode_handle___31 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___31 *, const struct device___34 *);
	bool (*property_present)(const struct fwnode_handle___31 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___31 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___31 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___31 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___31 *);
	struct fwnode_handle___31 * (*get_parent)(const struct fwnode_handle___31 *);
	struct fwnode_handle___31 * (*get_next_child_node)(const struct fwnode_handle___31 *, struct fwnode_handle___31 *);
	struct fwnode_handle___31 * (*get_named_child_node)(const struct fwnode_handle___31 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___31 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___31 *);
	struct fwnode_handle___31 * (*graph_get_next_endpoint)(const struct fwnode_handle___31 *, struct fwnode_handle___31 *);
	struct fwnode_handle___31 * (*graph_get_remote_endpoint)(const struct fwnode_handle___31 *);
	struct fwnode_handle___31 * (*graph_get_port_parent)(struct fwnode_handle___31 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___31 *, struct fwnode_endpoint___31 *);
	int (*add_links)(struct fwnode_handle___31 *);
};

struct fwnode_endpoint___31 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___31 *local_fwnode;
};

struct fwnode_reference_args___31 {
	struct fwnode_handle___31 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

typedef void rq_end_io_fn___21(struct request___21 *, blk_status_t);

struct request___21 {
	struct request_queue___21 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int tag;
	int internal_tag;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___21 *bio;
	struct bio___21 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct llist_node ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___26 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___21 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___21 *saved_end_io;
		} flush;
	};
	struct gendisk___21 *rq_disk;
	struct block_device___21 *part;
	u64 alloc_time_ns;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int stats_sectors;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	struct bio_crypt_ctx *crypt_ctx;
	struct blk_ksm_keyslot *crypt_keyslot;
	short unsigned int write_hint;
	short unsigned int ioprio;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___21 *end_io;
	void *end_io_data;
};

struct elevator_type___21;

struct elevator_mq_ops___21 {
	int (*init_sched)(struct request_queue___21 *, struct elevator_type___21 *);
	void (*exit_sched)(struct elevator_queue___21 *);
	int (*init_hctx)(struct blk_mq_hw_ctx *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx *, unsigned int);
	void (*depth_updated)(struct blk_mq_hw_ctx *);
	bool (*allow_merge)(struct request_queue___21 *, struct request___21 *, struct bio___21 *);
	bool (*bio_merge)(struct request_queue___21 *, struct bio___21 *, unsigned int);
	int (*request_merge)(struct request_queue___21 *, struct request___21 **, struct bio___21 *);
	void (*request_merged)(struct request_queue___21 *, struct request___21 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___21 *, struct request___21 *, struct request___21 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___21 *);
	void (*finish_request)(struct request___21 *);
	void (*insert_requests)(struct blk_mq_hw_ctx *, struct list_head *, bool);
	struct request___21 * (*dispatch_request)(struct blk_mq_hw_ctx *);
	bool (*has_work)(struct blk_mq_hw_ctx *);
	void (*completed_request)(struct request___21 *, u64);
	void (*requeue_request)(struct request___21 *);
	struct request___21 * (*former_request)(struct request_queue___21 *, struct request___21 *);
	struct request___21 * (*next_request)(struct request_queue___21 *, struct request___21 *);
	void (*init_icq)(struct io_cq___21 *);
	void (*exit_icq)(struct io_cq___21 *);
};

struct elv_fs_entry___21;

struct elevator_type___21 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___21 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___21 *elevator_attrs;
	const char *elevator_name;
	const char *elevator_alias;
	const unsigned int elevator_features;
	struct module___31 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
};

struct elevator_queue___21 {
	struct elevator_type___21 *type;
	void *elevator_data;
	struct kobject___32 kobj;
	struct mutex sysfs_lock;
	unsigned int registered: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hlist_head hash[64];
};

struct elv_fs_entry___21 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___21 *, char *);
	ssize_t (*store)(struct elevator_queue___21 *, const char *, size_t);
};

struct blkcg_policy_data___20;

struct blkcg___20 {
	struct cgroup_subsys_state___26 css;
	spinlock_t lock;
	refcount_t online_pin;
	struct xarray blkg_tree;
	struct blkcg_gq___20 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___20 *cpd[6];
	struct list_head all_blkcgs_node;
	char fc_app_id[129];
	struct list_head cgwb_list;
};

struct blkcg_policy_data___20 {
	struct blkcg___20 *blkcg;
	int plid;
};

struct blkg_policy_data___20 {
	struct blkcg_gq___20 *blkg;
	int plid;
};

struct mem_cgroup_reclaim_iter___20 {
	struct mem_cgroup___20 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___20 {
	struct lruvec___21 lruvec;
	struct lruvec_stats_percpu *lruvec_stats_percpu;
	struct lruvec_stats lruvec_stats;
	long unsigned int lru_zone_size[25];
	struct mem_cgroup_reclaim_iter___20 iter;
	struct shrinker_info *shrinker_info;
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	struct mem_cgroup___20 *memcg;
};

struct obj_cgroup___20 {
	struct percpu_ref refcnt;
	struct mem_cgroup___20 *memcg;
	atomic_t nr_charged_bytes;
	union {
		struct list_head list;
		struct callback_head rcu;
	};
};

struct fs_parameter___6 {
	const char *key;
	enum fs_value_type type: 8;
	long: 56;
	long: 64;
	union {
		char *string;
		void *blob;
		struct filename *name;
		struct file___32 *file;
	};
	size_t size;
	int dirfd;
};

struct fc_log___5 {
	refcount_t usage;
	u8 head;
	u8 tail;
	u8 need_free;
	struct module___31 *owner;
	char *buffer[8];
};

struct fs_context_operations___6 {
	void (*free)(struct fs_context___6 *);
	int (*dup)(struct fs_context___6 *, struct fs_context___6 *);
	int (*parse_param)(struct fs_context___6 *, struct fs_parameter___6 *);
	int (*parse_monolithic)(struct fs_context___6 *, void *);
	int (*get_tree)(struct fs_context___6 *);
	int (*reconfigure)(struct fs_context___6 *);
};

struct pipe_buf_operations___11;

struct pipe_buffer___11 {
	struct page___34 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___11 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___11 {
	int (*confirm)(struct pipe_inode_info___11 *, struct pipe_buffer___11 *);
	void (*release)(struct pipe_inode_info___11 *, struct pipe_buffer___11 *);
	bool (*try_steal)(struct pipe_inode_info___11 *, struct pipe_buffer___11 *);
	bool (*get)(struct pipe_inode_info___11 *, struct pipe_buffer___11 *);
};

struct umd_info {
	const char *driver_name;
	struct file___32 *pipe_to_umh;
	struct file___32 *pipe_from_umh;
	struct path___32 wd;
	struct pid___27 *tgid;
};

struct dentry___33;

struct super_block___33;

struct module___32;

struct file_system_type___33 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___33 * (*mount)(struct file_system_type___33 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___33 *);
	struct module___32 *owner;
	struct file_system_type___33 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct pin_cookie {};

struct file___33;

struct kiocb___33;

struct iov_iter___27;

struct poll_table_struct___24;

struct vm_area_struct___36;

struct inode___33;

struct file_lock___33;

struct page___35;

struct pipe_inode_info___12;

struct seq_file___31;

struct file_operations___33 {
	struct module___32 *owner;
	loff_t (*llseek)(struct file___33 *, loff_t, int);
	ssize_t (*read)(struct file___33 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___33 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___33 *, struct iov_iter___27 *);
	ssize_t (*write_iter)(struct kiocb___33 *, struct iov_iter___27 *);
	int (*iopoll)(struct kiocb___33 *, bool);
	int (*iterate)(struct file___33 *, struct dir_context *);
	int (*iterate_shared)(struct file___33 *, struct dir_context *);
	__poll_t (*poll)(struct file___33 *, struct poll_table_struct___24 *);
	long int (*unlocked_ioctl)(struct file___33 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___33 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___33 *, struct vm_area_struct___36 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___33 *, struct file___33 *);
	int (*flush)(struct file___33 *, fl_owner_t);
	int (*release)(struct inode___33 *, struct file___33 *);
	int (*fsync)(struct file___33 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___33 *, int);
	int (*lock)(struct file___33 *, int, struct file_lock___33 *);
	ssize_t (*sendpage)(struct file___33 *, struct page___35 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___33 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___33 *, long unsigned int);
	int (*flock)(struct file___33 *, int, struct file_lock___33 *);
	ssize_t (*splice_write)(struct pipe_inode_info___12 *, struct file___33 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___33 *, loff_t *, struct pipe_inode_info___12 *, size_t, unsigned int);
	int (*setlease)(struct file___33 *, long int, struct file_lock___33 **, void **);
	long int (*fallocate)(struct file___33 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___31 *, struct file___33 *);
	ssize_t (*copy_file_range)(struct file___33 *, loff_t, struct file___33 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___33 *, loff_t, struct file___33 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___33 *, loff_t, loff_t, int);
};

struct static_call_mod___24 {
	struct static_call_mod___24 *next;
	struct module___32 *mod;
	struct static_call_site *sites;
};

struct static_call_key___24 {
	void *func;
	union {
		long unsigned int type;
		struct static_call_mod___24 *mods;
		struct static_call_site *sites;
	};
};

struct vmacache___35 {
	u64 seqnum;
	struct vm_area_struct___36 *vmas[4];
};

struct page_frag___35 {
	struct page___35 *page;
	__u32 offset;
	__u32 size;
};

struct perf_event___21;

struct thread_struct___22 {
	struct desc_struct tls_array[3];
	long unsigned int sp;
	short unsigned int es;
	short unsigned int ds;
	short unsigned int fsindex;
	short unsigned int gsindex;
	long unsigned int fsbase;
	long unsigned int gsbase;
	struct perf_event___21 *ptrace_bps[4];
	long unsigned int virtual_dr6;
	long unsigned int ptrace_dr7;
	long unsigned int cr2;
	long unsigned int trap_nr;
	long unsigned int error_code;
	struct io_bitmap *io_bitmap;
	long unsigned int iopl_emul;
	unsigned int iopl_warn: 1;
	unsigned int sig_on_uaccess_err: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u32 pkru;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct fpu fpu;
};

struct sched_class___2;

struct task_group___2;

struct mm_struct___36;

struct pid___28;

struct nsproxy___32;

struct signal_struct___33;

struct bio_list___22;

struct backing_dev_info___21;

struct io_context___22;

struct css_set___27;

struct perf_event_context___21;

struct mem_cgroup___21;

struct request_queue___22;

struct vm_struct___30;

struct task_struct___37 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___37 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class___2 *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group___2 *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___36 *mm;
	struct mm_struct___36 *active_mm;
	struct vmacache___35 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int restore_sigmask: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___37 *real_parent;
	struct task_struct___37 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___37 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___28 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	struct posix_cputimers_work posix_cputimers_work;
	const struct cred___2 *ptracer_cred;
	const struct cred___2 *real_cred;
	const struct cred___2 *cred;
	struct key *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___32 *nsproxy;
	struct signal_struct___33 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___37 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___22 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___21 *backing_dev_info;
	struct io_context___22 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___27 *cgroups;
	struct list_head cg_list;
	u32 closid;
	u32 rmid;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___21 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	struct pipe_inode_info___12 *splice_pipe;
	struct page_frag___35 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___21 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___21 *active_memcg;
	struct request_queue___22 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___37 *oom_reaper_list;
	struct vm_struct___30 *stack_vm_area;
	refcount_t stack_refcount;
	int patch_state;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	void *mce_vaddr;
	__u64 mce_kflags;
	u64 mce_addr;
	__u64 mce_ripv: 1;
	__u64 mce_whole_page: 1;
	__u64 __mce_reserved: 62;
	long: 2;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct callback_head mce_kill_me;
	int mce_count;
	struct llist_head kretprobe_instances;
	struct callback_head l1d_flush_kill;
	long: 64;
	struct thread_struct___22 thread;
};

typedef struct page___35 *pgtable_t___35;

struct address_space___33;

struct page_pool___11;

struct dev_pagemap___33;

struct page___35 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___33 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___11 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___35 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___35 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___36 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___33 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct pv_cpu_ops___28 {
	void (*io_delay)();
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	void (*write_cr4)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___22 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(long unsigned int);
	void (*invalidate_io_bitmap)();
	void (*update_io_bitmap)();
	void (*wbinvd)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int);
	void (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_msr_safe)(unsigned int, int *);
	int (*write_msr_safe)(unsigned int, unsigned int, unsigned int);
	u64 (*read_pmc)(int);
	void (*start_context_switch)(struct task_struct___37 *);
	void (*end_context_switch)(struct task_struct___37 *);
};

struct flush_tlb_info___13;

struct mmu_gather___6;

struct pv_mmu_ops___30 {
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_one_user)(long unsigned int);
	void (*flush_tlb_multi)(const struct cpumask *, const struct flush_tlb_info___13 *);
	void (*tlb_remove_table)(struct mmu_gather___6 *, void *);
	void (*exit_mmap)(struct mm_struct___36 *);
	struct paravirt_callee_save read_cr2;
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___36 *, struct mm_struct___36 *);
	void (*dup_mmap)(struct mm_struct___36 *, struct mm_struct___36 *);
	int (*pgd_alloc)(struct mm_struct___36 *);
	void (*pgd_free)(struct mm_struct___36 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___36 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___36 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___36 *, long unsigned int);
	void (*alloc_p4d)(struct mm_struct___36 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*release_p4d)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	pte_t (*ptep_modify_prot_start)(struct vm_area_struct___36 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct vm_area_struct___36 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_p4d)(p4d_t *, p4d_t);
	struct paravirt_callee_save p4d_val;
	struct paravirt_callee_save make_p4d;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

struct flush_tlb_info___13 {
	struct mm_struct___36 *mm;
	long unsigned int start;
	long unsigned int end;
	u64 new_tlb_gen;
	unsigned int initiating_cpu;
	u8 stride_shift;
	u8 freed_tables;
};

struct mmu_gather_batch___6 {
	struct mmu_gather_batch___6 *next;
	unsigned int nr;
	unsigned int max;
	struct page___35 *pages[0];
};

struct mmu_gather___6 {
	struct mm_struct___36 *mm;
	struct mmu_table_batch *batch;
	long unsigned int start;
	long unsigned int end;
	unsigned int fullmm: 1;
	unsigned int need_flush_all: 1;
	unsigned int freed_tables: 1;
	unsigned int cleared_ptes: 1;
	unsigned int cleared_pmds: 1;
	unsigned int cleared_puds: 1;
	unsigned int cleared_p4ds: 1;
	unsigned int vma_exec: 1;
	unsigned int vma_huge: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int batch_count;
	struct mmu_gather_batch___6 *active;
	struct mmu_gather_batch___6 local;
	struct page___35 *__pages[8];
};

struct linux_binfmt___8;

struct core_state___35;

struct mm_struct___36 {
	struct {
		struct vm_area_struct___36 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___33 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int mmap_compat_base;
		long unsigned int mmap_compat_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[48];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___8 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___35 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___37 *owner;
		struct user_namespace___2 *user_ns;
		struct file___33 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		bool tlb_flush_batched;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct vm_operations_struct___33;

struct vm_area_struct___36 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___36 *vm_next;
	struct vm_area_struct___36 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___36 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___33 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___33 *vm_file;
	struct file___33 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct paravirt_patch_template___30 {
	struct pv_cpu_ops___28 cpu;
	struct pv_irq_ops irq;
	struct pv_mmu_ops___30 mmu;
	struct pv_lock_ops lock;
};

struct tracepoint___24 {
	const char *name;
	struct static_key key;
	struct static_call_key___24 *static_call_key;
	void *static_call_tramp;
	void *iterator;
	int (*regfunc)();
	void (*unregfunc)();
	struct tracepoint_func *funcs;
};

struct bpf_raw_event_map___24 {
	struct tracepoint___24 *tp;
	void *bpf_func;
	u32 num_args;
	u32 writable_size;
	long: 64;
};

struct seq_operations___31 {
	void * (*start)(struct seq_file___31 *, loff_t *);
	void (*stop)(struct seq_file___31 *, void *);
	void * (*next)(struct seq_file___31 *, void *, loff_t *);
	int (*show)(struct seq_file___31 *, void *);
};

struct hw_perf_event___21 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___37 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	union {
		struct {
			u64 last_period;
			local64_t period_left;
		};
		struct {
			u64 saved_metric;
			u64 saved_slots;
		};
	};
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___21)(struct perf_event___21 *, struct perf_sample_data *, struct pt_regs *);

struct pmu___21;

struct fasync_struct___33;

struct pid_namespace___28;

struct trace_event_call___21;

struct perf_cgroup___21;

struct perf_event___21 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___21 *group_leader;
	struct pmu___21 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___21 hw;
	struct perf_event_context___21 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___21 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___37 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct perf_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___33 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	long unsigned int pending_addr;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	struct perf_addr_filter_range *addr_filter_ranges;
	long unsigned int addr_filters_gen;
	struct perf_event___21 *aux_event;
	void (*destroy)(struct perf_event___21 *);
	struct callback_head callback_head;
	struct pid_namespace___28 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___21 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___21 orig_overflow_handler;
	struct bpf_prog *prog;
	u64 bpf_cookie;
	struct trace_event_call___21 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___21 *cgrp;
	void *security;
	struct list_head sb_list;
};

struct preempt_notifier;

struct preempt_ops {
	void (*sched_in)(struct preempt_notifier *, int);
	void (*sched_out)(struct preempt_notifier *, struct task_struct___37 *);
};

struct preempt_notifier {
	struct hlist_node link;
	struct preempt_ops *ops;
};

enum {
	CSD_FLAG_LOCK = 1,
	IRQ_WORK_PENDING = 1,
	IRQ_WORK_BUSY = 2,
	IRQ_WORK_LAZY = 4,
	IRQ_WORK_HARD_IRQ = 8,
	IRQ_WORK_CLAIMED = 3,
	CSD_TYPE_ASYNC = 0,
	CSD_TYPE_SYNC = 16,
	CSD_TYPE_IRQ_WORK = 32,
	CSD_TYPE_TTWU = 48,
	CSD_FLAG_TYPE_MASK = 240,
};

typedef struct __call_single_data call_single_data_t;

struct smp_ops___9 {
	void (*smp_prepare_boot_cpu)();
	void (*smp_prepare_cpus)(unsigned int);
	void (*smp_cpus_done)(unsigned int);
	void (*stop_other_cpus)(int);
	void (*crash_stop_other_cpus)();
	void (*smp_send_reschedule)(int);
	int (*cpu_up)(unsigned int, struct task_struct___37 *);
	int (*cpu_disable)();
	void (*cpu_die)(unsigned int);
	void (*play_dead)();
	void (*send_call_func_ipi)(const struct cpumask *);
	void (*send_call_func_single_ipi)(int);
};

struct upid___28 {
	int nr;
	struct pid_namespace___28 *ns;
};

struct pid_namespace___28 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___37 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___28 *parent;
	struct fs_pin *bacct;
	struct user_namespace___2 *user_ns;
	struct ucounts___2 *ucounts;
	int reboot;
	struct ns_common___5 ns;
};

struct pid___28 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___28 numbers[1];
};

struct autogroup___2;

struct signal_struct___33 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___37 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___37 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper;
	unsigned int has_child_subreaper;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___28 *pids[4];
	struct pid___28 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup___2 *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___36 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct dl_bw {
	raw_spinlock_t lock;
	u64 bw;
	u64 total_bw;
};

struct cpudl_item;

struct cpudl {
	raw_spinlock_t lock;
	int size;
	cpumask_var_t free_cpus;
	struct cpudl_item *elements;
};

struct cpupri_vec {
	atomic_t count;
	cpumask_var_t mask;
};

struct cpupri {
	struct cpupri_vec pri_to_cpu[101];
	int *cpu_to_pri;
};

struct perf_domain;

struct root_domain {
	atomic_t refcount;
	atomic_t rto_count;
	struct callback_head rcu;
	cpumask_var_t span;
	cpumask_var_t online;
	int overload;
	int overutilized;
	cpumask_var_t dlo_mask;
	atomic_t dlo_count;
	struct dl_bw dl_bw;
	struct cpudl cpudl;
	u64 visit_gen;
	struct irq_work rto_push_work;
	raw_spinlock_t rto_lock;
	int rto_loop;
	int rto_cpu;
	atomic_t rto_loop_next;
	atomic_t rto_loop_start;
	cpumask_var_t rto_mask;
	struct cpupri cpupri;
	long unsigned int max_cpu_capacity;
	struct perf_domain *pd;
};

struct rq___2;

struct cfs_rq {
	struct load_weight load;
	unsigned int nr_running;
	unsigned int h_nr_running;
	unsigned int idle_h_nr_running;
	u64 exec_clock;
	u64 min_vruntime;
	unsigned int forceidle_seq;
	u64 min_vruntime_fi;
	struct rb_root_cached tasks_timeline;
	struct sched_entity *curr;
	struct sched_entity *next;
	struct sched_entity *last;
	struct sched_entity *skip;
	unsigned int nr_spread_over;
	long: 32;
	long: 64;
	struct sched_avg avg;
	struct {
		raw_spinlock_t lock;
		int nr;
		long unsigned int load_avg;
		long unsigned int util_avg;
		long unsigned int runnable_avg;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	} removed;
	long unsigned int tg_load_avg_contrib;
	long int propagate;
	long int prop_runnable_sum;
	long unsigned int h_load;
	u64 last_h_load_update;
	struct sched_entity *h_load_next;
	struct rq___2 *rq;
	int on_list;
	struct list_head leaf_cfs_rq_list;
	struct task_group___2 *tg;
	int idle;
	int runtime_enabled;
	s64 runtime_remaining;
	u64 throttled_clock;
	u64 throttled_clock_task;
	u64 throttled_clock_task_time;
	int throttled;
	int throttle_count;
	struct list_head throttled_list;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct sched_class___2 {
	int uclamp_enabled;
	void (*enqueue_task)(struct rq___2 *, struct task_struct___37 *, int);
	void (*dequeue_task)(struct rq___2 *, struct task_struct___37 *, int);
	void (*yield_task)(struct rq___2 *);
	bool (*yield_to_task)(struct rq___2 *, struct task_struct___37 *);
	void (*check_preempt_curr)(struct rq___2 *, struct task_struct___37 *, int);
	struct task_struct___37 * (*pick_next_task)(struct rq___2 *);
	void (*put_prev_task)(struct rq___2 *, struct task_struct___37 *);
	void (*set_next_task)(struct rq___2 *, struct task_struct___37 *, bool);
	int (*balance)(struct rq___2 *, struct task_struct___37 *, struct rq_flags *);
	int (*select_task_rq)(struct task_struct___37 *, int, int);
	struct task_struct___37 * (*pick_task)(struct rq___2 *);
	void (*migrate_task_rq)(struct task_struct___37 *, int);
	void (*task_woken)(struct rq___2 *, struct task_struct___37 *);
	void (*set_cpus_allowed)(struct task_struct___37 *, const struct cpumask *, u32);
	void (*rq_online)(struct rq___2 *);
	void (*rq_offline)(struct rq___2 *);
	struct rq___2 * (*find_lock_rq)(struct task_struct___37 *, struct rq___2 *);
	void (*task_tick)(struct rq___2 *, struct task_struct___37 *, int);
	void (*task_fork)(struct task_struct___37 *);
	void (*task_dead)(struct task_struct___37 *);
	void (*switched_from)(struct rq___2 *, struct task_struct___37 *);
	void (*switched_to)(struct rq___2 *, struct task_struct___37 *);
	void (*prio_changed)(struct rq___2 *, struct task_struct___37 *, int);
	unsigned int (*get_rr_interval)(struct rq___2 *, struct task_struct___37 *);
	void (*update_curr)(struct rq___2 *);
	void (*task_change_group)(struct task_struct___37 *, int);
};

struct cgroup___27;

struct cgroup_subsys___27;

struct cgroup_subsys_state___27 {
	struct cgroup___27 *cgroup;
	struct cgroup_subsys___27 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___27 *parent;
};

struct cfs_bandwidth {
	raw_spinlock_t lock;
	ktime_t period;
	u64 quota;
	u64 runtime;
	u64 burst;
	s64 hierarchical_quota;
	u8 idle;
	u8 period_active;
	u8 slack_started;
	struct hrtimer period_timer;
	struct hrtimer slack_timer;
	struct list_head throttled_cfs_rq;
	int nr_periods;
	int nr_throttled;
	u64 throttled_time;
};

struct task_group___2 {
	struct cgroup_subsys_state___27 css;
	struct sched_entity **se;
	struct cfs_rq **cfs_rq;
	long unsigned int shares;
	int idle;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	atomic_long_t load_avg;
	struct callback_head rcu;
	struct list_head list;
	struct task_group___2 *parent;
	struct list_head siblings;
	struct list_head children;
	struct autogroup___2 *autogroup;
	struct cfs_bandwidth cfs_bandwidth;
	unsigned int uclamp_pct[2];
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct cgroup_namespace___27;

struct nsproxy___32 {
	atomic_t count;
	struct uts_namespace___4 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___28 *pid_ns_for_children;
	struct net___4 *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___27 *cgroup_ns;
};

struct bio___22;

struct bio_list___22 {
	struct bio___22 *head;
	struct bio___22 *tail;
};

struct bdi_writeback___21 {
	struct backing_dev_info___21 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	atomic_t writeback_inodes;
	struct percpu_counter stat[4];
	long unsigned int congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	struct delayed_work bw_dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___27 *memcg_css;
	struct cgroup_subsys_state___27 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	struct list_head b_attached;
	struct list_head offline_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
};

struct device___35;

struct backing_dev_info___21 {
	u64 id;
	struct rb_node rb_node;
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___21 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct mutex cgwb_release_mutex;
	struct rw_semaphore wb_switch_rwsem;
	wait_queue_head_t wb_waitq;
	struct device___35 *dev;
	char dev_name[64];
	struct device___35 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___33 *debug_dir;
};

struct io_cq___22;

struct io_context___22 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	struct xarray icq_tree;
	struct io_cq___22 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct css_set___27 {
	struct cgroup_subsys_state___27 *subsys[14];
	refcount_t refcount;
	struct css_set___27 *dom_cset;
	struct cgroup___27 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___27 *mg_src_cgrp;
	struct cgroup___27 *mg_dst_cgrp;
	struct css_set___27 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___21 {
	struct pmu___21 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	int rotate_necessary;
	refcount_t refcount;
	struct task_struct___37 *task;
	u64 time;
	u64 timestamp;
	u64 timeoffset;
	struct perf_event_context___21 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

struct pipe_buffer___12;

struct pipe_inode_info___12 {
	struct mutex mutex;
	wait_queue_head_t rd_wait;
	wait_queue_head_t wr_wait;
	unsigned int head;
	unsigned int tail;
	unsigned int max_usage;
	unsigned int ring_size;
	bool note_loss;
	unsigned int nr_accounted;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int r_counter;
	unsigned int w_counter;
	unsigned int poll_usage;
	struct page___35 *tmp_page;
	struct fasync_struct___33 *fasync_readers;
	struct fasync_struct___33 *fasync_writers;
	struct pipe_buffer___12 *bufs;
	struct user_struct *user;
	struct watch_queue *watch_queue;
};

struct kernfs_node___33;

struct cgroup_file___27 {
	struct kernfs_node___33 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct obj_cgroup___21;

struct mem_cgroup_per_node___21;

struct mem_cgroup___21 {
	struct cgroup_subsys_state___27 css;
	struct mem_cgroup_id id;
	struct page_counter memory;
	union {
		struct page_counter swap;
		struct page_counter memsw;
	};
	struct page_counter kmem;
	struct page_counter tcpmem;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool oom_group;
	bool oom_lock;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___27 events_file;
	struct cgroup_file___27 events_local_file;
	struct cgroup_file___27 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	struct memcg_vmstats vmstats;
	atomic_long_t memory_events[8];
	atomic_long_t memory_events_local[8];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct obj_cgroup___21 *objcg;
	struct list_head objcg_list;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad2_;
	atomic_t moving_account;
	struct task_struct___37 *move_lock_task;
	struct memcg_vmstats_percpu *vmstats_percpu;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct memcg_cgwb_frn cgwb_frn[4];
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct deferred_split deferred_split_queue;
	struct mem_cgroup_per_node___21 *nodeinfo[0];
	long: 64;
};

struct kset___32;

struct kobj_type___32;

struct kobject___33 {
	const char *name;
	struct list_head entry;
	struct kobject___33 *parent;
	struct kset___32 *kset;
	struct kobj_type___32 *ktype;
	struct kernfs_node___33 *sd;
	struct kref kref;
	unsigned int state_initialized;
	unsigned int state_in_sysfs;
	unsigned int state_add_uevent_sent;
	unsigned int state_remove_uevent_sent;
	unsigned int uevent_suppress;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct blk_integrity_profile___22;

struct blk_integrity___22 {
	const struct blk_integrity_profile___22 *profile;
	unsigned char flags;
	unsigned char tuple_size;
	unsigned char interval_exp;
	unsigned char tag_size;
};

struct bio_set___22 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	struct bio_alloc_cache *cache;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	unsigned int back_pad;
	spinlock_t rescue_lock;
	struct bio_list___22 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	struct hlist_node cpuhp_dead;
};

struct request___22;

struct elevator_queue___22;

struct gendisk___22;

struct blkcg_gq___21;

struct request_queue___22 {
	struct request___22 *last_merge;
	struct elevator_queue___22 *elevator;
	struct percpu_ref q_usage_counter;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	const struct blk_mq_ops *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx **queue_hw_ctx;
	unsigned int nr_hw_queues;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	spinlock_t queue_lock;
	struct gendisk___22 *disk;
	struct kobject___33 kobj;
	struct kobject___33 *mq_kobj;
	struct blk_integrity___22 integrity;
	struct device___35 *dev;
	enum rpm_status rpm_status;
	long unsigned int nr_requests;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_keyslot_manager *ksm;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	atomic_t nr_active_requests_shared_sbitmap;
	struct sbitmap_queue sched_bitmap_tags;
	struct sbitmap_queue sched_breserved_tags;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___21 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int required_elevator_features;
	unsigned int nr_zones;
	long unsigned int *conv_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int max_open_zones;
	unsigned int max_active_zones;
	int node;
	struct mutex debugfs_mutex;
	struct blk_trace *blk_trace;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	struct mutex sysfs_dir_lock;
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	int mq_freeze_depth;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct mutex mq_freeze_lock;
	struct blk_mq_tag_set *tag_set;
	struct list_head tag_set_list;
	struct bio_set___22 bio_split;
	struct dentry___33 *debugfs_dir;
	struct dentry___33 *sched_debugfs_dir;
	struct dentry___33 *rqos_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	u64 write_hints[5];
};

struct vm_struct___30 {
	struct vm_struct___30 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___35 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct kthread_work___2;

typedef void (*kthread_work_func_t___2)(struct kthread_work___2 *);

struct kthread_worker___2;

struct kthread_work___2 {
	struct list_head node;
	kthread_work_func_t___2 func;
	struct kthread_worker___2 *worker;
	int canceling;
};

struct kthread_worker___2 {
	unsigned int flags;
	raw_spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___37 *task;
	struct kthread_work___2 *current_work;
};

struct address_space_operations___33;

struct address_space___33 {
	struct inode___33 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___33 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct page_pool_params___11 {
	unsigned int flags;
	unsigned int order;
	unsigned int pool_size;
	int nid;
	struct device___35 *dev;
	enum dma_data_direction dma_dir;
	unsigned int max_len;
	unsigned int offset;
};

struct pp_alloc_cache___11 {
	u32 count;
	struct page___35 *cache[128];
};

struct page_pool___11 {
	struct page_pool_params___11 p;
	struct delayed_work release_dw;
	void (*disconnect)(void *);
	long unsigned int defer_start;
	long unsigned int defer_warn;
	u32 pages_state_hold_cnt;
	unsigned int frag_offset;
	struct page___35 *frag_page;
	long int frag_users;
	long: 64;
	long: 64;
	struct pp_alloc_cache___11 alloc;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct ptr_ring ring;
	atomic_t pages_state_release_cnt;
	refcount_t user_cnt;
	u64 destroy_cnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pagemap_ops___33;

struct dev_pagemap___33 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___33 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vfsmount___33;

struct path___33 {
	struct vfsmount___33 *mnt;
	struct dentry___33 *dentry;
};

struct fown_struct___28 {
	rwlock_t lock;
	struct pid___28 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___33 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___33 f_path;
	struct inode___33 *f_inode;
	const struct file_operations___33 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___28 f_owner;
	const struct cred___2 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___33 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___33;

struct vm_operations_struct___33 {
	void (*open)(struct vm_area_struct___36 *);
	void (*close)(struct vm_area_struct___36 *);
	int (*may_split)(struct vm_area_struct___36 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___36 *);
	int (*mprotect)(struct vm_area_struct___36 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___33 *);
	vm_fault_t (*huge_fault)(struct vm_fault___33 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___33 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___36 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___33 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___33 *);
	int (*access)(struct vm_area_struct___36 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___36 *);
	int (*set_policy)(struct vm_area_struct___36 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___36 *, long unsigned int);
	struct page___35 * (*find_special_page)(struct vm_area_struct___36 *, long unsigned int);
};

struct core_thread___35 {
	struct task_struct___37 *task;
	struct core_thread___35 *next;
};

struct core_state___35 {
	atomic_t nr_threads;
	struct core_thread___35 dumper;
	struct completion startup;
};

struct linux_binprm___9;

struct coredump_params___8;

struct linux_binfmt___8 {
	struct list_head lh;
	struct module___32 *module;
	int (*load_binary)(struct linux_binprm___9 *);
	int (*load_shlib)(struct file___33 *);
	int (*core_dump)(struct coredump_params___8 *);
	long unsigned int min_coredump;
};

struct vm_fault___33 {
	const struct {
		struct vm_area_struct___36 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___35 *cow_page;
	struct page___35 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___35 prealloc_pte;
};

struct pglist_data___22;

struct lruvec___22 {
	struct list_head lists[5];
	spinlock_t lru_lock;
	long unsigned int anon_cost;
	long unsigned int file_cost;
	atomic_long_t nonresident_age;
	long unsigned int refaults[2];
	long unsigned int flags;
	struct pglist_data___22 *pgdat;
};

struct zone___22 {
	long unsigned int _watermark[3];
	long unsigned int watermark_boost;
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[5];
	int node;
	struct pglist_data___22 *zone_pgdat;
	struct per_cpu_pages *per_cpu_pageset;
	struct per_cpu_zonestat *per_cpu_zonestats;
	int pageset_high;
	int pageset_batch;
	long unsigned int zone_start_pfn;
	atomic_long_t managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int present_early_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	seqlock_t span_seqlock;
	int initialized;
	int: 32;
	struct zone_padding _pad1_;
	struct free_area free_area[11];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	long unsigned int compact_init_migrate_pfn;
	long unsigned int compact_init_free_pfn;
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	short: 16;
	struct zone_padding _pad3_;
	atomic_long_t vm_stat[11];
	atomic_long_t vm_numa_event[6];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___22 {
	struct zone___22 *zone;
	int zone_idx;
};

struct zonelist___22 {
	struct zoneref___22 _zonerefs[5121];
};

struct pglist_data___22 {
	struct zone___22 node_zones[5];
	struct zonelist___22 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___37 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_highest_zoneidx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_highest_zoneidx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___37 *kcompactd;
	bool proactive_compact_trigger;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct deferred_split deferred_split_queue;
	struct lruvec___22 __lruvec;
	long unsigned int flags;
	long: 64;
	struct zone_padding _pad2_;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[39];
};

struct kernfs_root___33;

struct kernfs_elem_dir___33 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___33 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___33;

struct kernfs_root___33 {
	struct kernfs_node___33 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___33 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___33 {
	struct kernfs_node___33 *target_kn;
};

struct kernfs_ops___33;

struct kernfs_elem_attr___33 {
	const struct kernfs_ops___33 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___33 *notify_next;
};

struct kernfs_node___33 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___33 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___33 dir;
		struct kernfs_elem_symlink___33 symlink;
		struct kernfs_elem_attr___33 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___33;

struct kernfs_ops___33 {
	int (*open)(struct kernfs_open_file___33 *);
	void (*release)(struct kernfs_open_file___33 *);
	int (*seq_show)(struct seq_file___31 *, void *);
	void * (*seq_start)(struct seq_file___31 *, loff_t *);
	void * (*seq_next)(struct seq_file___31 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___31 *, void *);
	ssize_t (*read)(struct kernfs_open_file___33 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___33 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___33 *, struct poll_table_struct___24 *);
	int (*mmap)(struct kernfs_open_file___33 *, struct vm_area_struct___36 *);
};

struct kernfs_syscall_ops___33 {
	int (*show_options)(struct seq_file___31 *, struct kernfs_root___33 *);
	int (*mkdir)(struct kernfs_node___33 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___33 *);
	int (*rename)(struct kernfs_node___33 *, struct kernfs_node___33 *, const char *);
	int (*show_path)(struct seq_file___31 *, struct kernfs_node___33 *, struct kernfs_root___33 *);
};

struct seq_file___31 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___31 *op;
	int poll_event;
	const struct file___33 *file;
	void *private;
};

struct kernfs_open_file___33 {
	struct kernfs_node___33 *kn;
	struct file___33 *file;
	struct seq_file___31 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped;
	bool released;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___33 *vm_ops;
};

typedef void (*poll_queue_proc___24)(struct file___33 *, wait_queue_head_t *, struct poll_table_struct___24 *);

struct poll_table_struct___24 {
	poll_queue_proc___24 _qproc;
	__poll_t _key;
};

struct bin_attribute___33;

struct attribute_group___33 {
	const char *name;
	umode_t (*is_visible)(struct kobject___33 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___33 *, struct bin_attribute___33 *, int);
	struct attribute **attrs;
	struct bin_attribute___33 **bin_attrs;
};

struct bin_attribute___33 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___33 * (*f_mapping)();
	ssize_t (*read)(struct file___33 *, struct kobject___33 *, struct bin_attribute___33 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___33 *, struct kobject___33 *, struct bin_attribute___33 *, char *, loff_t, size_t);
	int (*mmap)(struct file___33 *, struct kobject___33 *, struct bin_attribute___33 *, struct vm_area_struct___36 *);
};

struct sysfs_ops___32 {
	ssize_t (*show)(struct kobject___33 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___33 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___32;

struct kset___32 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___33 kobj;
	const struct kset_uevent_ops___32 *uevent_ops;
};

struct kobj_type___32 {
	void (*release)(struct kobject___33 *);
	const struct sysfs_ops___32 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___33 **default_groups;
	const struct kobj_ns_type_operations___3 * (*child_ns_type)(struct kobject___33 *);
	const void * (*namespace)(struct kobject___33 *);
	void (*get_ownership)(struct kobject___33 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___32 {
	int (* const filter)(struct kset___32 *, struct kobject___33 *);
	const char * (* const name)(struct kset___32 *, struct kobject___33 *);
	int (* const uevent)(struct kset___32 *, struct kobject___33 *, struct kobj_uevent_env *);
};

struct sched_domain_attr {
	int relax_domain_level;
};

struct sched_group {
	struct sched_group *next;
	atomic_t ref;
	unsigned int group_weight;
	struct sched_group_capacity *sgc;
	int asym_prefer_cpu;
	int flags;
	long unsigned int cpumask[0];
};

struct sched_group_capacity {
	atomic_t ref;
	long unsigned int capacity;
	long unsigned int min_capacity;
	long unsigned int max_capacity;
	long unsigned int next_update;
	int imbalance;
	int id;
	long unsigned int cpumask[0];
};

struct wakeup_source___35;

struct dev_pm_qos___5;

struct dev_pm_info___35 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___35 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___35 *, s32);
	struct dev_pm_qos___5 *qos;
};

struct device_type___35;

struct bus_type___35;

struct device_driver___35;

struct dev_pm_domain___35;

struct device_node___18;

struct fwnode_handle___32;

struct class___35;

struct device___35 {
	struct kobject___33 kobj;
	struct device___35 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___35 *type;
	struct bus_type___35 *bus;
	struct device_driver___35 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___35 power;
	struct dev_pm_domain___35 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___18 *of_node;
	struct fwnode_handle___32 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___35 *class;
	const struct attribute_group___33 **groups;
	void (*release)(struct device___35 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_ops___35 {
	int (*prepare)(struct device___35 *);
	void (*complete)(struct device___35 *);
	int (*suspend)(struct device___35 *);
	int (*resume)(struct device___35 *);
	int (*freeze)(struct device___35 *);
	int (*thaw)(struct device___35 *);
	int (*poweroff)(struct device___35 *);
	int (*restore)(struct device___35 *);
	int (*suspend_late)(struct device___35 *);
	int (*resume_early)(struct device___35 *);
	int (*freeze_late)(struct device___35 *);
	int (*thaw_early)(struct device___35 *);
	int (*poweroff_late)(struct device___35 *);
	int (*restore_early)(struct device___35 *);
	int (*suspend_noirq)(struct device___35 *);
	int (*resume_noirq)(struct device___35 *);
	int (*freeze_noirq)(struct device___35 *);
	int (*thaw_noirq)(struct device___35 *);
	int (*poweroff_noirq)(struct device___35 *);
	int (*restore_noirq)(struct device___35 *);
	int (*runtime_suspend)(struct device___35 *);
	int (*runtime_resume)(struct device___35 *);
	int (*runtime_idle)(struct device___35 *);
};

struct wakeup_source___35 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___35 *dev;
	bool active;
	bool autosleep_enabled;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_qos_request___5;

struct dev_pm_qos___5 {
	struct pm_qos_constraints resume_latency;
	struct pm_qos_constraints latency_tolerance;
	struct freq_constraints freq;
	struct pm_qos_flags flags;
	struct dev_pm_qos_request___5 *resume_latency_req;
	struct dev_pm_qos_request___5 *latency_tolerance_req;
	struct dev_pm_qos_request___5 *flags_req;
};

struct dev_pm_domain___35 {
	struct dev_pm_ops___35 ops;
	int (*start)(struct device___35 *);
	void (*detach)(struct device___35 *, bool);
	int (*activate)(struct device___35 *);
	void (*sync)(struct device___35 *);
	void (*dismiss)(struct device___35 *);
};

struct bus_type___35 {
	const char *name;
	const char *dev_name;
	struct device___35 *dev_root;
	const struct attribute_group___33 **bus_groups;
	const struct attribute_group___33 **dev_groups;
	const struct attribute_group___33 **drv_groups;
	int (*match)(struct device___35 *, struct device_driver___35 *);
	int (*uevent)(struct device___35 *, struct kobj_uevent_env *);
	int (*probe)(struct device___35 *);
	void (*sync_state)(struct device___35 *);
	void (*remove)(struct device___35 *);
	void (*shutdown)(struct device___35 *);
	int (*online)(struct device___35 *);
	int (*offline)(struct device___35 *);
	int (*suspend)(struct device___35 *, pm_message_t);
	int (*resume)(struct device___35 *);
	int (*num_vf)(struct device___35 *);
	int (*dma_configure)(struct device___35 *);
	const struct dev_pm_ops___35 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___35 {
	const char *name;
	struct bus_type___35 *bus;
	struct module___32 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___35 *);
	void (*sync_state)(struct device___35 *);
	int (*remove)(struct device___35 *);
	void (*shutdown)(struct device___35 *);
	int (*suspend)(struct device___35 *, pm_message_t);
	int (*resume)(struct device___35 *);
	const struct attribute_group___33 **groups;
	const struct attribute_group___33 **dev_groups;
	const struct dev_pm_ops___35 *pm;
	void (*coredump)(struct device___35 *);
	struct driver_private *p;
};

struct device_type___35 {
	const char *name;
	const struct attribute_group___33 **groups;
	int (*uevent)(struct device___35 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___35 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___35 *);
	const struct dev_pm_ops___35 *pm;
};

struct class___35 {
	const char *name;
	struct module___32 *owner;
	const struct attribute_group___33 **class_groups;
	const struct attribute_group___33 **dev_groups;
	struct kobject___33 *dev_kobj;
	int (*dev_uevent)(struct device___35 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___35 *, umode_t *);
	void (*class_release)(struct class___35 *);
	void (*dev_release)(struct device___35 *);
	int (*shutdown_pre)(struct device___35 *);
	const struct kobj_ns_type_operations___3 *ns_type;
	const void * (*namespace)(struct device___35 *);
	void (*get_ownership)(struct device___35 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___35 *pm;
	struct subsys_private *p;
};

struct module_kobject___32 {
	struct kobject___33 kobj;
	struct module___32 *mod;
	struct kobject___33 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___32 {
	struct module___32 *mod;
	struct latch_tree_node node;
};

struct module_layout___32 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___32 mtn;
};

struct module_attribute___32;

struct kernel_param___32;

struct module___32 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___32 mkobj;
	struct module_attribute___32 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___33 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___32 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___32 core_layout;
	struct module_layout___32 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map___24 *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___21 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	int num_static_call_sites;
	struct static_call_site *static_call_sites;
	bool klp;
	bool klp_alive;
	struct klp_modinfo *klp_info;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fwnode_operations___32;

struct fwnode_handle___32 {
	struct fwnode_handle___32 *secondary;
	const struct fwnode_operations___32 *ops;
	struct device___35 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct device_node___18 {
	const char *name;
	phandle phandle;
	const char *full_name;
	struct fwnode_handle___32 fwnode;
	struct property *properties;
	struct property *deadprops;
	struct device_node___18 *parent;
	struct device_node___18 *child;
	struct device_node___18 *sibling;
	long unsigned int _flags;
	void *data;
};

struct linux_binprm___9 {
	struct vm_area_struct___36 *vma;
	long unsigned int vma_pages;
	struct mm_struct___36 *mm;
	long unsigned int p;
	long unsigned int argmin;
	unsigned int have_execfd;
	unsigned int execfd_creds;
	unsigned int secureexec;
	unsigned int point_of_no_return;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct file___33 *executable;
	struct file___33 *interpreter;
	struct file___33 *file;
	struct cred___2 *cred;
	int unsafe;
	unsigned int per_clear;
	int argc;
	int envc;
	const char *filename;
	const char *interp;
	const char *fdpath;
	unsigned int interp_flags;
	int execfd;
	long unsigned int loader;
	long unsigned int exec;
	struct rlimit rlim_stack;
	char buf[256];
};

struct coredump_params___8 {
	const kernel_siginfo_t *siginfo;
	struct pt_regs *regs;
	struct file___33 *file;
	long unsigned int limit;
	long unsigned int mm_flags;
	loff_t written;
	loff_t pos;
	loff_t to_skip;
};

struct shrink_control___21 {
	gfp_t gfp_mask;
	int nid;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	struct mem_cgroup___21 *memcg;
};

struct shrinker___21 {
	long unsigned int (*count_objects)(struct shrinker___21 *, struct shrink_control___21 *);
	long unsigned int (*scan_objects)(struct shrinker___21 *, struct shrink_control___21 *);
	long int batch;
	int seeks;
	unsigned int flags;
	struct list_head list;
	int id;
	atomic_long_t *nr_deferred;
};

struct dev_pagemap_ops___33 {
	void (*page_free)(struct page___35 *);
	void (*kill)(struct dev_pagemap___33 *);
	void (*cleanup)(struct dev_pagemap___33 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___33 *);
};

struct dentry_operations___33;

struct dentry___33 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___33 *d_parent;
	struct qstr d_name;
	struct inode___33 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___33 *d_op;
	struct super_block___33 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___33;

struct inode___33 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___33 *i_op;
	struct super_block___33 *i_sb;
	struct address_space___33 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___21 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___33 *i_fop;
		void (*free_inode)(struct inode___33 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___33 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___12 *i_pipe;
		struct cdev *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___33 {
	int (*d_revalidate)(struct dentry___33 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___33 *, unsigned int);
	int (*d_hash)(const struct dentry___33 *, struct qstr *);
	int (*d_compare)(const struct dentry___33 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___33 *);
	int (*d_init)(struct dentry___33 *);
	void (*d_release)(struct dentry___33 *);
	void (*d_prune)(struct dentry___33 *);
	void (*d_iput)(struct dentry___33 *, struct inode___33 *);
	char * (*d_dname)(struct dentry___33 *, char *, int);
	struct vfsmount___33 * (*d_automount)(struct path___33 *);
	int (*d_manage)(const struct path___33 *, bool);
	struct dentry___33 * (*d_real)(struct dentry___33 *, const struct inode___33 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___33;

struct mem_dqinfo___33 {
	struct quota_format_type___33 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___33;

struct quota_info___33 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___33 *files[3];
	struct mem_dqinfo___33 info[3];
	const struct quota_format_ops___33 *ops[3];
};

struct rcuwait___33 {
	struct task_struct___37 *task;
};

struct percpu_rw_semaphore___33 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___33 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___33 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___33 rw_sem[3];
};

struct super_operations___33;

struct dquot_operations___33;

struct quotactl_ops___33;

struct block_device___22;

struct super_block___33 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___33 *s_type;
	const struct super_operations___33 *s_op;
	const struct dquot_operations___33 *dq_op;
	const struct quotactl_ops___33 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___33 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___22 *s_bdev;
	struct backing_dev_info___21 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___33 s_dquot;
	struct sb_writers___33 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___33 *s_d_op;
	int cleancache_poolid;
	struct shrinker___21 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___2 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___33 {
	struct dentry___33 *mnt_root;
	struct super_block___33 *mnt_sb;
	int mnt_flags;
	struct user_namespace___2 *mnt_userns;
};

struct kernel_clone_args___3 {
	u64 flags;
	int *pidfd;
	int *child_tid;
	int *parent_tid;
	int exit_signal;
	long unsigned int stack;
	long unsigned int stack_size;
	long unsigned int tls;
	pid_t *set_tid;
	size_t set_tid_size;
	int cgroup;
	int io_thread;
	struct cgroup___27 *cgrp;
	struct css_set___27 *cset;
};

struct psi_group___27 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___37 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___27;

struct cgroup_rstat_cpu___27;

struct cgroup___27 {
	struct cgroup_subsys_state___27 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___33 *kn;
	struct cgroup_file___27 procs_file;
	struct cgroup_file___27 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___27 *subsys[14];
	struct cgroup_root___27 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___27 *dom_cgrp;
	struct cgroup___27 *old_dom_cgrp;
	struct cgroup_rstat_cpu___27 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___27 psi;
	struct cgroup_bpf___4 bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct autogroup___2 {
	struct kref kref;
	struct task_group___2 *tg;
	struct rw_semaphore lock;
	long unsigned int id;
	int nice;
};

struct io_cq___22 {
	struct request_queue___22 *q;
	struct io_context___22 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct wait_page_queue___18;

struct kiocb___33 {
	struct file___33 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___33 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___18 *ki_waitq;
	};
};

struct iattr___33 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___33 *ia_file;
};

struct dquot___33 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___33 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___33 {
	int qf_fmt_id;
	const struct quota_format_ops___33 *qf_ops;
	struct module___32 *qf_owner;
	struct quota_format_type___33 *qf_next;
};

struct quota_format_ops___33 {
	int (*check_quota_file)(struct super_block___33 *, int);
	int (*read_file_info)(struct super_block___33 *, int);
	int (*write_file_info)(struct super_block___33 *, int);
	int (*free_file_info)(struct super_block___33 *, int);
	int (*read_dqblk)(struct dquot___33 *);
	int (*commit_dqblk)(struct dquot___33 *);
	int (*release_dqblk)(struct dquot___33 *);
	int (*get_next_id)(struct super_block___33 *, struct kqid *);
};

struct dquot_operations___33 {
	int (*write_dquot)(struct dquot___33 *);
	struct dquot___33 * (*alloc_dquot)(struct super_block___33 *, int);
	void (*destroy_dquot)(struct dquot___33 *);
	int (*acquire_dquot)(struct dquot___33 *);
	int (*release_dquot)(struct dquot___33 *);
	int (*mark_dirty)(struct dquot___33 *);
	int (*write_info)(struct super_block___33 *, int);
	qsize_t * (*get_reserved_space)(struct inode___33 *);
	int (*get_projid)(struct inode___33 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___33 *, qsize_t *);
	int (*get_next_id)(struct super_block___33 *, struct kqid *);
};

struct quotactl_ops___33 {
	int (*quota_on)(struct super_block___33 *, int, int, const struct path___33 *);
	int (*quota_off)(struct super_block___33 *, int);
	int (*quota_enable)(struct super_block___33 *, unsigned int);
	int (*quota_disable)(struct super_block___33 *, unsigned int);
	int (*quota_sync)(struct super_block___33 *, int);
	int (*set_info)(struct super_block___33 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___33 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___33 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___33 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___33 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___33 *, unsigned int);
};

struct wait_page_queue___18 {
	struct page___35 *page;
	int bit_nr;
	wait_queue_entry_t wait;
};

struct writeback_control___21;

struct readahead_control___18;

struct swap_info_struct___14;

struct address_space_operations___33 {
	int (*writepage)(struct page___35 *, struct writeback_control___21 *);
	int (*readpage)(struct file___33 *, struct page___35 *);
	int (*writepages)(struct address_space___33 *, struct writeback_control___21 *);
	int (*set_page_dirty)(struct page___35 *);
	int (*readpages)(struct file___33 *, struct address_space___33 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___18 *);
	int (*write_begin)(struct file___33 *, struct address_space___33 *, loff_t, unsigned int, unsigned int, struct page___35 **, void **);
	int (*write_end)(struct file___33 *, struct address_space___33 *, loff_t, unsigned int, unsigned int, struct page___35 *, void *);
	sector_t (*bmap)(struct address_space___33 *, sector_t);
	void (*invalidatepage)(struct page___35 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___35 *, gfp_t);
	void (*freepage)(struct page___35 *);
	ssize_t (*direct_IO)(struct kiocb___33 *, struct iov_iter___27 *);
	int (*migratepage)(struct address_space___33 *, struct page___35 *, struct page___35 *, enum migrate_mode);
	bool (*isolate_page)(struct page___35 *, isolate_mode_t);
	void (*putback_page)(struct page___35 *);
	int (*launder_page)(struct page___35 *);
	int (*is_partially_uptodate)(struct page___35 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___35 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___33 *, struct page___35 *);
	int (*swap_activate)(struct swap_info_struct___14 *, struct file___33 *, sector_t *);
	void (*swap_deactivate)(struct file___33 *);
};

struct writeback_control___21 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate;
	unsigned int for_background;
	unsigned int tagged_writepages;
	unsigned int for_reclaim;
	unsigned int range_cyclic;
	unsigned int for_sync;
	unsigned int no_cgroup_owner;
	unsigned int punt_to_cgroup;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bdi_writeback___21 *wb;
	struct inode___33 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
};

struct readahead_control___18 {
	struct file___33 *file;
	struct address_space___33 *mapping;
	struct file_ra_state *ra;
	long unsigned int _index;
	unsigned int _nr_pages;
	unsigned int _batch_count;
};

struct bio_vec___27;

struct iov_iter___27 {
	u8 iter_type;
	bool data_source;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___27 *bvec;
		struct xarray *xarray;
		struct pipe_inode_info___12 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			unsigned int head;
			unsigned int start_head;
		};
		loff_t xarray_start;
	};
};

struct swap_info_struct___14 {
	struct percpu_ref users;
	long unsigned int flags;
	short int prio;
	struct plist_node list;
	signed char type;
	unsigned int max;
	unsigned char *swap_map;
	struct swap_cluster_info *cluster_info;
	struct swap_cluster_list free_clusters;
	unsigned int lowest_bit;
	unsigned int highest_bit;
	unsigned int pages;
	unsigned int inuse_pages;
	unsigned int cluster_next;
	unsigned int cluster_nr;
	unsigned int *cluster_next_cpu;
	struct percpu_cluster *percpu_cluster;
	struct rb_root swap_extent_root;
	struct block_device___22 *bdev;
	struct file___33 *swap_file;
	unsigned int old_block_size;
	struct completion comp;
	long unsigned int *frontswap_map;
	atomic_t frontswap_pages;
	spinlock_t lock;
	spinlock_t cont_lock;
	struct work_struct discard_work;
	struct swap_cluster_list discard_clusters;
	struct plist_node avail_lists[0];
};

struct inode_operations___33 {
	struct dentry___33 * (*lookup)(struct inode___33 *, struct dentry___33 *, unsigned int);
	const char * (*get_link)(struct dentry___33 *, struct inode___33 *, struct delayed_call *);
	int (*permission)(struct user_namespace___2 *, struct inode___33 *, int);
	struct posix_acl * (*get_acl)(struct inode___33 *, int, bool);
	int (*readlink)(struct dentry___33 *, char *, int);
	int (*create)(struct user_namespace___2 *, struct inode___33 *, struct dentry___33 *, umode_t, bool);
	int (*link)(struct dentry___33 *, struct inode___33 *, struct dentry___33 *);
	int (*unlink)(struct inode___33 *, struct dentry___33 *);
	int (*symlink)(struct user_namespace___2 *, struct inode___33 *, struct dentry___33 *, const char *);
	int (*mkdir)(struct user_namespace___2 *, struct inode___33 *, struct dentry___33 *, umode_t);
	int (*rmdir)(struct inode___33 *, struct dentry___33 *);
	int (*mknod)(struct user_namespace___2 *, struct inode___33 *, struct dentry___33 *, umode_t, dev_t);
	int (*rename)(struct user_namespace___2 *, struct inode___33 *, struct dentry___33 *, struct inode___33 *, struct dentry___33 *, unsigned int);
	int (*setattr)(struct user_namespace___2 *, struct dentry___33 *, struct iattr___33 *);
	int (*getattr)(struct user_namespace___2 *, const struct path___33 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___33 *, char *, size_t);
	int (*fiemap)(struct inode___33 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___33 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___33 *, struct dentry___33 *, struct file___33 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace___2 *, struct inode___33 *, struct dentry___33 *, umode_t);
	int (*set_acl)(struct user_namespace___2 *, struct inode___33 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace___2 *, struct dentry___33 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___33 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___33 {
	void (*fl_copy_lock)(struct file_lock___33 *, struct file_lock___33 *);
	void (*fl_release_private)(struct file_lock___33 *);
};

struct lock_manager_operations___33;

struct file_lock___33 {
	struct file_lock___33 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___33 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___33 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___33 *fl_ops;
	const struct lock_manager_operations___33 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___33 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___33 *);
	int (*lm_grant)(struct file_lock___33 *, int);
	bool (*lm_break)(struct file_lock___33 *);
	int (*lm_change)(struct file_lock___33 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___33 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___33 *);
};

struct fasync_struct___33 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___33 *fa_next;
	struct file___33 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___33 {
	struct inode___33 * (*alloc_inode)(struct super_block___33 *);
	void (*destroy_inode)(struct inode___33 *);
	void (*free_inode)(struct inode___33 *);
	void (*dirty_inode)(struct inode___33 *, int);
	int (*write_inode)(struct inode___33 *, struct writeback_control___21 *);
	int (*drop_inode)(struct inode___33 *);
	void (*evict_inode)(struct inode___33 *);
	void (*put_super)(struct super_block___33 *);
	int (*sync_fs)(struct super_block___33 *, int);
	int (*freeze_super)(struct super_block___33 *);
	int (*freeze_fs)(struct super_block___33 *);
	int (*thaw_super)(struct super_block___33 *);
	int (*unfreeze_fs)(struct super_block___33 *);
	int (*statfs)(struct dentry___33 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___33 *, int *, char *);
	void (*umount_begin)(struct super_block___33 *);
	int (*show_options)(struct seq_file___31 *, struct dentry___33 *);
	int (*show_devname)(struct seq_file___31 *, struct dentry___33 *);
	int (*show_path)(struct seq_file___31 *, struct dentry___33 *);
	int (*show_stats)(struct seq_file___31 *, struct dentry___33 *);
	ssize_t (*quota_read)(struct super_block___33 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___33 *, int, const char *, size_t, loff_t);
	struct dquot___33 ** (*get_dquots)(struct inode___33 *);
	long int (*nr_cached_objects)(struct super_block___33 *, struct shrink_control___21 *);
	long int (*free_cached_objects)(struct super_block___33 *, struct shrink_control___21 *);
	struct file___33 * (*real_loop)(struct file___33 *);
};

struct block_device___22 {
	sector_t bd_start_sect;
	struct disk_stats *bd_stats;
	long unsigned int bd_stamp;
	bool bd_read_only;
	dev_t bd_dev;
	int bd_openers;
	struct inode___33 *bd_inode;
	struct super_block___33 *bd_super;
	void *bd_claiming;
	struct device___35 bd_device;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct kobject___33 *bd_holder_dir;
	u8 bd_partno;
	spinlock_t bd_size_lock;
	struct gendisk___22 *bd_disk;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	struct super_block___33 *bd_fsfreeze_sb;
	struct partition_meta_info *bd_meta_info;
};

typedef void bio_end_io_t___22(struct bio___22 *);

struct bio_vec___27 {
	struct page___35 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___22;

struct bio___22 {
	struct bio___22 *bi_next;
	struct block_device___22 *bi_bdev;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	atomic_t __bi_remaining;
	struct bvec_iter bi_iter;
	bio_end_io_t___22 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___21 *bi_blkg;
	struct bio_issue bi_issue;
	u64 bi_iocost_cost;
	struct bio_crypt_ctx *bi_crypt_context;
	union {
		struct bio_integrity_payload___22 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___27 *bi_io_vec;
	struct bio_set___22 *bi_pool;
	struct bio_vec___27 bi_inline_vecs[0];
};

enum ctx_state {
	CONTEXT_DISABLED = 4294967295,
	CONTEXT_KERNEL = 0,
	CONTEXT_USER = 1,
	CONTEXT_GUEST = 2,
};

struct cgroup_namespace___27 {
	struct ns_common___5 ns;
	struct user_namespace___2 *user_ns;
	struct ucounts___2 *ucounts;
	struct css_set___27 *root_cset;
};

struct perf_cpu_context___21;

struct perf_output_handle___21;

struct pmu___21 {
	struct list_head entry;
	struct module___32 *module;
	struct device___35 *dev;
	const struct attribute_group___33 **attr_groups;
	const struct attribute_group___33 **attr_update;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___21 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___21 *);
	void (*pmu_disable)(struct pmu___21 *);
	int (*event_init)(struct perf_event___21 *);
	void (*event_mapped)(struct perf_event___21 *, struct mm_struct___36 *);
	void (*event_unmapped)(struct perf_event___21 *, struct mm_struct___36 *);
	int (*add)(struct perf_event___21 *, int);
	void (*del)(struct perf_event___21 *, int);
	void (*start)(struct perf_event___21 *, int);
	void (*stop)(struct perf_event___21 *, int);
	void (*read)(struct perf_event___21 *);
	void (*start_txn)(struct pmu___21 *, unsigned int);
	int (*commit_txn)(struct pmu___21 *);
	void (*cancel_txn)(struct pmu___21 *);
	int (*event_idx)(struct perf_event___21 *);
	void (*sched_task)(struct perf_event_context___21 *, bool);
	struct kmem_cache *task_ctx_cache;
	void (*swap_task_ctx)(struct perf_event_context___21 *, struct perf_event_context___21 *);
	void * (*setup_aux)(struct perf_event___21 *, void **, int, bool);
	void (*free_aux)(void *);
	long int (*snapshot_aux)(struct perf_event___21 *, struct perf_output_handle___21 *, long unsigned int);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___21 *);
	int (*aux_output_match)(struct perf_event___21 *);
	int (*filter_match)(struct perf_event___21 *);
	int (*check_period)(struct perf_event___21 *, u64);
};

struct kernel_param_ops___32 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___32 *);
	int (*get)(char *, const struct kernel_param___32 *);
	void (*free)(void *);
};

struct kparam_array___32;

struct kernel_param___32 {
	const char *name;
	struct module___32 *mod;
	const struct kernel_param_ops___32 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___32 *arr;
	};
};

struct kparam_array___32 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___32 *ops;
	void *elem;
};

struct module_attribute___32 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___32 *, struct module_kobject___32 *, char *);
	ssize_t (*store)(struct module_attribute___32 *, struct module_kobject___32 *, const char *, size_t);
	void (*setup)(struct module___32 *, const char *);
	int (*test)(struct module___32 *);
	void (*free)(struct module___32 *);
};

struct trace_event_class___21;

struct trace_event_call___21 {
	struct list_head list;
	struct trace_event_class___21 *class;
	union {
		char *name;
		struct tracepoint___24 *tp;
	};
	struct trace_event event;
	char *print_fmt;
	struct event_filter *filter;
	union {
		void *module;
		atomic_t refcnt;
	};
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
	struct bpf_prog_array___2 *prog_array;
	int (*perf_perm)(struct trace_event_call___21 *, struct perf_event___21 *);
};

struct kernel_cpustat {
	u64 cpustat[10];
};

enum {
	MEMBARRIER_STATE_PRIVATE_EXPEDITED_READY = 1,
	MEMBARRIER_STATE_PRIVATE_EXPEDITED = 2,
	MEMBARRIER_STATE_GLOBAL_EXPEDITED_READY = 4,
	MEMBARRIER_STATE_GLOBAL_EXPEDITED = 8,
	MEMBARRIER_STATE_PRIVATE_EXPEDITED_SYNC_CORE_READY = 16,
	MEMBARRIER_STATE_PRIVATE_EXPEDITED_SYNC_CORE = 32,
	MEMBARRIER_STATE_PRIVATE_EXPEDITED_RSEQ_READY = 64,
	MEMBARRIER_STATE_PRIVATE_EXPEDITED_RSEQ = 128,
};

enum {
	CFTYPE_ONLY_ON_ROOT = 1,
	CFTYPE_NOT_ON_ROOT = 2,
	CFTYPE_NS_DELEGATABLE = 4,
	CFTYPE_NO_PREFIX = 8,
	CFTYPE_WORLD_WRITABLE = 16,
	CFTYPE_DEBUG = 32,
	CFTYPE_PRESSURE = 64,
	__CFTYPE_ONLY_ON_DFL = 65536,
	__CFTYPE_NOT_ON_DFL = 131072,
};

struct cftype___27;

struct cgroup_subsys___27 {
	struct cgroup_subsys_state___27 * (*css_alloc)(struct cgroup_subsys_state___27 *);
	int (*css_online)(struct cgroup_subsys_state___27 *);
	void (*css_offline)(struct cgroup_subsys_state___27 *);
	void (*css_released)(struct cgroup_subsys_state___27 *);
	void (*css_free)(struct cgroup_subsys_state___27 *);
	void (*css_reset)(struct cgroup_subsys_state___27 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___27 *, int);
	int (*css_extra_stat_show)(struct seq_file___31 *, struct cgroup_subsys_state___27 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___37 *, struct css_set___27 *);
	void (*cancel_fork)(struct task_struct___37 *, struct css_set___27 *);
	void (*fork)(struct task_struct___37 *);
	void (*exit)(struct task_struct___37 *);
	void (*release)(struct task_struct___37 *);
	void (*bind)(struct cgroup_subsys_state___27 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___27 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___27 *dfl_cftypes;
	struct cftype___27 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___27 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___27 *updated_children;
	struct cgroup___27 *updated_next;
};

struct cgroup_root___27 {
	struct kernfs_root___33 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___27 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___27 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___27 *ss;
	struct list_head node;
	struct kernfs_ops___33 *kf_ops;
	int (*open)(struct kernfs_open_file___33 *);
	void (*release)(struct kernfs_open_file___33 *);
	u64 (*read_u64)(struct cgroup_subsys_state___27 *, struct cftype___27 *);
	s64 (*read_s64)(struct cgroup_subsys_state___27 *, struct cftype___27 *);
	int (*seq_show)(struct seq_file___31 *, void *);
	void * (*seq_start)(struct seq_file___31 *, loff_t *);
	void * (*seq_next)(struct seq_file___31 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___31 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___27 *, struct cftype___27 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___27 *, struct cftype___27 *, s64);
	ssize_t (*write)(struct kernfs_open_file___33 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___33 *, struct poll_table_struct___24 *);
};

struct css_task_iter {
	struct cgroup_subsys___27 *ss;
	unsigned int flags;
	struct list_head *cset_pos;
	struct list_head *cset_head;
	struct list_head *tcset_pos;
	struct list_head *tcset_head;
	struct list_head *task_pos;
	struct list_head *cur_tasks_head;
	struct css_set___27 *cur_cset;
	struct css_set___27 *cur_dcset;
	struct task_struct___37 *cur_task;
	struct list_head iters_node;
};

struct perf_cpu_context___21 {
	struct perf_event_context___21 ctx;
	struct perf_event_context___21 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___21 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
	int heap_size;
	struct perf_event___21 **heap;
	struct perf_event___21 *heap_default[2];
};

struct perf_output_handle___21 {
	struct perf_event___21 *event;
	struct perf_buffer *rb;
	long unsigned int wakeup;
	long unsigned int size;
	u64 aux_flags;
	union {
		void *addr;
		long unsigned int head;
	};
	int page;
};

struct perf_cgroup___21 {
	struct cgroup_subsys_state___27 css;
	struct perf_cgroup_info *info;
};

struct trace_event_fields___21 {
	const char *type;
	union {
		struct {
			const char *name;
			const int size;
			const int align;
			const int is_signed;
			const int filter_type;
		};
		int (*define_fields)(struct trace_event_call___21 *);
	};
};

struct trace_event_class___21 {
	const char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct trace_event_call___21 *, enum trace_reg, void *);
	struct trace_event_fields___21 *fields_array;
	struct list_head * (*get_fields)(struct trace_event_call___21 *);
	struct list_head fields;
	int (*raw_init)(struct trace_event_call___21 *);
};

struct trace_event_file___11;

struct trace_event_buffer___11 {
	struct trace_buffer *buffer;
	struct ring_buffer_event *event;
	struct trace_event_file___11 *trace_file;
	void *entry;
	unsigned int trace_ctx;
	struct pt_regs *regs;
};

struct trace_event_file___11 {
	struct list_head list;
	struct trace_event_call___21 *event_call;
	struct event_filter *filter;
	struct dentry___33 *dir;
	struct trace_array *tr;
	struct trace_subsystem_dir *system;
	struct list_head triggers;
	long unsigned int flags;
	atomic_t sm_ref;
	atomic_t tm_ref;
};

struct trace_event_raw_sched_kthread_stop {
	struct trace_entry ent;
	char comm[16];
	pid_t pid;
	char __data[0];
};

struct trace_event_raw_sched_kthread_stop_ret {
	struct trace_entry ent;
	int ret;
	char __data[0];
};

struct trace_event_raw_sched_kthread_work_queue_work {
	struct trace_entry ent;
	void *work;
	void *function;
	void *worker;
	char __data[0];
};

struct trace_event_raw_sched_kthread_work_execute_start {
	struct trace_entry ent;
	void *work;
	void *function;
	char __data[0];
};

struct trace_event_raw_sched_kthread_work_execute_end {
	struct trace_entry ent;
	void *work;
	void *function;
	char __data[0];
};

struct trace_event_raw_sched_wakeup_template {
	struct trace_entry ent;
	char comm[16];
	pid_t pid;
	int prio;
	int target_cpu;
	char __data[0];
};

struct trace_event_raw_sched_switch {
	struct trace_entry ent;
	char prev_comm[16];
	pid_t prev_pid;
	int prev_prio;
	long int prev_state;
	char next_comm[16];
	pid_t next_pid;
	int next_prio;
	char __data[0];
};

struct trace_event_raw_sched_migrate_task {
	struct trace_entry ent;
	char comm[16];
	pid_t pid;
	int prio;
	int orig_cpu;
	int dest_cpu;
	char __data[0];
};

struct trace_event_raw_sched_process_template {
	struct trace_entry ent;
	char comm[16];
	pid_t pid;
	int prio;
	char __data[0];
};

struct trace_event_raw_sched_process_wait {
	struct trace_entry ent;
	char comm[16];
	pid_t pid;
	int prio;
	char __data[0];
};

struct trace_event_raw_sched_process_fork {
	struct trace_entry ent;
	char parent_comm[16];
	pid_t parent_pid;
	char child_comm[16];
	pid_t child_pid;
	char __data[0];
};

struct trace_event_raw_sched_process_exec {
	struct trace_entry ent;
	u32 __data_loc_filename;
	pid_t pid;
	pid_t old_pid;
	char __data[0];
};

struct trace_event_raw_sched_stat_template {
	struct trace_entry ent;
	char comm[16];
	pid_t pid;
	u64 delay;
	char __data[0];
};

struct trace_event_raw_sched_stat_runtime {
	struct trace_entry ent;
	char comm[16];
	pid_t pid;
	u64 runtime;
	u64 vruntime;
	char __data[0];
};

struct trace_event_raw_sched_pi_setprio {
	struct trace_entry ent;
	char comm[16];
	pid_t pid;
	int oldprio;
	int newprio;
	char __data[0];
};

struct trace_event_raw_sched_process_hang {
	struct trace_entry ent;
	char comm[16];
	pid_t pid;
	char __data[0];
};

struct trace_event_raw_sched_move_numa {
	struct trace_entry ent;
	pid_t pid;
	pid_t tgid;
	pid_t ngid;
	int src_cpu;
	int src_nid;
	int dst_cpu;
	int dst_nid;
	char __data[0];
};

struct trace_event_raw_sched_numa_pair_template {
	struct trace_entry ent;
	pid_t src_pid;
	pid_t src_tgid;
	pid_t src_ngid;
	int src_cpu;
	int src_nid;
	pid_t dst_pid;
	pid_t dst_tgid;
	pid_t dst_ngid;
	int dst_cpu;
	int dst_nid;
	char __data[0];
};

struct trace_event_raw_sched_wake_idle_without_ipi {
	struct trace_entry ent;
	int cpu;
	char __data[0];
};

struct trace_event_data_offsets_sched_kthread_stop {};

struct trace_event_data_offsets_sched_kthread_stop_ret {};

struct trace_event_data_offsets_sched_kthread_work_queue_work {};

struct trace_event_data_offsets_sched_kthread_work_execute_start {};

struct trace_event_data_offsets_sched_kthread_work_execute_end {};

struct trace_event_data_offsets_sched_wakeup_template {};

struct trace_event_data_offsets_sched_switch {};

struct trace_event_data_offsets_sched_migrate_task {};

struct trace_event_data_offsets_sched_process_template {};

struct trace_event_data_offsets_sched_process_wait {};

struct trace_event_data_offsets_sched_process_fork {};

struct trace_event_data_offsets_sched_process_exec {
	u32 filename;
};

struct trace_event_data_offsets_sched_stat_template {};

struct trace_event_data_offsets_sched_stat_runtime {};

struct trace_event_data_offsets_sched_pi_setprio {};

struct trace_event_data_offsets_sched_process_hang {};

struct trace_event_data_offsets_sched_move_numa {};

struct trace_event_data_offsets_sched_numa_pair_template {};

struct trace_event_data_offsets_sched_wake_idle_without_ipi {};

typedef void (*btf_trace_sched_kthread_stop)(void *, struct task_struct___37 *);

typedef void (*btf_trace_sched_kthread_stop_ret)(void *, int);

typedef void (*btf_trace_sched_kthread_work_queue_work)(void *, struct kthread_worker___2 *, struct kthread_work___2 *);

typedef void (*btf_trace_sched_kthread_work_execute_start)(void *, struct kthread_work___2 *);

typedef void (*btf_trace_sched_kthread_work_execute_end)(void *, struct kthread_work___2 *, kthread_work_func_t___2);

typedef void (*btf_trace_sched_waking)(void *, struct task_struct___37 *);

typedef void (*btf_trace_sched_wakeup)(void *, struct task_struct___37 *);

typedef void (*btf_trace_sched_wakeup_new)(void *, struct task_struct___37 *);

typedef void (*btf_trace_sched_switch)(void *, bool, struct task_struct___37 *, struct task_struct___37 *);

typedef void (*btf_trace_sched_migrate_task)(void *, struct task_struct___37 *, int);

typedef void (*btf_trace_sched_process_free)(void *, struct task_struct___37 *);

typedef void (*btf_trace_sched_process_exit)(void *, struct task_struct___37 *);

typedef void (*btf_trace_sched_wait_task)(void *, struct task_struct___37 *);

typedef void (*btf_trace_sched_process_wait)(void *, struct pid___28 *);

typedef void (*btf_trace_sched_process_fork)(void *, struct task_struct___37 *, struct task_struct___37 *);

typedef void (*btf_trace_sched_process_exec)(void *, struct task_struct___37 *, pid_t, struct linux_binprm___9 *);

typedef void (*btf_trace_sched_stat_wait)(void *, struct task_struct___37 *, u64);

typedef void (*btf_trace_sched_stat_sleep)(void *, struct task_struct___37 *, u64);

typedef void (*btf_trace_sched_stat_iowait)(void *, struct task_struct___37 *, u64);

typedef void (*btf_trace_sched_stat_blocked)(void *, struct task_struct___37 *, u64);

typedef void (*btf_trace_sched_stat_runtime)(void *, struct task_struct___37 *, u64, u64);

typedef void (*btf_trace_sched_pi_setprio)(void *, struct task_struct___37 *, struct task_struct___37 *);

typedef void (*btf_trace_sched_process_hang)(void *, struct task_struct___37 *);

typedef void (*btf_trace_sched_move_numa)(void *, struct task_struct___37 *, int, int);

typedef void (*btf_trace_sched_stick_numa)(void *, struct task_struct___37 *, int, struct task_struct___37 *, int);

typedef void (*btf_trace_sched_swap_numa)(void *, struct task_struct___37 *, int, struct task_struct___37 *, int);

typedef void (*btf_trace_sched_wake_idle_without_ipi)(void *, int);

typedef void (*btf_trace_pelt_cfs_tp)(void *, struct cfs_rq *);

typedef void (*btf_trace_pelt_rt_tp)(void *, struct rq___2 *);

struct uclamp_bucket {
	long unsigned int value: 11;
	long unsigned int tasks: 53;
};

struct uclamp_rq {
	unsigned int value;
	struct uclamp_bucket bucket[5];
};

struct rt_prio_array {
	long unsigned int bitmap[2];
	struct list_head queue[100];
};

struct rt_rq {
	struct rt_prio_array active;
	unsigned int rt_nr_running;
	unsigned int rr_nr_running;
	struct {
		int curr;
		int next;
	} highest_prio;
	unsigned int rt_nr_migratory;
	unsigned int rt_nr_total;
	int overloaded;
	struct plist_head pushable_tasks;
	int rt_queued;
	int rt_throttled;
	u64 rt_time;
	u64 rt_runtime;
	raw_spinlock_t rt_runtime_lock;
};

struct dl_rq {
	struct rb_root_cached root;
	unsigned int dl_nr_running;
	struct {
		u64 curr;
		u64 next;
	} earliest_dl;
	unsigned int dl_nr_migratory;
	int overloaded;
	struct rb_root_cached pushable_dl_tasks_root;
	u64 running_bw;
	u64 this_bw;
	u64 extra_bw;
	u64 bw_ratio;
};

struct cpu_stop_done;

struct cpu_stop_work {
	struct list_head list;
	cpu_stop_fn_t fn;
	long unsigned int caller;
	void *arg;
	struct cpu_stop_done *done;
};

struct cpuidle_state;

struct rq___2 {
	raw_spinlock_t __lock;
	unsigned int nr_running;
	unsigned int nr_numa_running;
	unsigned int nr_preferred_running;
	unsigned int numa_migrate_on;
	long unsigned int last_blocked_load_update_tick;
	unsigned int has_blocked_load;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	call_single_data_t nohz_csd;
	unsigned int nohz_tick_stopped;
	atomic_t nohz_flags;
	unsigned int ttwu_pending;
	u64 nr_switches;
	long: 64;
	struct uclamp_rq uclamp[2];
	unsigned int uclamp_flags;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	struct cfs_rq cfs;
	struct rt_rq rt;
	struct dl_rq dl;
	struct list_head leaf_cfs_rq_list;
	struct list_head *tmp_alone_branch;
	unsigned int nr_uninterruptible;
	struct task_struct___37 *curr;
	struct task_struct___37 *idle;
	struct task_struct___37 *stop;
	long unsigned int next_balance;
	struct mm_struct___36 *prev_mm;
	unsigned int clock_update_flags;
	u64 clock;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u64 clock_task;
	u64 clock_pelt;
	long unsigned int lost_idle_time;
	atomic_t nr_iowait;
	u64 last_seen_need_resched_ns;
	int ticks_without_resched;
	int membarrier_state;
	struct root_domain *rd;
	struct sched_domain *sd;
	long unsigned int cpu_capacity;
	long unsigned int cpu_capacity_orig;
	struct callback_head *balance_callback;
	unsigned char nohz_idle_balance;
	unsigned char idle_balance;
	long unsigned int misfit_task_load;
	int active_balance;
	int push_cpu;
	struct cpu_stop_work active_balance_work;
	int cpu;
	int online;
	struct list_head cfs_tasks;
	long: 64;
	struct sched_avg avg_rt;
	struct sched_avg avg_dl;
	u64 idle_stamp;
	u64 avg_idle;
	long unsigned int wake_stamp;
	u64 wake_avg_idle;
	u64 max_idle_balance_cost;
	struct rcuwait___33 hotplug_wait;
	u64 prev_steal_time;
	long unsigned int calc_load_update;
	long int calc_load_active;
	long: 64;
	long: 64;
	long: 64;
	call_single_data_t hrtick_csd;
	struct hrtimer hrtick_timer;
	ktime_t hrtick_time;
	struct sched_info rq_sched_info;
	long long unsigned int rq_cpu_time;
	unsigned int yld_count;
	unsigned int sched_count;
	unsigned int sched_goidle;
	unsigned int ttwu_count;
	unsigned int ttwu_local;
	struct cpuidle_state *idle_state;
	unsigned int nr_pinned;
	unsigned int push_busy;
	struct cpu_stop_work push_work;
	struct rq___2 *core;
	struct task_struct___37 *core_pick;
	unsigned int core_enabled;
	unsigned int core_sched_seq;
	struct rb_root core_tree;
	unsigned int core_task_seq;
	unsigned int core_pick_seq;
	long unsigned int core_cookie;
	unsigned char core_forceidle;
	unsigned int core_forceidle_seq;
};

typedef void (*btf_trace_pelt_dl_tp)(void *, struct rq___2 *);

typedef void (*btf_trace_pelt_thermal_tp)(void *, struct rq___2 *);

typedef void (*btf_trace_pelt_irq_tp)(void *, struct rq___2 *);

typedef void (*btf_trace_pelt_se_tp)(void *, struct sched_entity *);

typedef void (*btf_trace_sched_cpu_capacity_tp)(void *, struct rq___2 *);

typedef void (*btf_trace_sched_overutilized_tp)(void *, struct root_domain *, bool);

typedef void (*btf_trace_sched_util_est_cfs_tp)(void *, struct cfs_rq *);

typedef void (*btf_trace_sched_util_est_se_tp)(void *, struct sched_entity *);

typedef void (*btf_trace_sched_update_nr_running_tp)(void *, struct rq___2 *, int);

struct fwnode_reference_args___32;

struct fwnode_endpoint___32;

struct fwnode_operations___32 {
	struct fwnode_handle___32 * (*get)(struct fwnode_handle___32 *);
	void (*put)(struct fwnode_handle___32 *);
	bool (*device_is_available)(const struct fwnode_handle___32 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___32 *, const struct device___35 *);
	bool (*property_present)(const struct fwnode_handle___32 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___32 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___32 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___32 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___32 *);
	struct fwnode_handle___32 * (*get_parent)(const struct fwnode_handle___32 *);
	struct fwnode_handle___32 * (*get_next_child_node)(const struct fwnode_handle___32 *, struct fwnode_handle___32 *);
	struct fwnode_handle___32 * (*get_named_child_node)(const struct fwnode_handle___32 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___32 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___32 *);
	struct fwnode_handle___32 * (*graph_get_next_endpoint)(const struct fwnode_handle___32 *, struct fwnode_handle___32 *);
	struct fwnode_handle___32 * (*graph_get_remote_endpoint)(const struct fwnode_handle___32 *);
	struct fwnode_handle___32 * (*graph_get_port_parent)(struct fwnode_handle___32 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___32 *, struct fwnode_endpoint___32 *);
	int (*add_links)(struct fwnode_handle___32 *);
};

struct fwnode_endpoint___32 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___32 *local_fwnode;
};

struct fwnode_reference_args___32 {
	struct fwnode_handle___32 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct wake_q_head {
	struct wake_q_node *first;
	struct wake_q_node **lastp;
};

struct sched_attr {
	__u32 size;
	__u32 sched_policy;
	__u64 sched_flags;
	__s32 sched_nice;
	__u32 sched_priority;
	__u64 sched_runtime;
	__u64 sched_deadline;
	__u64 sched_period;
	__u32 sched_util_min;
	__u32 sched_util_max;
};

struct block_device_operations___22;

struct gendisk___22 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	short unsigned int events;
	short unsigned int event_flags;
	struct xarray part_tbl;
	struct block_device___22 *part0;
	const struct block_device_operations___22 *fops;
	struct request_queue___22 *queue;
	void *private_data;
	int flags;
	long unsigned int state;
	struct mutex open_mutex;
	unsigned int open_partitions;
	struct backing_dev_info___21 *bdi;
	struct kobject___33 *slave_dir;
	struct list_head slave_bdevs;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___33 integrity_kobj;
	struct cdrom_device_info *cdi;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	u64 diskseq;
};

struct bio_integrity_payload___22 {
	struct bio___22 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___27 *bip_vec;
	struct bio_vec___27 bip_inline_vecs[0];
};

struct blkcg___21;

struct blkg_policy_data___21;

struct blkcg_gq___21 {
	struct request_queue___22 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___21 *blkcg;
	struct blkcg_gq___21 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_iostat_set *iostat_cpu;
	struct blkg_iostat_set iostat;
	struct blkg_policy_data___21 *pd[6];
	spinlock_t async_bio_lock;
	struct bio_list___22 async_bios;
	struct work_struct async_bio_work;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
	struct callback_head callback_head;
};

typedef void integrity_prepare_fn___22(struct request___22 *);

typedef void integrity_complete_fn___22(struct request___22 *, unsigned int);

struct blk_integrity_profile___22 {
	integrity_processing_fn *generate_fn;
	integrity_processing_fn *verify_fn;
	integrity_prepare_fn___22 *prepare_fn;
	integrity_complete_fn___22 *complete_fn;
	const char *name;
};

struct block_device_operations___22 {
	blk_qc_t (*submit_bio)(struct bio___22 *);
	int (*open)(struct block_device___22 *, fmode_t);
	void (*release)(struct gendisk___22 *, fmode_t);
	int (*rw_page)(struct block_device___22 *, sector_t, struct page___35 *, unsigned int);
	int (*ioctl)(struct block_device___22 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___22 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___22 *, unsigned int);
	void (*unlock_native_capacity)(struct gendisk___22 *);
	int (*getgeo)(struct block_device___22 *, struct hd_geometry *);
	int (*set_read_only)(struct block_device___22 *, bool);
	void (*swap_slot_free_notify)(struct block_device___22 *, long unsigned int);
	int (*report_zones)(struct gendisk___22 *, sector_t, unsigned int, report_zones_cb, void *);
	char * (*devnode)(struct gendisk___22 *, umode_t *);
	struct module___32 *owner;
	const struct pr_ops *pr_ops;
	int (*alternative_gpt_sector)(struct gendisk___22 *, sector_t *);
};

typedef void rq_end_io_fn___22(struct request___22 *, blk_status_t);

struct request___22 {
	struct request_queue___22 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int tag;
	int internal_tag;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___22 *bio;
	struct bio___22 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct llist_node ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___27 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___22 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___22 *saved_end_io;
		} flush;
	};
	struct gendisk___22 *rq_disk;
	struct block_device___22 *part;
	u64 alloc_time_ns;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int stats_sectors;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	struct bio_crypt_ctx *crypt_ctx;
	struct blk_ksm_keyslot *crypt_keyslot;
	short unsigned int write_hint;
	short unsigned int ioprio;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___22 *end_io;
	void *end_io_data;
};

struct elevator_type___22;

struct elevator_mq_ops___22 {
	int (*init_sched)(struct request_queue___22 *, struct elevator_type___22 *);
	void (*exit_sched)(struct elevator_queue___22 *);
	int (*init_hctx)(struct blk_mq_hw_ctx *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx *, unsigned int);
	void (*depth_updated)(struct blk_mq_hw_ctx *);
	bool (*allow_merge)(struct request_queue___22 *, struct request___22 *, struct bio___22 *);
	bool (*bio_merge)(struct request_queue___22 *, struct bio___22 *, unsigned int);
	int (*request_merge)(struct request_queue___22 *, struct request___22 **, struct bio___22 *);
	void (*request_merged)(struct request_queue___22 *, struct request___22 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___22 *, struct request___22 *, struct request___22 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___22 *);
	void (*finish_request)(struct request___22 *);
	void (*insert_requests)(struct blk_mq_hw_ctx *, struct list_head *, bool);
	struct request___22 * (*dispatch_request)(struct blk_mq_hw_ctx *);
	bool (*has_work)(struct blk_mq_hw_ctx *);
	void (*completed_request)(struct request___22 *, u64);
	void (*requeue_request)(struct request___22 *);
	struct request___22 * (*former_request)(struct request_queue___22 *, struct request___22 *);
	struct request___22 * (*next_request)(struct request_queue___22 *, struct request___22 *);
	void (*init_icq)(struct io_cq___22 *);
	void (*exit_icq)(struct io_cq___22 *);
};

struct elv_fs_entry___22;

struct elevator_type___22 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___22 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___22 *elevator_attrs;
	const char *elevator_name;
	const char *elevator_alias;
	const unsigned int elevator_features;
	struct module___32 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
};

struct elevator_queue___22 {
	struct elevator_type___22 *type;
	void *elevator_data;
	struct kobject___33 kobj;
	struct mutex sysfs_lock;
	unsigned int registered: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hlist_head hash[64];
};

struct elv_fs_entry___22 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___22 *, char *);
	ssize_t (*store)(struct elevator_queue___22 *, const char *, size_t);
};

struct dev_pm_qos_request___5 {
	enum dev_pm_qos_req_type type;
	union {
		struct plist_node pnode;
		struct pm_qos_flags_request flr;
		struct freq_qos_request freq;
	} data;
	struct device___35 *dev;
};

struct cpuidle_state_usage {
	long long unsigned int disable;
	long long unsigned int usage;
	u64 time_ns;
	long long unsigned int above;
	long long unsigned int below;
	long long unsigned int rejected;
	long long unsigned int s2idle_usage;
	long long unsigned int s2idle_time;
};

struct cpuidle_device;

struct cpuidle_driver;

struct cpuidle_state {
	char name[16];
	char desc[32];
	s64 exit_latency_ns;
	s64 target_residency_ns;
	unsigned int flags;
	unsigned int exit_latency;
	int power_usage;
	unsigned int target_residency;
	int (*enter)(struct cpuidle_device *, struct cpuidle_driver *, int);
	int (*enter_dead)(struct cpuidle_device *, int);
	int (*enter_s2idle)(struct cpuidle_device *, struct cpuidle_driver *, int);
};

struct cpuidle_state_kobj;

struct cpuidle_driver_kobj;

struct cpuidle_device_kobj;

struct cpuidle_device {
	unsigned int registered;
	unsigned int enabled;
	unsigned int poll_time_limit;
	unsigned int cpu;
	ktime_t next_hrtimer;
	int last_state_idx;
	u64 last_residency_ns;
	u64 poll_limit_ns;
	u64 forced_idle_latency_limit_ns;
	struct cpuidle_state_usage states_usage[10];
	struct cpuidle_state_kobj *kobjs[10];
	struct cpuidle_driver_kobj *kobj_driver;
	struct cpuidle_device_kobj *kobj_dev;
	struct list_head device_list;
};

struct cpuidle_driver {
	const char *name;
	struct module___32 *owner;
	unsigned int bctimer;
	long: 32;
	long: 64;
	long: 64;
	struct cpuidle_state states[10];
	int state_count;
	int safe_state_index;
	struct cpumask *cpumask;
	const char *governor;
};

struct pipe_buf_operations___12;

struct pipe_buffer___12 {
	struct page___35 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___12 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___12 {
	int (*confirm)(struct pipe_inode_info___12 *, struct pipe_buffer___12 *);
	void (*release)(struct pipe_inode_info___12 *, struct pipe_buffer___12 *);
	bool (*try_steal)(struct pipe_inode_info___12 *, struct pipe_buffer___12 *);
	bool (*get)(struct pipe_inode_info___12 *, struct pipe_buffer___12 *);
};

struct blkcg_policy_data___21;

struct blkcg___21 {
	struct cgroup_subsys_state___27 css;
	spinlock_t lock;
	refcount_t online_pin;
	struct xarray blkg_tree;
	struct blkcg_gq___21 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___21 *cpd[6];
	struct list_head all_blkcgs_node;
	char fc_app_id[129];
	struct list_head cgwb_list;
};

struct blkcg_policy_data___21 {
	struct blkcg___21 *blkcg;
	int plid;
};

struct blkg_policy_data___21 {
	struct blkcg_gq___21 *blkg;
	int plid;
};

struct mem_cgroup_reclaim_iter___21 {
	struct mem_cgroup___21 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___21 {
	struct lruvec___22 lruvec;
	struct lruvec_stats_percpu *lruvec_stats_percpu;
	struct lruvec_stats lruvec_stats;
	long unsigned int lru_zone_size[25];
	struct mem_cgroup_reclaim_iter___21 iter;
	struct shrinker_info *shrinker_info;
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	struct mem_cgroup___21 *memcg;
};

struct obj_cgroup___21 {
	struct percpu_ref refcnt;
	struct mem_cgroup___21 *memcg;
	atomic_t nr_charged_bytes;
	union {
		struct list_head list;
		struct callback_head rcu;
	};
};

struct syscall_metadata___9 {
	const char *name;
	int syscall_nr;
	int nb_args;
	const char **types;
	const char **args;
	struct list_head enter_fields;
	struct trace_event_call___21 *enter_event;
	struct trace_event_call___21 *exit_event;
};

struct cpudl_item {
	u64 dl;
	int cpu;
	int idx;
};

struct rt_bandwidth {
	raw_spinlock_t rt_runtime_lock;
	ktime_t rt_period;
	u64 rt_runtime;
	struct hrtimer rt_period_timer;
	unsigned int rt_period_active;
};

struct dl_bandwidth {
	raw_spinlock_t dl_runtime_lock;
	u64 dl_runtime;
	u64 dl_period;
};

typedef int (*tg_visitor)(struct task_group___2 *, void *);

struct perf_domain {
	struct em_perf_domain *em_pd;
	struct perf_domain *next;
	struct callback_head rcu;
};

struct rq_flags {
	long unsigned int flags;
	struct pin_cookie cookie;
	unsigned int clock_update_flags;
};

enum {
	__SCHED_FEAT_GENTLE_FAIR_SLEEPERS = 0,
	__SCHED_FEAT_START_DEBIT = 1,
	__SCHED_FEAT_NEXT_BUDDY = 2,
	__SCHED_FEAT_LAST_BUDDY = 3,
	__SCHED_FEAT_CACHE_HOT_BUDDY = 4,
	__SCHED_FEAT_WAKEUP_PREEMPTION = 5,
	__SCHED_FEAT_HRTICK = 6,
	__SCHED_FEAT_HRTICK_DL = 7,
	__SCHED_FEAT_DOUBLE_TICK = 8,
	__SCHED_FEAT_NONTASK_CAPACITY = 9,
	__SCHED_FEAT_TTWU_QUEUE = 10,
	__SCHED_FEAT_SIS_PROP = 11,
	__SCHED_FEAT_WARN_DOUBLE_CLOCK = 12,
	__SCHED_FEAT_RT_PUSH_IPI = 13,
	__SCHED_FEAT_RT_RUNTIME_SHARE = 14,
	__SCHED_FEAT_LB_MIN = 15,
	__SCHED_FEAT_ATTACH_AGE_LOAD = 16,
	__SCHED_FEAT_WA_IDLE = 17,
	__SCHED_FEAT_WA_WEIGHT = 18,
	__SCHED_FEAT_WA_BIAS = 19,
	__SCHED_FEAT_UTIL_EST = 20,
	__SCHED_FEAT_UTIL_EST_FASTUP = 21,
	__SCHED_FEAT_LATENCY_WARN = 22,
	__SCHED_FEAT_ALT_PERIOD = 23,
	__SCHED_FEAT_BASE_SLICE = 24,
	__SCHED_FEAT_NR = 25,
};

enum cpu_util_type {
	FREQUENCY_UTIL = 0,
	ENERGY_UTIL = 1,
};

struct set_affinity_pending;

struct migration_arg {
	struct task_struct___37 *task;
	int dest_cpu;
	struct set_affinity_pending *pending;
};

struct set_affinity_pending {
	refcount_t refs;
	unsigned int stop_pending;
	struct completion done;
	struct cpu_stop_work stop_work;
	struct migration_arg arg;
};

struct migration_swap_arg {
	struct task_struct___37 *src_task;
	struct task_struct___37 *dst_task;
	int src_cpu;
	int dst_cpu;
};

struct uclamp_request {
	s64 percent;
	u64 util;
	int ret;
};

struct cfs_schedulable_data {
	struct task_group___2 *tg;
	u64 period;
	u64 quota;
};

enum {
	cpuset = 0,
	possible = 1,
	fail = 2,
};

struct dentry___34;

struct super_block___34;

struct module___33;

struct file_system_type___34 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___34 * (*mount)(struct file_system_type___34 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___34 *);
	struct module___33 *owner;
	struct file_system_type___34 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___34;

struct kiocb___34;

struct iov_iter___28;

struct poll_table_struct___25;

struct vm_area_struct___37;

struct inode___34;

struct file_lock___34;

struct page___36;

struct pipe_inode_info___13;

struct seq_file___32;

struct file_operations___34 {
	struct module___33 *owner;
	loff_t (*llseek)(struct file___34 *, loff_t, int);
	ssize_t (*read)(struct file___34 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___34 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___34 *, struct iov_iter___28 *);
	ssize_t (*write_iter)(struct kiocb___34 *, struct iov_iter___28 *);
	int (*iopoll)(struct kiocb___34 *, bool);
	int (*iterate)(struct file___34 *, struct dir_context *);
	int (*iterate_shared)(struct file___34 *, struct dir_context *);
	__poll_t (*poll)(struct file___34 *, struct poll_table_struct___25 *);
	long int (*unlocked_ioctl)(struct file___34 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___34 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___34 *, struct vm_area_struct___37 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___34 *, struct file___34 *);
	int (*flush)(struct file___34 *, fl_owner_t);
	int (*release)(struct inode___34 *, struct file___34 *);
	int (*fsync)(struct file___34 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___34 *, int);
	int (*lock)(struct file___34 *, int, struct file_lock___34 *);
	ssize_t (*sendpage)(struct file___34 *, struct page___36 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___34 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___34 *, long unsigned int);
	int (*flock)(struct file___34 *, int, struct file_lock___34 *);
	ssize_t (*splice_write)(struct pipe_inode_info___13 *, struct file___34 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___34 *, loff_t *, struct pipe_inode_info___13 *, size_t, unsigned int);
	int (*setlease)(struct file___34 *, long int, struct file_lock___34 **, void **);
	long int (*fallocate)(struct file___34 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___32 *, struct file___34 *);
	ssize_t (*copy_file_range)(struct file___34 *, loff_t, struct file___34 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___34 *, loff_t, struct file___34 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___34 *, loff_t, loff_t, int);
};

struct static_call_mod___25 {
	struct static_call_mod___25 *next;
	struct module___33 *mod;
	struct static_call_site *sites;
};

struct static_call_key___25 {
	void *func;
	union {
		long unsigned int type;
		struct static_call_mod___25 *mods;
		struct static_call_site *sites;
	};
};

struct cfs_rq___2;

struct sched_entity___2 {
	struct load_weight load;
	struct rb_node run_node;
	struct list_head group_node;
	unsigned int on_rq;
	u64 exec_start;
	u64 sum_exec_runtime;
	u64 vruntime;
	u64 prev_sum_exec_runtime;
	u64 nr_migrations;
	struct sched_statistics statistics;
	int depth;
	struct sched_entity___2 *parent;
	struct cfs_rq___2 *cfs_rq;
	struct cfs_rq___2 *my_q;
	long unsigned int runnable_weight;
	long: 64;
	long: 64;
	long: 64;
	struct sched_avg avg;
};

struct vmacache___36 {
	u64 seqnum;
	struct vm_area_struct___37 *vmas[4];
};

struct page_frag___36 {
	struct page___36 *page;
	__u32 offset;
	__u32 size;
};

struct perf_event___22;

struct thread_struct___23 {
	struct desc_struct tls_array[3];
	long unsigned int sp;
	short unsigned int es;
	short unsigned int ds;
	short unsigned int fsindex;
	short unsigned int gsindex;
	long unsigned int fsbase;
	long unsigned int gsbase;
	struct perf_event___22 *ptrace_bps[4];
	long unsigned int virtual_dr6;
	long unsigned int ptrace_dr7;
	long unsigned int cr2;
	long unsigned int trap_nr;
	long unsigned int error_code;
	struct io_bitmap *io_bitmap;
	long unsigned int iopl_emul;
	unsigned int iopl_warn: 1;
	unsigned int sig_on_uaccess_err: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u32 pkru;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct fpu fpu;
};

struct sched_class___3;

struct task_group___3;

struct mm_struct___37;

struct pid___29;

struct nsproxy___33;

struct signal_struct___34;

struct bio_list___23;

struct backing_dev_info___22;

struct io_context___23;

struct css_set___28;

struct perf_event_context___22;

struct mem_cgroup___22;

struct request_queue___23;

struct vm_struct___31;

struct task_struct___38 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___38 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class___3 *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___2 se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group___3 *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___37 *mm;
	struct mm_struct___37 *active_mm;
	struct vmacache___36 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int restore_sigmask: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___38 *real_parent;
	struct task_struct___38 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___38 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___29 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	struct posix_cputimers_work posix_cputimers_work;
	const struct cred___2 *ptracer_cred;
	const struct cred___2 *real_cred;
	const struct cred___2 *cred;
	struct key *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___33 *nsproxy;
	struct signal_struct___34 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___38 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___23 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___22 *backing_dev_info;
	struct io_context___23 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___28 *cgroups;
	struct list_head cg_list;
	u32 closid;
	u32 rmid;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___22 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	struct pipe_inode_info___13 *splice_pipe;
	struct page_frag___36 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___22 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___22 *active_memcg;
	struct request_queue___23 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___38 *oom_reaper_list;
	struct vm_struct___31 *stack_vm_area;
	refcount_t stack_refcount;
	int patch_state;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	void *mce_vaddr;
	__u64 mce_kflags;
	u64 mce_addr;
	__u64 mce_ripv: 1;
	__u64 mce_whole_page: 1;
	__u64 __mce_reserved: 62;
	long: 2;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct callback_head mce_kill_me;
	int mce_count;
	struct llist_head kretprobe_instances;
	struct callback_head l1d_flush_kill;
	long: 64;
	struct thread_struct___23 thread;
};

typedef struct page___36 *pgtable_t___36;

struct address_space___34;

struct page_pool___12;

struct dev_pagemap___34;

struct page___36 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___34 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___12 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___36 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___36 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___37 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___34 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct linux_binfmt___9;

struct core_state___36;

struct mm_struct___37 {
	struct {
		struct vm_area_struct___37 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___34 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int mmap_compat_base;
		long unsigned int mmap_compat_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[48];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___9 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___36 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___38 *owner;
		struct user_namespace___2 *user_ns;
		struct file___34 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		bool tlb_flush_batched;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct vm_operations_struct___34;

struct vm_area_struct___37 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___37 *vm_next;
	struct vm_area_struct___37 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___37 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___34 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___34 *vm_file;
	struct file___34 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct tracepoint___25 {
	const char *name;
	struct static_key key;
	struct static_call_key___25 *static_call_key;
	void *static_call_tramp;
	void *iterator;
	int (*regfunc)();
	void (*unregfunc)();
	struct tracepoint_func *funcs;
};

struct bpf_raw_event_map___25 {
	struct tracepoint___25 *tp;
	void *bpf_func;
	u32 num_args;
	u32 writable_size;
	long: 64;
};

struct seq_operations___32 {
	void * (*start)(struct seq_file___32 *, loff_t *);
	void (*stop)(struct seq_file___32 *, void *);
	void * (*next)(struct seq_file___32 *, void *, loff_t *);
	int (*show)(struct seq_file___32 *, void *);
};

struct hw_perf_event___22 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___38 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	union {
		struct {
			u64 last_period;
			local64_t period_left;
		};
		struct {
			u64 saved_metric;
			u64 saved_slots;
		};
	};
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___22)(struct perf_event___22 *, struct perf_sample_data *, struct pt_regs *);

struct pmu___22;

struct fasync_struct___34;

struct pid_namespace___29;

struct trace_event_call___22;

struct perf_cgroup___22;

struct perf_event___22 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___22 *group_leader;
	struct pmu___22 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___22 hw;
	struct perf_event_context___22 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___22 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___38 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct perf_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___34 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	long unsigned int pending_addr;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	struct perf_addr_filter_range *addr_filter_ranges;
	long unsigned int addr_filters_gen;
	struct perf_event___22 *aux_event;
	void (*destroy)(struct perf_event___22 *);
	struct callback_head callback_head;
	struct pid_namespace___29 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___22 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___22 orig_overflow_handler;
	struct bpf_prog *prog;
	u64 bpf_cookie;
	struct trace_event_call___22 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___22 *cgrp;
	void *security;
	struct list_head sb_list;
};

struct upid___29 {
	int nr;
	struct pid_namespace___29 *ns;
};

struct pid_namespace___29 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___38 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___29 *parent;
	struct fs_pin *bacct;
	struct user_namespace___2 *user_ns;
	struct ucounts___2 *ucounts;
	int reboot;
	struct ns_common___5 ns;
};

struct pid___29 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___29 numbers[1];
};

struct autogroup___3;

struct signal_struct___34 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___38 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___38 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper;
	unsigned int has_child_subreaper;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___29 *pids[4];
	struct pid___29 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup___3 *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___37 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct rq___3;

struct cfs_rq___2 {
	struct load_weight load;
	unsigned int nr_running;
	unsigned int h_nr_running;
	unsigned int idle_h_nr_running;
	u64 exec_clock;
	u64 min_vruntime;
	unsigned int forceidle_seq;
	u64 min_vruntime_fi;
	struct rb_root_cached tasks_timeline;
	struct sched_entity___2 *curr;
	struct sched_entity___2 *next;
	struct sched_entity___2 *last;
	struct sched_entity___2 *skip;
	unsigned int nr_spread_over;
	long: 32;
	long: 64;
	struct sched_avg avg;
	struct {
		raw_spinlock_t lock;
		int nr;
		long unsigned int load_avg;
		long unsigned int util_avg;
		long unsigned int runnable_avg;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	} removed;
	long unsigned int tg_load_avg_contrib;
	long int propagate;
	long int prop_runnable_sum;
	long unsigned int h_load;
	u64 last_h_load_update;
	struct sched_entity___2 *h_load_next;
	struct rq___3 *rq;
	int on_list;
	struct list_head leaf_cfs_rq_list;
	struct task_group___3 *tg;
	int idle;
	int runtime_enabled;
	s64 runtime_remaining;
	u64 throttled_clock;
	u64 throttled_clock_task;
	u64 throttled_clock_task_time;
	int throttled;
	int throttle_count;
	struct list_head throttled_list;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct sched_class___3 {
	int uclamp_enabled;
	void (*enqueue_task)(struct rq___3 *, struct task_struct___38 *, int);
	void (*dequeue_task)(struct rq___3 *, struct task_struct___38 *, int);
	void (*yield_task)(struct rq___3 *);
	bool (*yield_to_task)(struct rq___3 *, struct task_struct___38 *);
	void (*check_preempt_curr)(struct rq___3 *, struct task_struct___38 *, int);
	struct task_struct___38 * (*pick_next_task)(struct rq___3 *);
	void (*put_prev_task)(struct rq___3 *, struct task_struct___38 *);
	void (*set_next_task)(struct rq___3 *, struct task_struct___38 *, bool);
	int (*balance)(struct rq___3 *, struct task_struct___38 *, struct rq_flags *);
	int (*select_task_rq)(struct task_struct___38 *, int, int);
	struct task_struct___38 * (*pick_task)(struct rq___3 *);
	void (*migrate_task_rq)(struct task_struct___38 *, int);
	void (*task_woken)(struct rq___3 *, struct task_struct___38 *);
	void (*set_cpus_allowed)(struct task_struct___38 *, const struct cpumask *, u32);
	void (*rq_online)(struct rq___3 *);
	void (*rq_offline)(struct rq___3 *);
	struct rq___3 * (*find_lock_rq)(struct task_struct___38 *, struct rq___3 *);
	void (*task_tick)(struct rq___3 *, struct task_struct___38 *, int);
	void (*task_fork)(struct task_struct___38 *);
	void (*task_dead)(struct task_struct___38 *);
	void (*switched_from)(struct rq___3 *, struct task_struct___38 *);
	void (*switched_to)(struct rq___3 *, struct task_struct___38 *);
	void (*prio_changed)(struct rq___3 *, struct task_struct___38 *, int);
	unsigned int (*get_rr_interval)(struct rq___3 *, struct task_struct___38 *);
	void (*update_curr)(struct rq___3 *);
	void (*task_change_group)(struct task_struct___38 *, int);
};

struct cgroup___28;

struct cgroup_subsys___28;

struct cgroup_subsys_state___28 {
	struct cgroup___28 *cgroup;
	struct cgroup_subsys___28 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___28 *parent;
};

struct task_group___3 {
	struct cgroup_subsys_state___28 css;
	struct sched_entity___2 **se;
	struct cfs_rq___2 **cfs_rq;
	long unsigned int shares;
	int idle;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	atomic_long_t load_avg;
	struct callback_head rcu;
	struct list_head list;
	struct task_group___3 *parent;
	struct list_head siblings;
	struct list_head children;
	struct autogroup___3 *autogroup;
	struct cfs_bandwidth cfs_bandwidth;
	unsigned int uclamp_pct[2];
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct cgroup_namespace___28;

struct nsproxy___33 {
	atomic_t count;
	struct uts_namespace___4 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___29 *pid_ns_for_children;
	struct net___6 *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___28 *cgroup_ns;
};

struct bio___23;

struct bio_list___23 {
	struct bio___23 *head;
	struct bio___23 *tail;
};

struct bdi_writeback___22 {
	struct backing_dev_info___22 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	atomic_t writeback_inodes;
	struct percpu_counter stat[4];
	long unsigned int congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	struct delayed_work bw_dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___28 *memcg_css;
	struct cgroup_subsys_state___28 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	struct list_head b_attached;
	struct list_head offline_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
};

struct device___36;

struct backing_dev_info___22 {
	u64 id;
	struct rb_node rb_node;
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___22 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct mutex cgwb_release_mutex;
	struct rw_semaphore wb_switch_rwsem;
	wait_queue_head_t wb_waitq;
	struct device___36 *dev;
	char dev_name[64];
	struct device___36 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___34 *debug_dir;
};

struct io_cq___23;

struct io_context___23 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	struct xarray icq_tree;
	struct io_cq___23 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct css_set___28 {
	struct cgroup_subsys_state___28 *subsys[14];
	refcount_t refcount;
	struct css_set___28 *dom_cset;
	struct cgroup___28 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___28 *mg_src_cgrp;
	struct cgroup___28 *mg_dst_cgrp;
	struct css_set___28 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___22 {
	struct pmu___22 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	int rotate_necessary;
	refcount_t refcount;
	struct task_struct___38 *task;
	u64 time;
	u64 timestamp;
	u64 timeoffset;
	struct perf_event_context___22 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

struct pipe_buffer___13;

struct pipe_inode_info___13 {
	struct mutex mutex;
	wait_queue_head_t rd_wait;
	wait_queue_head_t wr_wait;
	unsigned int head;
	unsigned int tail;
	unsigned int max_usage;
	unsigned int ring_size;
	bool note_loss;
	unsigned int nr_accounted;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int r_counter;
	unsigned int w_counter;
	unsigned int poll_usage;
	struct page___36 *tmp_page;
	struct fasync_struct___34 *fasync_readers;
	struct fasync_struct___34 *fasync_writers;
	struct pipe_buffer___13 *bufs;
	struct user_struct *user;
	struct watch_queue *watch_queue;
};

struct kernfs_node___34;

struct cgroup_file___28 {
	struct kernfs_node___34 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct obj_cgroup___22;

struct mem_cgroup_per_node___22;

struct mem_cgroup___22 {
	struct cgroup_subsys_state___28 css;
	struct mem_cgroup_id id;
	struct page_counter memory;
	union {
		struct page_counter swap;
		struct page_counter memsw;
	};
	struct page_counter kmem;
	struct page_counter tcpmem;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool oom_group;
	bool oom_lock;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___28 events_file;
	struct cgroup_file___28 events_local_file;
	struct cgroup_file___28 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	struct memcg_vmstats vmstats;
	atomic_long_t memory_events[8];
	atomic_long_t memory_events_local[8];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct obj_cgroup___22 *objcg;
	struct list_head objcg_list;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad2_;
	atomic_t moving_account;
	struct task_struct___38 *move_lock_task;
	struct memcg_vmstats_percpu *vmstats_percpu;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct memcg_cgwb_frn cgwb_frn[4];
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct deferred_split deferred_split_queue;
	struct mem_cgroup_per_node___22 *nodeinfo[0];
	long: 64;
};

struct kset___33;

struct kobj_type___33;

struct kobject___34 {
	const char *name;
	struct list_head entry;
	struct kobject___34 *parent;
	struct kset___33 *kset;
	struct kobj_type___33 *ktype;
	struct kernfs_node___34 *sd;
	struct kref kref;
	unsigned int state_initialized;
	unsigned int state_in_sysfs;
	unsigned int state_add_uevent_sent;
	unsigned int state_remove_uevent_sent;
	unsigned int uevent_suppress;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct blk_integrity_profile___23;

struct blk_integrity___23 {
	const struct blk_integrity_profile___23 *profile;
	unsigned char flags;
	unsigned char tuple_size;
	unsigned char interval_exp;
	unsigned char tag_size;
};

struct bio_set___23 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	struct bio_alloc_cache *cache;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	unsigned int back_pad;
	spinlock_t rescue_lock;
	struct bio_list___23 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	struct hlist_node cpuhp_dead;
};

struct request___23;

struct elevator_queue___23;

struct gendisk___23;

struct blkcg_gq___22;

struct request_queue___23 {
	struct request___23 *last_merge;
	struct elevator_queue___23 *elevator;
	struct percpu_ref q_usage_counter;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	const struct blk_mq_ops *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx **queue_hw_ctx;
	unsigned int nr_hw_queues;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	spinlock_t queue_lock;
	struct gendisk___23 *disk;
	struct kobject___34 kobj;
	struct kobject___34 *mq_kobj;
	struct blk_integrity___23 integrity;
	struct device___36 *dev;
	enum rpm_status rpm_status;
	long unsigned int nr_requests;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_keyslot_manager *ksm;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	atomic_t nr_active_requests_shared_sbitmap;
	struct sbitmap_queue sched_bitmap_tags;
	struct sbitmap_queue sched_breserved_tags;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___22 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int required_elevator_features;
	unsigned int nr_zones;
	long unsigned int *conv_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int max_open_zones;
	unsigned int max_active_zones;
	int node;
	struct mutex debugfs_mutex;
	struct blk_trace *blk_trace;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	struct mutex sysfs_dir_lock;
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	int mq_freeze_depth;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct mutex mq_freeze_lock;
	struct blk_mq_tag_set *tag_set;
	struct list_head tag_set_list;
	struct bio_set___23 bio_split;
	struct dentry___34 *debugfs_dir;
	struct dentry___34 *sched_debugfs_dir;
	struct dentry___34 *rqos_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	u64 write_hints[5];
};

struct vm_struct___31 {
	struct vm_struct___31 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___36 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct address_space_operations___34;

struct address_space___34 {
	struct inode___34 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___34 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct page_pool_params___12 {
	unsigned int flags;
	unsigned int order;
	unsigned int pool_size;
	int nid;
	struct device___36 *dev;
	enum dma_data_direction dma_dir;
	unsigned int max_len;
	unsigned int offset;
};

struct pp_alloc_cache___12 {
	u32 count;
	struct page___36 *cache[128];
};

struct page_pool___12 {
	struct page_pool_params___12 p;
	struct delayed_work release_dw;
	void (*disconnect)(void *);
	long unsigned int defer_start;
	long unsigned int defer_warn;
	u32 pages_state_hold_cnt;
	unsigned int frag_offset;
	struct page___36 *frag_page;
	long int frag_users;
	long: 64;
	long: 64;
	struct pp_alloc_cache___12 alloc;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct ptr_ring ring;
	atomic_t pages_state_release_cnt;
	refcount_t user_cnt;
	u64 destroy_cnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pagemap_ops___34;

struct dev_pagemap___34 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___34 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vfsmount___34;

struct path___34 {
	struct vfsmount___34 *mnt;
	struct dentry___34 *dentry;
};

struct fown_struct___29 {
	rwlock_t lock;
	struct pid___29 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___34 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___34 f_path;
	struct inode___34 *f_inode;
	const struct file_operations___34 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___29 f_owner;
	const struct cred___2 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___34 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___34;

struct vm_operations_struct___34 {
	void (*open)(struct vm_area_struct___37 *);
	void (*close)(struct vm_area_struct___37 *);
	int (*may_split)(struct vm_area_struct___37 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___37 *);
	int (*mprotect)(struct vm_area_struct___37 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___34 *);
	vm_fault_t (*huge_fault)(struct vm_fault___34 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___34 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___37 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___34 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___34 *);
	int (*access)(struct vm_area_struct___37 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___37 *);
	int (*set_policy)(struct vm_area_struct___37 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___37 *, long unsigned int);
	struct page___36 * (*find_special_page)(struct vm_area_struct___37 *, long unsigned int);
};

struct core_thread___36 {
	struct task_struct___38 *task;
	struct core_thread___36 *next;
};

struct core_state___36 {
	atomic_t nr_threads;
	struct core_thread___36 dumper;
	struct completion startup;
};

struct linux_binprm___10;

struct coredump_params___9;

struct linux_binfmt___9 {
	struct list_head lh;
	struct module___33 *module;
	int (*load_binary)(struct linux_binprm___10 *);
	int (*load_shlib)(struct file___34 *);
	int (*core_dump)(struct coredump_params___9 *);
	long unsigned int min_coredump;
};

struct vm_fault___34 {
	const struct {
		struct vm_area_struct___37 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___36 *cow_page;
	struct page___36 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___36 prealloc_pte;
};

struct psi_group___28 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___38 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___28;

struct cgroup_rstat_cpu___28;

struct cgroup___28 {
	struct cgroup_subsys_state___28 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___34 *kn;
	struct cgroup_file___28 procs_file;
	struct cgroup_file___28 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___28 *subsys[14];
	struct cgroup_root___28 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___28 *dom_cgrp;
	struct cgroup___28 *old_dom_cgrp;
	struct cgroup_rstat_cpu___28 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___28 psi;
	struct cgroup_bpf___4 bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct pglist_data___23;

struct lruvec___23 {
	struct list_head lists[5];
	spinlock_t lru_lock;
	long unsigned int anon_cost;
	long unsigned int file_cost;
	atomic_long_t nonresident_age;
	long unsigned int refaults[2];
	long unsigned int flags;
	struct pglist_data___23 *pgdat;
};

struct zone___23 {
	long unsigned int _watermark[3];
	long unsigned int watermark_boost;
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[5];
	int node;
	struct pglist_data___23 *zone_pgdat;
	struct per_cpu_pages *per_cpu_pageset;
	struct per_cpu_zonestat *per_cpu_zonestats;
	int pageset_high;
	int pageset_batch;
	long unsigned int zone_start_pfn;
	atomic_long_t managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int present_early_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	seqlock_t span_seqlock;
	int initialized;
	int: 32;
	struct zone_padding _pad1_;
	struct free_area free_area[11];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	long unsigned int compact_init_migrate_pfn;
	long unsigned int compact_init_free_pfn;
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	short: 16;
	struct zone_padding _pad3_;
	atomic_long_t vm_stat[11];
	atomic_long_t vm_numa_event[6];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___23 {
	struct zone___23 *zone;
	int zone_idx;
};

struct zonelist___23 {
	struct zoneref___23 _zonerefs[5121];
};

struct pglist_data___23 {
	struct zone___23 node_zones[5];
	struct zonelist___23 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___38 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_highest_zoneidx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_highest_zoneidx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___38 *kcompactd;
	bool proactive_compact_trigger;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct deferred_split deferred_split_queue;
	struct lruvec___23 __lruvec;
	long unsigned int flags;
	long: 64;
	struct zone_padding _pad2_;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[39];
};

struct autogroup___3 {
	struct kref kref;
	struct task_group___3 *tg;
	struct rw_semaphore lock;
	long unsigned int id;
	int nice;
};

struct kernfs_root___34;

struct kernfs_elem_dir___34 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___34 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___34;

struct kernfs_root___34 {
	struct kernfs_node___34 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___34 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___34 {
	struct kernfs_node___34 *target_kn;
};

struct kernfs_ops___34;

struct kernfs_elem_attr___34 {
	const struct kernfs_ops___34 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___34 *notify_next;
};

struct kernfs_node___34 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___34 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___34 dir;
		struct kernfs_elem_symlink___34 symlink;
		struct kernfs_elem_attr___34 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___34;

struct kernfs_ops___34 {
	int (*open)(struct kernfs_open_file___34 *);
	void (*release)(struct kernfs_open_file___34 *);
	int (*seq_show)(struct seq_file___32 *, void *);
	void * (*seq_start)(struct seq_file___32 *, loff_t *);
	void * (*seq_next)(struct seq_file___32 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___32 *, void *);
	ssize_t (*read)(struct kernfs_open_file___34 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___34 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___34 *, struct poll_table_struct___25 *);
	int (*mmap)(struct kernfs_open_file___34 *, struct vm_area_struct___37 *);
};

struct kernfs_syscall_ops___34 {
	int (*show_options)(struct seq_file___32 *, struct kernfs_root___34 *);
	int (*mkdir)(struct kernfs_node___34 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___34 *);
	int (*rename)(struct kernfs_node___34 *, struct kernfs_node___34 *, const char *);
	int (*show_path)(struct seq_file___32 *, struct kernfs_node___34 *, struct kernfs_root___34 *);
};

struct seq_file___32 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___32 *op;
	int poll_event;
	const struct file___34 *file;
	void *private;
};

struct kernfs_open_file___34 {
	struct kernfs_node___34 *kn;
	struct file___34 *file;
	struct seq_file___32 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped;
	bool released;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___34 *vm_ops;
};

typedef void (*poll_queue_proc___25)(struct file___34 *, wait_queue_head_t *, struct poll_table_struct___25 *);

struct poll_table_struct___25 {
	poll_queue_proc___25 _qproc;
	__poll_t _key;
};

struct bin_attribute___34;

struct attribute_group___34 {
	const char *name;
	umode_t (*is_visible)(struct kobject___34 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___34 *, struct bin_attribute___34 *, int);
	struct attribute **attrs;
	struct bin_attribute___34 **bin_attrs;
};

struct bin_attribute___34 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___34 * (*f_mapping)();
	ssize_t (*read)(struct file___34 *, struct kobject___34 *, struct bin_attribute___34 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___34 *, struct kobject___34 *, struct bin_attribute___34 *, char *, loff_t, size_t);
	int (*mmap)(struct file___34 *, struct kobject___34 *, struct bin_attribute___34 *, struct vm_area_struct___37 *);
};

struct sysfs_ops___33 {
	ssize_t (*show)(struct kobject___34 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___34 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___33;

struct kset___33 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___34 kobj;
	const struct kset_uevent_ops___33 *uevent_ops;
};

struct kobj_type___33 {
	void (*release)(struct kobject___34 *);
	const struct sysfs_ops___33 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___34 **default_groups;
	const struct kobj_ns_type_operations___3 * (*child_ns_type)(struct kobject___34 *);
	const void * (*namespace)(struct kobject___34 *);
	void (*get_ownership)(struct kobject___34 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___33 {
	int (* const filter)(struct kset___33 *, struct kobject___34 *);
	const char * (* const name)(struct kset___33 *, struct kobject___34 *);
	int (* const uevent)(struct kset___33 *, struct kobject___34 *, struct kobj_uevent_env *);
};

struct fwnode_operations___33;

struct fwnode_handle___33 {
	struct fwnode_handle___33 *secondary;
	const struct fwnode_operations___33 *ops;
	struct device___36 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct fwnode_reference_args___33;

struct fwnode_endpoint___33;

struct fwnode_operations___33 {
	struct fwnode_handle___33 * (*get)(struct fwnode_handle___33 *);
	void (*put)(struct fwnode_handle___33 *);
	bool (*device_is_available)(const struct fwnode_handle___33 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___33 *, const struct device___36 *);
	bool (*property_present)(const struct fwnode_handle___33 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___33 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___33 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___33 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___33 *);
	struct fwnode_handle___33 * (*get_parent)(const struct fwnode_handle___33 *);
	struct fwnode_handle___33 * (*get_next_child_node)(const struct fwnode_handle___33 *, struct fwnode_handle___33 *);
	struct fwnode_handle___33 * (*get_named_child_node)(const struct fwnode_handle___33 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___33 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___33 *);
	struct fwnode_handle___33 * (*graph_get_next_endpoint)(const struct fwnode_handle___33 *, struct fwnode_handle___33 *);
	struct fwnode_handle___33 * (*graph_get_remote_endpoint)(const struct fwnode_handle___33 *);
	struct fwnode_handle___33 * (*graph_get_port_parent)(struct fwnode_handle___33 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___33 *, struct fwnode_endpoint___33 *);
	int (*add_links)(struct fwnode_handle___33 *);
};

struct wakeup_source___36;

struct dev_pm_qos___6;

struct dev_pm_info___36 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___36 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___36 *, s32);
	struct dev_pm_qos___6 *qos;
};

struct device_type___36;

struct bus_type___36;

struct device_driver___36;

struct dev_pm_domain___36;

struct device_node___19;

struct class___36;

struct device___36 {
	struct kobject___34 kobj;
	struct device___36 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___36 *type;
	struct bus_type___36 *bus;
	struct device_driver___36 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___36 power;
	struct dev_pm_domain___36 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___19 *of_node;
	struct fwnode_handle___33 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___36 *class;
	const struct attribute_group___34 **groups;
	void (*release)(struct device___36 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fwnode_endpoint___33 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___33 *local_fwnode;
};

struct fwnode_reference_args___33 {
	struct fwnode_handle___33 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct device_node___19 {
	const char *name;
	phandle phandle;
	const char *full_name;
	struct fwnode_handle___33 fwnode;
	struct property *properties;
	struct property *deadprops;
	struct device_node___19 *parent;
	struct device_node___19 *child;
	struct device_node___19 *sibling;
	long unsigned int _flags;
	void *data;
};

struct module_kobject___33 {
	struct kobject___34 kobj;
	struct module___33 *mod;
	struct kobject___34 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___33 {
	struct module___33 *mod;
	struct latch_tree_node node;
};

struct module_layout___33 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___33 mtn;
};

struct module_attribute___33;

struct kernel_param___33;

struct module___33 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___33 mkobj;
	struct module_attribute___33 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___34 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___33 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___33 core_layout;
	struct module_layout___33 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map___25 *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___22 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	int num_static_call_sites;
	struct static_call_site *static_call_sites;
	bool klp;
	bool klp_alive;
	struct klp_modinfo *klp_info;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct linux_binprm___10 {
	struct vm_area_struct___37 *vma;
	long unsigned int vma_pages;
	struct mm_struct___37 *mm;
	long unsigned int p;
	long unsigned int argmin;
	unsigned int have_execfd;
	unsigned int execfd_creds;
	unsigned int secureexec;
	unsigned int point_of_no_return;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct file___34 *executable;
	struct file___34 *interpreter;
	struct file___34 *file;
	struct cred___2 *cred;
	int unsafe;
	unsigned int per_clear;
	int argc;
	int envc;
	const char *filename;
	const char *interp;
	const char *fdpath;
	unsigned int interp_flags;
	int execfd;
	long unsigned int loader;
	long unsigned int exec;
	struct rlimit rlim_stack;
	char buf[256];
};

struct coredump_params___9 {
	const kernel_siginfo_t *siginfo;
	struct pt_regs *regs;
	struct file___34 *file;
	long unsigned int limit;
	long unsigned int mm_flags;
	loff_t written;
	loff_t pos;
	loff_t to_skip;
};

struct dentry_operations___34;

struct dentry___34 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___34 *d_parent;
	struct qstr d_name;
	struct inode___34 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___34 *d_op;
	struct super_block___34 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___34;

struct inode___34 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___34 *i_op;
	struct super_block___34 *i_sb;
	struct address_space___34 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___22 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___34 *i_fop;
		void (*free_inode)(struct inode___34 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___34 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___13 *i_pipe;
		struct cdev *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___34 {
	int (*d_revalidate)(struct dentry___34 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___34 *, unsigned int);
	int (*d_hash)(const struct dentry___34 *, struct qstr *);
	int (*d_compare)(const struct dentry___34 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___34 *);
	int (*d_init)(struct dentry___34 *);
	void (*d_release)(struct dentry___34 *);
	void (*d_prune)(struct dentry___34 *);
	void (*d_iput)(struct dentry___34 *, struct inode___34 *);
	char * (*d_dname)(struct dentry___34 *, char *, int);
	struct vfsmount___34 * (*d_automount)(struct path___34 *);
	int (*d_manage)(const struct path___34 *, bool);
	struct dentry___34 * (*d_real)(struct dentry___34 *, const struct inode___34 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___34;

struct mem_dqinfo___34 {
	struct quota_format_type___34 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___34;

struct quota_info___34 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___34 *files[3];
	struct mem_dqinfo___34 info[3];
	const struct quota_format_ops___34 *ops[3];
};

struct rcuwait___34 {
	struct task_struct___38 *task;
};

struct percpu_rw_semaphore___34 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___34 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___34 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___34 rw_sem[3];
};

struct shrink_control___22;

struct shrinker___22 {
	long unsigned int (*count_objects)(struct shrinker___22 *, struct shrink_control___22 *);
	long unsigned int (*scan_objects)(struct shrinker___22 *, struct shrink_control___22 *);
	long int batch;
	int seeks;
	unsigned int flags;
	struct list_head list;
	int id;
	atomic_long_t *nr_deferred;
};

struct super_operations___34;

struct dquot_operations___34;

struct quotactl_ops___34;

struct block_device___23;

struct super_block___34 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___34 *s_type;
	const struct super_operations___34 *s_op;
	const struct dquot_operations___34 *dq_op;
	const struct quotactl_ops___34 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___34 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___23 *s_bdev;
	struct backing_dev_info___22 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___34 s_dquot;
	struct sb_writers___34 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___34 *s_d_op;
	int cleancache_poolid;
	struct shrinker___22 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___2 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___34 {
	struct dentry___34 *mnt_root;
	struct super_block___34 *mnt_sb;
	int mnt_flags;
	struct user_namespace___2 *mnt_userns;
};

struct shrink_control___22 {
	gfp_t gfp_mask;
	int nid;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	struct mem_cgroup___22 *memcg;
};

struct io_cq___23 {
	struct request_queue___23 *q;
	struct io_context___23 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct wait_page_queue___19;

struct kiocb___34 {
	struct file___34 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___34 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___19 *ki_waitq;
	};
};

struct iattr___34 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___34 *ia_file;
};

struct dquot___34 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___34 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___34 {
	int qf_fmt_id;
	const struct quota_format_ops___34 *qf_ops;
	struct module___33 *qf_owner;
	struct quota_format_type___34 *qf_next;
};

struct quota_format_ops___34 {
	int (*check_quota_file)(struct super_block___34 *, int);
	int (*read_file_info)(struct super_block___34 *, int);
	int (*write_file_info)(struct super_block___34 *, int);
	int (*free_file_info)(struct super_block___34 *, int);
	int (*read_dqblk)(struct dquot___34 *);
	int (*commit_dqblk)(struct dquot___34 *);
	int (*release_dqblk)(struct dquot___34 *);
	int (*get_next_id)(struct super_block___34 *, struct kqid *);
};

struct dquot_operations___34 {
	int (*write_dquot)(struct dquot___34 *);
	struct dquot___34 * (*alloc_dquot)(struct super_block___34 *, int);
	void (*destroy_dquot)(struct dquot___34 *);
	int (*acquire_dquot)(struct dquot___34 *);
	int (*release_dquot)(struct dquot___34 *);
	int (*mark_dirty)(struct dquot___34 *);
	int (*write_info)(struct super_block___34 *, int);
	qsize_t * (*get_reserved_space)(struct inode___34 *);
	int (*get_projid)(struct inode___34 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___34 *, qsize_t *);
	int (*get_next_id)(struct super_block___34 *, struct kqid *);
};

struct quotactl_ops___34 {
	int (*quota_on)(struct super_block___34 *, int, int, const struct path___34 *);
	int (*quota_off)(struct super_block___34 *, int);
	int (*quota_enable)(struct super_block___34 *, unsigned int);
	int (*quota_disable)(struct super_block___34 *, unsigned int);
	int (*quota_sync)(struct super_block___34 *, int);
	int (*set_info)(struct super_block___34 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___34 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___34 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___34 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___34 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___34 *, unsigned int);
};

struct wait_page_queue___19 {
	struct page___36 *page;
	int bit_nr;
	wait_queue_entry_t wait;
};

struct writeback_control___22;

struct readahead_control___19;

struct swap_info_struct___15;

struct address_space_operations___34 {
	int (*writepage)(struct page___36 *, struct writeback_control___22 *);
	int (*readpage)(struct file___34 *, struct page___36 *);
	int (*writepages)(struct address_space___34 *, struct writeback_control___22 *);
	int (*set_page_dirty)(struct page___36 *);
	int (*readpages)(struct file___34 *, struct address_space___34 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___19 *);
	int (*write_begin)(struct file___34 *, struct address_space___34 *, loff_t, unsigned int, unsigned int, struct page___36 **, void **);
	int (*write_end)(struct file___34 *, struct address_space___34 *, loff_t, unsigned int, unsigned int, struct page___36 *, void *);
	sector_t (*bmap)(struct address_space___34 *, sector_t);
	void (*invalidatepage)(struct page___36 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___36 *, gfp_t);
	void (*freepage)(struct page___36 *);
	ssize_t (*direct_IO)(struct kiocb___34 *, struct iov_iter___28 *);
	int (*migratepage)(struct address_space___34 *, struct page___36 *, struct page___36 *, enum migrate_mode);
	bool (*isolate_page)(struct page___36 *, isolate_mode_t);
	void (*putback_page)(struct page___36 *);
	int (*launder_page)(struct page___36 *);
	int (*is_partially_uptodate)(struct page___36 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___36 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___34 *, struct page___36 *);
	int (*swap_activate)(struct swap_info_struct___15 *, struct file___34 *, sector_t *);
	void (*swap_deactivate)(struct file___34 *);
};

struct writeback_control___22 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate;
	unsigned int for_background;
	unsigned int tagged_writepages;
	unsigned int for_reclaim;
	unsigned int range_cyclic;
	unsigned int for_sync;
	unsigned int no_cgroup_owner;
	unsigned int punt_to_cgroup;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bdi_writeback___22 *wb;
	struct inode___34 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
};

struct readahead_control___19 {
	struct file___34 *file;
	struct address_space___34 *mapping;
	struct file_ra_state *ra;
	long unsigned int _index;
	unsigned int _nr_pages;
	unsigned int _batch_count;
};

struct bio_vec___28;

struct iov_iter___28 {
	u8 iter_type;
	bool data_source;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___28 *bvec;
		struct xarray *xarray;
		struct pipe_inode_info___13 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			unsigned int head;
			unsigned int start_head;
		};
		loff_t xarray_start;
	};
};

struct swap_info_struct___15 {
	struct percpu_ref users;
	long unsigned int flags;
	short int prio;
	struct plist_node list;
	signed char type;
	unsigned int max;
	unsigned char *swap_map;
	struct swap_cluster_info *cluster_info;
	struct swap_cluster_list free_clusters;
	unsigned int lowest_bit;
	unsigned int highest_bit;
	unsigned int pages;
	unsigned int inuse_pages;
	unsigned int cluster_next;
	unsigned int cluster_nr;
	unsigned int *cluster_next_cpu;
	struct percpu_cluster *percpu_cluster;
	struct rb_root swap_extent_root;
	struct block_device___23 *bdev;
	struct file___34 *swap_file;
	unsigned int old_block_size;
	struct completion comp;
	long unsigned int *frontswap_map;
	atomic_t frontswap_pages;
	spinlock_t lock;
	spinlock_t cont_lock;
	struct work_struct discard_work;
	struct swap_cluster_list discard_clusters;
	struct plist_node avail_lists[0];
};

struct inode_operations___34 {
	struct dentry___34 * (*lookup)(struct inode___34 *, struct dentry___34 *, unsigned int);
	const char * (*get_link)(struct dentry___34 *, struct inode___34 *, struct delayed_call *);
	int (*permission)(struct user_namespace___2 *, struct inode___34 *, int);
	struct posix_acl * (*get_acl)(struct inode___34 *, int, bool);
	int (*readlink)(struct dentry___34 *, char *, int);
	int (*create)(struct user_namespace___2 *, struct inode___34 *, struct dentry___34 *, umode_t, bool);
	int (*link)(struct dentry___34 *, struct inode___34 *, struct dentry___34 *);
	int (*unlink)(struct inode___34 *, struct dentry___34 *);
	int (*symlink)(struct user_namespace___2 *, struct inode___34 *, struct dentry___34 *, const char *);
	int (*mkdir)(struct user_namespace___2 *, struct inode___34 *, struct dentry___34 *, umode_t);
	int (*rmdir)(struct inode___34 *, struct dentry___34 *);
	int (*mknod)(struct user_namespace___2 *, struct inode___34 *, struct dentry___34 *, umode_t, dev_t);
	int (*rename)(struct user_namespace___2 *, struct inode___34 *, struct dentry___34 *, struct inode___34 *, struct dentry___34 *, unsigned int);
	int (*setattr)(struct user_namespace___2 *, struct dentry___34 *, struct iattr___34 *);
	int (*getattr)(struct user_namespace___2 *, const struct path___34 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___34 *, char *, size_t);
	int (*fiemap)(struct inode___34 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___34 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___34 *, struct dentry___34 *, struct file___34 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace___2 *, struct inode___34 *, struct dentry___34 *, umode_t);
	int (*set_acl)(struct user_namespace___2 *, struct inode___34 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace___2 *, struct dentry___34 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___34 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___34 {
	void (*fl_copy_lock)(struct file_lock___34 *, struct file_lock___34 *);
	void (*fl_release_private)(struct file_lock___34 *);
};

struct lock_manager_operations___34;

struct file_lock___34 {
	struct file_lock___34 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___34 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___34 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___34 *fl_ops;
	const struct lock_manager_operations___34 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___34 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___34 *);
	int (*lm_grant)(struct file_lock___34 *, int);
	bool (*lm_break)(struct file_lock___34 *);
	int (*lm_change)(struct file_lock___34 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___34 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___34 *);
};

struct fasync_struct___34 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___34 *fa_next;
	struct file___34 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___34 {
	struct inode___34 * (*alloc_inode)(struct super_block___34 *);
	void (*destroy_inode)(struct inode___34 *);
	void (*free_inode)(struct inode___34 *);
	void (*dirty_inode)(struct inode___34 *, int);
	int (*write_inode)(struct inode___34 *, struct writeback_control___22 *);
	int (*drop_inode)(struct inode___34 *);
	void (*evict_inode)(struct inode___34 *);
	void (*put_super)(struct super_block___34 *);
	int (*sync_fs)(struct super_block___34 *, int);
	int (*freeze_super)(struct super_block___34 *);
	int (*freeze_fs)(struct super_block___34 *);
	int (*thaw_super)(struct super_block___34 *);
	int (*unfreeze_fs)(struct super_block___34 *);
	int (*statfs)(struct dentry___34 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___34 *, int *, char *);
	void (*umount_begin)(struct super_block___34 *);
	int (*show_options)(struct seq_file___32 *, struct dentry___34 *);
	int (*show_devname)(struct seq_file___32 *, struct dentry___34 *);
	int (*show_path)(struct seq_file___32 *, struct dentry___34 *);
	int (*show_stats)(struct seq_file___32 *, struct dentry___34 *);
	ssize_t (*quota_read)(struct super_block___34 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___34 *, int, const char *, size_t, loff_t);
	struct dquot___34 ** (*get_dquots)(struct inode___34 *);
	long int (*nr_cached_objects)(struct super_block___34 *, struct shrink_control___22 *);
	long int (*free_cached_objects)(struct super_block___34 *, struct shrink_control___22 *);
	struct file___34 * (*real_loop)(struct file___34 *);
};

struct block_device___23 {
	sector_t bd_start_sect;
	struct disk_stats *bd_stats;
	long unsigned int bd_stamp;
	bool bd_read_only;
	dev_t bd_dev;
	int bd_openers;
	struct inode___34 *bd_inode;
	struct super_block___34 *bd_super;
	void *bd_claiming;
	struct device___36 bd_device;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct kobject___34 *bd_holder_dir;
	u8 bd_partno;
	spinlock_t bd_size_lock;
	struct gendisk___23 *bd_disk;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	struct super_block___34 *bd_fsfreeze_sb;
	struct partition_meta_info *bd_meta_info;
};

typedef void bio_end_io_t___23(struct bio___23 *);

struct bio_vec___28 {
	struct page___36 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___23;

struct bio___23 {
	struct bio___23 *bi_next;
	struct block_device___23 *bi_bdev;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	atomic_t __bi_remaining;
	struct bvec_iter bi_iter;
	bio_end_io_t___23 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___22 *bi_blkg;
	struct bio_issue bi_issue;
	u64 bi_iocost_cost;
	struct bio_crypt_ctx *bi_crypt_context;
	union {
		struct bio_integrity_payload___23 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___28 *bi_io_vec;
	struct bio_set___23 *bi_pool;
	struct bio_vec___28 bi_inline_vecs[0];
};

struct dev_pagemap_ops___34 {
	void (*page_free)(struct page___36 *);
	void (*kill)(struct dev_pagemap___34 *);
	void (*cleanup)(struct dev_pagemap___34 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___34 *);
};

struct dev_pm_ops___36 {
	int (*prepare)(struct device___36 *);
	void (*complete)(struct device___36 *);
	int (*suspend)(struct device___36 *);
	int (*resume)(struct device___36 *);
	int (*freeze)(struct device___36 *);
	int (*thaw)(struct device___36 *);
	int (*poweroff)(struct device___36 *);
	int (*restore)(struct device___36 *);
	int (*suspend_late)(struct device___36 *);
	int (*resume_early)(struct device___36 *);
	int (*freeze_late)(struct device___36 *);
	int (*thaw_early)(struct device___36 *);
	int (*poweroff_late)(struct device___36 *);
	int (*restore_early)(struct device___36 *);
	int (*suspend_noirq)(struct device___36 *);
	int (*resume_noirq)(struct device___36 *);
	int (*freeze_noirq)(struct device___36 *);
	int (*thaw_noirq)(struct device___36 *);
	int (*poweroff_noirq)(struct device___36 *);
	int (*restore_noirq)(struct device___36 *);
	int (*runtime_suspend)(struct device___36 *);
	int (*runtime_resume)(struct device___36 *);
	int (*runtime_idle)(struct device___36 *);
};

struct wakeup_source___36 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___36 *dev;
	bool active;
	bool autosleep_enabled;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_qos_request___6;

struct dev_pm_qos___6 {
	struct pm_qos_constraints resume_latency;
	struct pm_qos_constraints latency_tolerance;
	struct freq_constraints freq;
	struct pm_qos_flags flags;
	struct dev_pm_qos_request___6 *resume_latency_req;
	struct dev_pm_qos_request___6 *latency_tolerance_req;
	struct dev_pm_qos_request___6 *flags_req;
};

struct dev_pm_domain___36 {
	struct dev_pm_ops___36 ops;
	int (*start)(struct device___36 *);
	void (*detach)(struct device___36 *, bool);
	int (*activate)(struct device___36 *);
	void (*sync)(struct device___36 *);
	void (*dismiss)(struct device___36 *);
};

struct bus_type___36 {
	const char *name;
	const char *dev_name;
	struct device___36 *dev_root;
	const struct attribute_group___34 **bus_groups;
	const struct attribute_group___34 **dev_groups;
	const struct attribute_group___34 **drv_groups;
	int (*match)(struct device___36 *, struct device_driver___36 *);
	int (*uevent)(struct device___36 *, struct kobj_uevent_env *);
	int (*probe)(struct device___36 *);
	void (*sync_state)(struct device___36 *);
	void (*remove)(struct device___36 *);
	void (*shutdown)(struct device___36 *);
	int (*online)(struct device___36 *);
	int (*offline)(struct device___36 *);
	int (*suspend)(struct device___36 *, pm_message_t);
	int (*resume)(struct device___36 *);
	int (*num_vf)(struct device___36 *);
	int (*dma_configure)(struct device___36 *);
	const struct dev_pm_ops___36 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___36 {
	const char *name;
	struct bus_type___36 *bus;
	struct module___33 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___36 *);
	void (*sync_state)(struct device___36 *);
	int (*remove)(struct device___36 *);
	void (*shutdown)(struct device___36 *);
	int (*suspend)(struct device___36 *, pm_message_t);
	int (*resume)(struct device___36 *);
	const struct attribute_group___34 **groups;
	const struct attribute_group___34 **dev_groups;
	const struct dev_pm_ops___36 *pm;
	void (*coredump)(struct device___36 *);
	struct driver_private *p;
};

struct device_type___36 {
	const char *name;
	const struct attribute_group___34 **groups;
	int (*uevent)(struct device___36 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___36 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___36 *);
	const struct dev_pm_ops___36 *pm;
};

struct class___36 {
	const char *name;
	struct module___33 *owner;
	const struct attribute_group___34 **class_groups;
	const struct attribute_group___34 **dev_groups;
	struct kobject___34 *dev_kobj;
	int (*dev_uevent)(struct device___36 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___36 *, umode_t *);
	void (*class_release)(struct class___36 *);
	void (*dev_release)(struct device___36 *);
	int (*shutdown_pre)(struct device___36 *);
	const struct kobj_ns_type_operations___3 *ns_type;
	const void * (*namespace)(struct device___36 *);
	void (*get_ownership)(struct device___36 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___36 *pm;
	struct subsys_private *p;
};

struct block_device_operations___23;

struct gendisk___23 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	short unsigned int events;
	short unsigned int event_flags;
	struct xarray part_tbl;
	struct block_device___23 *part0;
	const struct block_device_operations___23 *fops;
	struct request_queue___23 *queue;
	void *private_data;
	int flags;
	long unsigned int state;
	struct mutex open_mutex;
	unsigned int open_partitions;
	struct backing_dev_info___22 *bdi;
	struct kobject___34 *slave_dir;
	struct list_head slave_bdevs;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___34 integrity_kobj;
	struct cdrom_device_info *cdi;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	u64 diskseq;
};

struct bio_integrity_payload___23 {
	struct bio___23 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___28 *bip_vec;
	struct bio_vec___28 bip_inline_vecs[0];
};

struct blkcg___22;

struct blkg_policy_data___22;

struct blkcg_gq___22 {
	struct request_queue___23 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___22 *blkcg;
	struct blkcg_gq___22 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_iostat_set *iostat_cpu;
	struct blkg_iostat_set iostat;
	struct blkg_policy_data___22 *pd[6];
	spinlock_t async_bio_lock;
	struct bio_list___23 async_bios;
	struct work_struct async_bio_work;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
	struct callback_head callback_head;
};

typedef void integrity_prepare_fn___23(struct request___23 *);

typedef void integrity_complete_fn___23(struct request___23 *, unsigned int);

struct blk_integrity_profile___23 {
	integrity_processing_fn *generate_fn;
	integrity_processing_fn *verify_fn;
	integrity_prepare_fn___23 *prepare_fn;
	integrity_complete_fn___23 *complete_fn;
	const char *name;
};

struct block_device_operations___23 {
	blk_qc_t (*submit_bio)(struct bio___23 *);
	int (*open)(struct block_device___23 *, fmode_t);
	void (*release)(struct gendisk___23 *, fmode_t);
	int (*rw_page)(struct block_device___23 *, sector_t, struct page___36 *, unsigned int);
	int (*ioctl)(struct block_device___23 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___23 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___23 *, unsigned int);
	void (*unlock_native_capacity)(struct gendisk___23 *);
	int (*getgeo)(struct block_device___23 *, struct hd_geometry *);
	int (*set_read_only)(struct block_device___23 *, bool);
	void (*swap_slot_free_notify)(struct block_device___23 *, long unsigned int);
	int (*report_zones)(struct gendisk___23 *, sector_t, unsigned int, report_zones_cb, void *);
	char * (*devnode)(struct gendisk___23 *, umode_t *);
	struct module___33 *owner;
	const struct pr_ops *pr_ops;
	int (*alternative_gpt_sector)(struct gendisk___23 *, sector_t *);
};

typedef void rq_end_io_fn___23(struct request___23 *, blk_status_t);

struct request___23 {
	struct request_queue___23 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int tag;
	int internal_tag;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___23 *bio;
	struct bio___23 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct llist_node ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___28 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___23 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___23 *saved_end_io;
		} flush;
	};
	struct gendisk___23 *rq_disk;
	struct block_device___23 *part;
	u64 alloc_time_ns;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int stats_sectors;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	struct bio_crypt_ctx *crypt_ctx;
	struct blk_ksm_keyslot *crypt_keyslot;
	short unsigned int write_hint;
	short unsigned int ioprio;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___23 *end_io;
	void *end_io_data;
};

struct elevator_type___23;

struct elevator_mq_ops___23 {
	int (*init_sched)(struct request_queue___23 *, struct elevator_type___23 *);
	void (*exit_sched)(struct elevator_queue___23 *);
	int (*init_hctx)(struct blk_mq_hw_ctx *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx *, unsigned int);
	void (*depth_updated)(struct blk_mq_hw_ctx *);
	bool (*allow_merge)(struct request_queue___23 *, struct request___23 *, struct bio___23 *);
	bool (*bio_merge)(struct request_queue___23 *, struct bio___23 *, unsigned int);
	int (*request_merge)(struct request_queue___23 *, struct request___23 **, struct bio___23 *);
	void (*request_merged)(struct request_queue___23 *, struct request___23 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___23 *, struct request___23 *, struct request___23 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___23 *);
	void (*finish_request)(struct request___23 *);
	void (*insert_requests)(struct blk_mq_hw_ctx *, struct list_head *, bool);
	struct request___23 * (*dispatch_request)(struct blk_mq_hw_ctx *);
	bool (*has_work)(struct blk_mq_hw_ctx *);
	void (*completed_request)(struct request___23 *, u64);
	void (*requeue_request)(struct request___23 *);
	struct request___23 * (*former_request)(struct request_queue___23 *, struct request___23 *);
	struct request___23 * (*next_request)(struct request_queue___23 *, struct request___23 *);
	void (*init_icq)(struct io_cq___23 *);
	void (*exit_icq)(struct io_cq___23 *);
};

struct elv_fs_entry___23;

struct elevator_type___23 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___23 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___23 *elevator_attrs;
	const char *elevator_name;
	const char *elevator_alias;
	const unsigned int elevator_features;
	struct module___33 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
};

struct elevator_queue___23 {
	struct elevator_type___23 *type;
	void *elevator_data;
	struct kobject___34 kobj;
	struct mutex sysfs_lock;
	unsigned int registered;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hlist_head hash[64];
};

struct elv_fs_entry___23 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___23 *, char *);
	ssize_t (*store)(struct elevator_queue___23 *, const char *, size_t);
};

struct dev_pm_qos_request___6 {
	enum dev_pm_qos_req_type type;
	union {
		struct plist_node pnode;
		struct pm_qos_flags_request flr;
		struct freq_qos_request freq;
	} data;
	struct device___36 *dev;
};

struct cpuidle_device___2;

struct cpuidle_driver___2;

struct cpuidle_state___2 {
	char name[16];
	char desc[32];
	s64 exit_latency_ns;
	s64 target_residency_ns;
	unsigned int flags;
	unsigned int exit_latency;
	int power_usage;
	unsigned int target_residency;
	int (*enter)(struct cpuidle_device___2 *, struct cpuidle_driver___2 *, int);
	int (*enter_dead)(struct cpuidle_device___2 *, int);
	int (*enter_s2idle)(struct cpuidle_device___2 *, struct cpuidle_driver___2 *, int);
};

struct cpuidle_device___2 {
	unsigned int registered: 1;
	unsigned int enabled: 1;
	unsigned int poll_time_limit: 1;
	unsigned int cpu;
	ktime_t next_hrtimer;
	int last_state_idx;
	u64 last_residency_ns;
	u64 poll_limit_ns;
	u64 forced_idle_latency_limit_ns;
	struct cpuidle_state_usage states_usage[10];
	struct cpuidle_state_kobj *kobjs[10];
	struct cpuidle_driver_kobj *kobj_driver;
	struct cpuidle_device_kobj *kobj_dev;
	struct list_head device_list;
};

struct cpuidle_driver___2 {
	const char *name;
	struct module___33 *owner;
	unsigned int bctimer: 1;
	long: 63;
	long: 64;
	long: 64;
	struct cpuidle_state___2 states[10];
	int state_count;
	int safe_state_index;
	struct cpumask *cpumask;
	const char *governor;
};

struct cgroup_namespace___28 {
	struct ns_common___5 ns;
	struct user_namespace___2 *user_ns;
	struct ucounts___2 *ucounts;
	struct css_set___28 *root_cset;
};

struct kernel_param_ops___33 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___33 *);
	int (*get)(char *, const struct kernel_param___33 *);
	void (*free)(void *);
};

struct kparam_array___33;

struct kernel_param___33 {
	const char *name;
	struct module___33 *mod;
	const struct kernel_param_ops___33 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___33 *arr;
	};
};

struct kparam_array___33 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___33 *ops;
	void *elem;
};

struct module_attribute___33 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___33 *, struct module_kobject___33 *, char *);
	ssize_t (*store)(struct module_attribute___33 *, struct module_kobject___33 *, const char *, size_t);
	void (*setup)(struct module___33 *, const char *);
	int (*test)(struct module___33 *);
	void (*free)(struct module___33 *);
};

struct trace_event_class___22;

struct trace_event_call___22 {
	struct list_head list;
	struct trace_event_class___22 *class;
	union {
		char *name;
		struct tracepoint___25 *tp;
	};
	struct trace_event event;
	char *print_fmt;
	struct event_filter *filter;
	union {
		void *module;
		atomic_t refcnt;
	};
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
	struct bpf_prog_array___4 *prog_array;
	int (*perf_perm)(struct trace_event_call___22 *, struct perf_event___22 *);
};

struct pipe_buf_operations___13;

struct pipe_buffer___13 {
	struct page___36 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___13 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___13 {
	int (*confirm)(struct pipe_inode_info___13 *, struct pipe_buffer___13 *);
	void (*release)(struct pipe_inode_info___13 *, struct pipe_buffer___13 *);
	bool (*try_steal)(struct pipe_inode_info___13 *, struct pipe_buffer___13 *);
	bool (*get)(struct pipe_inode_info___13 *, struct pipe_buffer___13 *);
};

struct cftype___28;

struct cgroup_subsys___28 {
	struct cgroup_subsys_state___28 * (*css_alloc)(struct cgroup_subsys_state___28 *);
	int (*css_online)(struct cgroup_subsys_state___28 *);
	void (*css_offline)(struct cgroup_subsys_state___28 *);
	void (*css_released)(struct cgroup_subsys_state___28 *);
	void (*css_free)(struct cgroup_subsys_state___28 *);
	void (*css_reset)(struct cgroup_subsys_state___28 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___28 *, int);
	int (*css_extra_stat_show)(struct seq_file___32 *, struct cgroup_subsys_state___28 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___38 *, struct css_set___28 *);
	void (*cancel_fork)(struct task_struct___38 *, struct css_set___28 *);
	void (*fork)(struct task_struct___38 *);
	void (*exit)(struct task_struct___38 *);
	void (*release)(struct task_struct___38 *);
	void (*bind)(struct cgroup_subsys_state___28 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___28 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___28 *dfl_cftypes;
	struct cftype___28 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___28 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___28 *updated_children;
	struct cgroup___28 *updated_next;
};

struct cgroup_root___28 {
	struct kernfs_root___34 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___28 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___28 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___28 *ss;
	struct list_head node;
	struct kernfs_ops___34 *kf_ops;
	int (*open)(struct kernfs_open_file___34 *);
	void (*release)(struct kernfs_open_file___34 *);
	u64 (*read_u64)(struct cgroup_subsys_state___28 *, struct cftype___28 *);
	s64 (*read_s64)(struct cgroup_subsys_state___28 *, struct cftype___28 *);
	int (*seq_show)(struct seq_file___32 *, void *);
	void * (*seq_start)(struct seq_file___32 *, loff_t *);
	void * (*seq_next)(struct seq_file___32 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___32 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___28 *, struct cftype___28 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___28 *, struct cftype___28 *, s64);
	ssize_t (*write)(struct kernfs_open_file___34 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___34 *, struct poll_table_struct___25 *);
};

struct blkcg_policy_data___22;

struct blkcg___22 {
	struct cgroup_subsys_state___28 css;
	spinlock_t lock;
	refcount_t online_pin;
	struct xarray blkg_tree;
	struct blkcg_gq___22 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___22 *cpd[6];
	struct list_head all_blkcgs_node;
	char fc_app_id[129];
	struct list_head cgwb_list;
};

struct blkcg_policy_data___22 {
	struct blkcg___22 *blkcg;
	int plid;
};

struct blkg_policy_data___22 {
	struct blkcg_gq___22 *blkg;
	int plid;
};

struct mem_cgroup_reclaim_iter___22 {
	struct mem_cgroup___22 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___22 {
	struct lruvec___23 lruvec;
	struct lruvec_stats_percpu *lruvec_stats_percpu;
	struct lruvec_stats lruvec_stats;
	long unsigned int lru_zone_size[25];
	struct mem_cgroup_reclaim_iter___22 iter;
	struct shrinker_info *shrinker_info;
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	struct mem_cgroup___22 *memcg;
};

struct obj_cgroup___22 {
	struct percpu_ref refcnt;
	struct mem_cgroup___22 *memcg;
	atomic_t nr_charged_bytes;
	union {
		struct list_head list;
		struct callback_head rcu;
	};
};

struct perf_cpu_context___22;

struct perf_output_handle___22;

struct pmu___22 {
	struct list_head entry;
	struct module___33 *module;
	struct device___36 *dev;
	const struct attribute_group___34 **attr_groups;
	const struct attribute_group___34 **attr_update;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___22 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___22 *);
	void (*pmu_disable)(struct pmu___22 *);
	int (*event_init)(struct perf_event___22 *);
	void (*event_mapped)(struct perf_event___22 *, struct mm_struct___37 *);
	void (*event_unmapped)(struct perf_event___22 *, struct mm_struct___37 *);
	int (*add)(struct perf_event___22 *, int);
	void (*del)(struct perf_event___22 *, int);
	void (*start)(struct perf_event___22 *, int);
	void (*stop)(struct perf_event___22 *, int);
	void (*read)(struct perf_event___22 *);
	void (*start_txn)(struct pmu___22 *, unsigned int);
	int (*commit_txn)(struct pmu___22 *);
	void (*cancel_txn)(struct pmu___22 *);
	int (*event_idx)(struct perf_event___22 *);
	void (*sched_task)(struct perf_event_context___22 *, bool);
	struct kmem_cache *task_ctx_cache;
	void (*swap_task_ctx)(struct perf_event_context___22 *, struct perf_event_context___22 *);
	void * (*setup_aux)(struct perf_event___22 *, void **, int, bool);
	void (*free_aux)(void *);
	long int (*snapshot_aux)(struct perf_event___22 *, struct perf_output_handle___22 *, long unsigned int);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___22 *);
	int (*aux_output_match)(struct perf_event___22 *);
	int (*filter_match)(struct perf_event___22 *);
	int (*check_period)(struct perf_event___22 *, u64);
};

struct perf_cpu_context___22 {
	struct perf_event_context___22 ctx;
	struct perf_event_context___22 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___22 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
	int heap_size;
	struct perf_event___22 **heap;
	struct perf_event___22 *heap_default[2];
};

struct perf_output_handle___22 {
	struct perf_event___22 *event;
	struct perf_buffer *rb;
	long unsigned int wakeup;
	long unsigned int size;
	u64 aux_flags;
	union {
		void *addr;
		long unsigned int head;
	};
	int page;
};

struct perf_cgroup___22 {
	struct cgroup_subsys_state___28 css;
	struct perf_cgroup_info *info;
};

struct trace_event_fields___22 {
	const char *type;
	union {
		struct {
			const char *name;
			const int size;
			const int align;
			const int is_signed;
			const int filter_type;
		};
		int (*define_fields)(struct trace_event_call___22 *);
	};
};

struct trace_event_class___22 {
	const char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct trace_event_call___22 *, enum trace_reg, void *);
	struct trace_event_fields___22 *fields_array;
	struct list_head * (*get_fields)(struct trace_event_call___22 *);
	struct list_head fields;
	int (*raw_init)(struct trace_event_call___22 *);
};

struct rq___3 {
	raw_spinlock_t __lock;
	unsigned int nr_running;
	unsigned int nr_numa_running;
	unsigned int nr_preferred_running;
	unsigned int numa_migrate_on;
	long unsigned int last_blocked_load_update_tick;
	unsigned int has_blocked_load;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	call_single_data_t nohz_csd;
	unsigned int nohz_tick_stopped;
	atomic_t nohz_flags;
	unsigned int ttwu_pending;
	u64 nr_switches;
	long: 64;
	struct uclamp_rq uclamp[2];
	unsigned int uclamp_flags;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	struct cfs_rq___2 cfs;
	struct rt_rq rt;
	struct dl_rq dl;
	struct list_head leaf_cfs_rq_list;
	struct list_head *tmp_alone_branch;
	unsigned int nr_uninterruptible;
	struct task_struct___38 *curr;
	struct task_struct___38 *idle;
	struct task_struct___38 *stop;
	long unsigned int next_balance;
	struct mm_struct___37 *prev_mm;
	unsigned int clock_update_flags;
	u64 clock;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u64 clock_task;
	u64 clock_pelt;
	long unsigned int lost_idle_time;
	atomic_t nr_iowait;
	u64 last_seen_need_resched_ns;
	int ticks_without_resched;
	int membarrier_state;
	struct root_domain *rd;
	struct sched_domain *sd;
	long unsigned int cpu_capacity;
	long unsigned int cpu_capacity_orig;
	struct callback_head *balance_callback;
	unsigned char nohz_idle_balance;
	unsigned char idle_balance;
	long unsigned int misfit_task_load;
	int active_balance;
	int push_cpu;
	struct cpu_stop_work active_balance_work;
	int cpu;
	int online;
	struct list_head cfs_tasks;
	long: 64;
	struct sched_avg avg_rt;
	struct sched_avg avg_dl;
	u64 idle_stamp;
	u64 avg_idle;
	long unsigned int wake_stamp;
	u64 wake_avg_idle;
	u64 max_idle_balance_cost;
	struct rcuwait___34 hotplug_wait;
	u64 prev_steal_time;
	long unsigned int calc_load_update;
	long int calc_load_active;
	long: 64;
	long: 64;
	long: 64;
	call_single_data_t hrtick_csd;
	struct hrtimer hrtick_timer;
	ktime_t hrtick_time;
	struct sched_info rq_sched_info;
	long long unsigned int rq_cpu_time;
	unsigned int yld_count;
	unsigned int sched_count;
	unsigned int sched_goidle;
	unsigned int ttwu_count;
	unsigned int ttwu_local;
	struct cpuidle_state___2 *idle_state;
	unsigned int nr_pinned;
	unsigned int push_busy;
	struct cpu_stop_work push_work;
	struct rq___3 *core;
	struct task_struct___38 *core_pick;
	unsigned int core_enabled;
	unsigned int core_sched_seq;
	struct rb_root core_tree;
	unsigned int core_task_seq;
	unsigned int core_pick_seq;
	long unsigned int core_cookie;
	unsigned char core_forceidle;
	unsigned int core_forceidle_seq;
};

struct pv_cpu_ops___29 {
	void (*io_delay)();
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	void (*write_cr4)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___23 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(long unsigned int);
	void (*invalidate_io_bitmap)();
	void (*update_io_bitmap)();
	void (*wbinvd)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int);
	void (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_msr_safe)(unsigned int, int *);
	int (*write_msr_safe)(unsigned int, unsigned int, unsigned int);
	u64 (*read_pmc)(int);
	void (*start_context_switch)(struct task_struct___38 *);
	void (*end_context_switch)(struct task_struct___38 *);
};

struct flush_tlb_info___14;

struct mmu_gather___7;

struct pv_mmu_ops___31 {
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_one_user)(long unsigned int);
	void (*flush_tlb_multi)(const struct cpumask *, const struct flush_tlb_info___14 *);
	void (*tlb_remove_table)(struct mmu_gather___7 *, void *);
	void (*exit_mmap)(struct mm_struct___37 *);
	struct paravirt_callee_save read_cr2;
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___37 *, struct mm_struct___37 *);
	void (*dup_mmap)(struct mm_struct___37 *, struct mm_struct___37 *);
	int (*pgd_alloc)(struct mm_struct___37 *);
	void (*pgd_free)(struct mm_struct___37 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___37 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___37 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___37 *, long unsigned int);
	void (*alloc_p4d)(struct mm_struct___37 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*release_p4d)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	pte_t (*ptep_modify_prot_start)(struct vm_area_struct___37 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct vm_area_struct___37 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_p4d)(p4d_t *, p4d_t);
	struct paravirt_callee_save p4d_val;
	struct paravirt_callee_save make_p4d;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

struct flush_tlb_info___14 {
	struct mm_struct___37 *mm;
	long unsigned int start;
	long unsigned int end;
	u64 new_tlb_gen;
	unsigned int initiating_cpu;
	u8 stride_shift;
	u8 freed_tables;
};

struct mmu_gather_batch___7 {
	struct mmu_gather_batch___7 *next;
	unsigned int nr;
	unsigned int max;
	struct page___36 *pages[0];
};

struct mmu_gather___7 {
	struct mm_struct___37 *mm;
	struct mmu_table_batch *batch;
	long unsigned int start;
	long unsigned int end;
	unsigned int fullmm: 1;
	unsigned int need_flush_all: 1;
	unsigned int freed_tables: 1;
	unsigned int cleared_ptes: 1;
	unsigned int cleared_pmds: 1;
	unsigned int cleared_puds: 1;
	unsigned int cleared_p4ds: 1;
	unsigned int vma_exec: 1;
	unsigned int vma_huge: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int batch_count;
	struct mmu_gather_batch___7 *active;
	struct mmu_gather_batch___7 local;
	struct page___36 *__pages[8];
};

struct paravirt_patch_template___31 {
	struct pv_cpu_ops___29 cpu;
	struct pv_irq_ops irq;
	struct pv_mmu_ops___31 mmu;
	struct pv_lock_ops lock;
};

enum tick_dep_bits {
	TICK_DEP_BIT_POSIX_TIMER = 0,
	TICK_DEP_BIT_PERF_EVENTS = 1,
	TICK_DEP_BIT_SCHED = 2,
	TICK_DEP_BIT_CLOCK_UNSTABLE = 3,
	TICK_DEP_BIT_RCU = 4,
	TICK_DEP_BIT_RCU_EXP = 5,
};

struct sched_clock_data {
	u64 tick_raw;
	u64 tick_gtod;
	u64 clock;
};

struct dentry___35;

struct super_block___35;

struct module___34;

struct file_system_type___35 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___35 * (*mount)(struct file_system_type___35 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___35 *);
	struct module___34 *owner;
	struct file_system_type___35 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___35;

struct kiocb___35;

struct iov_iter___29;

struct poll_table_struct___26;

struct vm_area_struct___38;

struct inode___35;

struct file_lock___35;

struct page___37;

struct pipe_inode_info___14;

struct seq_file___33;

struct file_operations___35 {
	struct module___34 *owner;
	loff_t (*llseek)(struct file___35 *, loff_t, int);
	ssize_t (*read)(struct file___35 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___35 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___35 *, struct iov_iter___29 *);
	ssize_t (*write_iter)(struct kiocb___35 *, struct iov_iter___29 *);
	int (*iopoll)(struct kiocb___35 *, bool);
	int (*iterate)(struct file___35 *, struct dir_context *);
	int (*iterate_shared)(struct file___35 *, struct dir_context *);
	__poll_t (*poll)(struct file___35 *, struct poll_table_struct___26 *);
	long int (*unlocked_ioctl)(struct file___35 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___35 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___35 *, struct vm_area_struct___38 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___35 *, struct file___35 *);
	int (*flush)(struct file___35 *, fl_owner_t);
	int (*release)(struct inode___35 *, struct file___35 *);
	int (*fsync)(struct file___35 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___35 *, int);
	int (*lock)(struct file___35 *, int, struct file_lock___35 *);
	ssize_t (*sendpage)(struct file___35 *, struct page___37 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___35 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___35 *, long unsigned int);
	int (*flock)(struct file___35 *, int, struct file_lock___35 *);
	ssize_t (*splice_write)(struct pipe_inode_info___14 *, struct file___35 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___35 *, loff_t *, struct pipe_inode_info___14 *, size_t, unsigned int);
	int (*setlease)(struct file___35 *, long int, struct file_lock___35 **, void **);
	long int (*fallocate)(struct file___35 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___33 *, struct file___35 *);
	ssize_t (*copy_file_range)(struct file___35 *, loff_t, struct file___35 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___35 *, loff_t, struct file___35 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___35 *, loff_t, loff_t, int);
};

struct static_call_mod___26 {
	struct static_call_mod___26 *next;
	struct module___34 *mod;
	struct static_call_site *sites;
};

struct static_call_key___26 {
	void *func;
	union {
		long unsigned int type;
		struct static_call_mod___26 *mods;
		struct static_call_site *sites;
	};
};

struct cfs_rq___3;

struct sched_entity___3 {
	struct load_weight load;
	struct rb_node run_node;
	struct list_head group_node;
	unsigned int on_rq;
	u64 exec_start;
	u64 sum_exec_runtime;
	u64 vruntime;
	u64 prev_sum_exec_runtime;
	u64 nr_migrations;
	struct sched_statistics statistics;
	int depth;
	struct sched_entity___3 *parent;
	struct cfs_rq___3 *cfs_rq;
	struct cfs_rq___3 *my_q;
	long unsigned int runnable_weight;
	long: 64;
	long: 64;
	long: 64;
	struct sched_avg avg;
};

struct vmacache___37 {
	u64 seqnum;
	struct vm_area_struct___38 *vmas[4];
};

struct page_frag___37 {
	struct page___37 *page;
	__u32 offset;
	__u32 size;
};

struct perf_event___23;

struct thread_struct___24 {
	struct desc_struct tls_array[3];
	long unsigned int sp;
	short unsigned int es;
	short unsigned int ds;
	short unsigned int fsindex;
	short unsigned int gsindex;
	long unsigned int fsbase;
	long unsigned int gsbase;
	struct perf_event___23 *ptrace_bps[4];
	long unsigned int virtual_dr6;
	long unsigned int ptrace_dr7;
	long unsigned int cr2;
	long unsigned int trap_nr;
	long unsigned int error_code;
	struct io_bitmap *io_bitmap;
	long unsigned int iopl_emul;
	unsigned int iopl_warn: 1;
	unsigned int sig_on_uaccess_err: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u32 pkru;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct fpu fpu;
};

struct mm_struct___38;

struct pid___30;

struct nsproxy___34;

struct signal_struct___35;

struct bio_list___24;

struct backing_dev_info___23;

struct io_context___24;

struct css_set___29;

struct perf_event_context___23;

struct mem_cgroup___23;

struct request_queue___24;

struct vm_struct___32;

struct task_struct___2 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___2 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___3 se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___38 *mm;
	struct mm_struct___38 *active_mm;
	struct vmacache___37 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int restore_sigmask: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___2 *real_parent;
	struct task_struct___2 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___2 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___30 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	struct posix_cputimers_work posix_cputimers_work;
	const struct cred___2 *ptracer_cred;
	const struct cred___2 *real_cred;
	const struct cred___2 *cred;
	struct key *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___34 *nsproxy;
	struct signal_struct___35 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___2 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___24 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___23 *backing_dev_info;
	struct io_context___24 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___29 *cgroups;
	struct list_head cg_list;
	u32 closid;
	u32 rmid;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___23 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	struct pipe_inode_info___14 *splice_pipe;
	struct page_frag___37 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___23 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___23 *active_memcg;
	struct request_queue___24 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___2 *oom_reaper_list;
	struct vm_struct___32 *stack_vm_area;
	refcount_t stack_refcount;
	int patch_state;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	void *mce_vaddr;
	__u64 mce_kflags;
	u64 mce_addr;
	__u64 mce_ripv: 1;
	__u64 mce_whole_page: 1;
	__u64 __mce_reserved: 62;
	long: 2;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct callback_head mce_kill_me;
	int mce_count;
	struct llist_head kretprobe_instances;
	struct callback_head l1d_flush_kill;
	long: 64;
	struct thread_struct___24 thread;
};

typedef struct page___37 *pgtable_t___37;

struct address_space___35;

struct page_pool___13;

struct dev_pagemap___35;

struct page___37 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___35 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___13 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___37 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___37 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___38 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___35 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct pv_cpu_ops___30 {
	void (*io_delay)();
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	void (*write_cr4)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___24 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(long unsigned int);
	void (*invalidate_io_bitmap)();
	void (*update_io_bitmap)();
	void (*wbinvd)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int);
	void (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_msr_safe)(unsigned int, int *);
	int (*write_msr_safe)(unsigned int, unsigned int, unsigned int);
	u64 (*read_pmc)(int);
	void (*start_context_switch)(struct task_struct___2 *);
	void (*end_context_switch)(struct task_struct___2 *);
};

struct flush_tlb_info___15;

struct mmu_gather___8;

struct pv_mmu_ops___32 {
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_one_user)(long unsigned int);
	void (*flush_tlb_multi)(const struct cpumask *, const struct flush_tlb_info___15 *);
	void (*tlb_remove_table)(struct mmu_gather___8 *, void *);
	void (*exit_mmap)(struct mm_struct___38 *);
	struct paravirt_callee_save read_cr2;
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___38 *, struct mm_struct___38 *);
	void (*dup_mmap)(struct mm_struct___38 *, struct mm_struct___38 *);
	int (*pgd_alloc)(struct mm_struct___38 *);
	void (*pgd_free)(struct mm_struct___38 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___38 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___38 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___38 *, long unsigned int);
	void (*alloc_p4d)(struct mm_struct___38 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*release_p4d)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	pte_t (*ptep_modify_prot_start)(struct vm_area_struct___38 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct vm_area_struct___38 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_p4d)(p4d_t *, p4d_t);
	struct paravirt_callee_save p4d_val;
	struct paravirt_callee_save make_p4d;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

struct flush_tlb_info___15 {
	struct mm_struct___38 *mm;
	long unsigned int start;
	long unsigned int end;
	u64 new_tlb_gen;
	unsigned int initiating_cpu;
	u8 stride_shift;
	u8 freed_tables;
};

struct mmu_gather_batch___8 {
	struct mmu_gather_batch___8 *next;
	unsigned int nr;
	unsigned int max;
	struct page___37 *pages[0];
};

struct mmu_gather___8 {
	struct mm_struct___38 *mm;
	struct mmu_table_batch *batch;
	long unsigned int start;
	long unsigned int end;
	unsigned int fullmm: 1;
	unsigned int need_flush_all: 1;
	unsigned int freed_tables: 1;
	unsigned int cleared_ptes: 1;
	unsigned int cleared_pmds: 1;
	unsigned int cleared_puds: 1;
	unsigned int cleared_p4ds: 1;
	unsigned int vma_exec: 1;
	unsigned int vma_huge: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int batch_count;
	struct mmu_gather_batch___8 *active;
	struct mmu_gather_batch___8 local;
	struct page___37 *__pages[8];
};

struct linux_binfmt___10;

struct core_state___37;

struct mm_struct___38 {
	struct {
		struct vm_area_struct___38 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___35 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int mmap_compat_base;
		long unsigned int mmap_compat_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[48];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___10 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___37 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___2 *owner;
		struct user_namespace___2 *user_ns;
		struct file___35 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		bool tlb_flush_batched;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct vm_operations_struct___35;

struct vm_area_struct___38 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___38 *vm_next;
	struct vm_area_struct___38 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___38 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___35 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___35 *vm_file;
	struct file___35 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct paravirt_patch_template___32 {
	struct pv_cpu_ops___30 cpu;
	struct pv_irq_ops irq;
	struct pv_mmu_ops___32 mmu;
	struct pv_lock_ops lock;
};

struct tracepoint___26 {
	const char *name;
	struct static_key key;
	struct static_call_key___26 *static_call_key;
	void *static_call_tramp;
	void *iterator;
	int (*regfunc)();
	void (*unregfunc)();
	struct tracepoint_func *funcs;
};

struct bpf_raw_event_map___26 {
	struct tracepoint___26 *tp;
	void *bpf_func;
	u32 num_args;
	u32 writable_size;
	long: 64;
};

struct seq_operations___33 {
	void * (*start)(struct seq_file___33 *, loff_t *);
	void (*stop)(struct seq_file___33 *, void *);
	void * (*next)(struct seq_file___33 *, void *, loff_t *);
	int (*show)(struct seq_file___33 *, void *);
};

struct hw_perf_event___23 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___2 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	union {
		struct {
			u64 last_period;
			local64_t period_left;
		};
		struct {
			u64 saved_metric;
			u64 saved_slots;
		};
	};
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

struct perf_sample_data___3;

typedef void (*perf_overflow_handler_t___23)(struct perf_event___23 *, struct perf_sample_data___3 *, struct pt_regs *);

struct pmu___23;

struct fasync_struct___35;

struct pid_namespace___30;

struct trace_event_call___23;

struct perf_cgroup___23;

struct perf_event___23 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___23 *group_leader;
	struct pmu___23 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___23 hw;
	struct perf_event_context___23 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___23 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___2 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct perf_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___35 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	long unsigned int pending_addr;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	struct perf_addr_filter_range *addr_filter_ranges;
	long unsigned int addr_filters_gen;
	struct perf_event___23 *aux_event;
	void (*destroy)(struct perf_event___23 *);
	struct callback_head callback_head;
	struct pid_namespace___30 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___23 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___23 orig_overflow_handler;
	struct bpf_prog *prog;
	u64 bpf_cookie;
	struct trace_event_call___23 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___23 *cgrp;
	void *security;
	struct list_head sb_list;
};

struct upid___30 {
	int nr;
	struct pid_namespace___30 *ns;
};

struct pid_namespace___30 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___2 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___30 *parent;
	struct fs_pin *bacct;
	struct user_namespace___2 *user_ns;
	struct ucounts___2 *ucounts;
	int reboot;
	struct ns_common___5 ns;
};

struct pid___30 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___30 numbers[1];
};

struct signal_struct___35 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___2 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___2 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper;
	unsigned int has_child_subreaper;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___30 *pids[4];
	struct pid___30 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___38 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct cfs_rq___3 {
	struct load_weight load;
	unsigned int nr_running;
	unsigned int h_nr_running;
	unsigned int idle_h_nr_running;
	u64 exec_clock;
	u64 min_vruntime;
	unsigned int forceidle_seq;
	u64 min_vruntime_fi;
	struct rb_root_cached tasks_timeline;
	struct sched_entity___3 *curr;
	struct sched_entity___3 *next;
	struct sched_entity___3 *last;
	struct sched_entity___3 *skip;
	unsigned int nr_spread_over;
	long: 32;
	long: 64;
	struct sched_avg avg;
	struct {
		raw_spinlock_t lock;
		int nr;
		long unsigned int load_avg;
		long unsigned int util_avg;
		long unsigned int runnable_avg;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	} removed;
	long unsigned int tg_load_avg_contrib;
	long int propagate;
	long int prop_runnable_sum;
	long unsigned int h_load;
	u64 last_h_load_update;
	struct sched_entity___3 *h_load_next;
	struct rq *rq;
	int on_list;
	struct list_head leaf_cfs_rq_list;
	struct task_group *tg;
	int idle;
	int runtime_enabled;
	s64 runtime_remaining;
	u64 throttled_clock;
	u64 throttled_clock_task;
	u64 throttled_clock_task_time;
	int throttled;
	int throttle_count;
	struct list_head throttled_list;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct cgroup___29;

struct cgroup_subsys___29;

struct cgroup_subsys_state___29 {
	struct cgroup___29 *cgroup;
	struct cgroup_subsys___29 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___29 *parent;
};

struct task_group {
	struct cgroup_subsys_state___29 css;
	struct sched_entity___3 **se;
	struct cfs_rq___3 **cfs_rq;
	long unsigned int shares;
	int idle;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	atomic_long_t load_avg;
	struct callback_head rcu;
	struct list_head list;
	struct task_group *parent;
	struct list_head siblings;
	struct list_head children;
	struct autogroup *autogroup;
	struct cfs_bandwidth cfs_bandwidth;
	unsigned int uclamp_pct[2];
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct cgroup_namespace___29;

struct nsproxy___34 {
	atomic_t count;
	struct uts_namespace___4 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___30 *pid_ns_for_children;
	struct net___6 *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___29 *cgroup_ns;
};

struct bio___24;

struct bio_list___24 {
	struct bio___24 *head;
	struct bio___24 *tail;
};

struct bdi_writeback___23 {
	struct backing_dev_info___23 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	atomic_t writeback_inodes;
	struct percpu_counter stat[4];
	long unsigned int congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	struct delayed_work bw_dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___29 *memcg_css;
	struct cgroup_subsys_state___29 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	struct list_head b_attached;
	struct list_head offline_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
};

struct device___37;

struct backing_dev_info___23 {
	u64 id;
	struct rb_node rb_node;
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___23 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct mutex cgwb_release_mutex;
	struct rw_semaphore wb_switch_rwsem;
	wait_queue_head_t wb_waitq;
	struct device___37 *dev;
	char dev_name[64];
	struct device___37 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___35 *debug_dir;
};

struct io_cq___24;

struct io_context___24 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	struct xarray icq_tree;
	struct io_cq___24 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct css_set___29 {
	struct cgroup_subsys_state___29 *subsys[14];
	refcount_t refcount;
	struct css_set___29 *dom_cset;
	struct cgroup___29 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___29 *mg_src_cgrp;
	struct cgroup___29 *mg_dst_cgrp;
	struct css_set___29 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___23 {
	struct pmu___23 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	int rotate_necessary;
	refcount_t refcount;
	struct task_struct___2 *task;
	u64 time;
	u64 timestamp;
	u64 timeoffset;
	struct perf_event_context___23 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

struct pipe_buffer___14;

struct pipe_inode_info___14 {
	struct mutex mutex;
	wait_queue_head_t rd_wait;
	wait_queue_head_t wr_wait;
	unsigned int head;
	unsigned int tail;
	unsigned int max_usage;
	unsigned int ring_size;
	bool note_loss;
	unsigned int nr_accounted;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int r_counter;
	unsigned int w_counter;
	unsigned int poll_usage;
	struct page___37 *tmp_page;
	struct fasync_struct___35 *fasync_readers;
	struct fasync_struct___35 *fasync_writers;
	struct pipe_buffer___14 *bufs;
	struct user_struct *user;
	struct watch_queue *watch_queue;
};

struct kernfs_node___35;

struct cgroup_file___29 {
	struct kernfs_node___35 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct obj_cgroup___23;

struct mem_cgroup_per_node___23;

struct mem_cgroup___23 {
	struct cgroup_subsys_state___29 css;
	struct mem_cgroup_id id;
	struct page_counter memory;
	union {
		struct page_counter swap;
		struct page_counter memsw;
	};
	struct page_counter kmem;
	struct page_counter tcpmem;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool oom_group;
	bool oom_lock;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___29 events_file;
	struct cgroup_file___29 events_local_file;
	struct cgroup_file___29 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	struct memcg_vmstats vmstats;
	atomic_long_t memory_events[8];
	atomic_long_t memory_events_local[8];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct obj_cgroup___23 *objcg;
	struct list_head objcg_list;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad2_;
	atomic_t moving_account;
	struct task_struct___2 *move_lock_task;
	struct memcg_vmstats_percpu *vmstats_percpu;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct memcg_cgwb_frn cgwb_frn[4];
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct deferred_split deferred_split_queue;
	struct mem_cgroup_per_node___23 *nodeinfo[0];
	long: 64;
};

struct kset___34;

struct kobj_type___34;

struct kobject___35 {
	const char *name;
	struct list_head entry;
	struct kobject___35 *parent;
	struct kset___34 *kset;
	struct kobj_type___34 *ktype;
	struct kernfs_node___35 *sd;
	struct kref kref;
	unsigned int state_initialized;
	unsigned int state_in_sysfs;
	unsigned int state_add_uevent_sent;
	unsigned int state_remove_uevent_sent;
	unsigned int uevent_suppress;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct blk_integrity_profile___24;

struct blk_integrity___24 {
	const struct blk_integrity_profile___24 *profile;
	unsigned char flags;
	unsigned char tuple_size;
	unsigned char interval_exp;
	unsigned char tag_size;
};

struct bio_set___24 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	struct bio_alloc_cache *cache;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	unsigned int back_pad;
	spinlock_t rescue_lock;
	struct bio_list___24 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	struct hlist_node cpuhp_dead;
};

struct request___24;

struct elevator_queue___24;

struct gendisk___24;

struct blkcg_gq___23;

struct request_queue___24 {
	struct request___24 *last_merge;
	struct elevator_queue___24 *elevator;
	struct percpu_ref q_usage_counter;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	const struct blk_mq_ops *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx **queue_hw_ctx;
	unsigned int nr_hw_queues;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	spinlock_t queue_lock;
	struct gendisk___24 *disk;
	struct kobject___35 kobj;
	struct kobject___35 *mq_kobj;
	struct blk_integrity___24 integrity;
	struct device___37 *dev;
	enum rpm_status rpm_status;
	long unsigned int nr_requests;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_keyslot_manager *ksm;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	atomic_t nr_active_requests_shared_sbitmap;
	struct sbitmap_queue sched_bitmap_tags;
	struct sbitmap_queue sched_breserved_tags;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___23 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int required_elevator_features;
	unsigned int nr_zones;
	long unsigned int *conv_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int max_open_zones;
	unsigned int max_active_zones;
	int node;
	struct mutex debugfs_mutex;
	struct blk_trace *blk_trace;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	struct mutex sysfs_dir_lock;
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	int mq_freeze_depth;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct mutex mq_freeze_lock;
	struct blk_mq_tag_set *tag_set;
	struct list_head tag_set_list;
	struct bio_set___24 bio_split;
	struct dentry___35 *debugfs_dir;
	struct dentry___35 *sched_debugfs_dir;
	struct dentry___35 *rqos_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	u64 write_hints[5];
};

struct vm_struct___32 {
	struct vm_struct___32 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___37 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct address_space_operations___35;

struct address_space___35 {
	struct inode___35 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___35 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct page_pool_params___13 {
	unsigned int flags;
	unsigned int order;
	unsigned int pool_size;
	int nid;
	struct device___37 *dev;
	enum dma_data_direction dma_dir;
	unsigned int max_len;
	unsigned int offset;
};

struct pp_alloc_cache___13 {
	u32 count;
	struct page___37 *cache[128];
};

struct page_pool___13 {
	struct page_pool_params___13 p;
	struct delayed_work release_dw;
	void (*disconnect)(void *);
	long unsigned int defer_start;
	long unsigned int defer_warn;
	u32 pages_state_hold_cnt;
	unsigned int frag_offset;
	struct page___37 *frag_page;
	long int frag_users;
	long: 64;
	long: 64;
	struct pp_alloc_cache___13 alloc;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct ptr_ring ring;
	atomic_t pages_state_release_cnt;
	refcount_t user_cnt;
	u64 destroy_cnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pagemap_ops___35;

struct dev_pagemap___35 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___35 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vfsmount___35;

struct path___35 {
	struct vfsmount___35 *mnt;
	struct dentry___35 *dentry;
};

struct fown_struct___30 {
	rwlock_t lock;
	struct pid___30 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___35 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___35 f_path;
	struct inode___35 *f_inode;
	const struct file_operations___35 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___30 f_owner;
	const struct cred___2 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___35 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___35;

struct vm_operations_struct___35 {
	void (*open)(struct vm_area_struct___38 *);
	void (*close)(struct vm_area_struct___38 *);
	int (*may_split)(struct vm_area_struct___38 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___38 *);
	int (*mprotect)(struct vm_area_struct___38 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___35 *);
	vm_fault_t (*huge_fault)(struct vm_fault___35 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___35 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___38 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___35 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___35 *);
	int (*access)(struct vm_area_struct___38 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___38 *);
	int (*set_policy)(struct vm_area_struct___38 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___38 *, long unsigned int);
	struct page___37 * (*find_special_page)(struct vm_area_struct___38 *, long unsigned int);
};

struct core_thread___37 {
	struct task_struct___2 *task;
	struct core_thread___37 *next;
};

struct core_state___37 {
	atomic_t nr_threads;
	struct core_thread___37 dumper;
	struct completion startup;
};

struct linux_binprm___11;

struct coredump_params___10;

struct linux_binfmt___10 {
	struct list_head lh;
	struct module___34 *module;
	int (*load_binary)(struct linux_binprm___11 *);
	int (*load_shlib)(struct file___35 *);
	int (*core_dump)(struct coredump_params___10 *);
	long unsigned int min_coredump;
};

struct vm_fault___35 {
	const struct {
		struct vm_area_struct___38 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___37 *cow_page;
	struct page___37 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___37 prealloc_pte;
};

struct psi_group___29 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___2 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___29;

struct cgroup_rstat_cpu___29;

struct cgroup___29 {
	struct cgroup_subsys_state___29 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___35 *kn;
	struct cgroup_file___29 procs_file;
	struct cgroup_file___29 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___29 *subsys[14];
	struct cgroup_root___29 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___29 *dom_cgrp;
	struct cgroup___29 *old_dom_cgrp;
	struct cgroup_rstat_cpu___29 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___29 psi;
	struct cgroup_bpf___4 bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct pglist_data___24;

struct lruvec___24 {
	struct list_head lists[5];
	spinlock_t lru_lock;
	long unsigned int anon_cost;
	long unsigned int file_cost;
	atomic_long_t nonresident_age;
	long unsigned int refaults[2];
	long unsigned int flags;
	struct pglist_data___24 *pgdat;
};

struct zone___24 {
	long unsigned int _watermark[3];
	long unsigned int watermark_boost;
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[5];
	int node;
	struct pglist_data___24 *zone_pgdat;
	struct per_cpu_pages *per_cpu_pageset;
	struct per_cpu_zonestat *per_cpu_zonestats;
	int pageset_high;
	int pageset_batch;
	long unsigned int zone_start_pfn;
	atomic_long_t managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int present_early_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	seqlock_t span_seqlock;
	int initialized;
	int: 32;
	struct zone_padding _pad1_;
	struct free_area free_area[11];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	long unsigned int compact_init_migrate_pfn;
	long unsigned int compact_init_free_pfn;
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	short: 16;
	struct zone_padding _pad3_;
	atomic_long_t vm_stat[11];
	atomic_long_t vm_numa_event[6];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___24 {
	struct zone___24 *zone;
	int zone_idx;
};

struct zonelist___24 {
	struct zoneref___24 _zonerefs[5121];
};

struct pglist_data___24 {
	struct zone___24 node_zones[5];
	struct zonelist___24 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___2 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_highest_zoneidx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_highest_zoneidx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___2 *kcompactd;
	bool proactive_compact_trigger;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct deferred_split deferred_split_queue;
	struct lruvec___24 __lruvec;
	long unsigned int flags;
	long: 64;
	struct zone_padding _pad2_;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[39];
};

struct autogroup {
	struct kref kref;
	struct task_group *tg;
	struct rw_semaphore lock;
	long unsigned int id;
	int nice;
};

struct kernfs_root___35;

struct kernfs_elem_dir___35 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___35 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___35;

struct kernfs_root___35 {
	struct kernfs_node___35 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___35 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___35 {
	struct kernfs_node___35 *target_kn;
};

struct kernfs_ops___35;

struct kernfs_elem_attr___35 {
	const struct kernfs_ops___35 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___35 *notify_next;
};

struct kernfs_node___35 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___35 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___35 dir;
		struct kernfs_elem_symlink___35 symlink;
		struct kernfs_elem_attr___35 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___35;

struct kernfs_ops___35 {
	int (*open)(struct kernfs_open_file___35 *);
	void (*release)(struct kernfs_open_file___35 *);
	int (*seq_show)(struct seq_file___33 *, void *);
	void * (*seq_start)(struct seq_file___33 *, loff_t *);
	void * (*seq_next)(struct seq_file___33 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___33 *, void *);
	ssize_t (*read)(struct kernfs_open_file___35 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___35 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___35 *, struct poll_table_struct___26 *);
	int (*mmap)(struct kernfs_open_file___35 *, struct vm_area_struct___38 *);
};

struct kernfs_syscall_ops___35 {
	int (*show_options)(struct seq_file___33 *, struct kernfs_root___35 *);
	int (*mkdir)(struct kernfs_node___35 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___35 *);
	int (*rename)(struct kernfs_node___35 *, struct kernfs_node___35 *, const char *);
	int (*show_path)(struct seq_file___33 *, struct kernfs_node___35 *, struct kernfs_root___35 *);
};

struct seq_file___33 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___33 *op;
	int poll_event;
	const struct file___35 *file;
	void *private;
};

struct kernfs_open_file___35 {
	struct kernfs_node___35 *kn;
	struct file___35 *file;
	struct seq_file___33 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped;
	bool released;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___35 *vm_ops;
};

typedef void (*poll_queue_proc___26)(struct file___35 *, wait_queue_head_t *, struct poll_table_struct___26 *);

struct poll_table_struct___26 {
	poll_queue_proc___26 _qproc;
	__poll_t _key;
};

struct bin_attribute___35;

struct attribute_group___35 {
	const char *name;
	umode_t (*is_visible)(struct kobject___35 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___35 *, struct bin_attribute___35 *, int);
	struct attribute **attrs;
	struct bin_attribute___35 **bin_attrs;
};

struct bin_attribute___35 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___35 * (*f_mapping)();
	ssize_t (*read)(struct file___35 *, struct kobject___35 *, struct bin_attribute___35 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___35 *, struct kobject___35 *, struct bin_attribute___35 *, char *, loff_t, size_t);
	int (*mmap)(struct file___35 *, struct kobject___35 *, struct bin_attribute___35 *, struct vm_area_struct___38 *);
};

struct sysfs_ops___34 {
	ssize_t (*show)(struct kobject___35 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___35 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___34;

struct kset___34 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___35 kobj;
	const struct kset_uevent_ops___34 *uevent_ops;
};

struct kobj_type___34 {
	void (*release)(struct kobject___35 *);
	const struct sysfs_ops___34 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___35 **default_groups;
	const struct kobj_ns_type_operations___3 * (*child_ns_type)(struct kobject___35 *);
	const void * (*namespace)(struct kobject___35 *);
	void (*get_ownership)(struct kobject___35 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___34 {
	int (* const filter)(struct kset___34 *, struct kobject___35 *);
	const char * (* const name)(struct kset___34 *, struct kobject___35 *);
	int (* const uevent)(struct kset___34 *, struct kobject___35 *, struct kobj_uevent_env *);
};

struct fwnode_operations___34;

struct fwnode_handle___34 {
	struct fwnode_handle___34 *secondary;
	const struct fwnode_operations___34 *ops;
	struct device___37 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct fwnode_reference_args___34;

struct fwnode_endpoint___34;

struct fwnode_operations___34 {
	struct fwnode_handle___34 * (*get)(struct fwnode_handle___34 *);
	void (*put)(struct fwnode_handle___34 *);
	bool (*device_is_available)(const struct fwnode_handle___34 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___34 *, const struct device___37 *);
	bool (*property_present)(const struct fwnode_handle___34 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___34 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___34 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___34 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___34 *);
	struct fwnode_handle___34 * (*get_parent)(const struct fwnode_handle___34 *);
	struct fwnode_handle___34 * (*get_next_child_node)(const struct fwnode_handle___34 *, struct fwnode_handle___34 *);
	struct fwnode_handle___34 * (*get_named_child_node)(const struct fwnode_handle___34 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___34 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___34 *);
	struct fwnode_handle___34 * (*graph_get_next_endpoint)(const struct fwnode_handle___34 *, struct fwnode_handle___34 *);
	struct fwnode_handle___34 * (*graph_get_remote_endpoint)(const struct fwnode_handle___34 *);
	struct fwnode_handle___34 * (*graph_get_port_parent)(struct fwnode_handle___34 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___34 *, struct fwnode_endpoint___34 *);
	int (*add_links)(struct fwnode_handle___34 *);
};

struct wakeup_source___37;

struct dev_pm_qos___7;

struct dev_pm_info___37 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___37 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___37 *, s32);
	struct dev_pm_qos___7 *qos;
};

struct device_type___37;

struct bus_type___37;

struct device_driver___37;

struct dev_pm_domain___37;

struct device_node___20;

struct class___37;

struct device___37 {
	struct kobject___35 kobj;
	struct device___37 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___37 *type;
	struct bus_type___37 *bus;
	struct device_driver___37 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___37 power;
	struct dev_pm_domain___37 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___20 *of_node;
	struct fwnode_handle___34 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___37 *class;
	const struct attribute_group___35 **groups;
	void (*release)(struct device___37 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fwnode_endpoint___34 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___34 *local_fwnode;
};

struct fwnode_reference_args___34 {
	struct fwnode_handle___34 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct device_node___20 {
	const char *name;
	phandle phandle;
	const char *full_name;
	struct fwnode_handle___34 fwnode;
	struct property *properties;
	struct property *deadprops;
	struct device_node___20 *parent;
	struct device_node___20 *child;
	struct device_node___20 *sibling;
	long unsigned int _flags;
	void *data;
};

struct module_kobject___34 {
	struct kobject___35 kobj;
	struct module___34 *mod;
	struct kobject___35 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___34 {
	struct module___34 *mod;
	struct latch_tree_node node;
};

struct module_layout___34 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___34 mtn;
};

struct module_attribute___34;

struct kernel_param___34;

struct module___34 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___34 mkobj;
	struct module_attribute___34 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___35 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___34 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___34 core_layout;
	struct module_layout___34 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map___26 *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___23 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	int num_static_call_sites;
	struct static_call_site *static_call_sites;
	bool klp;
	bool klp_alive;
	struct klp_modinfo *klp_info;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct linux_binprm___11 {
	struct vm_area_struct___38 *vma;
	long unsigned int vma_pages;
	struct mm_struct___38 *mm;
	long unsigned int p;
	long unsigned int argmin;
	unsigned int have_execfd;
	unsigned int execfd_creds;
	unsigned int secureexec;
	unsigned int point_of_no_return;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct file___35 *executable;
	struct file___35 *interpreter;
	struct file___35 *file;
	struct cred___2 *cred;
	int unsafe;
	unsigned int per_clear;
	int argc;
	int envc;
	const char *filename;
	const char *interp;
	const char *fdpath;
	unsigned int interp_flags;
	int execfd;
	long unsigned int loader;
	long unsigned int exec;
	struct rlimit rlim_stack;
	char buf[256];
};

struct coredump_params___10 {
	const kernel_siginfo_t *siginfo;
	struct pt_regs *regs;
	struct file___35 *file;
	long unsigned int limit;
	long unsigned int mm_flags;
	loff_t written;
	loff_t pos;
	loff_t to_skip;
};

struct dentry_operations___35;

struct dentry___35 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___35 *d_parent;
	struct qstr d_name;
	struct inode___35 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___35 *d_op;
	struct super_block___35 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___35;

struct inode___35 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___35 *i_op;
	struct super_block___35 *i_sb;
	struct address_space___35 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___23 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___35 *i_fop;
		void (*free_inode)(struct inode___35 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___35 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___14 *i_pipe;
		struct cdev *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___35 {
	int (*d_revalidate)(struct dentry___35 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___35 *, unsigned int);
	int (*d_hash)(const struct dentry___35 *, struct qstr *);
	int (*d_compare)(const struct dentry___35 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___35 *);
	int (*d_init)(struct dentry___35 *);
	void (*d_release)(struct dentry___35 *);
	void (*d_prune)(struct dentry___35 *);
	void (*d_iput)(struct dentry___35 *, struct inode___35 *);
	char * (*d_dname)(struct dentry___35 *, char *, int);
	struct vfsmount___35 * (*d_automount)(struct path___35 *);
	int (*d_manage)(const struct path___35 *, bool);
	struct dentry___35 * (*d_real)(struct dentry___35 *, const struct inode___35 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___35;

struct mem_dqinfo___35 {
	struct quota_format_type___35 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___35;

struct quota_info___35 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___35 *files[3];
	struct mem_dqinfo___35 info[3];
	const struct quota_format_ops___35 *ops[3];
};

struct rcuwait___35 {
	struct task_struct___2 *task;
};

struct percpu_rw_semaphore___35 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___35 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___35 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___35 rw_sem[3];
};

struct shrink_control___23;

struct shrinker___23 {
	long unsigned int (*count_objects)(struct shrinker___23 *, struct shrink_control___23 *);
	long unsigned int (*scan_objects)(struct shrinker___23 *, struct shrink_control___23 *);
	long int batch;
	int seeks;
	unsigned int flags;
	struct list_head list;
	int id;
	atomic_long_t *nr_deferred;
};

struct super_operations___35;

struct dquot_operations___35;

struct quotactl_ops___35;

struct block_device___24;

struct super_block___35 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___35 *s_type;
	const struct super_operations___35 *s_op;
	const struct dquot_operations___35 *dq_op;
	const struct quotactl_ops___35 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___35 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___24 *s_bdev;
	struct backing_dev_info___23 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___35 s_dquot;
	struct sb_writers___35 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___35 *s_d_op;
	int cleancache_poolid;
	struct shrinker___23 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___2 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___35 {
	struct dentry___35 *mnt_root;
	struct super_block___35 *mnt_sb;
	int mnt_flags;
	struct user_namespace___2 *mnt_userns;
};

struct shrink_control___23 {
	gfp_t gfp_mask;
	int nid;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	struct mem_cgroup___23 *memcg;
};

struct io_cq___24 {
	struct request_queue___24 *q;
	struct io_context___24 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct wait_page_queue___20;

struct kiocb___35 {
	struct file___35 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___35 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___20 *ki_waitq;
	};
};

struct iattr___35 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___35 *ia_file;
};

struct dquot___35 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___35 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___35 {
	int qf_fmt_id;
	const struct quota_format_ops___35 *qf_ops;
	struct module___34 *qf_owner;
	struct quota_format_type___35 *qf_next;
};

struct quota_format_ops___35 {
	int (*check_quota_file)(struct super_block___35 *, int);
	int (*read_file_info)(struct super_block___35 *, int);
	int (*write_file_info)(struct super_block___35 *, int);
	int (*free_file_info)(struct super_block___35 *, int);
	int (*read_dqblk)(struct dquot___35 *);
	int (*commit_dqblk)(struct dquot___35 *);
	int (*release_dqblk)(struct dquot___35 *);
	int (*get_next_id)(struct super_block___35 *, struct kqid *);
};

struct dquot_operations___35 {
	int (*write_dquot)(struct dquot___35 *);
	struct dquot___35 * (*alloc_dquot)(struct super_block___35 *, int);
	void (*destroy_dquot)(struct dquot___35 *);
	int (*acquire_dquot)(struct dquot___35 *);
	int (*release_dquot)(struct dquot___35 *);
	int (*mark_dirty)(struct dquot___35 *);
	int (*write_info)(struct super_block___35 *, int);
	qsize_t * (*get_reserved_space)(struct inode___35 *);
	int (*get_projid)(struct inode___35 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___35 *, qsize_t *);
	int (*get_next_id)(struct super_block___35 *, struct kqid *);
};

struct quotactl_ops___35 {
	int (*quota_on)(struct super_block___35 *, int, int, const struct path___35 *);
	int (*quota_off)(struct super_block___35 *, int);
	int (*quota_enable)(struct super_block___35 *, unsigned int);
	int (*quota_disable)(struct super_block___35 *, unsigned int);
	int (*quota_sync)(struct super_block___35 *, int);
	int (*set_info)(struct super_block___35 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___35 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___35 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___35 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___35 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___35 *, unsigned int);
};

struct wait_page_queue___20 {
	struct page___37 *page;
	int bit_nr;
	wait_queue_entry_t wait;
};

struct writeback_control___23;

struct readahead_control___20;

struct swap_info_struct___16;

struct address_space_operations___35 {
	int (*writepage)(struct page___37 *, struct writeback_control___23 *);
	int (*readpage)(struct file___35 *, struct page___37 *);
	int (*writepages)(struct address_space___35 *, struct writeback_control___23 *);
	int (*set_page_dirty)(struct page___37 *);
	int (*readpages)(struct file___35 *, struct address_space___35 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___20 *);
	int (*write_begin)(struct file___35 *, struct address_space___35 *, loff_t, unsigned int, unsigned int, struct page___37 **, void **);
	int (*write_end)(struct file___35 *, struct address_space___35 *, loff_t, unsigned int, unsigned int, struct page___37 *, void *);
	sector_t (*bmap)(struct address_space___35 *, sector_t);
	void (*invalidatepage)(struct page___37 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___37 *, gfp_t);
	void (*freepage)(struct page___37 *);
	ssize_t (*direct_IO)(struct kiocb___35 *, struct iov_iter___29 *);
	int (*migratepage)(struct address_space___35 *, struct page___37 *, struct page___37 *, enum migrate_mode);
	bool (*isolate_page)(struct page___37 *, isolate_mode_t);
	void (*putback_page)(struct page___37 *);
	int (*launder_page)(struct page___37 *);
	int (*is_partially_uptodate)(struct page___37 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___37 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___35 *, struct page___37 *);
	int (*swap_activate)(struct swap_info_struct___16 *, struct file___35 *, sector_t *);
	void (*swap_deactivate)(struct file___35 *);
};

struct writeback_control___23 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate;
	unsigned int for_background;
	unsigned int tagged_writepages;
	unsigned int for_reclaim;
	unsigned int range_cyclic;
	unsigned int for_sync;
	unsigned int no_cgroup_owner;
	unsigned int punt_to_cgroup;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bdi_writeback___23 *wb;
	struct inode___35 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
};

struct readahead_control___20 {
	struct file___35 *file;
	struct address_space___35 *mapping;
	struct file_ra_state *ra;
	long unsigned int _index;
	unsigned int _nr_pages;
	unsigned int _batch_count;
};

struct bio_vec___29;

struct iov_iter___29 {
	u8 iter_type;
	bool data_source;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___29 *bvec;
		struct xarray *xarray;
		struct pipe_inode_info___14 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			unsigned int head;
			unsigned int start_head;
		};
		loff_t xarray_start;
	};
};

struct swap_info_struct___16 {
	struct percpu_ref users;
	long unsigned int flags;
	short int prio;
	struct plist_node list;
	signed char type;
	unsigned int max;
	unsigned char *swap_map;
	struct swap_cluster_info *cluster_info;
	struct swap_cluster_list free_clusters;
	unsigned int lowest_bit;
	unsigned int highest_bit;
	unsigned int pages;
	unsigned int inuse_pages;
	unsigned int cluster_next;
	unsigned int cluster_nr;
	unsigned int *cluster_next_cpu;
	struct percpu_cluster *percpu_cluster;
	struct rb_root swap_extent_root;
	struct block_device___24 *bdev;
	struct file___35 *swap_file;
	unsigned int old_block_size;
	struct completion comp;
	long unsigned int *frontswap_map;
	atomic_t frontswap_pages;
	spinlock_t lock;
	spinlock_t cont_lock;
	struct work_struct discard_work;
	struct swap_cluster_list discard_clusters;
	struct plist_node avail_lists[0];
};

struct inode_operations___35 {
	struct dentry___35 * (*lookup)(struct inode___35 *, struct dentry___35 *, unsigned int);
	const char * (*get_link)(struct dentry___35 *, struct inode___35 *, struct delayed_call *);
	int (*permission)(struct user_namespace___2 *, struct inode___35 *, int);
	struct posix_acl * (*get_acl)(struct inode___35 *, int, bool);
	int (*readlink)(struct dentry___35 *, char *, int);
	int (*create)(struct user_namespace___2 *, struct inode___35 *, struct dentry___35 *, umode_t, bool);
	int (*link)(struct dentry___35 *, struct inode___35 *, struct dentry___35 *);
	int (*unlink)(struct inode___35 *, struct dentry___35 *);
	int (*symlink)(struct user_namespace___2 *, struct inode___35 *, struct dentry___35 *, const char *);
	int (*mkdir)(struct user_namespace___2 *, struct inode___35 *, struct dentry___35 *, umode_t);
	int (*rmdir)(struct inode___35 *, struct dentry___35 *);
	int (*mknod)(struct user_namespace___2 *, struct inode___35 *, struct dentry___35 *, umode_t, dev_t);
	int (*rename)(struct user_namespace___2 *, struct inode___35 *, struct dentry___35 *, struct inode___35 *, struct dentry___35 *, unsigned int);
	int (*setattr)(struct user_namespace___2 *, struct dentry___35 *, struct iattr___35 *);
	int (*getattr)(struct user_namespace___2 *, const struct path___35 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___35 *, char *, size_t);
	int (*fiemap)(struct inode___35 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___35 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___35 *, struct dentry___35 *, struct file___35 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace___2 *, struct inode___35 *, struct dentry___35 *, umode_t);
	int (*set_acl)(struct user_namespace___2 *, struct inode___35 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace___2 *, struct dentry___35 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___35 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___35 {
	void (*fl_copy_lock)(struct file_lock___35 *, struct file_lock___35 *);
	void (*fl_release_private)(struct file_lock___35 *);
};

struct lock_manager_operations___35;

struct file_lock___35 {
	struct file_lock___35 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___35 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___35 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___35 *fl_ops;
	const struct lock_manager_operations___35 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___35 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___35 *);
	int (*lm_grant)(struct file_lock___35 *, int);
	bool (*lm_break)(struct file_lock___35 *);
	int (*lm_change)(struct file_lock___35 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___35 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___35 *);
};

struct fasync_struct___35 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___35 *fa_next;
	struct file___35 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___35 {
	struct inode___35 * (*alloc_inode)(struct super_block___35 *);
	void (*destroy_inode)(struct inode___35 *);
	void (*free_inode)(struct inode___35 *);
	void (*dirty_inode)(struct inode___35 *, int);
	int (*write_inode)(struct inode___35 *, struct writeback_control___23 *);
	int (*drop_inode)(struct inode___35 *);
	void (*evict_inode)(struct inode___35 *);
	void (*put_super)(struct super_block___35 *);
	int (*sync_fs)(struct super_block___35 *, int);
	int (*freeze_super)(struct super_block___35 *);
	int (*freeze_fs)(struct super_block___35 *);
	int (*thaw_super)(struct super_block___35 *);
	int (*unfreeze_fs)(struct super_block___35 *);
	int (*statfs)(struct dentry___35 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___35 *, int *, char *);
	void (*umount_begin)(struct super_block___35 *);
	int (*show_options)(struct seq_file___33 *, struct dentry___35 *);
	int (*show_devname)(struct seq_file___33 *, struct dentry___35 *);
	int (*show_path)(struct seq_file___33 *, struct dentry___35 *);
	int (*show_stats)(struct seq_file___33 *, struct dentry___35 *);
	ssize_t (*quota_read)(struct super_block___35 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___35 *, int, const char *, size_t, loff_t);
	struct dquot___35 ** (*get_dquots)(struct inode___35 *);
	long int (*nr_cached_objects)(struct super_block___35 *, struct shrink_control___23 *);
	long int (*free_cached_objects)(struct super_block___35 *, struct shrink_control___23 *);
	struct file___35 * (*real_loop)(struct file___35 *);
};

struct block_device___24 {
	sector_t bd_start_sect;
	struct disk_stats *bd_stats;
	long unsigned int bd_stamp;
	bool bd_read_only;
	dev_t bd_dev;
	int bd_openers;
	struct inode___35 *bd_inode;
	struct super_block___35 *bd_super;
	void *bd_claiming;
	struct device___37 bd_device;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct kobject___35 *bd_holder_dir;
	u8 bd_partno;
	spinlock_t bd_size_lock;
	struct gendisk___24 *bd_disk;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	struct super_block___35 *bd_fsfreeze_sb;
	struct partition_meta_info *bd_meta_info;
};

typedef void bio_end_io_t___24(struct bio___24 *);

struct bio_vec___29 {
	struct page___37 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___24;

struct bio___24 {
	struct bio___24 *bi_next;
	struct block_device___24 *bi_bdev;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	atomic_t __bi_remaining;
	struct bvec_iter bi_iter;
	bio_end_io_t___24 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___23 *bi_blkg;
	struct bio_issue bi_issue;
	u64 bi_iocost_cost;
	struct bio_crypt_ctx *bi_crypt_context;
	union {
		struct bio_integrity_payload___24 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___29 *bi_io_vec;
	struct bio_set___24 *bi_pool;
	struct bio_vec___29 bi_inline_vecs[0];
};

struct dev_pagemap_ops___35 {
	void (*page_free)(struct page___37 *);
	void (*kill)(struct dev_pagemap___35 *);
	void (*cleanup)(struct dev_pagemap___35 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___35 *);
};

struct dev_pm_ops___37 {
	int (*prepare)(struct device___37 *);
	void (*complete)(struct device___37 *);
	int (*suspend)(struct device___37 *);
	int (*resume)(struct device___37 *);
	int (*freeze)(struct device___37 *);
	int (*thaw)(struct device___37 *);
	int (*poweroff)(struct device___37 *);
	int (*restore)(struct device___37 *);
	int (*suspend_late)(struct device___37 *);
	int (*resume_early)(struct device___37 *);
	int (*freeze_late)(struct device___37 *);
	int (*thaw_early)(struct device___37 *);
	int (*poweroff_late)(struct device___37 *);
	int (*restore_early)(struct device___37 *);
	int (*suspend_noirq)(struct device___37 *);
	int (*resume_noirq)(struct device___37 *);
	int (*freeze_noirq)(struct device___37 *);
	int (*thaw_noirq)(struct device___37 *);
	int (*poweroff_noirq)(struct device___37 *);
	int (*restore_noirq)(struct device___37 *);
	int (*runtime_suspend)(struct device___37 *);
	int (*runtime_resume)(struct device___37 *);
	int (*runtime_idle)(struct device___37 *);
};

struct wakeup_source___37 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___37 *dev;
	bool active;
	bool autosleep_enabled;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_qos_request___7;

struct dev_pm_qos___7 {
	struct pm_qos_constraints resume_latency;
	struct pm_qos_constraints latency_tolerance;
	struct freq_constraints freq;
	struct pm_qos_flags flags;
	struct dev_pm_qos_request___7 *resume_latency_req;
	struct dev_pm_qos_request___7 *latency_tolerance_req;
	struct dev_pm_qos_request___7 *flags_req;
};

struct dev_pm_domain___37 {
	struct dev_pm_ops___37 ops;
	int (*start)(struct device___37 *);
	void (*detach)(struct device___37 *, bool);
	int (*activate)(struct device___37 *);
	void (*sync)(struct device___37 *);
	void (*dismiss)(struct device___37 *);
};

struct bus_type___37 {
	const char *name;
	const char *dev_name;
	struct device___37 *dev_root;
	const struct attribute_group___35 **bus_groups;
	const struct attribute_group___35 **dev_groups;
	const struct attribute_group___35 **drv_groups;
	int (*match)(struct device___37 *, struct device_driver___37 *);
	int (*uevent)(struct device___37 *, struct kobj_uevent_env *);
	int (*probe)(struct device___37 *);
	void (*sync_state)(struct device___37 *);
	void (*remove)(struct device___37 *);
	void (*shutdown)(struct device___37 *);
	int (*online)(struct device___37 *);
	int (*offline)(struct device___37 *);
	int (*suspend)(struct device___37 *, pm_message_t);
	int (*resume)(struct device___37 *);
	int (*num_vf)(struct device___37 *);
	int (*dma_configure)(struct device___37 *);
	const struct dev_pm_ops___37 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___37 {
	const char *name;
	struct bus_type___37 *bus;
	struct module___34 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___37 *);
	void (*sync_state)(struct device___37 *);
	int (*remove)(struct device___37 *);
	void (*shutdown)(struct device___37 *);
	int (*suspend)(struct device___37 *, pm_message_t);
	int (*resume)(struct device___37 *);
	const struct attribute_group___35 **groups;
	const struct attribute_group___35 **dev_groups;
	const struct dev_pm_ops___37 *pm;
	void (*coredump)(struct device___37 *);
	struct driver_private *p;
};

struct device_type___37 {
	const char *name;
	const struct attribute_group___35 **groups;
	int (*uevent)(struct device___37 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___37 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___37 *);
	const struct dev_pm_ops___37 *pm;
};

struct class___37 {
	const char *name;
	struct module___34 *owner;
	const struct attribute_group___35 **class_groups;
	const struct attribute_group___35 **dev_groups;
	struct kobject___35 *dev_kobj;
	int (*dev_uevent)(struct device___37 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___37 *, umode_t *);
	void (*class_release)(struct class___37 *);
	void (*dev_release)(struct device___37 *);
	int (*shutdown_pre)(struct device___37 *);
	const struct kobj_ns_type_operations___3 *ns_type;
	const void * (*namespace)(struct device___37 *);
	void (*get_ownership)(struct device___37 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___37 *pm;
	struct subsys_private *p;
};

struct block_device_operations___24;

struct gendisk___24 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	short unsigned int events;
	short unsigned int event_flags;
	struct xarray part_tbl;
	struct block_device___24 *part0;
	const struct block_device_operations___24 *fops;
	struct request_queue___24 *queue;
	void *private_data;
	int flags;
	long unsigned int state;
	struct mutex open_mutex;
	unsigned int open_partitions;
	struct backing_dev_info___23 *bdi;
	struct kobject___35 *slave_dir;
	struct list_head slave_bdevs;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___35 integrity_kobj;
	struct cdrom_device_info *cdi;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	u64 diskseq;
};

struct bio_integrity_payload___24 {
	struct bio___24 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___29 *bip_vec;
	struct bio_vec___29 bip_inline_vecs[0];
};

struct blkcg___23;

struct blkg_policy_data___23;

struct blkcg_gq___23 {
	struct request_queue___24 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___23 *blkcg;
	struct blkcg_gq___23 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_iostat_set *iostat_cpu;
	struct blkg_iostat_set iostat;
	struct blkg_policy_data___23 *pd[6];
	spinlock_t async_bio_lock;
	struct bio_list___24 async_bios;
	struct work_struct async_bio_work;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
	struct callback_head callback_head;
};

typedef void integrity_prepare_fn___24(struct request___24 *);

typedef void integrity_complete_fn___24(struct request___24 *, unsigned int);

struct blk_integrity_profile___24 {
	integrity_processing_fn *generate_fn;
	integrity_processing_fn *verify_fn;
	integrity_prepare_fn___24 *prepare_fn;
	integrity_complete_fn___24 *complete_fn;
	const char *name;
};

struct block_device_operations___24 {
	blk_qc_t (*submit_bio)(struct bio___24 *);
	int (*open)(struct block_device___24 *, fmode_t);
	void (*release)(struct gendisk___24 *, fmode_t);
	int (*rw_page)(struct block_device___24 *, sector_t, struct page___37 *, unsigned int);
	int (*ioctl)(struct block_device___24 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___24 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___24 *, unsigned int);
	void (*unlock_native_capacity)(struct gendisk___24 *);
	int (*getgeo)(struct block_device___24 *, struct hd_geometry *);
	int (*set_read_only)(struct block_device___24 *, bool);
	void (*swap_slot_free_notify)(struct block_device___24 *, long unsigned int);
	int (*report_zones)(struct gendisk___24 *, sector_t, unsigned int, report_zones_cb, void *);
	char * (*devnode)(struct gendisk___24 *, umode_t *);
	struct module___34 *owner;
	const struct pr_ops *pr_ops;
	int (*alternative_gpt_sector)(struct gendisk___24 *, sector_t *);
};

typedef void rq_end_io_fn___24(struct request___24 *, blk_status_t);

struct request___24 {
	struct request_queue___24 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int tag;
	int internal_tag;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___24 *bio;
	struct bio___24 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct llist_node ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___29 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___24 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___24 *saved_end_io;
		} flush;
	};
	struct gendisk___24 *rq_disk;
	struct block_device___24 *part;
	u64 alloc_time_ns;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int stats_sectors;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	struct bio_crypt_ctx *crypt_ctx;
	struct blk_ksm_keyslot *crypt_keyslot;
	short unsigned int write_hint;
	short unsigned int ioprio;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___24 *end_io;
	void *end_io_data;
};

struct elevator_type___24;

struct elevator_mq_ops___24 {
	int (*init_sched)(struct request_queue___24 *, struct elevator_type___24 *);
	void (*exit_sched)(struct elevator_queue___24 *);
	int (*init_hctx)(struct blk_mq_hw_ctx *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx *, unsigned int);
	void (*depth_updated)(struct blk_mq_hw_ctx *);
	bool (*allow_merge)(struct request_queue___24 *, struct request___24 *, struct bio___24 *);
	bool (*bio_merge)(struct request_queue___24 *, struct bio___24 *, unsigned int);
	int (*request_merge)(struct request_queue___24 *, struct request___24 **, struct bio___24 *);
	void (*request_merged)(struct request_queue___24 *, struct request___24 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___24 *, struct request___24 *, struct request___24 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___24 *);
	void (*finish_request)(struct request___24 *);
	void (*insert_requests)(struct blk_mq_hw_ctx *, struct list_head *, bool);
	struct request___24 * (*dispatch_request)(struct blk_mq_hw_ctx *);
	bool (*has_work)(struct blk_mq_hw_ctx *);
	void (*completed_request)(struct request___24 *, u64);
	void (*requeue_request)(struct request___24 *);
	struct request___24 * (*former_request)(struct request_queue___24 *, struct request___24 *);
	struct request___24 * (*next_request)(struct request_queue___24 *, struct request___24 *);
	void (*init_icq)(struct io_cq___24 *);
	void (*exit_icq)(struct io_cq___24 *);
};

struct elv_fs_entry___24;

struct elevator_type___24 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___24 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___24 *elevator_attrs;
	const char *elevator_name;
	const char *elevator_alias;
	const unsigned int elevator_features;
	struct module___34 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
};

struct elevator_queue___24 {
	struct elevator_type___24 *type;
	void *elevator_data;
	struct kobject___35 kobj;
	struct mutex sysfs_lock;
	unsigned int registered;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hlist_head hash[64];
};

struct elv_fs_entry___24 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___24 *, char *);
	ssize_t (*store)(struct elevator_queue___24 *, const char *, size_t);
};

struct dev_pm_qos_request___7 {
	enum dev_pm_qos_req_type type;
	union {
		struct plist_node pnode;
		struct pm_qos_flags_request flr;
		struct freq_qos_request freq;
	} data;
	struct device___37 *dev;
};

struct cpuidle_driver___3;

struct cpuidle_state___3 {
	char name[16];
	char desc[32];
	s64 exit_latency_ns;
	s64 target_residency_ns;
	unsigned int flags;
	unsigned int exit_latency;
	int power_usage;
	unsigned int target_residency;
	int (*enter)(struct cpuidle_device___2 *, struct cpuidle_driver___3 *, int);
	int (*enter_dead)(struct cpuidle_device___2 *, int);
	int (*enter_s2idle)(struct cpuidle_device___2 *, struct cpuidle_driver___3 *, int);
};

struct cpuidle_driver___3 {
	const char *name;
	struct module___34 *owner;
	unsigned int bctimer: 1;
	long: 63;
	long: 64;
	long: 64;
	struct cpuidle_state___3 states[10];
	int state_count;
	int safe_state_index;
	struct cpumask *cpumask;
	const char *governor;
};

struct cgroup_namespace___29 {
	struct ns_common___5 ns;
	struct user_namespace___2 *user_ns;
	struct ucounts___2 *ucounts;
	struct css_set___29 *root_cset;
};

struct kernel_param_ops___34 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___34 *);
	int (*get)(char *, const struct kernel_param___34 *);
	void (*free)(void *);
};

struct kparam_array___34;

struct kernel_param___34 {
	const char *name;
	struct module___34 *mod;
	const struct kernel_param_ops___34 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___34 *arr;
	};
};

struct kparam_array___34 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___34 *ops;
	void *elem;
};

struct module_attribute___34 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___34 *, struct module_kobject___34 *, char *);
	ssize_t (*store)(struct module_attribute___34 *, struct module_kobject___34 *, const char *, size_t);
	void (*setup)(struct module___34 *, const char *);
	int (*test)(struct module___34 *);
	void (*free)(struct module___34 *);
};

struct trace_event_class___23;

struct trace_event_call___23 {
	struct list_head list;
	struct trace_event_class___23 *class;
	union {
		char *name;
		struct tracepoint___26 *tp;
	};
	struct trace_event event;
	char *print_fmt;
	struct event_filter *filter;
	union {
		void *module;
		atomic_t refcnt;
	};
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
	struct bpf_prog_array___4 *prog_array;
	int (*perf_perm)(struct trace_event_call___23 *, struct perf_event___23 *);
};

struct pipe_buf_operations___14;

struct pipe_buffer___14 {
	struct page___37 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___14 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___14 {
	int (*confirm)(struct pipe_inode_info___14 *, struct pipe_buffer___14 *);
	void (*release)(struct pipe_inode_info___14 *, struct pipe_buffer___14 *);
	bool (*try_steal)(struct pipe_inode_info___14 *, struct pipe_buffer___14 *);
	bool (*get)(struct pipe_inode_info___14 *, struct pipe_buffer___14 *);
};

struct cftype___29;

struct cgroup_subsys___29 {
	struct cgroup_subsys_state___29 * (*css_alloc)(struct cgroup_subsys_state___29 *);
	int (*css_online)(struct cgroup_subsys_state___29 *);
	void (*css_offline)(struct cgroup_subsys_state___29 *);
	void (*css_released)(struct cgroup_subsys_state___29 *);
	void (*css_free)(struct cgroup_subsys_state___29 *);
	void (*css_reset)(struct cgroup_subsys_state___29 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___29 *, int);
	int (*css_extra_stat_show)(struct seq_file___33 *, struct cgroup_subsys_state___29 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___2 *, struct css_set___29 *);
	void (*cancel_fork)(struct task_struct___2 *, struct css_set___29 *);
	void (*fork)(struct task_struct___2 *);
	void (*exit)(struct task_struct___2 *);
	void (*release)(struct task_struct___2 *);
	void (*bind)(struct cgroup_subsys_state___29 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___29 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___29 *dfl_cftypes;
	struct cftype___29 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___29 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___29 *updated_children;
	struct cgroup___29 *updated_next;
};

struct cgroup_root___29 {
	struct kernfs_root___35 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___29 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___29 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___29 *ss;
	struct list_head node;
	struct kernfs_ops___35 *kf_ops;
	int (*open)(struct kernfs_open_file___35 *);
	void (*release)(struct kernfs_open_file___35 *);
	u64 (*read_u64)(struct cgroup_subsys_state___29 *, struct cftype___29 *);
	s64 (*read_s64)(struct cgroup_subsys_state___29 *, struct cftype___29 *);
	int (*seq_show)(struct seq_file___33 *, void *);
	void * (*seq_start)(struct seq_file___33 *, loff_t *);
	void * (*seq_next)(struct seq_file___33 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___33 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___29 *, struct cftype___29 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___29 *, struct cftype___29 *, s64);
	ssize_t (*write)(struct kernfs_open_file___35 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___35 *, struct poll_table_struct___26 *);
};

struct blkcg_policy_data___23;

struct blkcg___23 {
	struct cgroup_subsys_state___29 css;
	spinlock_t lock;
	refcount_t online_pin;
	struct xarray blkg_tree;
	struct blkcg_gq___23 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___23 *cpd[6];
	struct list_head all_blkcgs_node;
	char fc_app_id[129];
	struct list_head cgwb_list;
};

struct blkcg_policy_data___23 {
	struct blkcg___23 *blkcg;
	int plid;
};

struct blkg_policy_data___23 {
	struct blkcg_gq___23 *blkg;
	int plid;
};

struct mem_cgroup_reclaim_iter___23 {
	struct mem_cgroup___23 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___23 {
	struct lruvec___24 lruvec;
	struct lruvec_stats_percpu *lruvec_stats_percpu;
	struct lruvec_stats lruvec_stats;
	long unsigned int lru_zone_size[25];
	struct mem_cgroup_reclaim_iter___23 iter;
	struct shrinker_info *shrinker_info;
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	struct mem_cgroup___23 *memcg;
};

struct obj_cgroup___23 {
	struct percpu_ref refcnt;
	struct mem_cgroup___23 *memcg;
	atomic_t nr_charged_bytes;
	union {
		struct list_head list;
		struct callback_head rcu;
	};
};

enum s2idle_states {
	S2IDLE_STATE_NONE = 0,
	S2IDLE_STATE_ENTER = 1,
	S2IDLE_STATE_WAKE = 2,
};

union perf_mem_data_src___3 {
	__u64 val;
	struct {
		__u64 mem_op: 5;
		__u64 mem_lvl: 14;
		__u64 mem_snoop: 5;
		__u64 mem_lock: 2;
		__u64 mem_dtlb: 7;
		__u64 mem_lvl_num: 4;
		__u64 mem_remote: 1;
		__u64 mem_snoopx: 2;
		__u64 mem_blk: 3;
		__u64 mem_rsvd: 21;
	};
};

union perf_sample_weight___3 {
	__u64 full;
	struct {
		__u32 var1_dw;
		__u16 var2_w;
		__u16 var3_w;
	};
};

struct perf_cpu_context___23;

struct perf_output_handle___23;

struct pmu___23 {
	struct list_head entry;
	struct module___34 *module;
	struct device___37 *dev;
	const struct attribute_group___35 **attr_groups;
	const struct attribute_group___35 **attr_update;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___23 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___23 *);
	void (*pmu_disable)(struct pmu___23 *);
	int (*event_init)(struct perf_event___23 *);
	void (*event_mapped)(struct perf_event___23 *, struct mm_struct___38 *);
	void (*event_unmapped)(struct perf_event___23 *, struct mm_struct___38 *);
	int (*add)(struct perf_event___23 *, int);
	void (*del)(struct perf_event___23 *, int);
	void (*start)(struct perf_event___23 *, int);
	void (*stop)(struct perf_event___23 *, int);
	void (*read)(struct perf_event___23 *);
	void (*start_txn)(struct pmu___23 *, unsigned int);
	int (*commit_txn)(struct pmu___23 *);
	void (*cancel_txn)(struct pmu___23 *);
	int (*event_idx)(struct perf_event___23 *);
	void (*sched_task)(struct perf_event_context___23 *, bool);
	struct kmem_cache *task_ctx_cache;
	void (*swap_task_ctx)(struct perf_event_context___23 *, struct perf_event_context___23 *);
	void * (*setup_aux)(struct perf_event___23 *, void **, int, bool);
	void (*free_aux)(void *);
	long int (*snapshot_aux)(struct perf_event___23 *, struct perf_output_handle___23 *, long unsigned int);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___23 *);
	int (*aux_output_match)(struct perf_event___23 *);
	int (*filter_match)(struct perf_event___23 *);
	int (*check_period)(struct perf_event___23 *, u64);
};

struct perf_cpu_context___23 {
	struct perf_event_context___23 ctx;
	struct perf_event_context___23 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___23 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
	int heap_size;
	struct perf_event___23 **heap;
	struct perf_event___23 *heap_default[2];
};

struct perf_output_handle___23 {
	struct perf_event___23 *event;
	struct perf_buffer *rb;
	long unsigned int wakeup;
	long unsigned int size;
	u64 aux_flags;
	union {
		void *addr;
		long unsigned int head;
	};
	int page;
};

struct perf_sample_data___3 {
	u64 addr;
	struct perf_raw_record *raw;
	struct perf_branch_stack *br_stack;
	u64 period;
	union perf_sample_weight___3 weight;
	long: 64;
	u64 txn;
	union perf_mem_data_src___3 data_src;
	long: 64;
	u64 type;
	u64 ip;
	struct {
		u32 pid;
		u32 tid;
	} tid_entry;
	u64 time;
	u64 id;
	u64 stream_id;
	struct {
		u32 cpu;
		u32 reserved;
	} cpu_entry;
	struct perf_callchain_entry *callchain;
	u64 aux_size;
	struct perf_regs regs_user;
	struct perf_regs regs_intr;
	u64 stack_user_size;
	u64 phys_addr;
	u64 cgroup;
	u64 data_page_size;
	u64 code_page_size;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct perf_cgroup___23 {
	struct cgroup_subsys_state___29 css;
	struct perf_cgroup_info *info;
};

struct trace_event_fields___23 {
	const char *type;
	union {
		struct {
			const char *name;
			const int size;
			const int align;
			const int is_signed;
			const int filter_type;
		};
		int (*define_fields)(struct trace_event_call___23 *);
	};
};

struct trace_event_class___23 {
	const char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct trace_event_call___23 *, enum trace_reg, void *);
	struct trace_event_fields___23 *fields_array;
	struct list_head * (*get_fields)(struct trace_event_call___23 *);
	struct list_head fields;
	int (*raw_init)(struct trace_event_call___23 *);
};

struct rq {
	raw_spinlock_t __lock;
	unsigned int nr_running;
	unsigned int nr_numa_running;
	unsigned int nr_preferred_running;
	unsigned int numa_migrate_on;
	long unsigned int last_blocked_load_update_tick;
	unsigned int has_blocked_load;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	call_single_data_t nohz_csd;
	unsigned int nohz_tick_stopped;
	atomic_t nohz_flags;
	unsigned int ttwu_pending;
	u64 nr_switches;
	long: 64;
	struct uclamp_rq uclamp[2];
	unsigned int uclamp_flags;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	struct cfs_rq___3 cfs;
	struct rt_rq rt;
	struct dl_rq dl;
	struct list_head leaf_cfs_rq_list;
	struct list_head *tmp_alone_branch;
	unsigned int nr_uninterruptible;
	struct task_struct___2 *curr;
	struct task_struct___2 *idle;
	struct task_struct___2 *stop;
	long unsigned int next_balance;
	struct mm_struct___38 *prev_mm;
	unsigned int clock_update_flags;
	u64 clock;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u64 clock_task;
	u64 clock_pelt;
	long unsigned int lost_idle_time;
	atomic_t nr_iowait;
	u64 last_seen_need_resched_ns;
	int ticks_without_resched;
	int membarrier_state;
	struct root_domain *rd;
	struct sched_domain *sd;
	long unsigned int cpu_capacity;
	long unsigned int cpu_capacity_orig;
	struct callback_head *balance_callback;
	unsigned char nohz_idle_balance;
	unsigned char idle_balance;
	long unsigned int misfit_task_load;
	int active_balance;
	int push_cpu;
	struct cpu_stop_work active_balance_work;
	int cpu;
	int online;
	struct list_head cfs_tasks;
	long: 64;
	struct sched_avg avg_rt;
	struct sched_avg avg_dl;
	u64 idle_stamp;
	u64 avg_idle;
	long unsigned int wake_stamp;
	u64 wake_avg_idle;
	u64 max_idle_balance_cost;
	struct rcuwait___35 hotplug_wait;
	u64 prev_steal_time;
	long unsigned int calc_load_update;
	long int calc_load_active;
	long: 64;
	long: 64;
	long: 64;
	call_single_data_t hrtick_csd;
	struct hrtimer hrtick_timer;
	ktime_t hrtick_time;
	struct sched_info rq_sched_info;
	long long unsigned int rq_cpu_time;
	unsigned int yld_count;
	unsigned int sched_count;
	unsigned int sched_goidle;
	unsigned int ttwu_count;
	unsigned int ttwu_local;
	struct cpuidle_state___3 *idle_state;
	unsigned int nr_pinned;
	unsigned int push_busy;
	struct cpu_stop_work push_work;
	struct rq *core;
	struct task_struct___2 *core_pick;
	unsigned int core_enabled;
	unsigned int core_sched_seq;
	struct rb_root core_tree;
	unsigned int core_task_seq;
	unsigned int core_pick_seq;
	long unsigned int core_cookie;
	unsigned char core_forceidle;
	unsigned int core_forceidle_seq;
};

struct idle_timer {
	struct hrtimer timer;
	int done;
};

struct numa_group {
	refcount_t refcount;
	spinlock_t lock;
	int nr_tasks;
	pid_t gid;
	int active_nodes;
	struct callback_head rcu;
	long unsigned int total_faults;
	long unsigned int max_faults_cpu;
	long unsigned int *faults_cpu;
	long unsigned int faults[0];
};

struct update_util_data {
	void (*func)(struct update_util_data *, u64, unsigned int);
};

enum sched_tunable_scaling {
	SCHED_TUNABLESCALING_NONE = 0,
	SCHED_TUNABLESCALING_LOG = 1,
	SCHED_TUNABLESCALING_LINEAR = 2,
	SCHED_TUNABLESCALING_END = 3,
};

typedef int (*tg_visitor___2)(struct task_group *, void *);

enum numa_topology_type {
	NUMA_DIRECT = 0,
	NUMA_GLUELESS_MESH = 1,
	NUMA_BACKPLANE = 2,
};

enum numa_faults_stats {
	NUMA_MEM = 0,
	NUMA_CPU = 1,
	NUMA_MEMBUF = 2,
	NUMA_CPUBUF = 3,
};

enum numa_type {
	node_has_spare = 0,
	node_fully_busy = 1,
	node_overloaded = 2,
};

struct numa_stats {
	long unsigned int load;
	long unsigned int runnable;
	long unsigned int util;
	long unsigned int compute_capacity;
	unsigned int nr_running;
	unsigned int weight;
	enum numa_type node_type;
	int idle_cpu;
};

struct task_numa_env {
	struct task_struct___2 *p;
	int src_cpu;
	int src_nid;
	int dst_cpu;
	int dst_nid;
	struct numa_stats src_stats;
	struct numa_stats dst_stats;
	int imbalance_pct;
	int dist;
	struct task_struct___2 *best_task;
	long int best_imp;
	int best_cpu;
};

enum fbq_type {
	regular = 0,
	remote = 1,
	all = 2,
};

enum group_type {
	group_has_spare = 0,
	group_fully_busy = 1,
	group_misfit_task = 2,
	group_asym_packing = 3,
	group_imbalanced = 4,
	group_overloaded = 5,
};

enum migration_type {
	migrate_load = 0,
	migrate_util = 1,
	migrate_task = 2,
	migrate_misfit = 3,
};

struct lb_env {
	struct sched_domain *sd;
	struct rq *src_rq;
	int src_cpu;
	int dst_cpu;
	struct rq *dst_rq;
	struct cpumask *dst_grpmask;
	int new_dst_cpu;
	enum cpu_idle_type idle;
	long int imbalance;
	struct cpumask *cpus;
	unsigned int flags;
	unsigned int loop;
	unsigned int loop_break;
	unsigned int loop_max;
	enum fbq_type fbq_type;
	enum migration_type migration_type;
	struct list_head tasks;
};

struct sg_lb_stats {
	long unsigned int avg_load;
	long unsigned int group_load;
	long unsigned int group_capacity;
	long unsigned int group_util;
	long unsigned int group_runnable;
	unsigned int sum_nr_running;
	unsigned int sum_h_nr_running;
	unsigned int idle_cpus;
	unsigned int group_weight;
	enum group_type group_type;
	unsigned int group_asym_packing;
	long unsigned int group_misfit_task_load;
	unsigned int nr_numa_running;
	unsigned int nr_preferred_running;
};

struct sd_lb_stats {
	struct sched_group *busiest;
	struct sched_group *local;
	long unsigned int total_load;
	long unsigned int total_capacity;
	long unsigned int avg_load;
	unsigned int prefer_sibling;
	struct sg_lb_stats busiest_stat;
	struct sg_lb_stats local_stat;
};

typedef struct rt_rq *rt_rq_iter_t;

struct swait_queue___2 {
	struct task_struct___38 *task;
	struct list_head task_list;
};

struct sd_flag_debug {
	unsigned int meta_flags;
	char *name;
};

struct cpufreq_governor___2;

struct cpufreq_policy___2 {
	cpumask_var_t cpus;
	cpumask_var_t related_cpus;
	cpumask_var_t real_cpus;
	unsigned int shared_type;
	unsigned int cpu;
	struct clk *clk;
	struct cpufreq_cpuinfo cpuinfo;
	unsigned int min;
	unsigned int max;
	unsigned int cur;
	unsigned int suspend_freq;
	unsigned int policy;
	unsigned int last_policy;
	struct cpufreq_governor___2 *governor;
	void *governor_data;
	char last_governor[16];
	struct work_struct update;
	struct freq_constraints constraints;
	struct freq_qos_request *min_freq_req;
	struct freq_qos_request *max_freq_req;
	struct cpufreq_frequency_table *freq_table;
	enum cpufreq_table_sorting freq_table_sorted;
	struct list_head policy_list;
	struct kobject___35 kobj;
	struct completion kobj_unregister;
	struct rw_semaphore rwsem;
	bool fast_switch_possible;
	bool fast_switch_enabled;
	bool strict_target;
	unsigned int transition_delay_us;
	bool dvfs_possible_from_any_cpu;
	unsigned int cached_target_freq;
	unsigned int cached_resolved_idx;
	bool transition_ongoing;
	spinlock_t transition_lock;
	wait_queue_head_t transition_wait;
	struct task_struct___2 *transition_task;
	struct cpufreq_stats *stats;
	void *driver_data;
	struct thermal_cooling_device *cdev;
	struct notifier_block nb_min;
	struct notifier_block nb_max;
};

struct cpufreq_governor___2 {
	char name[16];
	int (*init)(struct cpufreq_policy___2 *);
	void (*exit)(struct cpufreq_policy___2 *);
	int (*start)(struct cpufreq_policy___2 *);
	void (*stop)(struct cpufreq_policy___2 *);
	void (*limits)(struct cpufreq_policy___2 *);
	ssize_t (*show_setspeed)(struct cpufreq_policy___2 *, char *);
	int (*store_setspeed)(struct cpufreq_policy___2 *, unsigned int);
	struct list_head governor_list;
	struct module___34 *owner;
	u8 flags;
};

struct s_data {
	struct sched_domain **sd;
	struct root_domain *rd;
};

enum s_alloc {
	sa_rootdomain = 0,
	sa_sd = 1,
	sa_sd_storage = 2,
	sa_none = 3,
};

struct asym_cap_data {
	struct list_head link;
	long unsigned int capacity;
	long unsigned int cpus[0];
};

enum cpuacct_stat_index {
	CPUACCT_STAT_USER = 0,
	CPUACCT_STAT_SYSTEM = 1,
	CPUACCT_STAT_NSTATS = 2,
};

struct cpuacct {
	struct cgroup_subsys_state___28 css;
	u64 *cpuusage;
	struct kernel_cpustat *cpustat;
};

struct cpufreq_governor___3;

struct cpufreq_policy___3 {
	cpumask_var_t cpus;
	cpumask_var_t related_cpus;
	cpumask_var_t real_cpus;
	unsigned int shared_type;
	unsigned int cpu;
	struct clk *clk;
	struct cpufreq_cpuinfo cpuinfo;
	unsigned int min;
	unsigned int max;
	unsigned int cur;
	unsigned int suspend_freq;
	unsigned int policy;
	unsigned int last_policy;
	struct cpufreq_governor___3 *governor;
	void *governor_data;
	char last_governor[16];
	struct work_struct update;
	struct freq_constraints constraints;
	struct freq_qos_request *min_freq_req;
	struct freq_qos_request *max_freq_req;
	struct cpufreq_frequency_table *freq_table;
	enum cpufreq_table_sorting freq_table_sorted;
	struct list_head policy_list;
	struct kobject___34 kobj;
	struct completion kobj_unregister;
	struct rw_semaphore rwsem;
	bool fast_switch_possible;
	bool fast_switch_enabled;
	bool strict_target;
	unsigned int transition_delay_us;
	bool dvfs_possible_from_any_cpu;
	unsigned int cached_target_freq;
	unsigned int cached_resolved_idx;
	bool transition_ongoing;
	spinlock_t transition_lock;
	wait_queue_head_t transition_wait;
	struct task_struct___38 *transition_task;
	struct cpufreq_stats *stats;
	void *driver_data;
	struct thermal_cooling_device *cdev;
	struct notifier_block nb_min;
	struct notifier_block nb_max;
};

struct cpufreq_governor___3 {
	char name[16];
	int (*init)(struct cpufreq_policy___3 *);
	void (*exit)(struct cpufreq_policy___3 *);
	int (*start)(struct cpufreq_policy___3 *);
	void (*stop)(struct cpufreq_policy___3 *);
	void (*limits)(struct cpufreq_policy___3 *);
	ssize_t (*show_setspeed)(struct cpufreq_policy___3 *, char *);
	int (*store_setspeed)(struct cpufreq_policy___3 *, unsigned int);
	struct list_head governor_list;
	struct module___33 *owner;
	u8 flags;
};

struct gov_attr_set {
	struct kobject___35 kobj;
	struct list_head policy_list;
	struct mutex update_lock;
	int usage_count;
};

struct governor_attr {
	struct attribute attr;
	ssize_t (*show)(struct gov_attr_set *, char *);
	ssize_t (*store)(struct gov_attr_set *, const char *, size_t);
};

struct kthread_work___3;

typedef void (*kthread_work_func_t___3)(struct kthread_work___3 *);

struct kthread_worker___3;

struct kthread_work___3 {
	struct list_head node;
	kthread_work_func_t___3 func;
	struct kthread_worker___3 *worker;
	int canceling;
};

struct kthread_worker___3 {
	unsigned int flags;
	raw_spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___2 *task;
	struct kthread_work___3 *current_work;
};

struct sugov_tunables {
	struct gov_attr_set attr_set;
	unsigned int rate_limit_us;
};

struct sugov_policy {
	struct cpufreq_policy___2 *policy;
	struct sugov_tunables *tunables;
	struct list_head tunables_hook;
	raw_spinlock_t update_lock;
	u64 last_freq_update_time;
	s64 freq_update_delay_ns;
	unsigned int next_freq;
	unsigned int cached_raw_freq;
	struct irq_work irq_work;
	struct kthread_work___3 work;
	struct mutex work_lock;
	struct kthread_worker___3 worker;
	struct task_struct___2 *thread;
	bool work_in_progress;
	bool limits_changed;
	bool need_freq_update;
};

struct sugov_cpu {
	struct update_util_data update_util;
	struct sugov_policy *sg_policy;
	unsigned int cpu;
	bool iowait_boost_pending;
	unsigned int iowait_boost;
	u64 last_update;
	long unsigned int util;
	long unsigned int bw_dl;
	long unsigned int max;
	long unsigned int saved_idle_calls;
};

enum {
	MEMBARRIER_FLAG_SYNC_CORE = 1,
	MEMBARRIER_FLAG_RSEQ = 2,
};

enum membarrier_cmd {
	MEMBARRIER_CMD_QUERY = 0,
	MEMBARRIER_CMD_GLOBAL = 1,
	MEMBARRIER_CMD_GLOBAL_EXPEDITED = 2,
	MEMBARRIER_CMD_REGISTER_GLOBAL_EXPEDITED = 4,
	MEMBARRIER_CMD_PRIVATE_EXPEDITED = 8,
	MEMBARRIER_CMD_REGISTER_PRIVATE_EXPEDITED = 16,
	MEMBARRIER_CMD_PRIVATE_EXPEDITED_SYNC_CORE = 32,
	MEMBARRIER_CMD_REGISTER_PRIVATE_EXPEDITED_SYNC_CORE = 64,
	MEMBARRIER_CMD_PRIVATE_EXPEDITED_RSEQ = 128,
	MEMBARRIER_CMD_REGISTER_PRIVATE_EXPEDITED_RSEQ = 256,
	MEMBARRIER_CMD_SHARED = 1,
};

enum membarrier_cmd_flag {
	MEMBARRIER_CMD_FLAG_CPU = 1,
};

struct syscall_metadata___10 {
	const char *name;
	int syscall_nr;
	int nb_args;
	const char **types;
	const char **args;
	struct list_head enter_fields;
	struct trace_event_call___22 *enter_event;
	struct trace_event_call___22 *exit_event;
};

struct proc_ops___2 {
	unsigned int proc_flags;
	int (*proc_open)(struct inode___35 *, struct file___35 *);
	ssize_t (*proc_read)(struct file___35 *, char *, size_t, loff_t *);
	ssize_t (*proc_read_iter)(struct kiocb___35 *, struct iov_iter___29 *);
	ssize_t (*proc_write)(struct file___35 *, const char *, size_t, loff_t *);
	loff_t (*proc_lseek)(struct file___35 *, loff_t, int);
	int (*proc_release)(struct inode___35 *, struct file___35 *);
	__poll_t (*proc_poll)(struct file___35 *, struct poll_table_struct___26 *);
	long int (*proc_ioctl)(struct file___35 *, unsigned int, long unsigned int);
	long int (*proc_compat_ioctl)(struct file___35 *, unsigned int, long unsigned int);
	int (*proc_mmap)(struct file___35 *, struct vm_area_struct___38 *);
	long unsigned int (*proc_get_unmapped_area)(struct file___35 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
};

enum psi_res {
	PSI_IO = 0,
	PSI_MEM = 1,
	PSI_CPU = 2,
	NR_PSI_RESOURCES = 3,
};

struct psi_window {
	u64 size;
	u64 start_time;
	u64 start_value;
	u64 prev_growth;
};

struct psi_trigger {
	enum psi_states state;
	u64 threshold;
	struct list_head node;
	struct psi_group___29 *group;
	wait_queue_head_t event_wait;
	int event;
	struct psi_window win;
	u64 last_event_time;
};

typedef struct poll_table_struct___26 poll_table___3;

struct sched_core_cookie {
	refcount_t refcnt;
};

struct ww_acquire_ctx;

struct ww_mutex {
	struct mutex base;
	struct ww_acquire_ctx *ctx;
};

struct ww_acquire_ctx {
	struct task_struct___2 *task;
	long unsigned int stamp;
	unsigned int acquired;
	short unsigned int wounded;
	short unsigned int is_wait_die;
};

struct mutex_waiter {
	struct list_head list;
	struct task_struct___2 *task;
	struct ww_acquire_ctx *ww_ctx;
};

struct semaphore_waiter {
	struct list_head list;
	struct task_struct___33 *task;
	bool up;
};

enum rwsem_waiter_type {
	RWSEM_WAITING_FOR_WRITE = 0,
	RWSEM_WAITING_FOR_READ = 1,
};

struct rwsem_waiter {
	struct list_head list;
	struct task_struct___2 *task;
	enum rwsem_waiter_type type;
	long unsigned int timeout;
	bool handoff_set;
};

enum rwsem_wake_type {
	RWSEM_WAKE_ANY = 0,
	RWSEM_WAKE_READERS = 1,
	RWSEM_WAKE_READ_OWNED = 2,
};

enum owner_state {
	OWNER_NULL = 1,
	OWNER_WRITER = 2,
	OWNER_READER = 4,
	OWNER_NONSPINNABLE = 8,
};

struct optimistic_spin_node {
	struct optimistic_spin_node *next;
	struct optimistic_spin_node *prev;
	int locked;
	int cpu;
};

struct mcs_spinlock {
	struct mcs_spinlock *next;
	int locked;
	int count;
};

struct qnode {
	struct mcs_spinlock mcs;
	long int reserved[2];
};

enum vcpu_state {
	vcpu_running = 0,
	vcpu_halted = 1,
	vcpu_hashed = 2,
};

struct pv_node {
	struct mcs_spinlock mcs;
	int cpu;
	u8 state;
};

struct pv_hash_entry {
	struct qspinlock *lock;
	struct pv_node *node;
};

struct rt_mutex_base {
	raw_spinlock_t wait_lock;
	struct rb_root_cached waiters;
	struct task_struct___2 *owner;
};

struct rt_mutex {
	struct rt_mutex_base rtmutex;
};

struct hrtimer_sleeper {
	struct hrtimer timer;
	struct task_struct___2 *task;
};

struct rt_mutex_waiter {
	struct rb_node tree_entry;
	struct rb_node pi_tree_entry;
	struct task_struct___2 *task;
	struct rt_mutex_base *lock;
	unsigned int wake_state;
	int prio;
	u64 deadline;
	struct ww_acquire_ctx *ww_ctx;
};

struct rt_wake_q_head {
	struct wake_q_head head;
	struct task_struct___2 *rtlock_task;
};

enum rtmutex_chainwalk {
	RT_MUTEX_MIN_CHAINWALK = 0,
	RT_MUTEX_FULL_CHAINWALK = 1,
};

enum pm_qos_req_action {
	PM_QOS_ADD_REQ = 0,
	PM_QOS_UPDATE_REQ = 1,
	PM_QOS_REMOVE_REQ = 2,
};

typedef int suspend_state_t;

enum suspend_stat_step {
	SUSPEND_FREEZE = 1,
	SUSPEND_PREPARE = 2,
	SUSPEND_SUSPEND = 3,
	SUSPEND_SUSPEND_LATE = 4,
	SUSPEND_SUSPEND_NOIRQ = 5,
	SUSPEND_RESUME_NOIRQ = 6,
	SUSPEND_RESUME_EARLY = 7,
	SUSPEND_RESUME = 8,
};

struct suspend_stats {
	int success;
	int fail;
	int failed_freeze;
	int failed_prepare;
	int failed_suspend;
	int failed_suspend_late;
	int failed_suspend_noirq;
	int failed_resume;
	int failed_resume_early;
	int failed_resume_noirq;
	int last_failed_dev;
	char failed_devs[80];
	int last_failed_errno;
	int errno[2];
	int last_failed_step;
	enum suspend_stat_step failed_steps[2];
};

enum {
	TEST_NONE = 0,
	TEST_CORE = 1,
	TEST_CPUS = 2,
	TEST_PLATFORM = 3,
	TEST_DEVICES = 4,
	TEST_FREEZER = 5,
	__TEST_AFTER_LAST = 6,
};

struct pm_vt_switch {
	struct list_head head;
	struct device___31 *dev;
	bool required;
};

struct dentry___36;

struct super_block___36;

struct module___35;

struct file_system_type___36 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___36 * (*mount)(struct file_system_type___36 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___36 *);
	struct module___35 *owner;
	struct file_system_type___36 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___36;

struct kiocb___36;

struct iov_iter___30;

struct poll_table_struct___27;

struct vm_area_struct___39;

struct inode___36;

struct file_lock___36;

struct page___38;

struct seq_file___34;

struct file_operations___36 {
	struct module___35 *owner;
	loff_t (*llseek)(struct file___36 *, loff_t, int);
	ssize_t (*read)(struct file___36 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___36 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___36 *, struct iov_iter___30 *);
	ssize_t (*write_iter)(struct kiocb___36 *, struct iov_iter___30 *);
	int (*iopoll)(struct kiocb___36 *, bool);
	int (*iterate)(struct file___36 *, struct dir_context *);
	int (*iterate_shared)(struct file___36 *, struct dir_context *);
	__poll_t (*poll)(struct file___36 *, struct poll_table_struct___27 *);
	long int (*unlocked_ioctl)(struct file___36 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___36 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___36 *, struct vm_area_struct___39 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___36 *, struct file___36 *);
	int (*flush)(struct file___36 *, fl_owner_t);
	int (*release)(struct inode___36 *, struct file___36 *);
	int (*fsync)(struct file___36 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___36 *, int);
	int (*lock)(struct file___36 *, int, struct file_lock___36 *);
	ssize_t (*sendpage)(struct file___36 *, struct page___38 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___36 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___36 *, long unsigned int);
	int (*flock)(struct file___36 *, int, struct file_lock___36 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___36 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___36 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___36 *, long int, struct file_lock___36 **, void **);
	long int (*fallocate)(struct file___36 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___34 *, struct file___36 *);
	ssize_t (*copy_file_range)(struct file___36 *, loff_t, struct file___36 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___36 *, loff_t, struct file___36 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___36 *, loff_t, loff_t, int);
};

struct static_call_mod___27 {
	struct static_call_mod___27 *next;
	struct module___35 *mod;
	struct static_call_site *sites;
};

struct static_call_key___27 {
	void *func;
	union {
		long unsigned int type;
		struct static_call_mod___27 *mods;
		struct static_call_site *sites;
	};
};

struct vmacache___38 {
	u64 seqnum;
	struct vm_area_struct___39 *vmas[4];
};

struct page_frag___38 {
	struct page___38 *page;
	__u32 offset;
	__u32 size;
};

struct perf_event___24;

struct thread_struct___25 {
	struct desc_struct tls_array[3];
	long unsigned int sp;
	short unsigned int es;
	short unsigned int ds;
	short unsigned int fsindex;
	short unsigned int gsindex;
	long unsigned int fsbase;
	long unsigned int gsbase;
	struct perf_event___24 *ptrace_bps[4];
	long unsigned int virtual_dr6;
	long unsigned int ptrace_dr7;
	long unsigned int cr2;
	long unsigned int trap_nr;
	long unsigned int error_code;
	struct io_bitmap *io_bitmap;
	long unsigned int iopl_emul;
	unsigned int iopl_warn: 1;
	unsigned int sig_on_uaccess_err: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u32 pkru;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct fpu fpu;
};

struct mm_struct___39;

struct pid___31;

struct nsproxy___35;

struct signal_struct___36;

struct bio_list___25;

struct backing_dev_info___24;

struct io_context___25;

struct css_set___30;

struct perf_event_context___24;

struct mem_cgroup___24;

struct request_queue___25;

struct vm_struct___33;

struct task_struct___39 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___39 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___3 se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___39 *mm;
	struct mm_struct___39 *active_mm;
	struct vmacache___38 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int restore_sigmask: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___39 *real_parent;
	struct task_struct___39 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___39 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___31 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	struct posix_cputimers_work posix_cputimers_work;
	const struct cred___2 *ptracer_cred;
	const struct cred___2 *real_cred;
	const struct cred___2 *cred;
	struct key *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___35 *nsproxy;
	struct signal_struct___36 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___39 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___25 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___24 *backing_dev_info;
	struct io_context___25 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___30 *cgroups;
	struct list_head cg_list;
	u32 closid;
	u32 rmid;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___24 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	long: 64;
	long: 64;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___38 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___24 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___24 *active_memcg;
	struct request_queue___25 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___39 *oom_reaper_list;
	struct vm_struct___33 *stack_vm_area;
	refcount_t stack_refcount;
	int patch_state;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	void *mce_vaddr;
	__u64 mce_kflags;
	u64 mce_addr;
	__u64 mce_ripv: 1;
	__u64 mce_whole_page: 1;
	__u64 __mce_reserved: 62;
	long: 2;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct callback_head mce_kill_me;
	int mce_count;
	struct llist_head kretprobe_instances;
	struct callback_head l1d_flush_kill;
	long: 64;
	struct thread_struct___25 thread;
};

typedef struct page___38 *pgtable_t___38;

struct address_space___36;

struct dev_pagemap___36;

struct page___38 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___36 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___13 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___38 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___38 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___39 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___36 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct core_state___38;

struct mm_struct___39 {
	struct {
		struct vm_area_struct___39 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___36 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int mmap_compat_base;
		long unsigned int mmap_compat_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[48];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___38 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___39 *owner;
		struct user_namespace___2 *user_ns;
		struct file___36 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		bool tlb_flush_batched;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct vm_operations_struct___36;

struct vm_area_struct___39 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___39 *vm_next;
	struct vm_area_struct___39 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___39 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___36 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___36 *vm_file;
	struct file___36 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct tracepoint___27 {
	const char *name;
	struct static_key key;
	struct static_call_key___27 *static_call_key;
	void *static_call_tramp;
	void *iterator;
	int (*regfunc)();
	void (*unregfunc)();
	struct tracepoint_func *funcs;
};

struct bpf_raw_event_map___27 {
	struct tracepoint___27 *tp;
	void *bpf_func;
	u32 num_args;
	u32 writable_size;
	long: 64;
};

struct seq_operations___34 {
	void * (*start)(struct seq_file___34 *, loff_t *);
	void (*stop)(struct seq_file___34 *, void *);
	void * (*next)(struct seq_file___34 *, void *, loff_t *);
	int (*show)(struct seq_file___34 *, void *);
};

struct hw_perf_event___24 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___39 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	union {
		struct {
			u64 last_period;
			local64_t period_left;
		};
		struct {
			u64 saved_metric;
			u64 saved_slots;
		};
	};
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___24)(struct perf_event___24 *, struct perf_sample_data *, struct pt_regs *);

struct pmu___24;

struct fasync_struct___36;

struct pid_namespace___31;

struct trace_event_call___24;

struct perf_cgroup___24;

struct perf_event___24 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___24 *group_leader;
	struct pmu___24 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___24 hw;
	struct perf_event_context___24 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___24 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___39 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct perf_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___36 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	long unsigned int pending_addr;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	struct perf_addr_filter_range *addr_filter_ranges;
	long unsigned int addr_filters_gen;
	struct perf_event___24 *aux_event;
	void (*destroy)(struct perf_event___24 *);
	struct callback_head callback_head;
	struct pid_namespace___31 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___24 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___24 orig_overflow_handler;
	struct bpf_prog *prog;
	u64 bpf_cookie;
	struct trace_event_call___24 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___24 *cgrp;
	void *security;
	struct list_head sb_list;
};

struct upid___31 {
	int nr;
	struct pid_namespace___31 *ns;
};

struct pid_namespace___31 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___39 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___31 *parent;
	struct fs_pin *bacct;
	struct user_namespace___2 *user_ns;
	struct ucounts___2 *ucounts;
	int reboot;
	struct ns_common___5 ns;
};

struct pid___31 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___31 numbers[1];
};

struct signal_struct___36 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___39 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___39 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper;
	unsigned int has_child_subreaper;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___31 *pids[4];
	struct pid___31 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___39 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct cgroup_namespace___30;

struct nsproxy___35 {
	atomic_t count;
	struct uts_namespace *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___31 *pid_ns_for_children;
	struct net *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___30 *cgroup_ns;
};

struct bio___25;

struct bio_list___25 {
	struct bio___25 *head;
	struct bio___25 *tail;
};

struct cgroup_subsys_state___30;

struct bdi_writeback___24 {
	struct backing_dev_info___24 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	atomic_t writeback_inodes;
	struct percpu_counter stat[4];
	long unsigned int congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	struct delayed_work bw_dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___30 *memcg_css;
	struct cgroup_subsys_state___30 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	struct list_head b_attached;
	struct list_head offline_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
};

struct device___38;

struct backing_dev_info___24 {
	u64 id;
	struct rb_node rb_node;
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___24 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct mutex cgwb_release_mutex;
	struct rw_semaphore wb_switch_rwsem;
	wait_queue_head_t wb_waitq;
	struct device___38 *dev;
	char dev_name[64];
	struct device___38 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___36 *debug_dir;
};

struct io_cq___25;

struct io_context___25 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	struct xarray icq_tree;
	struct io_cq___25 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct cgroup___30;

struct css_set___30 {
	struct cgroup_subsys_state___30 *subsys[14];
	refcount_t refcount;
	struct css_set___30 *dom_cset;
	struct cgroup___30 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___30 *mg_src_cgrp;
	struct cgroup___30 *mg_dst_cgrp;
	struct css_set___30 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___24 {
	struct pmu___24 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	int rotate_necessary;
	refcount_t refcount;
	struct task_struct___39 *task;
	u64 time;
	u64 timestamp;
	u64 timeoffset;
	struct perf_event_context___24 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

struct cgroup_subsys___30;

struct cgroup_subsys_state___30 {
	struct cgroup___30 *cgroup;
	struct cgroup_subsys___30 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___30 *parent;
};

struct kernfs_node___36;

struct cgroup_file___30 {
	struct kernfs_node___36 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct obj_cgroup___24;

struct mem_cgroup_per_node___24;

struct mem_cgroup___24 {
	struct cgroup_subsys_state___30 css;
	struct mem_cgroup_id id;
	struct page_counter memory;
	union {
		struct page_counter swap;
		struct page_counter memsw;
	};
	struct page_counter kmem;
	struct page_counter tcpmem;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool oom_group;
	bool oom_lock;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___30 events_file;
	struct cgroup_file___30 events_local_file;
	struct cgroup_file___30 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	struct memcg_vmstats vmstats;
	atomic_long_t memory_events[8];
	atomic_long_t memory_events_local[8];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct obj_cgroup___24 *objcg;
	struct list_head objcg_list;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad2_;
	atomic_t moving_account;
	struct task_struct___39 *move_lock_task;
	struct memcg_vmstats_percpu *vmstats_percpu;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct memcg_cgwb_frn cgwb_frn[4];
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct deferred_split deferred_split_queue;
	struct mem_cgroup_per_node___24 *nodeinfo[0];
	long: 64;
};

struct kset___35;

struct kobj_type___35;

struct kobject___36 {
	const char *name;
	struct list_head entry;
	struct kobject___36 *parent;
	struct kset___35 *kset;
	struct kobj_type___35 *ktype;
	struct kernfs_node___36 *sd;
	struct kref kref;
	unsigned int state_initialized;
	unsigned int state_in_sysfs;
	unsigned int state_add_uevent_sent;
	unsigned int state_remove_uevent_sent;
	unsigned int uevent_suppress;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct blk_integrity_profile___25;

struct blk_integrity___25 {
	const struct blk_integrity_profile___25 *profile;
	unsigned char flags;
	unsigned char tuple_size;
	unsigned char interval_exp;
	unsigned char tag_size;
};

struct bio_set___25 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	struct bio_alloc_cache *cache;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	unsigned int back_pad;
	spinlock_t rescue_lock;
	struct bio_list___25 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	struct hlist_node cpuhp_dead;
};

struct request___25;

struct elevator_queue___25;

struct gendisk___25;

struct blkcg_gq___24;

struct request_queue___25 {
	struct request___25 *last_merge;
	struct elevator_queue___25 *elevator;
	struct percpu_ref q_usage_counter;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	const struct blk_mq_ops *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx **queue_hw_ctx;
	unsigned int nr_hw_queues;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	spinlock_t queue_lock;
	struct gendisk___25 *disk;
	struct kobject___36 kobj;
	struct kobject___36 *mq_kobj;
	struct blk_integrity___25 integrity;
	struct device___38 *dev;
	enum rpm_status rpm_status;
	long unsigned int nr_requests;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_keyslot_manager *ksm;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	atomic_t nr_active_requests_shared_sbitmap;
	struct sbitmap_queue sched_bitmap_tags;
	struct sbitmap_queue sched_breserved_tags;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___24 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int required_elevator_features;
	unsigned int nr_zones;
	long unsigned int *conv_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int max_open_zones;
	unsigned int max_active_zones;
	int node;
	struct mutex debugfs_mutex;
	struct blk_trace *blk_trace;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	struct mutex sysfs_dir_lock;
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	int mq_freeze_depth;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct mutex mq_freeze_lock;
	struct blk_mq_tag_set *tag_set;
	struct list_head tag_set_list;
	struct bio_set___25 bio_split;
	struct dentry___36 *debugfs_dir;
	struct dentry___36 *sched_debugfs_dir;
	struct dentry___36 *rqos_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	u64 write_hints[5];
};

struct vm_struct___33 {
	struct vm_struct___33 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___38 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct psi_group___30 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___39 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___30;

struct cgroup_rstat_cpu___30;

struct cgroup___30 {
	struct cgroup_subsys_state___30 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___36 *kn;
	struct cgroup_file___30 procs_file;
	struct cgroup_file___30 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___30 *subsys[14];
	struct cgroup_root___30 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___30 *dom_cgrp;
	struct cgroup___30 *old_dom_cgrp;
	struct cgroup_rstat_cpu___30 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___30 psi;
	struct cgroup_bpf___4 bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct address_space_operations___36;

struct address_space___36 {
	struct inode___36 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___36 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct dev_pagemap_ops___36;

struct dev_pagemap___36 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___36 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vfsmount___36;

struct path___36 {
	struct vfsmount___36 *mnt;
	struct dentry___36 *dentry;
};

struct fown_struct___31 {
	rwlock_t lock;
	struct pid___31 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___36 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	long: 64;
	long: 64;
	struct path___36 f_path;
	struct inode___36 *f_inode;
	const struct file_operations___36 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___31 f_owner;
	const struct cred___2 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___36 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___36;

struct vm_operations_struct___36 {
	void (*open)(struct vm_area_struct___39 *);
	void (*close)(struct vm_area_struct___39 *);
	int (*may_split)(struct vm_area_struct___39 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___39 *);
	int (*mprotect)(struct vm_area_struct___39 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___36 *);
	vm_fault_t (*huge_fault)(struct vm_fault___36 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___36 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___39 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___36 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___36 *);
	int (*access)(struct vm_area_struct___39 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___39 *);
	int (*set_policy)(struct vm_area_struct___39 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___39 *, long unsigned int);
	struct page___38 * (*find_special_page)(struct vm_area_struct___39 *, long unsigned int);
};

struct core_thread___38 {
	struct task_struct___39 *task;
	struct core_thread___38 *next;
};

struct core_state___38 {
	atomic_t nr_threads;
	struct core_thread___38 dumper;
	struct completion startup;
};

struct vm_fault___36 {
	const struct {
		struct vm_area_struct___39 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___38 *cow_page;
	struct page___38 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___38 prealloc_pte;
};

struct pglist_data___25;

struct lruvec___25 {
	struct list_head lists[5];
	spinlock_t lru_lock;
	long unsigned int anon_cost;
	long unsigned int file_cost;
	atomic_long_t nonresident_age;
	long unsigned int refaults[2];
	long unsigned int flags;
	struct pglist_data___25 *pgdat;
};

struct zone___25 {
	long unsigned int _watermark[3];
	long unsigned int watermark_boost;
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[5];
	int node;
	struct pglist_data___25 *zone_pgdat;
	struct per_cpu_pages *per_cpu_pageset;
	struct per_cpu_zonestat *per_cpu_zonestats;
	int pageset_high;
	int pageset_batch;
	long unsigned int zone_start_pfn;
	atomic_long_t managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int present_early_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	seqlock_t span_seqlock;
	int initialized;
	int: 32;
	struct zone_padding _pad1_;
	struct free_area free_area[11];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	long unsigned int compact_init_migrate_pfn;
	long unsigned int compact_init_free_pfn;
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	short: 16;
	struct zone_padding _pad3_;
	atomic_long_t vm_stat[11];
	atomic_long_t vm_numa_event[6];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___25 {
	struct zone___25 *zone;
	int zone_idx;
};

struct zonelist___25 {
	struct zoneref___25 _zonerefs[5121];
};

struct pglist_data___25 {
	struct zone___25 node_zones[5];
	struct zonelist___25 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___39 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_highest_zoneidx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_highest_zoneidx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___39 *kcompactd;
	bool proactive_compact_trigger;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct deferred_split deferred_split_queue;
	struct lruvec___25 __lruvec;
	long unsigned int flags;
	long: 64;
	struct zone_padding _pad2_;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[39];
};

struct shrink_control___24 {
	gfp_t gfp_mask;
	int nid;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	struct mem_cgroup___24 *memcg;
};

struct shrinker___24 {
	long unsigned int (*count_objects)(struct shrinker___24 *, struct shrink_control___24 *);
	long unsigned int (*scan_objects)(struct shrinker___24 *, struct shrink_control___24 *);
	long int batch;
	int seeks;
	unsigned int flags;
	struct list_head list;
	int id;
	atomic_long_t *nr_deferred;
};

struct dev_pagemap_ops___36 {
	void (*page_free)(struct page___38 *);
	void (*kill)(struct dev_pagemap___36 *);
	void (*cleanup)(struct dev_pagemap___36 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___36 *);
};

struct dentry_operations___36;

struct dentry___36 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___36 *d_parent;
	struct qstr d_name;
	struct inode___36 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___36 *d_op;
	struct super_block___36 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___36;

struct inode___36 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___36 *i_op;
	struct super_block___36 *i_sb;
	struct address_space___36 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___24 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	long: 64;
	long: 64;
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___36 *i_fop;
		void (*free_inode)(struct inode___36 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___36 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___14 *i_pipe;
		struct cdev *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___36 {
	int (*d_revalidate)(struct dentry___36 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___36 *, unsigned int);
	int (*d_hash)(const struct dentry___36 *, struct qstr *);
	int (*d_compare)(const struct dentry___36 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___36 *);
	int (*d_init)(struct dentry___36 *);
	void (*d_release)(struct dentry___36 *);
	void (*d_prune)(struct dentry___36 *);
	void (*d_iput)(struct dentry___36 *, struct inode___36 *);
	char * (*d_dname)(struct dentry___36 *, char *, int);
	struct vfsmount___36 * (*d_automount)(struct path___36 *);
	int (*d_manage)(const struct path___36 *, bool);
	struct dentry___36 * (*d_real)(struct dentry___36 *, const struct inode___36 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___36;

struct mem_dqinfo___36 {
	struct quota_format_type___36 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___36;

struct quota_info___36 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___36 *files[3];
	struct mem_dqinfo___36 info[3];
	const struct quota_format_ops___36 *ops[3];
};

struct rcuwait___36 {
	struct task_struct___39 *task;
};

struct percpu_rw_semaphore___36 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___36 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___36 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___36 rw_sem[3];
};

struct super_operations___36;

struct dquot_operations___36;

struct quotactl_ops___36;

struct block_device___25;

struct super_block___36 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___36 *s_type;
	const struct super_operations___36 *s_op;
	const struct dquot_operations___36 *dq_op;
	const struct quotactl_ops___36 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___36 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___25 *s_bdev;
	struct backing_dev_info___24 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___36 s_dquot;
	struct sb_writers___36 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___36 *s_d_op;
	int cleancache_poolid;
	struct shrinker___24 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___2 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___36 {
	struct dentry___36 *mnt_root;
	struct super_block___36 *mnt_sb;
	int mnt_flags;
	struct user_namespace___2 *mnt_userns;
};

struct io_cq___25 {
	struct request_queue___25 *q;
	struct io_context___25 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct wait_page_queue___21;

struct kiocb___36 {
	struct file___36 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___36 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___21 *ki_waitq;
	};
};

struct iattr___36 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___36 *ia_file;
};

struct dquot___36 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___36 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___36 {
	int qf_fmt_id;
	const struct quota_format_ops___36 *qf_ops;
	struct module___35 *qf_owner;
	struct quota_format_type___36 *qf_next;
};

struct quota_format_ops___36 {
	int (*check_quota_file)(struct super_block___36 *, int);
	int (*read_file_info)(struct super_block___36 *, int);
	int (*write_file_info)(struct super_block___36 *, int);
	int (*free_file_info)(struct super_block___36 *, int);
	int (*read_dqblk)(struct dquot___36 *);
	int (*commit_dqblk)(struct dquot___36 *);
	int (*release_dqblk)(struct dquot___36 *);
	int (*get_next_id)(struct super_block___36 *, struct kqid *);
};

struct dquot_operations___36 {
	int (*write_dquot)(struct dquot___36 *);
	struct dquot___36 * (*alloc_dquot)(struct super_block___36 *, int);
	void (*destroy_dquot)(struct dquot___36 *);
	int (*acquire_dquot)(struct dquot___36 *);
	int (*release_dquot)(struct dquot___36 *);
	int (*mark_dirty)(struct dquot___36 *);
	int (*write_info)(struct super_block___36 *, int);
	qsize_t * (*get_reserved_space)(struct inode___36 *);
	int (*get_projid)(struct inode___36 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___36 *, qsize_t *);
	int (*get_next_id)(struct super_block___36 *, struct kqid *);
};

struct quotactl_ops___36 {
	int (*quota_on)(struct super_block___36 *, int, int, const struct path___36 *);
	int (*quota_off)(struct super_block___36 *, int);
	int (*quota_enable)(struct super_block___36 *, unsigned int);
	int (*quota_disable)(struct super_block___36 *, unsigned int);
	int (*quota_sync)(struct super_block___36 *, int);
	int (*set_info)(struct super_block___36 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___36 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___36 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___36 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___36 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___36 *, unsigned int);
};

struct module_kobject___35 {
	struct kobject___36 kobj;
	struct module___35 *mod;
	struct kobject___36 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___35 {
	struct module___35 *mod;
	struct latch_tree_node node;
};

struct module_layout___35 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___35 mtn;
};

struct module_attribute___35;

struct kernel_param___35;

struct module___35 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___35 mkobj;
	struct module_attribute___35 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___36 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___35 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___35 core_layout;
	struct module_layout___35 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map___27 *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___24 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	int num_static_call_sites;
	struct static_call_site *static_call_sites;
	bool klp;
	bool klp_alive;
	struct klp_modinfo *klp_info;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct wait_page_queue___21 {
	struct page___38 *page;
	int bit_nr;
	wait_queue_entry_t wait;
};

struct writeback_control___24;

struct readahead_control___21;

struct swap_info_struct___17;

struct address_space_operations___36 {
	int (*writepage)(struct page___38 *, struct writeback_control___24 *);
	int (*readpage)(struct file___36 *, struct page___38 *);
	int (*writepages)(struct address_space___36 *, struct writeback_control___24 *);
	int (*set_page_dirty)(struct page___38 *);
	int (*readpages)(struct file___36 *, struct address_space___36 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___21 *);
	int (*write_begin)(struct file___36 *, struct address_space___36 *, loff_t, unsigned int, unsigned int, struct page___38 **, void **);
	int (*write_end)(struct file___36 *, struct address_space___36 *, loff_t, unsigned int, unsigned int, struct page___38 *, void *);
	sector_t (*bmap)(struct address_space___36 *, sector_t);
	void (*invalidatepage)(struct page___38 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___38 *, gfp_t);
	void (*freepage)(struct page___38 *);
	ssize_t (*direct_IO)(struct kiocb___36 *, struct iov_iter___30 *);
	int (*migratepage)(struct address_space___36 *, struct page___38 *, struct page___38 *, enum migrate_mode);
	bool (*isolate_page)(struct page___38 *, isolate_mode_t);
	void (*putback_page)(struct page___38 *);
	int (*launder_page)(struct page___38 *);
	int (*is_partially_uptodate)(struct page___38 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___38 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___36 *, struct page___38 *);
	int (*swap_activate)(struct swap_info_struct___17 *, struct file___36 *, sector_t *);
	void (*swap_deactivate)(struct file___36 *);
};

struct writeback_control___24 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate;
	unsigned int for_background;
	unsigned int tagged_writepages;
	unsigned int for_reclaim;
	unsigned int range_cyclic;
	unsigned int for_sync;
	unsigned int no_cgroup_owner;
	unsigned int punt_to_cgroup;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bdi_writeback___24 *wb;
	struct inode___36 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
};

struct readahead_control___21 {
	struct file___36 *file;
	struct address_space___36 *mapping;
	struct file_ra_state *ra;
	long unsigned int _index;
	unsigned int _nr_pages;
	unsigned int _batch_count;
};

struct bio_vec___30;

struct iov_iter___30 {
	u8 iter_type;
	bool data_source;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___30 *bvec;
		struct xarray *xarray;
		struct pipe_inode_info *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			unsigned int head;
			unsigned int start_head;
		};
		loff_t xarray_start;
	};
};

struct swap_info_struct___17 {
	struct percpu_ref users;
	long unsigned int flags;
	short int prio;
	struct plist_node list;
	signed char type;
	unsigned int max;
	unsigned char *swap_map;
	struct swap_cluster_info *cluster_info;
	struct swap_cluster_list free_clusters;
	unsigned int lowest_bit;
	unsigned int highest_bit;
	unsigned int pages;
	unsigned int inuse_pages;
	unsigned int cluster_next;
	unsigned int cluster_nr;
	unsigned int *cluster_next_cpu;
	struct percpu_cluster *percpu_cluster;
	struct rb_root swap_extent_root;
	struct block_device___25 *bdev;
	struct file___36 *swap_file;
	unsigned int old_block_size;
	struct completion comp;
	long unsigned int *frontswap_map;
	atomic_t frontswap_pages;
	spinlock_t lock;
	spinlock_t cont_lock;
	struct work_struct discard_work;
	struct swap_cluster_list discard_clusters;
	struct plist_node avail_lists[0];
};

struct inode_operations___36 {
	struct dentry___36 * (*lookup)(struct inode___36 *, struct dentry___36 *, unsigned int);
	const char * (*get_link)(struct dentry___36 *, struct inode___36 *, struct delayed_call *);
	int (*permission)(struct user_namespace___2 *, struct inode___36 *, int);
	struct posix_acl * (*get_acl)(struct inode___36 *, int, bool);
	int (*readlink)(struct dentry___36 *, char *, int);
	int (*create)(struct user_namespace___2 *, struct inode___36 *, struct dentry___36 *, umode_t, bool);
	int (*link)(struct dentry___36 *, struct inode___36 *, struct dentry___36 *);
	int (*unlink)(struct inode___36 *, struct dentry___36 *);
	int (*symlink)(struct user_namespace___2 *, struct inode___36 *, struct dentry___36 *, const char *);
	int (*mkdir)(struct user_namespace___2 *, struct inode___36 *, struct dentry___36 *, umode_t);
	int (*rmdir)(struct inode___36 *, struct dentry___36 *);
	int (*mknod)(struct user_namespace___2 *, struct inode___36 *, struct dentry___36 *, umode_t, dev_t);
	int (*rename)(struct user_namespace___2 *, struct inode___36 *, struct dentry___36 *, struct inode___36 *, struct dentry___36 *, unsigned int);
	int (*setattr)(struct user_namespace___2 *, struct dentry___36 *, struct iattr___36 *);
	int (*getattr)(struct user_namespace___2 *, const struct path___36 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___36 *, char *, size_t);
	int (*fiemap)(struct inode___36 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___36 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___36 *, struct dentry___36 *, struct file___36 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace___2 *, struct inode___36 *, struct dentry___36 *, umode_t);
	int (*set_acl)(struct user_namespace___2 *, struct inode___36 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace___2 *, struct dentry___36 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___36 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___36 {
	void (*fl_copy_lock)(struct file_lock___36 *, struct file_lock___36 *);
	void (*fl_release_private)(struct file_lock___36 *);
};

struct lock_manager_operations___36;

struct file_lock___36 {
	struct file_lock___36 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___36 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___36 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___36 *fl_ops;
	const struct lock_manager_operations___36 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___36 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___36 *);
	int (*lm_grant)(struct file_lock___36 *, int);
	bool (*lm_break)(struct file_lock___36 *);
	int (*lm_change)(struct file_lock___36 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___36 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___36 *);
};

struct fasync_struct___36 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___36 *fa_next;
	struct file___36 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___36 {
	struct inode___36 * (*alloc_inode)(struct super_block___36 *);
	void (*destroy_inode)(struct inode___36 *);
	void (*free_inode)(struct inode___36 *);
	void (*dirty_inode)(struct inode___36 *, int);
	int (*write_inode)(struct inode___36 *, struct writeback_control___24 *);
	int (*drop_inode)(struct inode___36 *);
	void (*evict_inode)(struct inode___36 *);
	void (*put_super)(struct super_block___36 *);
	int (*sync_fs)(struct super_block___36 *, int);
	int (*freeze_super)(struct super_block___36 *);
	int (*freeze_fs)(struct super_block___36 *);
	int (*thaw_super)(struct super_block___36 *);
	int (*unfreeze_fs)(struct super_block___36 *);
	int (*statfs)(struct dentry___36 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___36 *, int *, char *);
	void (*umount_begin)(struct super_block___36 *);
	int (*show_options)(struct seq_file___34 *, struct dentry___36 *);
	int (*show_devname)(struct seq_file___34 *, struct dentry___36 *);
	int (*show_path)(struct seq_file___34 *, struct dentry___36 *);
	int (*show_stats)(struct seq_file___34 *, struct dentry___36 *);
	ssize_t (*quota_read)(struct super_block___36 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___36 *, int, const char *, size_t, loff_t);
	struct dquot___36 ** (*get_dquots)(struct inode___36 *);
	long int (*nr_cached_objects)(struct super_block___36 *, struct shrink_control___24 *);
	long int (*free_cached_objects)(struct super_block___36 *, struct shrink_control___24 *);
	struct file___36 * (*real_loop)(struct file___36 *);
};

struct wakeup_source___38;

struct dev_pm_qos___8;

struct dev_pm_info___38 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___38 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___38 *, s32);
	struct dev_pm_qos___8 *qos;
};

struct device_type___38;

struct bus_type___38;

struct device_driver___38;

struct dev_pm_domain___38;

struct device_node___21;

struct fwnode_handle___35;

struct class___38;

struct attribute_group___36;

struct device___38 {
	struct kobject___36 kobj;
	struct device___38 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___38 *type;
	struct bus_type___38 *bus;
	struct device_driver___38 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___38 power;
	struct dev_pm_domain___38 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___21 *of_node;
	struct fwnode_handle___35 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___38 *class;
	const struct attribute_group___36 **groups;
	void (*release)(struct device___38 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct block_device___25 {
	sector_t bd_start_sect;
	struct disk_stats *bd_stats;
	long unsigned int bd_stamp;
	bool bd_read_only;
	dev_t bd_dev;
	int bd_openers;
	struct inode___36 *bd_inode;
	struct super_block___36 *bd_super;
	void *bd_claiming;
	struct device___38 bd_device;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct kobject___36 *bd_holder_dir;
	u8 bd_partno;
	spinlock_t bd_size_lock;
	struct gendisk___25 *bd_disk;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	struct super_block___36 *bd_fsfreeze_sb;
	struct partition_meta_info *bd_meta_info;
};

typedef void (*poll_queue_proc___27)(struct file___36 *, wait_queue_head_t *, struct poll_table_struct___27 *);

struct poll_table_struct___27 {
	poll_queue_proc___27 _qproc;
	__poll_t _key;
};

struct seq_file___34 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___34 *op;
	int poll_event;
	const struct file___36 *file;
	void *private;
};

typedef void bio_end_io_t___25(struct bio___25 *);

struct bio_vec___30 {
	struct page___38 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___25;

struct bio___25 {
	struct bio___25 *bi_next;
	struct block_device___25 *bi_bdev;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	atomic_t __bi_remaining;
	struct bvec_iter bi_iter;
	bio_end_io_t___25 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___24 *bi_blkg;
	struct bio_issue bi_issue;
	u64 bi_iocost_cost;
	struct bio_crypt_ctx *bi_crypt_context;
	union {
		struct bio_integrity_payload___25 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___30 *bi_io_vec;
	struct bio_set___25 *bi_pool;
	struct bio_vec___30 bi_inline_vecs[0];
};

struct kernfs_root___36;

struct kernfs_elem_dir___36 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___36 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___36;

struct kernfs_root___36 {
	struct kernfs_node___36 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___36 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___36 {
	struct kernfs_node___36 *target_kn;
};

struct kernfs_ops___36;

struct kernfs_elem_attr___36 {
	const struct kernfs_ops___36 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___36 *notify_next;
};

struct kernfs_node___36 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___36 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___36 dir;
		struct kernfs_elem_symlink___36 symlink;
		struct kernfs_elem_attr___36 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___36;

struct kernfs_ops___36 {
	int (*open)(struct kernfs_open_file___36 *);
	void (*release)(struct kernfs_open_file___36 *);
	int (*seq_show)(struct seq_file___34 *, void *);
	void * (*seq_start)(struct seq_file___34 *, loff_t *);
	void * (*seq_next)(struct seq_file___34 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___34 *, void *);
	ssize_t (*read)(struct kernfs_open_file___36 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___36 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___36 *, struct poll_table_struct___27 *);
	int (*mmap)(struct kernfs_open_file___36 *, struct vm_area_struct___39 *);
};

struct kernfs_syscall_ops___36 {
	int (*show_options)(struct seq_file___34 *, struct kernfs_root___36 *);
	int (*mkdir)(struct kernfs_node___36 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___36 *);
	int (*rename)(struct kernfs_node___36 *, struct kernfs_node___36 *, const char *);
	int (*show_path)(struct seq_file___34 *, struct kernfs_node___36 *, struct kernfs_root___36 *);
};

struct kernfs_open_file___36 {
	struct kernfs_node___36 *kn;
	struct file___36 *file;
	struct seq_file___34 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped;
	bool released;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___36 *vm_ops;
};

struct cgroup_namespace___30 {
	struct ns_common___5 ns;
	struct user_namespace___2 *user_ns;
	struct ucounts___2 *ucounts;
	struct css_set___30 *root_cset;
};

struct bin_attribute___36;

struct attribute_group___36 {
	const char *name;
	umode_t (*is_visible)(struct kobject___36 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___36 *, struct bin_attribute___36 *, int);
	struct attribute **attrs;
	struct bin_attribute___36 **bin_attrs;
};

struct bin_attribute___36 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___36 * (*f_mapping)();
	ssize_t (*read)(struct file___36 *, struct kobject___36 *, struct bin_attribute___36 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___36 *, struct kobject___36 *, struct bin_attribute___36 *, char *, loff_t, size_t);
	int (*mmap)(struct file___36 *, struct kobject___36 *, struct bin_attribute___36 *, struct vm_area_struct___39 *);
};

struct sysfs_ops___35 {
	ssize_t (*show)(struct kobject___36 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___36 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___35;

struct kset___35 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___36 kobj;
	const struct kset_uevent_ops___35 *uevent_ops;
};

struct kobj_type___35 {
	void (*release)(struct kobject___36 *);
	const struct sysfs_ops___35 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___36 **default_groups;
	const struct kobj_ns_type_operations___3 * (*child_ns_type)(struct kobject___36 *);
	const void * (*namespace)(struct kobject___36 *);
	void (*get_ownership)(struct kobject___36 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___35 {
	int (* const filter)(struct kset___35 *, struct kobject___36 *);
	const char * (* const name)(struct kset___35 *, struct kobject___36 *);
	int (* const uevent)(struct kset___35 *, struct kobject___36 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___35 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___35 *);
	int (*get)(char *, const struct kernel_param___35 *);
	void (*free)(void *);
};

struct kparam_array___35;

struct kernel_param___35 {
	const char *name;
	struct module___35 *mod;
	const struct kernel_param_ops___35 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___35 *arr;
	};
};

struct kparam_array___35 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___35 *ops;
	void *elem;
};

struct module_attribute___35 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___35 *, struct module_kobject___35 *, char *);
	ssize_t (*store)(struct module_attribute___35 *, struct module_kobject___35 *, const char *, size_t);
	void (*setup)(struct module___35 *, const char *);
	int (*test)(struct module___35 *);
	void (*free)(struct module___35 *);
};

struct trace_event_class___24;

struct trace_event_call___24 {
	struct list_head list;
	struct trace_event_class___24 *class;
	union {
		char *name;
		struct tracepoint___27 *tp;
	};
	struct trace_event event;
	char *print_fmt;
	struct event_filter *filter;
	union {
		void *module;
		atomic_t refcnt;
	};
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
	struct bpf_prog_array___4 *prog_array;
	int (*perf_perm)(struct trace_event_call___24 *, struct perf_event___24 *);
};

struct cftype___30;

struct cgroup_subsys___30 {
	struct cgroup_subsys_state___30 * (*css_alloc)(struct cgroup_subsys_state___30 *);
	int (*css_online)(struct cgroup_subsys_state___30 *);
	void (*css_offline)(struct cgroup_subsys_state___30 *);
	void (*css_released)(struct cgroup_subsys_state___30 *);
	void (*css_free)(struct cgroup_subsys_state___30 *);
	void (*css_reset)(struct cgroup_subsys_state___30 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___30 *, int);
	int (*css_extra_stat_show)(struct seq_file___34 *, struct cgroup_subsys_state___30 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___39 *, struct css_set___30 *);
	void (*cancel_fork)(struct task_struct___39 *, struct css_set___30 *);
	void (*fork)(struct task_struct___39 *);
	void (*exit)(struct task_struct___39 *);
	void (*release)(struct task_struct___39 *);
	void (*bind)(struct cgroup_subsys_state___30 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___30 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___30 *dfl_cftypes;
	struct cftype___30 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___30 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___30 *updated_children;
	struct cgroup___30 *updated_next;
};

struct cgroup_root___30 {
	struct kernfs_root___36 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___30 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___30 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___30 *ss;
	struct list_head node;
	struct kernfs_ops___36 *kf_ops;
	int (*open)(struct kernfs_open_file___36 *);
	void (*release)(struct kernfs_open_file___36 *);
	u64 (*read_u64)(struct cgroup_subsys_state___30 *, struct cftype___30 *);
	s64 (*read_s64)(struct cgroup_subsys_state___30 *, struct cftype___30 *);
	int (*seq_show)(struct seq_file___34 *, void *);
	void * (*seq_start)(struct seq_file___34 *, loff_t *);
	void * (*seq_next)(struct seq_file___34 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___34 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___30 *, struct cftype___30 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___30 *, struct cftype___30 *, s64);
	ssize_t (*write)(struct kernfs_open_file___36 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___36 *, struct poll_table_struct___27 *);
};

struct dev_pm_ops___38 {
	int (*prepare)(struct device___38 *);
	void (*complete)(struct device___38 *);
	int (*suspend)(struct device___38 *);
	int (*resume)(struct device___38 *);
	int (*freeze)(struct device___38 *);
	int (*thaw)(struct device___38 *);
	int (*poweroff)(struct device___38 *);
	int (*restore)(struct device___38 *);
	int (*suspend_late)(struct device___38 *);
	int (*resume_early)(struct device___38 *);
	int (*freeze_late)(struct device___38 *);
	int (*thaw_early)(struct device___38 *);
	int (*poweroff_late)(struct device___38 *);
	int (*restore_early)(struct device___38 *);
	int (*suspend_noirq)(struct device___38 *);
	int (*resume_noirq)(struct device___38 *);
	int (*freeze_noirq)(struct device___38 *);
	int (*thaw_noirq)(struct device___38 *);
	int (*poweroff_noirq)(struct device___38 *);
	int (*restore_noirq)(struct device___38 *);
	int (*runtime_suspend)(struct device___38 *);
	int (*runtime_resume)(struct device___38 *);
	int (*runtime_idle)(struct device___38 *);
};

struct wakeup_source___38 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___38 *dev;
	bool active;
	bool autosleep_enabled;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_qos_request___8;

struct dev_pm_qos___8 {
	struct pm_qos_constraints resume_latency;
	struct pm_qos_constraints latency_tolerance;
	struct freq_constraints freq;
	struct pm_qos_flags flags;
	struct dev_pm_qos_request___8 *resume_latency_req;
	struct dev_pm_qos_request___8 *latency_tolerance_req;
	struct dev_pm_qos_request___8 *flags_req;
};

struct dev_pm_domain___38 {
	struct dev_pm_ops___38 ops;
	int (*start)(struct device___38 *);
	void (*detach)(struct device___38 *, bool);
	int (*activate)(struct device___38 *);
	void (*sync)(struct device___38 *);
	void (*dismiss)(struct device___38 *);
};

struct bus_type___38 {
	const char *name;
	const char *dev_name;
	struct device___38 *dev_root;
	const struct attribute_group___36 **bus_groups;
	const struct attribute_group___36 **dev_groups;
	const struct attribute_group___36 **drv_groups;
	int (*match)(struct device___38 *, struct device_driver___38 *);
	int (*uevent)(struct device___38 *, struct kobj_uevent_env *);
	int (*probe)(struct device___38 *);
	void (*sync_state)(struct device___38 *);
	void (*remove)(struct device___38 *);
	void (*shutdown)(struct device___38 *);
	int (*online)(struct device___38 *);
	int (*offline)(struct device___38 *);
	int (*suspend)(struct device___38 *, pm_message_t);
	int (*resume)(struct device___38 *);
	int (*num_vf)(struct device___38 *);
	int (*dma_configure)(struct device___38 *);
	const struct dev_pm_ops___38 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___38 {
	const char *name;
	struct bus_type___38 *bus;
	struct module___35 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___38 *);
	void (*sync_state)(struct device___38 *);
	int (*remove)(struct device___38 *);
	void (*shutdown)(struct device___38 *);
	int (*suspend)(struct device___38 *, pm_message_t);
	int (*resume)(struct device___38 *);
	const struct attribute_group___36 **groups;
	const struct attribute_group___36 **dev_groups;
	const struct dev_pm_ops___38 *pm;
	void (*coredump)(struct device___38 *);
	struct driver_private *p;
};

struct device_type___38 {
	const char *name;
	const struct attribute_group___36 **groups;
	int (*uevent)(struct device___38 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___38 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___38 *);
	const struct dev_pm_ops___38 *pm;
};

struct class___38 {
	const char *name;
	struct module___35 *owner;
	const struct attribute_group___36 **class_groups;
	const struct attribute_group___36 **dev_groups;
	struct kobject___36 *dev_kobj;
	int (*dev_uevent)(struct device___38 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___38 *, umode_t *);
	void (*class_release)(struct class___38 *);
	void (*dev_release)(struct device___38 *);
	int (*shutdown_pre)(struct device___38 *);
	const struct kobj_ns_type_operations___3 *ns_type;
	const void * (*namespace)(struct device___38 *);
	void (*get_ownership)(struct device___38 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___38 *pm;
	struct subsys_private *p;
};

struct fwnode_operations___35;

struct fwnode_handle___35 {
	struct fwnode_handle___35 *secondary;
	const struct fwnode_operations___35 *ops;
	struct device___38 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct device_node___21 {
	const char *name;
	phandle phandle;
	const char *full_name;
	struct fwnode_handle___35 fwnode;
	struct property *properties;
	struct property *deadprops;
	struct device_node___21 *parent;
	struct device_node___21 *child;
	struct device_node___21 *sibling;
	long unsigned int _flags;
	void *data;
};

struct block_device_operations___25;

struct gendisk___25 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	short unsigned int events;
	short unsigned int event_flags;
	struct xarray part_tbl;
	struct block_device___25 *part0;
	const struct block_device_operations___25 *fops;
	struct request_queue___25 *queue;
	void *private_data;
	int flags;
	long unsigned int state;
	struct mutex open_mutex;
	unsigned int open_partitions;
	struct backing_dev_info___24 *bdi;
	struct kobject___36 *slave_dir;
	struct list_head slave_bdevs;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___36 integrity_kobj;
	struct cdrom_device_info *cdi;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	u64 diskseq;
};

struct bio_integrity_payload___25 {
	struct bio___25 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___30 *bip_vec;
	struct bio_vec___30 bip_inline_vecs[0];
};

struct blkcg___24;

struct blkg_policy_data___24;

struct blkcg_gq___24 {
	struct request_queue___25 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___24 *blkcg;
	struct blkcg_gq___24 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_iostat_set *iostat_cpu;
	struct blkg_iostat_set iostat;
	struct blkg_policy_data___24 *pd[6];
	spinlock_t async_bio_lock;
	struct bio_list___25 async_bios;
	struct work_struct async_bio_work;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
	struct callback_head callback_head;
};

typedef void integrity_prepare_fn___25(struct request___25 *);

typedef void integrity_complete_fn___25(struct request___25 *, unsigned int);

struct blk_integrity_profile___25 {
	integrity_processing_fn *generate_fn;
	integrity_processing_fn *verify_fn;
	integrity_prepare_fn___25 *prepare_fn;
	integrity_complete_fn___25 *complete_fn;
	const char *name;
};

struct block_device_operations___25 {
	blk_qc_t (*submit_bio)(struct bio___25 *);
	int (*open)(struct block_device___25 *, fmode_t);
	void (*release)(struct gendisk___25 *, fmode_t);
	int (*rw_page)(struct block_device___25 *, sector_t, struct page___38 *, unsigned int);
	int (*ioctl)(struct block_device___25 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___25 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___25 *, unsigned int);
	void (*unlock_native_capacity)(struct gendisk___25 *);
	int (*getgeo)(struct block_device___25 *, struct hd_geometry *);
	int (*set_read_only)(struct block_device___25 *, bool);
	void (*swap_slot_free_notify)(struct block_device___25 *, long unsigned int);
	int (*report_zones)(struct gendisk___25 *, sector_t, unsigned int, report_zones_cb, void *);
	char * (*devnode)(struct gendisk___25 *, umode_t *);
	struct module___35 *owner;
	const struct pr_ops *pr_ops;
	int (*alternative_gpt_sector)(struct gendisk___25 *, sector_t *);
};

struct fwnode_reference_args___35;

struct fwnode_endpoint___35;

struct fwnode_operations___35 {
	struct fwnode_handle___35 * (*get)(struct fwnode_handle___35 *);
	void (*put)(struct fwnode_handle___35 *);
	bool (*device_is_available)(const struct fwnode_handle___35 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___35 *, const struct device___38 *);
	bool (*property_present)(const struct fwnode_handle___35 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___35 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___35 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___35 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___35 *);
	struct fwnode_handle___35 * (*get_parent)(const struct fwnode_handle___35 *);
	struct fwnode_handle___35 * (*get_next_child_node)(const struct fwnode_handle___35 *, struct fwnode_handle___35 *);
	struct fwnode_handle___35 * (*get_named_child_node)(const struct fwnode_handle___35 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___35 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___35 *);
	struct fwnode_handle___35 * (*graph_get_next_endpoint)(const struct fwnode_handle___35 *, struct fwnode_handle___35 *);
	struct fwnode_handle___35 * (*graph_get_remote_endpoint)(const struct fwnode_handle___35 *);
	struct fwnode_handle___35 * (*graph_get_port_parent)(struct fwnode_handle___35 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___35 *, struct fwnode_endpoint___35 *);
	int (*add_links)(struct fwnode_handle___35 *);
};

struct fwnode_endpoint___35 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___35 *local_fwnode;
};

struct fwnode_reference_args___35 {
	struct fwnode_handle___35 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

typedef void rq_end_io_fn___25(struct request___25 *, blk_status_t);

struct request___25 {
	struct request_queue___25 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int tag;
	int internal_tag;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___25 *bio;
	struct bio___25 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct llist_node ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___30 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___25 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___25 *saved_end_io;
		} flush;
	};
	struct gendisk___25 *rq_disk;
	struct block_device___25 *part;
	u64 alloc_time_ns;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int stats_sectors;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	struct bio_crypt_ctx *crypt_ctx;
	struct blk_ksm_keyslot *crypt_keyslot;
	short unsigned int write_hint;
	short unsigned int ioprio;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___25 *end_io;
	void *end_io_data;
};

struct elevator_type___25;

struct elevator_mq_ops___25 {
	int (*init_sched)(struct request_queue___25 *, struct elevator_type___25 *);
	void (*exit_sched)(struct elevator_queue___25 *);
	int (*init_hctx)(struct blk_mq_hw_ctx *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx *, unsigned int);
	void (*depth_updated)(struct blk_mq_hw_ctx *);
	bool (*allow_merge)(struct request_queue___25 *, struct request___25 *, struct bio___25 *);
	bool (*bio_merge)(struct request_queue___25 *, struct bio___25 *, unsigned int);
	int (*request_merge)(struct request_queue___25 *, struct request___25 **, struct bio___25 *);
	void (*request_merged)(struct request_queue___25 *, struct request___25 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___25 *, struct request___25 *, struct request___25 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___25 *);
	void (*finish_request)(struct request___25 *);
	void (*insert_requests)(struct blk_mq_hw_ctx *, struct list_head *, bool);
	struct request___25 * (*dispatch_request)(struct blk_mq_hw_ctx *);
	bool (*has_work)(struct blk_mq_hw_ctx *);
	void (*completed_request)(struct request___25 *, u64);
	void (*requeue_request)(struct request___25 *);
	struct request___25 * (*former_request)(struct request_queue___25 *, struct request___25 *);
	struct request___25 * (*next_request)(struct request_queue___25 *, struct request___25 *);
	void (*init_icq)(struct io_cq___25 *);
	void (*exit_icq)(struct io_cq___25 *);
};

struct elv_fs_entry___25;

struct elevator_type___25 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___25 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___25 *elevator_attrs;
	const char *elevator_name;
	const char *elevator_alias;
	const unsigned int elevator_features;
	struct module___35 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
};

struct elevator_queue___25 {
	struct elevator_type___25 *type;
	void *elevator_data;
	struct kobject___36 kobj;
	struct mutex sysfs_lock;
	unsigned int registered;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hlist_head hash[64];
};

struct elv_fs_entry___25 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___25 *, char *);
	ssize_t (*store)(struct elevator_queue___25 *, const char *, size_t);
};

struct blkcg_policy_data___24;

struct blkcg___24 {
	struct cgroup_subsys_state___30 css;
	spinlock_t lock;
	refcount_t online_pin;
	struct xarray blkg_tree;
	struct blkcg_gq___24 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___24 *cpd[6];
	struct list_head all_blkcgs_node;
	char fc_app_id[129];
	struct list_head cgwb_list;
};

struct blkcg_policy_data___24 {
	struct blkcg___24 *blkcg;
	int plid;
};

struct blkg_policy_data___24 {
	struct blkcg_gq___24 *blkg;
	int plid;
};

struct mem_cgroup_reclaim_iter___24 {
	struct mem_cgroup___24 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___24 {
	struct lruvec___25 lruvec;
	struct lruvec_stats_percpu *lruvec_stats_percpu;
	struct lruvec_stats lruvec_stats;
	long unsigned int lru_zone_size[25];
	struct mem_cgroup_reclaim_iter___24 iter;
	struct shrinker_info *shrinker_info;
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	struct mem_cgroup___24 *memcg;
};

struct obj_cgroup___24 {
	struct percpu_ref refcnt;
	struct mem_cgroup___24 *memcg;
	atomic_t nr_charged_bytes;
	union {
		struct list_head list;
		struct callback_head rcu;
	};
};

struct perf_cpu_context___24;

struct perf_output_handle___24;

struct pmu___24 {
	struct list_head entry;
	struct module___35 *module;
	struct device___38 *dev;
	const struct attribute_group___36 **attr_groups;
	const struct attribute_group___36 **attr_update;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___24 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___24 *);
	void (*pmu_disable)(struct pmu___24 *);
	int (*event_init)(struct perf_event___24 *);
	void (*event_mapped)(struct perf_event___24 *, struct mm_struct___39 *);
	void (*event_unmapped)(struct perf_event___24 *, struct mm_struct___39 *);
	int (*add)(struct perf_event___24 *, int);
	void (*del)(struct perf_event___24 *, int);
	void (*start)(struct perf_event___24 *, int);
	void (*stop)(struct perf_event___24 *, int);
	void (*read)(struct perf_event___24 *);
	void (*start_txn)(struct pmu___24 *, unsigned int);
	int (*commit_txn)(struct pmu___24 *);
	void (*cancel_txn)(struct pmu___24 *);
	int (*event_idx)(struct perf_event___24 *);
	void (*sched_task)(struct perf_event_context___24 *, bool);
	struct kmem_cache *task_ctx_cache;
	void (*swap_task_ctx)(struct perf_event_context___24 *, struct perf_event_context___24 *);
	void * (*setup_aux)(struct perf_event___24 *, void **, int, bool);
	void (*free_aux)(void *);
	long int (*snapshot_aux)(struct perf_event___24 *, struct perf_output_handle___24 *, long unsigned int);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___24 *);
	int (*aux_output_match)(struct perf_event___24 *);
	int (*filter_match)(struct perf_event___24 *);
	int (*check_period)(struct perf_event___24 *, u64);
};

struct perf_cpu_context___24 {
	struct perf_event_context___24 ctx;
	struct perf_event_context___24 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___24 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
	int heap_size;
	struct perf_event___24 **heap;
	struct perf_event___24 *heap_default[2];
};

struct perf_output_handle___24 {
	struct perf_event___24 *event;
	struct perf_buffer *rb;
	long unsigned int wakeup;
	long unsigned int size;
	u64 aux_flags;
	union {
		void *addr;
		long unsigned int head;
	};
	int page;
};

struct perf_cgroup___24 {
	struct cgroup_subsys_state___30 css;
	struct perf_cgroup_info *info;
};

struct trace_event_fields___24 {
	const char *type;
	union {
		struct {
			const char *name;
			const int size;
			const int align;
			const int is_signed;
			const int filter_type;
		};
		int (*define_fields)(struct trace_event_call___24 *);
	};
};

struct trace_event_class___24 {
	const char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct trace_event_call___24 *, enum trace_reg, void *);
	struct trace_event_fields___24 *fields_array;
	struct list_head * (*get_fields)(struct trace_event_call___24 *);
	struct list_head fields;
	int (*raw_init)(struct trace_event_call___24 *);
};

struct dev_pm_qos_request___8 {
	enum dev_pm_qos_req_type type;
	union {
		struct plist_node pnode;
		struct pm_qos_flags_request flr;
		struct freq_qos_request freq;
	} data;
	struct device___38 *dev;
};

struct pv_cpu_ops___31 {
	void (*io_delay)();
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	void (*write_cr4)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___25 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(long unsigned int);
	void (*invalidate_io_bitmap)();
	void (*update_io_bitmap)();
	void (*wbinvd)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int);
	void (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_msr_safe)(unsigned int, int *);
	int (*write_msr_safe)(unsigned int, unsigned int, unsigned int);
	u64 (*read_pmc)(int);
	void (*start_context_switch)(struct task_struct___39 *);
	void (*end_context_switch)(struct task_struct___39 *);
};

struct pv_mmu_ops___33 {
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_one_user)(long unsigned int);
	void (*flush_tlb_multi)(const struct cpumask *, const struct flush_tlb_info___3 *);
	void (*tlb_remove_table)(struct mmu_gather *, void *);
	void (*exit_mmap)(struct mm_struct___39 *);
	struct paravirt_callee_save read_cr2;
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___39 *, struct mm_struct___39 *);
	void (*dup_mmap)(struct mm_struct___39 *, struct mm_struct___39 *);
	int (*pgd_alloc)(struct mm_struct___39 *);
	void (*pgd_free)(struct mm_struct___39 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___39 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___39 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___39 *, long unsigned int);
	void (*alloc_p4d)(struct mm_struct___39 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*release_p4d)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	pte_t (*ptep_modify_prot_start)(struct vm_area_struct___39 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct vm_area_struct___39 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_p4d)(p4d_t *, p4d_t);
	struct paravirt_callee_save p4d_val;
	struct paravirt_callee_save make_p4d;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

struct paravirt_patch_template___33 {
	struct pv_cpu_ops___31 cpu;
	struct pv_irq_ops irq;
	struct pv_mmu_ops___33 mmu;
	struct pv_lock_ops lock;
};

struct swait_queue___3 {
	struct task_struct___39 *task;
	struct list_head task_list;
};

struct platform_suspend_ops {
	int (*valid)(suspend_state_t);
	int (*begin)(suspend_state_t);
	int (*prepare)();
	int (*prepare_late)();
	int (*enter)(suspend_state_t);
	void (*wake)();
	void (*finish)();
	bool (*suspend_again)();
	void (*end)();
	void (*recover)();
};

struct platform_s2idle_ops {
	int (*begin)();
	int (*prepare)();
	int (*prepare_late)();
	bool (*wake)();
	void (*restore_early)();
	void (*restore)();
	void (*end)();
};

struct kobj_attribute___4 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___36 *, struct kobj_attribute___4 *, char *);
	ssize_t (*store)(struct kobject___36 *, struct kobj_attribute___4 *, const char *, size_t);
};

struct platform_hibernation_ops {
	int (*begin)(pm_message_t);
	void (*end)();
	int (*pre_snapshot)();
	void (*finish)();
	int (*prepare)();
	int (*enter)();
	void (*leave)();
	int (*pre_restore)();
	void (*restore_cleanup)();
	void (*recover)();
};

enum {
	HIBERNATION_INVALID = 0,
	HIBERNATION_PLATFORM = 1,
	HIBERNATION_SHUTDOWN = 2,
	HIBERNATION_REBOOT = 3,
	HIBERNATION_SUSPEND = 4,
	HIBERNATION_TEST_RESUME = 5,
	__HIBERNATION_AFTER_LAST = 6,
};

typedef struct pglist_data___15 pg_data_t___5;

struct pbe {
	void *address;
	void *orig_address;
	struct pbe *next;
};

struct swsusp_info {
	struct new_utsname uts;
	u32 version_code;
	long unsigned int num_physpages;
	int cpus;
	long unsigned int image_pages;
	long unsigned int pages;
	long unsigned int size;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct snapshot_handle {
	unsigned int cur;
	void *buffer;
	int sync_read;
};

struct linked_page {
	struct linked_page *next;
	char data[4088];
};

struct chain_allocator {
	struct linked_page *chain;
	unsigned int used_space;
	gfp_t gfp_mask;
	int safe_needed;
};

struct rtree_node {
	struct list_head list;
	long unsigned int *data;
};

struct mem_zone_bm_rtree {
	struct list_head list;
	struct list_head nodes;
	struct list_head leaves;
	long unsigned int start_pfn;
	long unsigned int end_pfn;
	struct rtree_node *rtree;
	int levels;
	unsigned int blocks;
};

struct bm_position {
	struct mem_zone_bm_rtree *zone;
	struct rtree_node *node;
	long unsigned int node_pfn;
	int node_bit;
};

struct memory_bitmap {
	struct list_head zones;
	struct linked_page *p_list;
	struct bm_position cur;
};

struct mem_extent {
	struct list_head hook;
	long unsigned int start;
	long unsigned int end;
};

struct nosave_region {
	struct list_head list;
	long unsigned int start_pfn;
	long unsigned int end_pfn;
};

typedef struct {
	long unsigned int val;
} swp_entry_t;

enum {
	BIO_NO_PAGE_REF = 0,
	BIO_CLONED = 1,
	BIO_BOUNCED = 2,
	BIO_WORKINGSET = 3,
	BIO_QUIET = 4,
	BIO_CHAIN = 5,
	BIO_REFFED = 6,
	BIO_THROTTLED = 7,
	BIO_TRACE_COMPLETION = 8,
	BIO_CGROUP_ACCT = 9,
	BIO_TRACKED = 10,
	BIO_REMAPPED = 11,
	BIO_ZONE_WRITE_LOCKED = 12,
	BIO_PERCPU_CACHE = 13,
	BIO_FLAG_LAST = 14,
};

enum req_opf {
	REQ_OP_READ = 0,
	REQ_OP_WRITE = 1,
	REQ_OP_FLUSH = 2,
	REQ_OP_DISCARD = 3,
	REQ_OP_SECURE_ERASE = 5,
	REQ_OP_WRITE_SAME = 7,
	REQ_OP_WRITE_ZEROES = 9,
	REQ_OP_ZONE_OPEN = 10,
	REQ_OP_ZONE_CLOSE = 11,
	REQ_OP_ZONE_FINISH = 12,
	REQ_OP_ZONE_APPEND = 13,
	REQ_OP_ZONE_RESET = 15,
	REQ_OP_ZONE_RESET_ALL = 17,
	REQ_OP_DRV_IN = 34,
	REQ_OP_DRV_OUT = 35,
	REQ_OP_LAST = 36,
};

enum req_flag_bits {
	__REQ_FAILFAST_DEV = 8,
	__REQ_FAILFAST_TRANSPORT = 9,
	__REQ_FAILFAST_DRIVER = 10,
	__REQ_SYNC = 11,
	__REQ_META = 12,
	__REQ_PRIO = 13,
	__REQ_NOMERGE = 14,
	__REQ_IDLE = 15,
	__REQ_INTEGRITY = 16,
	__REQ_FUA = 17,
	__REQ_PREFLUSH = 18,
	__REQ_RAHEAD = 19,
	__REQ_BACKGROUND = 20,
	__REQ_NOWAIT = 21,
	__REQ_CGROUP_PUNT = 22,
	__REQ_NOUNMAP = 23,
	__REQ_HIPRI = 24,
	__REQ_DRV = 25,
	__REQ_SWAP = 26,
	__REQ_NR_BITS = 27,
};

struct swap_map_page {
	sector_t entries[511];
	sector_t next_swap;
};

struct swap_map_page_list {
	struct swap_map_page *map;
	struct swap_map_page_list *next;
};

struct swap_map_handle {
	struct swap_map_page *cur;
	struct swap_map_page_list *maps;
	sector_t cur_swap;
	sector_t first_sector;
	unsigned int k;
	long unsigned int reqd_free_pages;
	u32 crc32;
};

struct swsusp_header {
	char reserved[4060];
	u32 crc32;
	sector_t image;
	unsigned int flags;
	char orig_sig[10];
	char sig[10];
};

struct swsusp_extent {
	struct rb_node node;
	long unsigned int start;
	long unsigned int end;
};

struct hib_bio_batch {
	atomic_t count;
	wait_queue_head_t wait;
	blk_status_t error;
	struct blk_plug plug;
};

struct crc_data {
	struct task_struct___36 *thr;
	atomic_t ready;
	atomic_t stop;
	unsigned int run_threads;
	wait_queue_head_t go;
	wait_queue_head_t done;
	u32 *crc32;
	size_t *unc_len[3];
	unsigned char *unc[3];
};

struct cmp_data {
	struct task_struct___36 *thr;
	atomic_t ready;
	atomic_t stop;
	int ret;
	wait_queue_head_t go;
	wait_queue_head_t done;
	size_t unc_len;
	size_t cmp_len;
	unsigned char unc[131072];
	unsigned char cmp[143360];
	unsigned char wrk[16384];
};

struct dec_data {
	struct task_struct___36 *thr;
	atomic_t ready;
	atomic_t stop;
	int ret;
	wait_queue_head_t go;
	wait_queue_head_t done;
	size_t unc_len;
	size_t cmp_len;
	unsigned char unc[131072];
	unsigned char cmp[143360];
};

typedef s64 compat_loff_t;

struct resume_swap_area {
	__kernel_loff_t offset;
	__u32 dev;
} __attribute__((packed));

struct snapshot_data {
	struct snapshot_handle handle;
	int swap;
	int mode;
	bool frozen;
	bool ready;
	bool platform_support;
	bool free_bitmaps;
	dev_t dev;
};

struct compat_resume_swap_area {
	compat_loff_t offset;
	u32 dev;
} __attribute__((packed));

struct wakelock {
	char *name;
	struct rb_node node;
	struct wakeup_source___38 *ws;
	struct list_head lru;
};

struct sysrq_key_op {
	void (* const handler)(int);
	const char * const help_msg;
	const char * const action_msg;
	const int enable_mask;
};

struct em_data_callback {
	int (*active_power)(long unsigned int *, long unsigned int *, struct device___34 *);
};

struct dentry___37;

struct super_block___37;

struct module___36;

struct file_system_type___37 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___37 * (*mount)(struct file_system_type___37 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___37 *);
	struct module___36 *owner;
	struct file_system_type___37 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___37;

struct kiocb___37;

struct poll_table_struct___28;

struct vm_area_struct___40;

struct inode___37;

struct file_lock___37;

struct page___39;

struct seq_file___35;

struct file_operations___37 {
	struct module___36 *owner;
	loff_t (*llseek)(struct file___37 *, loff_t, int);
	ssize_t (*read)(struct file___37 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___37 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___37 *, struct iov_iter___30 *);
	ssize_t (*write_iter)(struct kiocb___37 *, struct iov_iter___30 *);
	int (*iopoll)(struct kiocb___37 *, bool);
	int (*iterate)(struct file___37 *, struct dir_context *);
	int (*iterate_shared)(struct file___37 *, struct dir_context *);
	__poll_t (*poll)(struct file___37 *, struct poll_table_struct___28 *);
	long int (*unlocked_ioctl)(struct file___37 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___37 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___37 *, struct vm_area_struct___40 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___37 *, struct file___37 *);
	int (*flush)(struct file___37 *, fl_owner_t);
	int (*release)(struct inode___37 *, struct file___37 *);
	int (*fsync)(struct file___37 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___37 *, int);
	int (*lock)(struct file___37 *, int, struct file_lock___37 *);
	ssize_t (*sendpage)(struct file___37 *, struct page___39 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___37 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___37 *, long unsigned int);
	int (*flock)(struct file___37 *, int, struct file_lock___37 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___37 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___37 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___37 *, long int, struct file_lock___37 **, void **);
	long int (*fallocate)(struct file___37 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___35 *, struct file___37 *);
	ssize_t (*copy_file_range)(struct file___37 *, loff_t, struct file___37 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___37 *, loff_t, struct file___37 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___37 *, loff_t, loff_t, int);
};

struct static_call_mod___28 {
	struct static_call_mod___28 *next;
	struct module___36 *mod;
	struct static_call_site *sites;
};

struct static_call_key___28 {
	void *func;
	union {
		long unsigned int type;
		struct static_call_mod___28 *mods;
		struct static_call_site *sites;
	};
};

struct vmacache___39 {
	u64 seqnum;
	struct vm_area_struct___40 *vmas[4];
};

struct page_frag___39 {
	struct page___39 *page;
	__u32 offset;
	__u32 size;
};

struct perf_event___25;

struct thread_struct___26 {
	struct desc_struct tls_array[3];
	long unsigned int sp;
	short unsigned int es;
	short unsigned int ds;
	short unsigned int fsindex;
	short unsigned int gsindex;
	long unsigned int fsbase;
	long unsigned int gsbase;
	struct perf_event___25 *ptrace_bps[4];
	long unsigned int virtual_dr6;
	long unsigned int ptrace_dr7;
	long unsigned int cr2;
	long unsigned int trap_nr;
	long unsigned int error_code;
	struct io_bitmap *io_bitmap;
	long unsigned int iopl_emul;
	unsigned int iopl_warn: 1;
	unsigned int sig_on_uaccess_err: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u32 pkru;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct fpu fpu;
};

struct mm_struct___40;

struct pid___32;

struct nsproxy___36;

struct signal_struct___37;

struct css_set___31;

struct perf_event_context___25;

struct vm_struct___34;

struct task_struct___40 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___40 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___3 se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___40 *mm;
	struct mm_struct___40 *active_mm;
	struct vmacache___39 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int restore_sigmask: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___40 *real_parent;
	struct task_struct___40 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___40 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___32 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	struct posix_cputimers_work posix_cputimers_work;
	const struct cred___2 *ptracer_cred;
	const struct cred___2 *real_cred;
	const struct cred___2 *cred;
	struct key *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___36 *nsproxy;
	struct signal_struct___37 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___40 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context___25 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___31 *cgroups;
	struct list_head cg_list;
	u32 closid;
	u32 rmid;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___25 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	long: 64;
	long: 64;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___39 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup *active_memcg;
	struct request_queue *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___40 *oom_reaper_list;
	struct vm_struct___34 *stack_vm_area;
	refcount_t stack_refcount;
	int patch_state;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	void *mce_vaddr;
	__u64 mce_kflags;
	u64 mce_addr;
	__u64 mce_ripv: 1;
	__u64 mce_whole_page: 1;
	__u64 __mce_reserved: 62;
	long: 2;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct callback_head mce_kill_me;
	int mce_count;
	struct llist_head kretprobe_instances;
	struct callback_head l1d_flush_kill;
	long: 64;
	struct thread_struct___26 thread;
};

typedef struct page___39 *pgtable_t___39;

struct address_space___37;

struct dev_pagemap___37;

struct page___39 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___37 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___13 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___39 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___39 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___40 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___37 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct pv_cpu_ops___32 {
	void (*io_delay)();
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	void (*write_cr4)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___26 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(long unsigned int);
	void (*invalidate_io_bitmap)();
	void (*update_io_bitmap)();
	void (*wbinvd)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int);
	void (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_msr_safe)(unsigned int, int *);
	int (*write_msr_safe)(unsigned int, unsigned int, unsigned int);
	u64 (*read_pmc)(int);
	void (*start_context_switch)(struct task_struct___40 *);
	void (*end_context_switch)(struct task_struct___40 *);
};

struct pv_mmu_ops___34 {
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_one_user)(long unsigned int);
	void (*flush_tlb_multi)(const struct cpumask *, const struct flush_tlb_info___3 *);
	void (*tlb_remove_table)(struct mmu_gather *, void *);
	void (*exit_mmap)(struct mm_struct___40 *);
	struct paravirt_callee_save read_cr2;
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___40 *, struct mm_struct___40 *);
	void (*dup_mmap)(struct mm_struct___40 *, struct mm_struct___40 *);
	int (*pgd_alloc)(struct mm_struct___40 *);
	void (*pgd_free)(struct mm_struct___40 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___40 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___40 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___40 *, long unsigned int);
	void (*alloc_p4d)(struct mm_struct___40 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*release_p4d)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	pte_t (*ptep_modify_prot_start)(struct vm_area_struct___40 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct vm_area_struct___40 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_p4d)(p4d_t *, p4d_t);
	struct paravirt_callee_save p4d_val;
	struct paravirt_callee_save make_p4d;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

struct core_state___39;

struct mm_struct___40 {
	struct {
		struct vm_area_struct___40 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___37 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int mmap_compat_base;
		long unsigned int mmap_compat_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[48];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___39 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___40 *owner;
		struct user_namespace___2 *user_ns;
		struct file___37 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		bool tlb_flush_batched;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct vm_operations_struct___37;

struct vm_area_struct___40 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___40 *vm_next;
	struct vm_area_struct___40 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___40 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___37 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___37 *vm_file;
	struct file___37 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct paravirt_patch_template___34 {
	struct pv_cpu_ops___32 cpu;
	struct pv_irq_ops irq;
	struct pv_mmu_ops___34 mmu;
	struct pv_lock_ops lock;
};

struct tracepoint___28 {
	const char *name;
	struct static_key key;
	struct static_call_key___28 *static_call_key;
	void *static_call_tramp;
	void *iterator;
	int (*regfunc)();
	void (*unregfunc)();
	struct tracepoint_func *funcs;
};

struct bpf_raw_event_map___28 {
	struct tracepoint___28 *tp;
	void *bpf_func;
	u32 num_args;
	u32 writable_size;
	long: 64;
};

struct seq_operations___35 {
	void * (*start)(struct seq_file___35 *, loff_t *);
	void (*stop)(struct seq_file___35 *, void *);
	void * (*next)(struct seq_file___35 *, void *, loff_t *);
	int (*show)(struct seq_file___35 *, void *);
};

struct hw_perf_event___25 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___40 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	union {
		struct {
			u64 last_period;
			local64_t period_left;
		};
		struct {
			u64 saved_metric;
			u64 saved_slots;
		};
	};
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___25)(struct perf_event___25 *, struct perf_sample_data *, struct pt_regs *);

struct pmu___25;

struct fasync_struct___37;

struct pid_namespace___32;

struct trace_event_call___25;

struct perf_cgroup___25;

struct perf_event___25 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___25 *group_leader;
	struct pmu___25 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___25 hw;
	struct perf_event_context___25 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___25 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___40 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct perf_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___37 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	long unsigned int pending_addr;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	struct perf_addr_filter_range *addr_filter_ranges;
	long unsigned int addr_filters_gen;
	struct perf_event___25 *aux_event;
	void (*destroy)(struct perf_event___25 *);
	struct callback_head callback_head;
	struct pid_namespace___32 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___25 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___25 orig_overflow_handler;
	struct bpf_prog *prog;
	u64 bpf_cookie;
	struct trace_event_call___25 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___25 *cgrp;
	void *security;
	struct list_head sb_list;
};

struct address_space_operations___37;

struct address_space___37 {
	struct inode___37 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___37 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct dev_pagemap_ops___37;

struct dev_pagemap___37 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___37 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vfsmount___37;

struct path___37 {
	struct vfsmount___37 *mnt;
	struct dentry___37 *dentry;
};

struct fown_struct___32 {
	rwlock_t lock;
	struct pid___32 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___37 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	long: 64;
	long: 64;
	struct path___37 f_path;
	struct inode___37 *f_inode;
	const struct file_operations___37 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___32 f_owner;
	const struct cred___2 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___37 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___37;

struct vm_operations_struct___37 {
	void (*open)(struct vm_area_struct___40 *);
	void (*close)(struct vm_area_struct___40 *);
	int (*may_split)(struct vm_area_struct___40 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___40 *);
	int (*mprotect)(struct vm_area_struct___40 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___37 *);
	vm_fault_t (*huge_fault)(struct vm_fault___37 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___37 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___40 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___37 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___37 *);
	int (*access)(struct vm_area_struct___40 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___40 *);
	int (*set_policy)(struct vm_area_struct___40 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___40 *, long unsigned int);
	struct page___39 * (*find_special_page)(struct vm_area_struct___40 *, long unsigned int);
};

struct core_thread___39 {
	struct task_struct___40 *task;
	struct core_thread___39 *next;
};

struct core_state___39 {
	atomic_t nr_threads;
	struct core_thread___39 dumper;
	struct completion startup;
};

struct vm_fault___37 {
	const struct {
		struct vm_area_struct___40 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___39 *cow_page;
	struct page___39 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___39 prealloc_pte;
};

struct dev_pagemap_ops___37 {
	void (*page_free)(struct page___39 *);
	void (*kill)(struct dev_pagemap___37 *);
	void (*cleanup)(struct dev_pagemap___37 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___37 *);
};

struct upid___32 {
	int nr;
	struct pid_namespace___32 *ns;
};

struct pid_namespace___32 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___40 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___32 *parent;
	struct fs_pin *bacct;
	struct user_namespace___2 *user_ns;
	struct ucounts___2 *ucounts;
	int reboot;
	struct ns_common___5 ns;
};

struct pid___32 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___32 numbers[1];
};

struct tty_struct___8;

struct signal_struct___37 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___40 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___40 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___32 *pids[4];
	struct pid___32 *tty_old_pgrp;
	int leader;
	struct tty_struct___8 *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___40 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct cgroup_namespace___31;

struct nsproxy___36 {
	atomic_t count;
	struct uts_namespace *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___32 *pid_ns_for_children;
	struct net *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___31 *cgroup_ns;
};

struct cgroup_subsys_state___31;

struct cgroup___31;

struct css_set___31 {
	struct cgroup_subsys_state___31 *subsys[14];
	refcount_t refcount;
	struct css_set___31 *dom_cset;
	struct cgroup___31 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___31 *mg_src_cgrp;
	struct cgroup___31 *mg_dst_cgrp;
	struct css_set___31 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___25 {
	struct pmu___25 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	int rotate_necessary;
	refcount_t refcount;
	struct task_struct___40 *task;
	u64 time;
	u64 timestamp;
	u64 timeoffset;
	struct perf_event_context___25 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

struct vm_struct___34 {
	struct vm_struct___34 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___39 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct dentry_operations___37;

struct dentry___37 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___37 *d_parent;
	struct qstr d_name;
	struct inode___37 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___37 *d_op;
	struct super_block___37 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___37;

struct cdev___15;

struct inode___37 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___37 *i_op;
	struct super_block___37 *i_sb;
	struct address_space___37 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	long: 64;
	long: 64;
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___37 *i_fop;
		void (*free_inode)(struct inode___37 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___37 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct cdev___15 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___37 {
	int (*d_revalidate)(struct dentry___37 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___37 *, unsigned int);
	int (*d_hash)(const struct dentry___37 *, struct qstr *);
	int (*d_compare)(const struct dentry___37 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___37 *);
	int (*d_init)(struct dentry___37 *);
	void (*d_release)(struct dentry___37 *);
	void (*d_prune)(struct dentry___37 *);
	void (*d_iput)(struct dentry___37 *, struct inode___37 *);
	char * (*d_dname)(struct dentry___37 *, char *, int);
	struct vfsmount___37 * (*d_automount)(struct path___37 *);
	int (*d_manage)(const struct path___37 *, bool);
	struct dentry___37 * (*d_real)(struct dentry___37 *, const struct inode___37 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___37;

struct mem_dqinfo___37 {
	struct quota_format_type___37 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___37;

struct quota_info___37 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___37 *files[3];
	struct mem_dqinfo___37 info[3];
	const struct quota_format_ops___37 *ops[3];
};

struct rcuwait___37 {
	struct task_struct___40 *task;
};

struct percpu_rw_semaphore___37 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___37 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___37 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___37 rw_sem[3];
};

struct super_operations___37;

struct dquot_operations___37;

struct quotactl_ops___37;

struct super_block___37 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___37 *s_type;
	const struct super_operations___37 *s_op;
	const struct dquot_operations___37 *dq_op;
	const struct quotactl_ops___37 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___37 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device *s_bdev;
	struct backing_dev_info *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___37 s_dquot;
	struct sb_writers___37 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___37 *s_d_op;
	int cleancache_poolid;
	struct shrinker___24 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___2 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___37 {
	struct dentry___37 *mnt_root;
	struct super_block___37 *mnt_sb;
	int mnt_flags;
	struct user_namespace___2 *mnt_userns;
};

struct cgroup_subsys___31;

struct cgroup_subsys_state___31 {
	struct cgroup___31 *cgroup;
	struct cgroup_subsys___31 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___31 *parent;
};

struct kernfs_node___37;

struct cgroup_file___31 {
	struct kernfs_node___37 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct psi_group___31 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___40 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___31;

struct cgroup_rstat_cpu___31;

struct cgroup___31 {
	struct cgroup_subsys_state___31 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___37 *kn;
	struct cgroup_file___31 procs_file;
	struct cgroup_file___31 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___31 *subsys[14];
	struct cgroup_root___31 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___31 *dom_cgrp;
	struct cgroup___31 *old_dom_cgrp;
	struct cgroup_rstat_cpu___31 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___31 psi;
	struct cgroup_bpf___4 bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct device___39;

struct tty_driver___8;

struct tty_operations___8;

struct tty_ldisc___8;

struct tty_port___8;

struct tty_struct___8 {
	int magic;
	struct kref kref;
	struct device___39 *dev;
	struct tty_driver___8 *driver;
	const struct tty_operations___8 *ops;
	int index;
	struct ld_semaphore ldisc_sem;
	struct tty_ldisc___8 *ldisc;
	struct mutex atomic_write_lock;
	struct mutex legacy_mutex;
	struct mutex throttle_mutex;
	struct rw_semaphore termios_rwsem;
	struct mutex winsize_mutex;
	struct ktermios termios;
	struct ktermios termios_locked;
	char name[64];
	long unsigned int flags;
	int count;
	struct winsize winsize;
	struct {
		spinlock_t lock;
		bool stopped;
		bool tco_stopped;
		long unsigned int unused[0];
	} flow;
	struct {
		spinlock_t lock;
		struct pid___32 *pgrp;
		struct pid___32 *session;
		unsigned char pktstatus;
		bool packet;
		long unsigned int unused[0];
	} ctrl;
	int hw_stopped;
	unsigned int receive_room;
	int flow_change;
	struct tty_struct___8 *link;
	struct fasync_struct___37 *fasync;
	wait_queue_head_t write_wait;
	wait_queue_head_t read_wait;
	struct work_struct hangup_work;
	void *disc_data;
	void *driver_data;
	spinlock_t files_lock;
	struct list_head tty_files;
	int closing;
	unsigned char *write_buf;
	int write_cnt;
	struct work_struct SAK_work;
	struct tty_port___8 *port;
};

struct kiocb___37 {
	struct file___37 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___37 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___21 *ki_waitq;
	};
};

struct iattr___37 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___37 *ia_file;
};

struct dquot___37 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___37 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___37 {
	int qf_fmt_id;
	const struct quota_format_ops___37 *qf_ops;
	struct module___36 *qf_owner;
	struct quota_format_type___37 *qf_next;
};

struct quota_format_ops___37 {
	int (*check_quota_file)(struct super_block___37 *, int);
	int (*read_file_info)(struct super_block___37 *, int);
	int (*write_file_info)(struct super_block___37 *, int);
	int (*free_file_info)(struct super_block___37 *, int);
	int (*read_dqblk)(struct dquot___37 *);
	int (*commit_dqblk)(struct dquot___37 *);
	int (*release_dqblk)(struct dquot___37 *);
	int (*get_next_id)(struct super_block___37 *, struct kqid *);
};

struct dquot_operations___37 {
	int (*write_dquot)(struct dquot___37 *);
	struct dquot___37 * (*alloc_dquot)(struct super_block___37 *, int);
	void (*destroy_dquot)(struct dquot___37 *);
	int (*acquire_dquot)(struct dquot___37 *);
	int (*release_dquot)(struct dquot___37 *);
	int (*mark_dirty)(struct dquot___37 *);
	int (*write_info)(struct super_block___37 *, int);
	qsize_t * (*get_reserved_space)(struct inode___37 *);
	int (*get_projid)(struct inode___37 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___37 *, qsize_t *);
	int (*get_next_id)(struct super_block___37 *, struct kqid *);
};

struct quotactl_ops___37 {
	int (*quota_on)(struct super_block___37 *, int, int, const struct path___37 *);
	int (*quota_off)(struct super_block___37 *, int);
	int (*quota_enable)(struct super_block___37 *, unsigned int);
	int (*quota_disable)(struct super_block___37 *, unsigned int);
	int (*quota_sync)(struct super_block___37 *, int);
	int (*set_info)(struct super_block___37 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___37 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___37 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___37 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___37 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___37 *, unsigned int);
};

struct kset___36;

struct kobj_type___36;

struct kobject___37 {
	const char *name;
	struct list_head entry;
	struct kobject___37 *parent;
	struct kset___36 *kset;
	struct kobj_type___36 *ktype;
	struct kernfs_node___37 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___36 {
	struct kobject___37 kobj;
	struct module___36 *mod;
	struct kobject___37 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___36 {
	struct module___36 *mod;
	struct latch_tree_node node;
};

struct module_layout___36 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___36 mtn;
};

struct module_attribute___36;

struct kernel_param___36;

struct module___36 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___36 mkobj;
	struct module_attribute___36 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___37 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___36 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___36 core_layout;
	struct module_layout___36 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map___28 *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___25 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	int num_static_call_sites;
	struct static_call_site *static_call_sites;
	bool klp;
	bool klp_alive;
	struct klp_modinfo *klp_info;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct address_space_operations___37 {
	int (*writepage)(struct page___39 *, struct writeback_control *);
	int (*readpage)(struct file___37 *, struct page___39 *);
	int (*writepages)(struct address_space___37 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___39 *);
	int (*readpages)(struct file___37 *, struct address_space___37 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control *);
	int (*write_begin)(struct file___37 *, struct address_space___37 *, loff_t, unsigned int, unsigned int, struct page___39 **, void **);
	int (*write_end)(struct file___37 *, struct address_space___37 *, loff_t, unsigned int, unsigned int, struct page___39 *, void *);
	sector_t (*bmap)(struct address_space___37 *, sector_t);
	void (*invalidatepage)(struct page___39 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___39 *, gfp_t);
	void (*freepage)(struct page___39 *);
	ssize_t (*direct_IO)(struct kiocb___37 *, struct iov_iter___30 *);
	int (*migratepage)(struct address_space___37 *, struct page___39 *, struct page___39 *, enum migrate_mode);
	bool (*isolate_page)(struct page___39 *, isolate_mode_t);
	void (*putback_page)(struct page___39 *);
	int (*launder_page)(struct page___39 *);
	int (*is_partially_uptodate)(struct page___39 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___39 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___37 *, struct page___39 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___37 *, sector_t *);
	void (*swap_deactivate)(struct file___37 *);
};

struct cdev___15 {
	struct kobject___37 kobj;
	struct module___36 *owner;
	const struct file_operations___37 *ops;
	struct list_head list;
	dev_t dev;
	unsigned int count;
};

struct inode_operations___37 {
	struct dentry___37 * (*lookup)(struct inode___37 *, struct dentry___37 *, unsigned int);
	const char * (*get_link)(struct dentry___37 *, struct inode___37 *, struct delayed_call *);
	int (*permission)(struct user_namespace___2 *, struct inode___37 *, int);
	struct posix_acl * (*get_acl)(struct inode___37 *, int, bool);
	int (*readlink)(struct dentry___37 *, char *, int);
	int (*create)(struct user_namespace___2 *, struct inode___37 *, struct dentry___37 *, umode_t, bool);
	int (*link)(struct dentry___37 *, struct inode___37 *, struct dentry___37 *);
	int (*unlink)(struct inode___37 *, struct dentry___37 *);
	int (*symlink)(struct user_namespace___2 *, struct inode___37 *, struct dentry___37 *, const char *);
	int (*mkdir)(struct user_namespace___2 *, struct inode___37 *, struct dentry___37 *, umode_t);
	int (*rmdir)(struct inode___37 *, struct dentry___37 *);
	int (*mknod)(struct user_namespace___2 *, struct inode___37 *, struct dentry___37 *, umode_t, dev_t);
	int (*rename)(struct user_namespace___2 *, struct inode___37 *, struct dentry___37 *, struct inode___37 *, struct dentry___37 *, unsigned int);
	int (*setattr)(struct user_namespace___2 *, struct dentry___37 *, struct iattr___37 *);
	int (*getattr)(struct user_namespace___2 *, const struct path___37 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___37 *, char *, size_t);
	int (*fiemap)(struct inode___37 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___37 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___37 *, struct dentry___37 *, struct file___37 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace___2 *, struct inode___37 *, struct dentry___37 *, umode_t);
	int (*set_acl)(struct user_namespace___2 *, struct inode___37 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace___2 *, struct dentry___37 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___37 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___37 {
	void (*fl_copy_lock)(struct file_lock___37 *, struct file_lock___37 *);
	void (*fl_release_private)(struct file_lock___37 *);
};

struct lock_manager_operations___37;

struct file_lock___37 {
	struct file_lock___37 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___37 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___37 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___37 *fl_ops;
	const struct lock_manager_operations___37 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___37 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___37 *);
	int (*lm_grant)(struct file_lock___37 *, int);
	bool (*lm_break)(struct file_lock___37 *);
	int (*lm_change)(struct file_lock___37 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___37 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___37 *);
};

struct fasync_struct___37 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___37 *fa_next;
	struct file___37 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___37 {
	struct inode___37 * (*alloc_inode)(struct super_block___37 *);
	void (*destroy_inode)(struct inode___37 *);
	void (*free_inode)(struct inode___37 *);
	void (*dirty_inode)(struct inode___37 *, int);
	int (*write_inode)(struct inode___37 *, struct writeback_control *);
	int (*drop_inode)(struct inode___37 *);
	void (*evict_inode)(struct inode___37 *);
	void (*put_super)(struct super_block___37 *);
	int (*sync_fs)(struct super_block___37 *, int);
	int (*freeze_super)(struct super_block___37 *);
	int (*freeze_fs)(struct super_block___37 *);
	int (*thaw_super)(struct super_block___37 *);
	int (*unfreeze_fs)(struct super_block___37 *);
	int (*statfs)(struct dentry___37 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___37 *, int *, char *);
	void (*umount_begin)(struct super_block___37 *);
	int (*show_options)(struct seq_file___35 *, struct dentry___37 *);
	int (*show_devname)(struct seq_file___35 *, struct dentry___37 *);
	int (*show_path)(struct seq_file___35 *, struct dentry___37 *);
	int (*show_stats)(struct seq_file___35 *, struct dentry___37 *);
	ssize_t (*quota_read)(struct super_block___37 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___37 *, int, const char *, size_t, loff_t);
	struct dquot___37 ** (*get_dquots)(struct inode___37 *);
	long int (*nr_cached_objects)(struct super_block___37 *, struct shrink_control___24 *);
	long int (*free_cached_objects)(struct super_block___37 *, struct shrink_control___24 *);
	struct file___37 * (*real_loop)(struct file___37 *);
};

typedef void (*poll_queue_proc___28)(struct file___37 *, wait_queue_head_t *, struct poll_table_struct___28 *);

struct poll_table_struct___28 {
	poll_queue_proc___28 _qproc;
	__poll_t _key;
};

struct seq_file___35 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___35 *op;
	int poll_event;
	const struct file___37 *file;
	void *private;
};

struct kernfs_root___37;

struct kernfs_elem_dir___37 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___37 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___37;

struct kernfs_root___37 {
	struct kernfs_node___37 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___37 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___37 {
	struct kernfs_node___37 *target_kn;
};

struct kernfs_ops___37;

struct kernfs_elem_attr___37 {
	const struct kernfs_ops___37 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___37 *notify_next;
};

struct kernfs_node___37 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___37 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___37 dir;
		struct kernfs_elem_symlink___37 symlink;
		struct kernfs_elem_attr___37 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___37;

struct kernfs_ops___37 {
	int (*open)(struct kernfs_open_file___37 *);
	void (*release)(struct kernfs_open_file___37 *);
	int (*seq_show)(struct seq_file___35 *, void *);
	void * (*seq_start)(struct seq_file___35 *, loff_t *);
	void * (*seq_next)(struct seq_file___35 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___35 *, void *);
	ssize_t (*read)(struct kernfs_open_file___37 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___37 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___37 *, struct poll_table_struct___28 *);
	int (*mmap)(struct kernfs_open_file___37 *, struct vm_area_struct___40 *);
};

struct kernfs_syscall_ops___37 {
	int (*show_options)(struct seq_file___35 *, struct kernfs_root___37 *);
	int (*mkdir)(struct kernfs_node___37 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___37 *);
	int (*rename)(struct kernfs_node___37 *, struct kernfs_node___37 *, const char *);
	int (*show_path)(struct seq_file___35 *, struct kernfs_node___37 *, struct kernfs_root___37 *);
};

struct kernfs_open_file___37 {
	struct kernfs_node___37 *kn;
	struct file___37 *file;
	struct seq_file___35 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___37 *vm_ops;
};

struct bin_attribute___37;

struct attribute_group___37 {
	const char *name;
	umode_t (*is_visible)(struct kobject___37 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___37 *, struct bin_attribute___37 *, int);
	struct attribute **attrs;
	struct bin_attribute___37 **bin_attrs;
};

struct bin_attribute___37 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___37 * (*f_mapping)();
	ssize_t (*read)(struct file___37 *, struct kobject___37 *, struct bin_attribute___37 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___37 *, struct kobject___37 *, struct bin_attribute___37 *, char *, loff_t, size_t);
	int (*mmap)(struct file___37 *, struct kobject___37 *, struct bin_attribute___37 *, struct vm_area_struct___40 *);
};

struct sysfs_ops___36 {
	ssize_t (*show)(struct kobject___37 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___37 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___36;

struct kset___36 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___37 kobj;
	const struct kset_uevent_ops___36 *uevent_ops;
};

struct kobj_type___36 {
	void (*release)(struct kobject___37 *);
	const struct sysfs_ops___36 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___37 **default_groups;
	const struct kobj_ns_type_operations___3 * (*child_ns_type)(struct kobject___37 *);
	const void * (*namespace)(struct kobject___37 *);
	void (*get_ownership)(struct kobject___37 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___36 {
	int (* const filter)(struct kset___36 *, struct kobject___37 *);
	const char * (* const name)(struct kset___36 *, struct kobject___37 *);
	int (* const uevent)(struct kset___36 *, struct kobject___37 *, struct kobj_uevent_env *);
};

struct dev_printk_info {
	char subsystem[16];
	char device[48];
};

struct wakeup_source___39;

struct dev_pm_info___39 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___39 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___39 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___39;

struct bus_type___39;

struct device_driver___39;

struct dev_pm_domain___39;

struct fwnode_handle___36;

struct class___39;

struct device___39 {
	struct kobject___37 kobj;
	struct device___39 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___39 *type;
	struct bus_type___39 *bus;
	struct device_driver___39 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___39 power;
	struct dev_pm_domain___39 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node *of_node;
	struct fwnode_handle___36 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___39 *class;
	const struct attribute_group___37 **groups;
	void (*release)(struct device___39 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_ops___39 {
	int (*prepare)(struct device___39 *);
	void (*complete)(struct device___39 *);
	int (*suspend)(struct device___39 *);
	int (*resume)(struct device___39 *);
	int (*freeze)(struct device___39 *);
	int (*thaw)(struct device___39 *);
	int (*poweroff)(struct device___39 *);
	int (*restore)(struct device___39 *);
	int (*suspend_late)(struct device___39 *);
	int (*resume_early)(struct device___39 *);
	int (*freeze_late)(struct device___39 *);
	int (*thaw_early)(struct device___39 *);
	int (*poweroff_late)(struct device___39 *);
	int (*restore_early)(struct device___39 *);
	int (*suspend_noirq)(struct device___39 *);
	int (*resume_noirq)(struct device___39 *);
	int (*freeze_noirq)(struct device___39 *);
	int (*thaw_noirq)(struct device___39 *);
	int (*poweroff_noirq)(struct device___39 *);
	int (*restore_noirq)(struct device___39 *);
	int (*runtime_suspend)(struct device___39 *);
	int (*runtime_resume)(struct device___39 *);
	int (*runtime_idle)(struct device___39 *);
};

struct wakeup_source___39 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___39 *dev;
	bool active: 1;
	bool autosleep_enabled: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___39 {
	struct dev_pm_ops___39 ops;
	int (*start)(struct device___39 *);
	void (*detach)(struct device___39 *, bool);
	int (*activate)(struct device___39 *);
	void (*sync)(struct device___39 *);
	void (*dismiss)(struct device___39 *);
};

struct bus_type___39 {
	const char *name;
	const char *dev_name;
	struct device___39 *dev_root;
	const struct attribute_group___37 **bus_groups;
	const struct attribute_group___37 **dev_groups;
	const struct attribute_group___37 **drv_groups;
	int (*match)(struct device___39 *, struct device_driver___39 *);
	int (*uevent)(struct device___39 *, struct kobj_uevent_env *);
	int (*probe)(struct device___39 *);
	void (*sync_state)(struct device___39 *);
	void (*remove)(struct device___39 *);
	void (*shutdown)(struct device___39 *);
	int (*online)(struct device___39 *);
	int (*offline)(struct device___39 *);
	int (*suspend)(struct device___39 *, pm_message_t);
	int (*resume)(struct device___39 *);
	int (*num_vf)(struct device___39 *);
	int (*dma_configure)(struct device___39 *);
	const struct dev_pm_ops___39 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___39 {
	const char *name;
	struct bus_type___39 *bus;
	struct module___36 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___39 *);
	void (*sync_state)(struct device___39 *);
	int (*remove)(struct device___39 *);
	void (*shutdown)(struct device___39 *);
	int (*suspend)(struct device___39 *, pm_message_t);
	int (*resume)(struct device___39 *);
	const struct attribute_group___37 **groups;
	const struct attribute_group___37 **dev_groups;
	const struct dev_pm_ops___39 *pm;
	void (*coredump)(struct device___39 *);
	struct driver_private *p;
};

struct device_type___39 {
	const char *name;
	const struct attribute_group___37 **groups;
	int (*uevent)(struct device___39 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___39 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___39 *);
	const struct dev_pm_ops___39 *pm;
};

struct class___39 {
	const char *name;
	struct module___36 *owner;
	const struct attribute_group___37 **class_groups;
	const struct attribute_group___37 **dev_groups;
	struct kobject___37 *dev_kobj;
	int (*dev_uevent)(struct device___39 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___39 *, umode_t *);
	void (*class_release)(struct class___39 *);
	void (*dev_release)(struct device___39 *);
	int (*shutdown_pre)(struct device___39 *);
	const struct kobj_ns_type_operations___3 *ns_type;
	const void * (*namespace)(struct device___39 *);
	void (*get_ownership)(struct device___39 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___39 *pm;
	struct subsys_private *p;
};

struct fwnode_operations___36;

struct fwnode_handle___36 {
	struct fwnode_handle___36 *secondary;
	const struct fwnode_operations___36 *ops;
	struct device___39 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct tty_operations___8 {
	struct tty_struct___8 * (*lookup)(struct tty_driver___8 *, struct file___37 *, int);
	int (*install)(struct tty_driver___8 *, struct tty_struct___8 *);
	void (*remove)(struct tty_driver___8 *, struct tty_struct___8 *);
	int (*open)(struct tty_struct___8 *, struct file___37 *);
	void (*close)(struct tty_struct___8 *, struct file___37 *);
	void (*shutdown)(struct tty_struct___8 *);
	void (*cleanup)(struct tty_struct___8 *);
	int (*write)(struct tty_struct___8 *, const unsigned char *, int);
	int (*put_char)(struct tty_struct___8 *, unsigned char);
	void (*flush_chars)(struct tty_struct___8 *);
	unsigned int (*write_room)(struct tty_struct___8 *);
	unsigned int (*chars_in_buffer)(struct tty_struct___8 *);
	int (*ioctl)(struct tty_struct___8 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct tty_struct___8 *, unsigned int, long unsigned int);
	void (*set_termios)(struct tty_struct___8 *, struct ktermios *);
	void (*throttle)(struct tty_struct___8 *);
	void (*unthrottle)(struct tty_struct___8 *);
	void (*stop)(struct tty_struct___8 *);
	void (*start)(struct tty_struct___8 *);
	void (*hangup)(struct tty_struct___8 *);
	int (*break_ctl)(struct tty_struct___8 *, int);
	void (*flush_buffer)(struct tty_struct___8 *);
	void (*set_ldisc)(struct tty_struct___8 *);
	void (*wait_until_sent)(struct tty_struct___8 *, int);
	void (*send_xchar)(struct tty_struct___8 *, char);
	int (*tiocmget)(struct tty_struct___8 *);
	int (*tiocmset)(struct tty_struct___8 *, unsigned int, unsigned int);
	int (*resize)(struct tty_struct___8 *, struct winsize *);
	int (*get_icount)(struct tty_struct___8 *, struct serial_icounter_struct *);
	int (*get_serial)(struct tty_struct___8 *, struct serial_struct *);
	int (*set_serial)(struct tty_struct___8 *, struct serial_struct *);
	void (*show_fdinfo)(struct tty_struct___8 *, struct seq_file___35 *);
	int (*poll_init)(struct tty_driver___8 *, int, char *);
	int (*poll_get_char)(struct tty_driver___8 *, int);
	void (*poll_put_char)(struct tty_driver___8 *, int, char);
	int (*proc_show)(struct seq_file___35 *, void *);
};

struct tty_driver___8 {
	int magic;
	struct kref kref;
	struct cdev___15 **cdevs;
	struct module___36 *owner;
	const char *driver_name;
	const char *name;
	int name_base;
	int major;
	int minor_start;
	unsigned int num;
	short int type;
	short int subtype;
	struct ktermios init_termios;
	long unsigned int flags;
	struct proc_dir_entry *proc_entry;
	struct tty_driver___8 *other;
	struct tty_struct___8 **ttys;
	struct tty_port___8 **ports;
	struct ktermios **termios;
	void *driver_state;
	const struct tty_operations___8 *ops;
	struct list_head tty_drivers;
};

struct tty_port_operations___8;

struct tty_port_client_operations___8;

struct tty_port___8 {
	struct tty_bufhead buf;
	struct tty_struct___8 *tty;
	struct tty_struct___8 *itty;
	const struct tty_port_operations___8 *ops;
	const struct tty_port_client_operations___8 *client_ops;
	spinlock_t lock;
	int blocked_open;
	int count;
	wait_queue_head_t open_wait;
	wait_queue_head_t delta_msr_wait;
	long unsigned int flags;
	long unsigned int iflags;
	unsigned char console: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct mutex mutex;
	struct mutex buf_mutex;
	unsigned char *xmit_buf;
	unsigned int close_delay;
	unsigned int closing_wait;
	int drain_delay;
	struct kref kref;
	void *client_data;
};

struct tty_ldisc_ops___8 {
	char *name;
	int num;
	int flags;
	int (*open)(struct tty_struct___8 *);
	void (*close)(struct tty_struct___8 *);
	void (*flush_buffer)(struct tty_struct___8 *);
	ssize_t (*read)(struct tty_struct___8 *, struct file___37 *, unsigned char *, size_t, void **, long unsigned int);
	ssize_t (*write)(struct tty_struct___8 *, struct file___37 *, const unsigned char *, size_t);
	int (*ioctl)(struct tty_struct___8 *, struct file___37 *, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct tty_struct___8 *, struct file___37 *, unsigned int, long unsigned int);
	void (*set_termios)(struct tty_struct___8 *, struct ktermios *);
	__poll_t (*poll)(struct tty_struct___8 *, struct file___37 *, struct poll_table_struct___28 *);
	int (*hangup)(struct tty_struct___8 *);
	void (*receive_buf)(struct tty_struct___8 *, const unsigned char *, const char *, int);
	void (*write_wakeup)(struct tty_struct___8 *);
	void (*dcd_change)(struct tty_struct___8 *, unsigned int);
	int (*receive_buf2)(struct tty_struct___8 *, const unsigned char *, const char *, int);
	struct module___36 *owner;
};

struct tty_ldisc___8 {
	struct tty_ldisc_ops___8 *ops;
	struct tty_struct___8 *tty;
};

struct tty_port_operations___8 {
	int (*carrier_raised)(struct tty_port___8 *);
	void (*dtr_rts)(struct tty_port___8 *, int);
	void (*shutdown)(struct tty_port___8 *);
	int (*activate)(struct tty_port___8 *, struct tty_struct___8 *);
	void (*destruct)(struct tty_port___8 *);
};

struct tty_port_client_operations___8 {
	int (*receive_buf)(struct tty_port___8 *, const unsigned char *, const unsigned char *, size_t);
	void (*write_wakeup)(struct tty_port___8 *);
};

struct console___2 {
	char name[16];
	void (*write)(struct console___2 *, const char *, unsigned int);
	int (*read)(struct console___2 *, char *, unsigned int);
	struct tty_driver___8 * (*device)(struct console___2 *, int *);
	void (*unblank)();
	int (*setup)(struct console___2 *, char *);
	int (*exit)(struct console___2 *);
	int (*match)(struct console___2 *, char *, int, char *);
	short int flags;
	short int index;
	int cflag;
	uint ispeed;
	uint ospeed;
	void *data;
	struct console___2 *next;
};

struct fwnode_reference_args___36;

struct fwnode_endpoint___36;

struct fwnode_operations___36 {
	struct fwnode_handle___36 * (*get)(struct fwnode_handle___36 *);
	void (*put)(struct fwnode_handle___36 *);
	bool (*device_is_available)(const struct fwnode_handle___36 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___36 *, const struct device___39 *);
	bool (*property_present)(const struct fwnode_handle___36 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___36 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___36 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___36 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___36 *);
	struct fwnode_handle___36 * (*get_parent)(const struct fwnode_handle___36 *);
	struct fwnode_handle___36 * (*get_next_child_node)(const struct fwnode_handle___36 *, struct fwnode_handle___36 *);
	struct fwnode_handle___36 * (*get_named_child_node)(const struct fwnode_handle___36 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___36 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___36 *);
	struct fwnode_handle___36 * (*graph_get_next_endpoint)(const struct fwnode_handle___36 *, struct fwnode_handle___36 *);
	struct fwnode_handle___36 * (*graph_get_remote_endpoint)(const struct fwnode_handle___36 *);
	struct fwnode_handle___36 * (*graph_get_port_parent)(struct fwnode_handle___36 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___36 *, struct fwnode_endpoint___36 *);
	int (*add_links)(struct fwnode_handle___36 *);
};

struct fwnode_endpoint___36 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___36 *local_fwnode;
};

struct fwnode_reference_args___36 {
	struct fwnode_handle___36 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct kernel_param_ops___36 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___36 *);
	int (*get)(char *, const struct kernel_param___36 *);
	void (*free)(void *);
};

struct kparam_array___36;

struct kernel_param___36 {
	const char *name;
	struct module___36 *mod;
	const struct kernel_param_ops___36 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___36 *arr;
	};
};

struct kparam_array___36 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___36 *ops;
	void *elem;
};

struct module_attribute___36 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___36 *, struct module_kobject___36 *, char *);
	ssize_t (*store)(struct module_attribute___36 *, struct module_kobject___36 *, const char *, size_t);
	void (*setup)(struct module___36 *, const char *);
	int (*test)(struct module___36 *);
	void (*free)(struct module___36 *);
};

struct trace_event_class___25;

struct trace_event_call___25 {
	struct list_head list;
	struct trace_event_class___25 *class;
	union {
		char *name;
		struct tracepoint___28 *tp;
	};
	struct trace_event event;
	char *print_fmt;
	struct event_filter *filter;
	union {
		void *module;
		atomic_t refcnt;
	};
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
	struct bpf_prog_array___4 *prog_array;
	int (*perf_perm)(struct trace_event_call___25 *, struct perf_event___25 *);
};

typedef struct poll_table_struct___28 poll_table___4;

struct cgroup_namespace___31 {
	struct ns_common___5 ns;
	struct user_namespace___2 *user_ns;
	struct ucounts___2 *ucounts;
	struct css_set___31 *root_cset;
};

struct perf_cpu_context___25;

struct perf_output_handle___25;

struct pmu___25 {
	struct list_head entry;
	struct module___36 *module;
	struct device___39 *dev;
	const struct attribute_group___37 **attr_groups;
	const struct attribute_group___37 **attr_update;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___25 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___25 *);
	void (*pmu_disable)(struct pmu___25 *);
	int (*event_init)(struct perf_event___25 *);
	void (*event_mapped)(struct perf_event___25 *, struct mm_struct___40 *);
	void (*event_unmapped)(struct perf_event___25 *, struct mm_struct___40 *);
	int (*add)(struct perf_event___25 *, int);
	void (*del)(struct perf_event___25 *, int);
	void (*start)(struct perf_event___25 *, int);
	void (*stop)(struct perf_event___25 *, int);
	void (*read)(struct perf_event___25 *);
	void (*start_txn)(struct pmu___25 *, unsigned int);
	int (*commit_txn)(struct pmu___25 *);
	void (*cancel_txn)(struct pmu___25 *);
	int (*event_idx)(struct perf_event___25 *);
	void (*sched_task)(struct perf_event_context___25 *, bool);
	struct kmem_cache *task_ctx_cache;
	void (*swap_task_ctx)(struct perf_event_context___25 *, struct perf_event_context___25 *);
	void * (*setup_aux)(struct perf_event___25 *, void **, int, bool);
	void (*free_aux)(void *);
	long int (*snapshot_aux)(struct perf_event___25 *, struct perf_output_handle___25 *, long unsigned int);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___25 *);
	int (*aux_output_match)(struct perf_event___25 *);
	int (*filter_match)(struct perf_event___25 *);
	int (*check_period)(struct perf_event___25 *, u64);
};

struct cftype___31;

struct cgroup_subsys___31 {
	struct cgroup_subsys_state___31 * (*css_alloc)(struct cgroup_subsys_state___31 *);
	int (*css_online)(struct cgroup_subsys_state___31 *);
	void (*css_offline)(struct cgroup_subsys_state___31 *);
	void (*css_released)(struct cgroup_subsys_state___31 *);
	void (*css_free)(struct cgroup_subsys_state___31 *);
	void (*css_reset)(struct cgroup_subsys_state___31 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___31 *, int);
	int (*css_extra_stat_show)(struct seq_file___35 *, struct cgroup_subsys_state___31 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___40 *, struct css_set___31 *);
	void (*cancel_fork)(struct task_struct___40 *, struct css_set___31 *);
	void (*fork)(struct task_struct___40 *);
	void (*exit)(struct task_struct___40 *);
	void (*release)(struct task_struct___40 *);
	void (*bind)(struct cgroup_subsys_state___31 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___31 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___31 *dfl_cftypes;
	struct cftype___31 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___31 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___31 *updated_children;
	struct cgroup___31 *updated_next;
};

struct cgroup_root___31 {
	struct kernfs_root___37 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___31 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___31 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___31 *ss;
	struct list_head node;
	struct kernfs_ops___37 *kf_ops;
	int (*open)(struct kernfs_open_file___37 *);
	void (*release)(struct kernfs_open_file___37 *);
	u64 (*read_u64)(struct cgroup_subsys_state___31 *, struct cftype___31 *);
	s64 (*read_s64)(struct cgroup_subsys_state___31 *, struct cftype___31 *);
	int (*seq_show)(struct seq_file___35 *, void *);
	void * (*seq_start)(struct seq_file___35 *, loff_t *);
	void * (*seq_next)(struct seq_file___35 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___35 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___31 *, struct cftype___31 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___31 *, struct cftype___31 *, s64);
	ssize_t (*write)(struct kernfs_open_file___37 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___37 *, struct poll_table_struct___28 *);
};

struct perf_cpu_context___25 {
	struct perf_event_context___25 ctx;
	struct perf_event_context___25 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___25 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
	int heap_size;
	struct perf_event___25 **heap;
	struct perf_event___25 *heap_default[2];
};

struct perf_output_handle___25 {
	struct perf_event___25 *event;
	struct perf_buffer *rb;
	long unsigned int wakeup;
	long unsigned int size;
	u64 aux_flags;
	union {
		void *addr;
		long unsigned int head;
	};
	int page;
};

struct perf_cgroup___25 {
	struct cgroup_subsys_state___31 css;
	struct perf_cgroup_info *info;
};

struct trace_event_fields___25 {
	const char *type;
	union {
		struct {
			const char *name;
			const int size;
			const int align;
			const int is_signed;
			const int filter_type;
		};
		int (*define_fields)(struct trace_event_call___25 *);
	};
};

struct trace_event_class___25 {
	const char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct trace_event_call___25 *, enum trace_reg, void *);
	struct trace_event_fields___25 *fields_array;
	struct list_head * (*get_fields)(struct trace_event_call___25 *);
	struct list_head fields;
	int (*raw_init)(struct trace_event_call___25 *);
};

struct trace_event_file___12;

struct trace_event_buffer___12 {
	struct trace_buffer *buffer;
	struct ring_buffer_event *event;
	struct trace_event_file___12 *trace_file;
	void *entry;
	unsigned int trace_ctx;
	struct pt_regs *regs;
};

struct trace_event_file___12 {
	struct list_head list;
	struct trace_event_call___25 *event_call;
	struct event_filter *filter;
	struct dentry___37 *dir;
	struct trace_array *tr;
	struct trace_subsystem_dir *system;
	struct list_head triggers;
	long unsigned int flags;
	atomic_t sm_ref;
	atomic_t tm_ref;
};

struct syscall_metadata___11 {
	const char *name;
	int syscall_nr;
	int nb_args;
	const char **types;
	const char **args;
	struct list_head enter_fields;
	struct trace_event_call___25 *enter_event;
	struct trace_event_call___25 *exit_event;
};

struct kmsg_dump_iter {
	u64 cur_seq;
	u64 next_seq;
};

struct kmsg_dumper {
	struct list_head list;
	void (*dump)(struct kmsg_dumper *, enum kmsg_dump_reason);
	enum kmsg_dump_reason max_reason;
	bool registered;
};

struct trace_event_raw_console {
	struct trace_entry ent;
	u32 __data_loc_msg;
	char __data[0];
};

struct trace_event_data_offsets_console {
	u32 msg;
};

typedef void (*btf_trace_console)(void *, const char *, size_t);

struct printk_info {
	u64 seq;
	u64 ts_nsec;
	u16 text_len;
	u8 facility;
	u8 flags: 5;
	u8 level: 3;
	long: 29;
	long: 64;
	long: 64;
	u32 caller_id;
	struct dev_printk_info dev_info;
};

struct printk_record {
	struct printk_info *info;
	char *text_buf;
	unsigned int text_buf_size;
};

struct prb_data_blk_lpos {
	long unsigned int begin;
	long unsigned int next;
};

struct prb_desc {
	atomic_long_t state_var;
	struct prb_data_blk_lpos text_blk_lpos;
};

struct prb_data_ring {
	unsigned int size_bits;
	char *data;
	atomic_long_t head_lpos;
	atomic_long_t tail_lpos;
};

struct prb_desc_ring {
	unsigned int count_bits;
	struct prb_desc *descs;
	struct printk_info *infos;
	atomic_long_t head_id;
	atomic_long_t tail_id;
};

struct printk_ringbuffer {
	struct prb_desc_ring desc_ring;
	struct prb_data_ring text_data_ring;
	atomic_long_t fail;
};

struct prb_reserved_entry {
	struct printk_ringbuffer *rb;
	long unsigned int irqflags;
	long unsigned int id;
	unsigned int text_space;
};

enum desc_state {
	desc_miss = 4294967295,
	desc_reserved = 0,
	desc_committed = 1,
	desc_finalized = 2,
	desc_reusable = 3,
};

struct console_cmdline {
	char name[16];
	int index;
	bool user_specified;
	char *options;
};

enum printk_info_flags {
	LOG_NEWLINE = 2,
	LOG_CONT = 8,
};

enum devkmsg_log_bits {
	__DEVKMSG_LOG_BIT_ON = 0,
	__DEVKMSG_LOG_BIT_OFF = 1,
	__DEVKMSG_LOG_BIT_LOCK = 2,
};

enum devkmsg_log_masks {
	DEVKMSG_LOG_MASK_ON = 1,
	DEVKMSG_LOG_MASK_OFF = 2,
	DEVKMSG_LOG_MASK_LOCK = 4,
};

enum con_msg_format_flags {
	MSG_FORMAT_DEFAULT = 0,
	MSG_FORMAT_SYSLOG = 1,
};

struct latched_seq {
	seqcount_latch_t latch;
	u64 val[2];
};

struct devkmsg_user {
	atomic64_t seq;
	struct ratelimit_state rs;
	struct mutex lock;
	char buf[8192];
	struct printk_info info;
	char text_buf[8192];
	struct printk_record record;
};

enum kdb_msgsrc {
	KDB_MSGSRC_INTERNAL = 0,
	KDB_MSGSRC_PRINTK = 1,
};

struct dev_printk_info___2;

struct prb_data_block {
	long unsigned int id;
	char data[0];
};

struct kobj_attribute___5 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___11 *, struct kobj_attribute___5 *, char *);
	ssize_t (*store)(struct kobject___11 *, struct kobj_attribute___5 *, const char *, size_t);
};

enum {
	IRQS_AUTODETECT = 1,
	IRQS_SPURIOUS_DISABLED = 2,
	IRQS_POLL_INPROGRESS = 8,
	IRQS_ONESHOT = 32,
	IRQS_REPLAY = 64,
	IRQS_WAITING = 128,
	IRQS_PENDING = 512,
	IRQS_SUSPENDED = 2048,
	IRQS_TIMINGS = 4096,
	IRQS_NMI = 8192,
};

enum {
	_IRQ_DEFAULT_INIT_FLAGS = 0,
	_IRQ_PER_CPU = 512,
	_IRQ_LEVEL = 256,
	_IRQ_NOPROBE = 1024,
	_IRQ_NOREQUEST = 2048,
	_IRQ_NOTHREAD = 65536,
	_IRQ_NOAUTOEN = 4096,
	_IRQ_MOVE_PCNTXT = 16384,
	_IRQ_NO_BALANCING = 8192,
	_IRQ_NESTED_THREAD = 32768,
	_IRQ_PER_CPU_DEVID = 131072,
	_IRQ_IS_POLLED = 262144,
	_IRQ_DISABLE_UNLAZY = 524288,
	_IRQ_HIDDEN = 1048576,
	_IRQ_NO_DEBUG = 2097152,
	_IRQF_MODIFY_MASK = 2096911,
};

enum {
	IRQTF_RUNTHREAD = 0,
	IRQTF_WARNED = 1,
	IRQTF_AFFINITY = 2,
	IRQTF_FORCED_THREAD = 3,
};

struct irq_desc___9;

typedef void (*irq_flow_handler_t___9)(struct irq_desc___9 *);

struct irq_chip___9;

struct irq_domain___16;

struct irq_data___9 {
	u32 mask;
	unsigned int irq;
	long unsigned int hwirq;
	struct irq_common_data *common;
	struct irq_chip___9 *chip;
	struct irq_domain___16 *domain;
	struct irq_data___9 *parent_data;
	void *chip_data;
};

struct kset___37;

struct kobj_type___37;

struct kernfs_node___38;

struct kobject___38 {
	const char *name;
	struct list_head entry;
	struct kobject___38 *parent;
	struct kset___37 *kset;
	struct kobj_type___37 *ktype;
	struct kernfs_node___38 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module___37;

struct irq_desc___9 {
	struct irq_common_data irq_common_data;
	struct irq_data___9 irq_data;
	unsigned int *kstat_irqs;
	irq_flow_handler_t___9 handle_irq;
	struct irqaction___5 *action;
	unsigned int status_use_accessors;
	unsigned int core_internal_state__do_not_mess_with_it;
	unsigned int depth;
	unsigned int wake_depth;
	unsigned int tot_count;
	unsigned int irq_count;
	long unsigned int last_unhandled;
	unsigned int irqs_unhandled;
	atomic_t threads_handled;
	int threads_handled_last;
	raw_spinlock_t lock;
	struct cpumask *percpu_enabled;
	const struct cpumask *percpu_affinity;
	const struct cpumask *affinity_hint;
	struct irq_affinity_notify *affinity_notify;
	cpumask_var_t pending_mask;
	long unsigned int threads_oneshot;
	atomic_t threads_active;
	wait_queue_head_t wait_for_threads;
	unsigned int nr_actions;
	unsigned int no_suspend_depth;
	unsigned int cond_suspend_depth;
	unsigned int force_resume_depth;
	struct proc_dir_entry *dir;
	struct callback_head rcu;
	struct kobject___38 kobj;
	struct mutex request_mutex;
	int parent_irq;
	struct module___37 *owner;
	const char *name;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irq_domain_ops___16;

struct fwnode_handle___37;

struct irq_domain_chip_generic___8;

struct irq_domain___16 {
	struct list_head link;
	const char *name;
	const struct irq_domain_ops___16 *ops;
	void *host_data;
	unsigned int flags;
	unsigned int mapcount;
	struct fwnode_handle___37 *fwnode;
	enum irq_domain_bus_token bus_token;
	struct irq_domain_chip_generic___8 *gc;
	struct irq_domain___16 *parent;
	irq_hw_number_t hwirq_max;
	unsigned int revmap_size;
	struct xarray revmap_tree;
	struct mutex revmap_mutex;
	struct irq_data___9 *revmap[0];
};

struct fwnode_operations___37;

struct device___40;

struct fwnode_handle___37 {
	struct fwnode_handle___37 *secondary;
	const struct fwnode_operations___37 *ops;
	struct device___40 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct fwnode_reference_args___37;

struct fwnode_endpoint___37;

struct fwnode_operations___37 {
	struct fwnode_handle___37 * (*get)(struct fwnode_handle___37 *);
	void (*put)(struct fwnode_handle___37 *);
	bool (*device_is_available)(const struct fwnode_handle___37 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___37 *, const struct device___40 *);
	bool (*property_present)(const struct fwnode_handle___37 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___37 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___37 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___37 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___37 *);
	struct fwnode_handle___37 * (*get_parent)(const struct fwnode_handle___37 *);
	struct fwnode_handle___37 * (*get_next_child_node)(const struct fwnode_handle___37 *, struct fwnode_handle___37 *);
	struct fwnode_handle___37 * (*get_named_child_node)(const struct fwnode_handle___37 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___37 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___37 *);
	struct fwnode_handle___37 * (*graph_get_next_endpoint)(const struct fwnode_handle___37 *, struct fwnode_handle___37 *);
	struct fwnode_handle___37 * (*graph_get_remote_endpoint)(const struct fwnode_handle___37 *);
	struct fwnode_handle___37 * (*graph_get_port_parent)(struct fwnode_handle___37 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___37 *, struct fwnode_endpoint___37 *);
	int (*add_links)(struct fwnode_handle___37 *);
};

struct wakeup_source___40;

struct dev_pm_info___40 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___40 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___40 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___40;

struct bus_type___40;

struct device_driver___40;

struct dev_pm_domain___40;

struct device_node___22;

struct class___40;

struct attribute_group___38;

struct device___40 {
	struct kobject___38 kobj;
	struct device___40 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___40 *type;
	struct bus_type___40 *bus;
	struct device_driver___40 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___40 power;
	struct dev_pm_domain___40 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___16 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___22 *of_node;
	struct fwnode_handle___37 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___40 *class;
	const struct attribute_group___38 **groups;
	void (*release)(struct device___40 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fwnode_endpoint___37 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___37 *local_fwnode;
};

struct fwnode_reference_args___37 {
	struct fwnode_handle___37 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct irq_chip___9 {
	struct device___40 *parent_device;
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___9 *);
	void (*irq_shutdown)(struct irq_data___9 *);
	void (*irq_enable)(struct irq_data___9 *);
	void (*irq_disable)(struct irq_data___9 *);
	void (*irq_ack)(struct irq_data___9 *);
	void (*irq_mask)(struct irq_data___9 *);
	void (*irq_mask_ack)(struct irq_data___9 *);
	void (*irq_unmask)(struct irq_data___9 *);
	void (*irq_eoi)(struct irq_data___9 *);
	int (*irq_set_affinity)(struct irq_data___9 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___9 *);
	int (*irq_set_type)(struct irq_data___9 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___9 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___9 *);
	void (*irq_bus_sync_unlock)(struct irq_data___9 *);
	void (*irq_cpu_online)(struct irq_data___9 *);
	void (*irq_cpu_offline)(struct irq_data___9 *);
	void (*irq_suspend)(struct irq_data___9 *);
	void (*irq_resume)(struct irq_data___9 *);
	void (*irq_pm_shutdown)(struct irq_data___9 *);
	void (*irq_calc_mask)(struct irq_data___9 *);
	void (*irq_print_chip)(struct irq_data___9 *, struct seq_file *);
	int (*irq_request_resources)(struct irq_data___9 *);
	void (*irq_release_resources)(struct irq_data___9 *);
	void (*irq_compose_msi_msg)(struct irq_data___9 *, struct msi_msg *);
	void (*irq_write_msi_msg)(struct irq_data___9 *, struct msi_msg *);
	int (*irq_get_irqchip_state)(struct irq_data___9 *, enum irqchip_irq_state, bool *);
	int (*irq_set_irqchip_state)(struct irq_data___9 *, enum irqchip_irq_state, bool);
	int (*irq_set_vcpu_affinity)(struct irq_data___9 *, void *);
	void (*ipi_send_single)(struct irq_data___9 *, unsigned int);
	void (*ipi_send_mask)(struct irq_data___9 *, const struct cpumask *);
	int (*irq_nmi_setup)(struct irq_data___9 *);
	void (*irq_nmi_teardown)(struct irq_data___9 *);
	long unsigned int flags;
};

struct kernfs_root___38;

struct kernfs_elem_dir___38 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___38 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___38;

struct kernfs_root___38 {
	struct kernfs_node___38 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___38 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___38 {
	struct kernfs_node___38 *target_kn;
};

struct kernfs_ops___38;

struct kernfs_elem_attr___38 {
	const struct kernfs_ops___38 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___38 *notify_next;
};

struct kernfs_node___38 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___38 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___38 dir;
		struct kernfs_elem_symlink___38 symlink;
		struct kernfs_elem_attr___38 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___38;

struct kernfs_ops___38 {
	int (*open)(struct kernfs_open_file___38 *);
	void (*release)(struct kernfs_open_file___38 *);
	int (*seq_show)(struct seq_file *, void *);
	void * (*seq_start)(struct seq_file *, loff_t *);
	void * (*seq_next)(struct seq_file *, void *, loff_t *);
	void (*seq_stop)(struct seq_file *, void *);
	ssize_t (*read)(struct kernfs_open_file___38 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___38 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___38 *, struct poll_table_struct *);
	int (*mmap)(struct kernfs_open_file___38 *, struct vm_area_struct___12 *);
};

struct kernfs_syscall_ops___38 {
	int (*show_options)(struct seq_file *, struct kernfs_root___38 *);
	int (*mkdir)(struct kernfs_node___38 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___38 *);
	int (*rename)(struct kernfs_node___38 *, struct kernfs_node___38 *, const char *);
	int (*show_path)(struct seq_file *, struct kernfs_node___38 *, struct kernfs_root___38 *);
};

struct kernfs_open_file___38 {
	struct kernfs_node___38 *kn;
	struct file___7 *file;
	struct seq_file *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___6 *vm_ops;
};

struct bin_attribute___38;

struct attribute_group___38 {
	const char *name;
	umode_t (*is_visible)(struct kobject___38 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___38 *, struct bin_attribute___38 *, int);
	struct attribute **attrs;
	struct bin_attribute___38 **bin_attrs;
};

struct bin_attribute___38 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___8 * (*f_mapping)();
	ssize_t (*read)(struct file___7 *, struct kobject___38 *, struct bin_attribute___38 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___7 *, struct kobject___38 *, struct bin_attribute___38 *, char *, loff_t, size_t);
	int (*mmap)(struct file___7 *, struct kobject___38 *, struct bin_attribute___38 *, struct vm_area_struct___12 *);
};

struct sysfs_ops___37 {
	ssize_t (*show)(struct kobject___38 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___38 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___37;

struct kset___37 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___38 kobj;
	const struct kset_uevent_ops___37 *uevent_ops;
};

struct kobj_type___37 {
	void (*release)(struct kobject___38 *);
	const struct sysfs_ops___37 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___38 **default_groups;
	const struct kobj_ns_type_operations___3 * (*child_ns_type)(struct kobject___38 *);
	const void * (*namespace)(struct kobject___38 *);
	void (*get_ownership)(struct kobject___38 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___37 {
	int (* const filter)(struct kset___37 *, struct kobject___38 *);
	const char * (* const name)(struct kset___37 *, struct kobject___38 *);
	int (* const uevent)(struct kset___37 *, struct kobject___38 *, struct kobj_uevent_env *);
};

struct module_kobject___37 {
	struct kobject___38 kobj;
	struct module___37 *mod;
	struct kobject___38 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___37 {
	struct module___37 *mod;
	struct latch_tree_node node;
};

struct module_layout___37 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___37 mtn;
};

struct module_attribute___37;

struct kernel_param___37;

struct module___37 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___37 mkobj;
	struct module_attribute___37 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___38 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___37 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___37 core_layout;
	struct module_layout___37 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map___28 *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___4 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	int num_static_call_sites;
	struct static_call_site *static_call_sites;
	bool klp;
	bool klp_alive;
	struct klp_modinfo *klp_info;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irq_chip_type___8 {
	struct irq_chip___9 chip;
	struct irq_chip_regs regs;
	irq_flow_handler_t___9 handler;
	u32 type;
	u32 mask_cache_priv;
	u32 *mask_cache;
};

struct irq_chip_generic___8 {
	raw_spinlock_t lock;
	void *reg_base;
	u32 (*reg_readl)(void *);
	void (*reg_writel)(u32, void *);
	void (*suspend)(struct irq_chip_generic___8 *);
	void (*resume)(struct irq_chip_generic___8 *);
	unsigned int irq_base;
	unsigned int irq_cnt;
	u32 mask_cache;
	u32 type_cache;
	u32 polarity_cache;
	u32 wake_enabled;
	u32 wake_active;
	unsigned int num_ct;
	void *private;
	long unsigned int installed;
	long unsigned int unused;
	struct irq_domain___16 *domain;
	struct list_head list;
	struct irq_chip_type___8 chip_types[0];
};

struct irq_domain_chip_generic___8 {
	unsigned int irqs_per_chip;
	unsigned int num_chips;
	unsigned int irq_flags_to_clear;
	unsigned int irq_flags_to_set;
	enum irq_gc_flags gc_flags;
	struct irq_chip_generic___8 *gc[0];
};

struct kernel_param_ops___37 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___37 *);
	int (*get)(char *, const struct kernel_param___37 *);
	void (*free)(void *);
};

struct kparam_array___37;

struct kernel_param___37 {
	const char *name;
	struct module___37 *mod;
	const struct kernel_param_ops___37 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___37 *arr;
	};
};

struct kparam_array___37 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___37 *ops;
	void *elem;
};

struct module_attribute___37 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___37 *, struct module_kobject___37 *, char *);
	ssize_t (*store)(struct module_attribute___37 *, struct module_kobject___37 *, const char *, size_t);
	void (*setup)(struct module___37 *, const char *);
	int (*test)(struct module___37 *);
	void (*free)(struct module___37 *);
};

enum {
	IRQC_IS_HARDIRQ = 0,
	IRQC_IS_NESTED = 1,
};

struct device_node___22 {
	const char *name;
	phandle phandle;
	const char *full_name;
	struct fwnode_handle___37 fwnode;
	struct property *properties;
	struct property *deadprops;
	struct device_node___22 *parent;
	struct device_node___22 *child;
	struct device_node___22 *sibling;
	long unsigned int _flags;
	void *data;
};

struct irq_fwspec___15 {
	struct fwnode_handle___37 *fwnode;
	int param_count;
	u32 param[16];
};

struct irq_domain_ops___16 {
	int (*match)(struct irq_domain___16 *, struct device_node___22 *, enum irq_domain_bus_token);
	int (*select)(struct irq_domain___16 *, struct irq_fwspec___15 *, enum irq_domain_bus_token);
	int (*map)(struct irq_domain___16 *, unsigned int, irq_hw_number_t);
	void (*unmap)(struct irq_domain___16 *, unsigned int);
	int (*xlate)(struct irq_domain___16 *, struct device_node___22 *, const u32 *, unsigned int, long unsigned int *, unsigned int *);
	int (*alloc)(struct irq_domain___16 *, unsigned int, unsigned int, void *);
	void (*free)(struct irq_domain___16 *, unsigned int, unsigned int);
	int (*activate)(struct irq_domain___16 *, struct irq_data___9 *, bool);
	void (*deactivate)(struct irq_domain___16 *, struct irq_data___9 *);
	int (*translate)(struct irq_domain___16 *, struct irq_fwspec___15 *, long unsigned int *, unsigned int *);
};

struct dev_pm_ops___40 {
	int (*prepare)(struct device___40 *);
	void (*complete)(struct device___40 *);
	int (*suspend)(struct device___40 *);
	int (*resume)(struct device___40 *);
	int (*freeze)(struct device___40 *);
	int (*thaw)(struct device___40 *);
	int (*poweroff)(struct device___40 *);
	int (*restore)(struct device___40 *);
	int (*suspend_late)(struct device___40 *);
	int (*resume_early)(struct device___40 *);
	int (*freeze_late)(struct device___40 *);
	int (*thaw_early)(struct device___40 *);
	int (*poweroff_late)(struct device___40 *);
	int (*restore_early)(struct device___40 *);
	int (*suspend_noirq)(struct device___40 *);
	int (*resume_noirq)(struct device___40 *);
	int (*freeze_noirq)(struct device___40 *);
	int (*thaw_noirq)(struct device___40 *);
	int (*poweroff_noirq)(struct device___40 *);
	int (*restore_noirq)(struct device___40 *);
	int (*runtime_suspend)(struct device___40 *);
	int (*runtime_resume)(struct device___40 *);
	int (*runtime_idle)(struct device___40 *);
};

struct wakeup_source___40 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___40 *dev;
	bool active: 1;
	bool autosleep_enabled: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___40 {
	struct dev_pm_ops___40 ops;
	int (*start)(struct device___40 *);
	void (*detach)(struct device___40 *, bool);
	int (*activate)(struct device___40 *);
	void (*sync)(struct device___40 *);
	void (*dismiss)(struct device___40 *);
};

struct bus_type___40 {
	const char *name;
	const char *dev_name;
	struct device___40 *dev_root;
	const struct attribute_group___38 **bus_groups;
	const struct attribute_group___38 **dev_groups;
	const struct attribute_group___38 **drv_groups;
	int (*match)(struct device___40 *, struct device_driver___40 *);
	int (*uevent)(struct device___40 *, struct kobj_uevent_env *);
	int (*probe)(struct device___40 *);
	void (*sync_state)(struct device___40 *);
	void (*remove)(struct device___40 *);
	void (*shutdown)(struct device___40 *);
	int (*online)(struct device___40 *);
	int (*offline)(struct device___40 *);
	int (*suspend)(struct device___40 *, pm_message_t);
	int (*resume)(struct device___40 *);
	int (*num_vf)(struct device___40 *);
	int (*dma_configure)(struct device___40 *);
	const struct dev_pm_ops___40 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___40 {
	const char *name;
	struct bus_type___40 *bus;
	struct module___37 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___40 *);
	void (*sync_state)(struct device___40 *);
	int (*remove)(struct device___40 *);
	void (*shutdown)(struct device___40 *);
	int (*suspend)(struct device___40 *, pm_message_t);
	int (*resume)(struct device___40 *);
	const struct attribute_group___38 **groups;
	const struct attribute_group___38 **dev_groups;
	const struct dev_pm_ops___40 *pm;
	void (*coredump)(struct device___40 *);
	struct driver_private *p;
};

struct device_type___40 {
	const char *name;
	const struct attribute_group___38 **groups;
	int (*uevent)(struct device___40 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___40 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___40 *);
	const struct dev_pm_ops___40 *pm;
};

struct class___40 {
	const char *name;
	struct module___37 *owner;
	const struct attribute_group___38 **class_groups;
	const struct attribute_group___38 **dev_groups;
	struct kobject___38 *dev_kobj;
	int (*dev_uevent)(struct device___40 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___40 *, umode_t *);
	void (*class_release)(struct class___40 *);
	void (*dev_release)(struct device___40 *);
	int (*shutdown_pre)(struct device___40 *);
	const struct kobj_ns_type_operations___3 *ns_type;
	const void * (*namespace)(struct device___40 *);
	void (*get_ownership)(struct device___40 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___40 *pm;
	struct subsys_private *p;
};

struct module___38;

struct static_call_mod___29 {
	struct static_call_mod___29 *next;
	struct module___38 *mod;
	struct static_call_site *sites;
};

struct static_call_key___29 {
	void *func;
	union {
		long unsigned int type;
		struct static_call_mod___29 *mods;
		struct static_call_site *sites;
	};
};

struct tracepoint___29 {
	const char *name;
	struct static_key key;
	struct static_call_key___29 *static_call_key;
	void *static_call_tramp;
	void *iterator;
	int (*regfunc)();
	void (*unregfunc)();
	struct tracepoint_func *funcs;
};

struct bpf_raw_event_map___29 {
	struct tracepoint___29 *tp;
	void *bpf_func;
	u32 num_args;
	u32 writable_size;
	long: 64;
};

struct irq_desc___10;

typedef void (*irq_flow_handler_t___10)(struct irq_desc___10 *);

struct msi_desc___6;

struct irq_common_data___6 {
	unsigned int state_use_accessors;
	unsigned int node;
	void *handler_data;
	struct msi_desc___6 *msi_desc;
	cpumask_var_t affinity;
	cpumask_var_t effective_affinity;
};

struct irq_chip___10;

struct irq_domain___17;

struct irq_data___10 {
	u32 mask;
	unsigned int irq;
	long unsigned int hwirq;
	struct irq_common_data___6 *common;
	struct irq_chip___10 *chip;
	struct irq_domain___17 *domain;
	struct irq_data___10 *parent_data;
	void *chip_data;
};

struct irq_desc___10 {
	struct irq_common_data___6 irq_common_data;
	struct irq_data___10 irq_data;
	unsigned int *kstat_irqs;
	irq_flow_handler_t___10 handle_irq;
	struct irqaction___5 *action;
	unsigned int status_use_accessors;
	unsigned int core_internal_state__do_not_mess_with_it;
	unsigned int depth;
	unsigned int wake_depth;
	unsigned int tot_count;
	unsigned int irq_count;
	long unsigned int last_unhandled;
	unsigned int irqs_unhandled;
	atomic_t threads_handled;
	int threads_handled_last;
	raw_spinlock_t lock;
	struct cpumask *percpu_enabled;
	const struct cpumask *percpu_affinity;
	const struct cpumask *affinity_hint;
	struct irq_affinity_notify *affinity_notify;
	cpumask_var_t pending_mask;
	long unsigned int threads_oneshot;
	atomic_t threads_active;
	wait_queue_head_t wait_for_threads;
	unsigned int nr_actions;
	unsigned int no_suspend_depth;
	unsigned int cond_suspend_depth;
	unsigned int force_resume_depth;
	struct proc_dir_entry *dir;
	struct callback_head rcu;
	struct kobject___11 kobj;
	struct mutex request_mutex;
	int parent_irq;
	struct module___38 *owner;
	const char *name;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irq_domain_ops___17;

struct fwnode_handle___38;

struct irq_domain_chip_generic___9;

struct irq_domain___17 {
	struct list_head link;
	const char *name;
	const struct irq_domain_ops___17 *ops;
	void *host_data;
	unsigned int flags;
	unsigned int mapcount;
	struct fwnode_handle___38 *fwnode;
	enum irq_domain_bus_token bus_token;
	struct irq_domain_chip_generic___9 *gc;
	struct irq_domain___17 *parent;
	irq_hw_number_t hwirq_max;
	unsigned int revmap_size;
	struct xarray revmap_tree;
	struct mutex revmap_mutex;
	struct irq_data___10 *revmap[0];
};

struct fwnode_operations___38;

struct device___41;

struct fwnode_handle___38 {
	struct fwnode_handle___38 *secondary;
	const struct fwnode_operations___38 *ops;
	struct device___41 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct fwnode_reference_args___38;

struct fwnode_endpoint___38;

struct fwnode_operations___38 {
	struct fwnode_handle___38 * (*get)(struct fwnode_handle___38 *);
	void (*put)(struct fwnode_handle___38 *);
	bool (*device_is_available)(const struct fwnode_handle___38 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___38 *, const struct device___41 *);
	bool (*property_present)(const struct fwnode_handle___38 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___38 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___38 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___38 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___38 *);
	struct fwnode_handle___38 * (*get_parent)(const struct fwnode_handle___38 *);
	struct fwnode_handle___38 * (*get_next_child_node)(const struct fwnode_handle___38 *, struct fwnode_handle___38 *);
	struct fwnode_handle___38 * (*get_named_child_node)(const struct fwnode_handle___38 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___38 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___38 *);
	struct fwnode_handle___38 * (*graph_get_next_endpoint)(const struct fwnode_handle___38 *, struct fwnode_handle___38 *);
	struct fwnode_handle___38 * (*graph_get_remote_endpoint)(const struct fwnode_handle___38 *);
	struct fwnode_handle___38 * (*graph_get_port_parent)(struct fwnode_handle___38 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___38 *, struct fwnode_endpoint___38 *);
	int (*add_links)(struct fwnode_handle___38 *);
};

struct wakeup_source___41;

struct dev_pm_info___41 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___41 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___41 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___41;

struct bus_type___41;

struct device_driver___41;

struct dev_pm_domain___41;

struct device_node___23;

struct class___41;

struct device___41 {
	struct kobject___11 kobj;
	struct device___41 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___41 *type;
	struct bus_type___41 *bus;
	struct device_driver___41 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___41 power;
	struct dev_pm_domain___41 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___17 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___23 *of_node;
	struct fwnode_handle___38 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___41 *class;
	const struct attribute_group___11 **groups;
	void (*release)(struct device___41 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fwnode_endpoint___38 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___38 *local_fwnode;
};

struct fwnode_reference_args___38 {
	struct fwnode_handle___38 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct msi_desc___6 {
	struct list_head list;
	unsigned int irq;
	unsigned int nvec_used;
	struct device___41 *dev;
	struct msi_msg msg;
	struct irq_affinity_desc *affinity;
	const void *iommu_cookie;
	void (*write_msi_msg)(struct msi_desc___6 *, void *);
	void *write_msi_msg_data;
	union {
		struct {
			union {
				u32 msi_mask;
				u32 msix_ctrl;
			};
			struct {
				u8 is_msix: 1;
				u8 multiple: 3;
				u8 multi_cap: 3;
				u8 can_mask: 1;
				u8 is_64: 1;
				u8 is_virtual: 1;
				u16 entry_nr;
				unsigned int default_irq;
			} msi_attrib;
			union {
				u8 mask_pos;
				void *mask_base;
			};
		};
		struct platform_msi_desc platform;
		struct fsl_mc_msi_desc fsl_mc;
		struct ti_sci_inta_msi_desc inta;
	};
};

struct irq_chip___10 {
	struct device___41 *parent_device;
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___10 *);
	void (*irq_shutdown)(struct irq_data___10 *);
	void (*irq_enable)(struct irq_data___10 *);
	void (*irq_disable)(struct irq_data___10 *);
	void (*irq_ack)(struct irq_data___10 *);
	void (*irq_mask)(struct irq_data___10 *);
	void (*irq_mask_ack)(struct irq_data___10 *);
	void (*irq_unmask)(struct irq_data___10 *);
	void (*irq_eoi)(struct irq_data___10 *);
	int (*irq_set_affinity)(struct irq_data___10 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___10 *);
	int (*irq_set_type)(struct irq_data___10 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___10 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___10 *);
	void (*irq_bus_sync_unlock)(struct irq_data___10 *);
	void (*irq_cpu_online)(struct irq_data___10 *);
	void (*irq_cpu_offline)(struct irq_data___10 *);
	void (*irq_suspend)(struct irq_data___10 *);
	void (*irq_resume)(struct irq_data___10 *);
	void (*irq_pm_shutdown)(struct irq_data___10 *);
	void (*irq_calc_mask)(struct irq_data___10 *);
	void (*irq_print_chip)(struct irq_data___10 *, struct seq_file *);
	int (*irq_request_resources)(struct irq_data___10 *);
	void (*irq_release_resources)(struct irq_data___10 *);
	void (*irq_compose_msi_msg)(struct irq_data___10 *, struct msi_msg *);
	void (*irq_write_msi_msg)(struct irq_data___10 *, struct msi_msg *);
	int (*irq_get_irqchip_state)(struct irq_data___10 *, enum irqchip_irq_state, bool *);
	int (*irq_set_irqchip_state)(struct irq_data___10 *, enum irqchip_irq_state, bool);
	int (*irq_set_vcpu_affinity)(struct irq_data___10 *, void *);
	void (*ipi_send_single)(struct irq_data___10 *, unsigned int);
	void (*ipi_send_mask)(struct irq_data___10 *, const struct cpumask *);
	int (*irq_nmi_setup)(struct irq_data___10 *);
	void (*irq_nmi_teardown)(struct irq_data___10 *);
	long unsigned int flags;
};

struct module_kobject___38 {
	struct kobject___11 kobj;
	struct module___38 *mod;
	struct kobject___11 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___38 {
	struct module___38 *mod;
	struct latch_tree_node node;
};

struct module_layout___38 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___38 mtn;
};

struct module_attribute___38;

struct kernel_param___38;

struct module___38 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___38 mkobj;
	struct module_attribute___38 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___11 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___38 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___38 core_layout;
	struct module_layout___38 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map___29 *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___4 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	int num_static_call_sites;
	struct static_call_site *static_call_sites;
	bool klp;
	bool klp_alive;
	struct klp_modinfo *klp_info;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irq_chip_type___9 {
	struct irq_chip___10 chip;
	struct irq_chip_regs regs;
	irq_flow_handler_t___10 handler;
	u32 type;
	u32 mask_cache_priv;
	u32 *mask_cache;
};

struct irq_chip_generic___9 {
	raw_spinlock_t lock;
	void *reg_base;
	u32 (*reg_readl)(void *);
	void (*reg_writel)(u32, void *);
	void (*suspend)(struct irq_chip_generic___9 *);
	void (*resume)(struct irq_chip_generic___9 *);
	unsigned int irq_base;
	unsigned int irq_cnt;
	u32 mask_cache;
	u32 type_cache;
	u32 polarity_cache;
	u32 wake_enabled;
	u32 wake_active;
	unsigned int num_ct;
	void *private;
	long unsigned int installed;
	long unsigned int unused;
	struct irq_domain___17 *domain;
	struct list_head list;
	struct irq_chip_type___9 chip_types[0];
};

struct irq_domain_chip_generic___9 {
	unsigned int irqs_per_chip;
	unsigned int num_chips;
	unsigned int irq_flags_to_clear;
	unsigned int irq_flags_to_set;
	enum irq_gc_flags gc_flags;
	struct irq_chip_generic___9 *gc[0];
};

struct device_node___23 {
	const char *name;
	phandle phandle;
	const char *full_name;
	struct fwnode_handle___38 fwnode;
	struct property *properties;
	struct property *deadprops;
	struct device_node___23 *parent;
	struct device_node___23 *child;
	struct device_node___23 *sibling;
	long unsigned int _flags;
	void *data;
};

struct irq_fwspec___16 {
	struct fwnode_handle___38 *fwnode;
	int param_count;
	u32 param[16];
};

struct irq_domain_ops___17 {
	int (*match)(struct irq_domain___17 *, struct device_node___23 *, enum irq_domain_bus_token);
	int (*select)(struct irq_domain___17 *, struct irq_fwspec___16 *, enum irq_domain_bus_token);
	int (*map)(struct irq_domain___17 *, unsigned int, irq_hw_number_t);
	void (*unmap)(struct irq_domain___17 *, unsigned int);
	int (*xlate)(struct irq_domain___17 *, struct device_node___23 *, const u32 *, unsigned int, long unsigned int *, unsigned int *);
	int (*alloc)(struct irq_domain___17 *, unsigned int, unsigned int, void *);
	void (*free)(struct irq_domain___17 *, unsigned int, unsigned int);
	int (*activate)(struct irq_domain___17 *, struct irq_data___10 *, bool);
	void (*deactivate)(struct irq_domain___17 *, struct irq_data___10 *);
	int (*translate)(struct irq_domain___17 *, struct irq_fwspec___16 *, long unsigned int *, unsigned int *);
};

struct kernel_param_ops___38 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___38 *);
	int (*get)(char *, const struct kernel_param___38 *);
	void (*free)(void *);
};

struct kparam_array___38;

struct kernel_param___38 {
	const char *name;
	struct module___38 *mod;
	const struct kernel_param_ops___38 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___38 *arr;
	};
};

struct kparam_array___38 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___38 *ops;
	void *elem;
};

struct module_attribute___38 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___38 *, struct module_kobject___38 *, char *);
	ssize_t (*store)(struct module_attribute___38 *, struct module_kobject___38 *, const char *, size_t);
	void (*setup)(struct module___38 *, const char *);
	int (*test)(struct module___38 *);
	void (*free)(struct module___38 *);
};

struct dev_pm_ops___41 {
	int (*prepare)(struct device___41 *);
	void (*complete)(struct device___41 *);
	int (*suspend)(struct device___41 *);
	int (*resume)(struct device___41 *);
	int (*freeze)(struct device___41 *);
	int (*thaw)(struct device___41 *);
	int (*poweroff)(struct device___41 *);
	int (*restore)(struct device___41 *);
	int (*suspend_late)(struct device___41 *);
	int (*resume_early)(struct device___41 *);
	int (*freeze_late)(struct device___41 *);
	int (*thaw_early)(struct device___41 *);
	int (*poweroff_late)(struct device___41 *);
	int (*restore_early)(struct device___41 *);
	int (*suspend_noirq)(struct device___41 *);
	int (*resume_noirq)(struct device___41 *);
	int (*freeze_noirq)(struct device___41 *);
	int (*thaw_noirq)(struct device___41 *);
	int (*poweroff_noirq)(struct device___41 *);
	int (*restore_noirq)(struct device___41 *);
	int (*runtime_suspend)(struct device___41 *);
	int (*runtime_resume)(struct device___41 *);
	int (*runtime_idle)(struct device___41 *);
};

struct wakeup_source___41 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___41 *dev;
	bool active;
	bool autosleep_enabled;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___41 {
	struct dev_pm_ops___41 ops;
	int (*start)(struct device___41 *);
	void (*detach)(struct device___41 *, bool);
	int (*activate)(struct device___41 *);
	void (*sync)(struct device___41 *);
	void (*dismiss)(struct device___41 *);
};

struct bus_type___41 {
	const char *name;
	const char *dev_name;
	struct device___41 *dev_root;
	const struct attribute_group___11 **bus_groups;
	const struct attribute_group___11 **dev_groups;
	const struct attribute_group___11 **drv_groups;
	int (*match)(struct device___41 *, struct device_driver___41 *);
	int (*uevent)(struct device___41 *, struct kobj_uevent_env *);
	int (*probe)(struct device___41 *);
	void (*sync_state)(struct device___41 *);
	void (*remove)(struct device___41 *);
	void (*shutdown)(struct device___41 *);
	int (*online)(struct device___41 *);
	int (*offline)(struct device___41 *);
	int (*suspend)(struct device___41 *, pm_message_t);
	int (*resume)(struct device___41 *);
	int (*num_vf)(struct device___41 *);
	int (*dma_configure)(struct device___41 *);
	const struct dev_pm_ops___41 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___41 {
	const char *name;
	struct bus_type___41 *bus;
	struct module___38 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___41 *);
	void (*sync_state)(struct device___41 *);
	int (*remove)(struct device___41 *);
	void (*shutdown)(struct device___41 *);
	int (*suspend)(struct device___41 *, pm_message_t);
	int (*resume)(struct device___41 *);
	const struct attribute_group___11 **groups;
	const struct attribute_group___11 **dev_groups;
	const struct dev_pm_ops___41 *pm;
	void (*coredump)(struct device___41 *);
	struct driver_private *p;
};

struct device_type___41 {
	const char *name;
	const struct attribute_group___11 **groups;
	int (*uevent)(struct device___41 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___41 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___41 *);
	const struct dev_pm_ops___41 *pm;
};

struct class___41 {
	const char *name;
	struct module___38 *owner;
	const struct attribute_group___11 **class_groups;
	const struct attribute_group___11 **dev_groups;
	struct kobject___11 *dev_kobj;
	int (*dev_uevent)(struct device___41 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___41 *, umode_t *);
	void (*class_release)(struct class___41 *);
	void (*dev_release)(struct device___41 *);
	int (*shutdown_pre)(struct device___41 *);
	const struct kobj_ns_type_operations___3 *ns_type;
	const void * (*namespace)(struct device___41 *);
	void (*get_ownership)(struct device___41 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___41 *pm;
	struct subsys_private *p;
};

enum {
	IRQ_STARTUP_NORMAL = 0,
	IRQ_STARTUP_MANAGED = 1,
	IRQ_STARTUP_ABORT = 2,
};

typedef void (*dr_release_t___3)(struct device___41 *, void *);

typedef int (*dr_match_t___2)(struct device___41 *, void *, void *);

struct irq_devres {
	unsigned int irq;
	void *dev_id;
};

struct irq_desc_devres {
	unsigned int from;
	unsigned int cnt;
};

struct irq_generic_chip_devres {
	struct irq_chip_generic___9 *gc;
	u32 msk;
	unsigned int clr;
	unsigned int set;
};

struct of_phandle_args___3 {
	struct device_node___13 *np;
	int args_count;
	uint32_t args[16];
};

struct irqchip_fwid {
	struct fwnode_handle___17 fwnode;
	unsigned int type;
	char *name;
	phys_addr_t *pa;
};

enum {
	AFFINITY = 0,
	AFFINITY_LIST = 1,
	EFFECTIVE = 2,
	EFFECTIVE_LIST = 3,
};

struct irq_desc___11;

typedef void (*irq_flow_handler_t___11)(struct irq_desc___11 *);

struct irq_chip___11;

struct irq_data___11 {
	u32 mask;
	unsigned int irq;
	long unsigned int hwirq;
	struct irq_common_data___6 *common;
	struct irq_chip___11 *chip;
	struct irq_domain *domain;
	struct irq_data___11 *parent_data;
	void *chip_data;
};

struct irqaction___7;

struct irq_desc___11 {
	struct irq_common_data___6 irq_common_data;
	struct irq_data___11 irq_data;
	unsigned int *kstat_irqs;
	irq_flow_handler_t___11 handle_irq;
	struct irqaction___7 *action;
	unsigned int status_use_accessors;
	unsigned int core_internal_state__do_not_mess_with_it;
	unsigned int depth;
	unsigned int wake_depth;
	unsigned int tot_count;
	unsigned int irq_count;
	long unsigned int last_unhandled;
	unsigned int irqs_unhandled;
	atomic_t threads_handled;
	int threads_handled_last;
	raw_spinlock_t lock;
	struct cpumask *percpu_enabled;
	const struct cpumask *percpu_affinity;
	const struct cpumask *affinity_hint;
	struct irq_affinity_notify *affinity_notify;
	cpumask_var_t pending_mask;
	long unsigned int threads_oneshot;
	atomic_t threads_active;
	wait_queue_head_t wait_for_threads;
	unsigned int nr_actions;
	unsigned int no_suspend_depth;
	unsigned int cond_suspend_depth;
	unsigned int force_resume_depth;
	struct proc_dir_entry *dir;
	struct callback_head rcu;
	struct kobject___36 kobj;
	struct mutex request_mutex;
	int parent_irq;
	struct module___35 *owner;
	const char *name;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irq_chip___11 {
	struct device___38 *parent_device;
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___11 *);
	void (*irq_shutdown)(struct irq_data___11 *);
	void (*irq_enable)(struct irq_data___11 *);
	void (*irq_disable)(struct irq_data___11 *);
	void (*irq_ack)(struct irq_data___11 *);
	void (*irq_mask)(struct irq_data___11 *);
	void (*irq_mask_ack)(struct irq_data___11 *);
	void (*irq_unmask)(struct irq_data___11 *);
	void (*irq_eoi)(struct irq_data___11 *);
	int (*irq_set_affinity)(struct irq_data___11 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___11 *);
	int (*irq_set_type)(struct irq_data___11 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___11 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___11 *);
	void (*irq_bus_sync_unlock)(struct irq_data___11 *);
	void (*irq_cpu_online)(struct irq_data___11 *);
	void (*irq_cpu_offline)(struct irq_data___11 *);
	void (*irq_suspend)(struct irq_data___11 *);
	void (*irq_resume)(struct irq_data___11 *);
	void (*irq_pm_shutdown)(struct irq_data___11 *);
	void (*irq_calc_mask)(struct irq_data___11 *);
	void (*irq_print_chip)(struct irq_data___11 *, struct seq_file___34 *);
	int (*irq_request_resources)(struct irq_data___11 *);
	void (*irq_release_resources)(struct irq_data___11 *);
	void (*irq_compose_msi_msg)(struct irq_data___11 *, struct msi_msg *);
	void (*irq_write_msi_msg)(struct irq_data___11 *, struct msi_msg *);
	int (*irq_get_irqchip_state)(struct irq_data___11 *, enum irqchip_irq_state, bool *);
	int (*irq_set_irqchip_state)(struct irq_data___11 *, enum irqchip_irq_state, bool);
	int (*irq_set_vcpu_affinity)(struct irq_data___11 *, void *);
	void (*ipi_send_single)(struct irq_data___11 *, unsigned int);
	void (*ipi_send_mask)(struct irq_data___11 *, const struct cpumask *);
	int (*irq_nmi_setup)(struct irq_data___11 *);
	void (*irq_nmi_teardown)(struct irq_data___11 *);
	long unsigned int flags;
};

struct irqaction___7 {
	irq_handler_t handler;
	void *dev_id;
	void *percpu_dev_id;
	struct irqaction___7 *next;
	irq_handler_t thread_fn;
	struct task_struct___39 *thread;
	struct irqaction___7 *secondary;
	unsigned int irq;
	unsigned int flags;
	long unsigned int thread_flags;
	long unsigned int thread_mask;
	const char *name;
	struct proc_dir_entry *dir;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct device_attribute___8 {
	struct attribute attr;
	ssize_t (*show)(struct device___13 *, struct device_attribute___8 *, char *);
	ssize_t (*store)(struct device___13 *, struct device_attribute___8 *, const char *, size_t);
};

struct irq_affinity {
	unsigned int pre_vectors;
	unsigned int post_vectors;
	unsigned int nr_sets;
	unsigned int set_size[4];
	void (*calc_sets)(struct irq_affinity *, unsigned int);
	void *priv;
};

struct node_vectors {
	unsigned int id;
	union {
		unsigned int nvectors;
		unsigned int ncpus;
	};
};

struct cpumap {
	unsigned int available;
	unsigned int allocated;
	unsigned int managed;
	unsigned int managed_allocated;
	bool initialized;
	bool online;
	long unsigned int alloc_map[4];
	long unsigned int managed_map[4];
};

struct irq_matrix___2 {
	unsigned int matrix_bits;
	unsigned int alloc_start;
	unsigned int alloc_end;
	unsigned int alloc_size;
	unsigned int global_available;
	unsigned int global_reserved;
	unsigned int systembits_inalloc;
	unsigned int total_allocated;
	unsigned int online_maps;
	struct cpumap *maps;
	long unsigned int scratch_map[4];
	long unsigned int system_map[4];
};

struct trace_event_raw_irq_matrix_global {
	struct trace_entry ent;
	unsigned int online_maps;
	unsigned int global_available;
	unsigned int global_reserved;
	unsigned int total_allocated;
	char __data[0];
};

struct trace_event_raw_irq_matrix_global_update {
	struct trace_entry ent;
	int bit;
	unsigned int online_maps;
	unsigned int global_available;
	unsigned int global_reserved;
	unsigned int total_allocated;
	char __data[0];
};

struct trace_event_raw_irq_matrix_cpu {
	struct trace_entry ent;
	int bit;
	unsigned int cpu;
	bool online;
	unsigned int available;
	unsigned int allocated;
	unsigned int managed;
	unsigned int online_maps;
	unsigned int global_available;
	unsigned int global_reserved;
	unsigned int total_allocated;
	char __data[0];
};

struct trace_event_data_offsets_irq_matrix_global {};

struct trace_event_data_offsets_irq_matrix_global_update {};

struct trace_event_data_offsets_irq_matrix_cpu {};

typedef void (*btf_trace_irq_matrix_online)(void *, struct irq_matrix___2 *);

typedef void (*btf_trace_irq_matrix_offline)(void *, struct irq_matrix___2 *);

typedef void (*btf_trace_irq_matrix_reserve)(void *, struct irq_matrix___2 *);

typedef void (*btf_trace_irq_matrix_remove_reserved)(void *, struct irq_matrix___2 *);

typedef void (*btf_trace_irq_matrix_assign_system)(void *, int, struct irq_matrix___2 *);

typedef void (*btf_trace_irq_matrix_alloc_reserved)(void *, int, unsigned int, struct irq_matrix___2 *, struct cpumap *);

typedef void (*btf_trace_irq_matrix_reserve_managed)(void *, int, unsigned int, struct irq_matrix___2 *, struct cpumap *);

typedef void (*btf_trace_irq_matrix_remove_managed)(void *, int, unsigned int, struct irq_matrix___2 *, struct cpumap *);

typedef void (*btf_trace_irq_matrix_alloc_managed)(void *, int, unsigned int, struct irq_matrix___2 *, struct cpumap *);

typedef void (*btf_trace_irq_matrix_assign)(void *, int, unsigned int, struct irq_matrix___2 *, struct cpumap *);

typedef void (*btf_trace_irq_matrix_alloc)(void *, int, unsigned int, struct irq_matrix___2 *, struct cpumap *);

typedef void (*btf_trace_irq_matrix_free)(void *, int, unsigned int, struct irq_matrix___2 *, struct cpumap *);

typedef void (*call_rcu_func_t)(struct callback_head *, rcu_callback_t);

struct rcu_synchronize {
	struct callback_head head;
	struct completion completion;
};

struct trace_event_raw_rcu_utilization {
	struct trace_entry ent;
	const char *s;
	char __data[0];
};

struct trace_event_raw_rcu_stall_warning {
	struct trace_entry ent;
	const char *rcuname;
	const char *msg;
	char __data[0];
};

struct trace_event_data_offsets_rcu_utilization {};

struct trace_event_data_offsets_rcu_stall_warning {};

typedef void (*btf_trace_rcu_utilization)(void *, const char *);

typedef void (*btf_trace_rcu_stall_warning)(void *, const char *, const char *);

struct rcu_tasks;

typedef void (*rcu_tasks_gp_func_t)(struct rcu_tasks *);

typedef void (*pregp_func_t)();

typedef void (*pertask_func_t)(struct task_struct___38 *, struct list_head *);

typedef void (*postscan_func_t)(struct list_head *);

typedef void (*holdouts_func_t)(struct list_head *, bool, bool *);

typedef void (*postgp_func_t)(struct rcu_tasks *);

struct rcu_tasks {
	struct callback_head *cbs_head;
	struct callback_head **cbs_tail;
	struct wait_queue_head cbs_wq;
	raw_spinlock_t cbs_lock;
	int gp_state;
	int gp_sleep;
	int init_fract;
	long unsigned int gp_jiffies;
	long unsigned int gp_start;
	long unsigned int n_gps;
	long unsigned int n_ipis;
	long unsigned int n_ipis_fails;
	struct task_struct___38 *kthread_ptr;
	rcu_tasks_gp_func_t gp_func;
	pregp_func_t pregp_func;
	pertask_func_t pertask_func;
	postscan_func_t postscan_func;
	holdouts_func_t holdouts_func;
	postgp_func_t postgp_func;
	call_rcu_func_t call_func;
	char *name;
	char *kname;
};

enum {
	GP_IDLE = 0,
	GP_ENTER = 1,
	GP_PASSED = 2,
	GP_EXIT = 3,
	GP_REPLAY = 4,
};

struct rcu_cblist {
	struct callback_head *head;
	struct callback_head **tail;
	long int len;
};

enum rcutorture_type {
	RCU_FLAVOR = 0,
	RCU_TASKS_FLAVOR = 1,
	RCU_TASKS_RUDE_FLAVOR = 2,
	RCU_TASKS_TRACING_FLAVOR = 3,
	RCU_TRIVIAL_FLAVOR = 4,
	SRCU_FLAVOR = 5,
	INVALID_RCU_FLAVOR = 6,
};

struct dentry___38;

struct super_block___38;

struct module___39;

struct file_system_type___38 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___38 * (*mount)(struct file_system_type___38 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___38 *);
	struct module___39 *owner;
	struct file_system_type___38 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___38;

struct kiocb___38;

struct iov_iter___31;

struct poll_table_struct___29;

struct vm_area_struct___41;

struct inode___38;

struct file_lock___38;

struct page___40;

struct seq_file___36;

struct file_operations___38 {
	struct module___39 *owner;
	loff_t (*llseek)(struct file___38 *, loff_t, int);
	ssize_t (*read)(struct file___38 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___38 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___38 *, struct iov_iter___31 *);
	ssize_t (*write_iter)(struct kiocb___38 *, struct iov_iter___31 *);
	int (*iopoll)(struct kiocb___38 *, bool);
	int (*iterate)(struct file___38 *, struct dir_context *);
	int (*iterate_shared)(struct file___38 *, struct dir_context *);
	__poll_t (*poll)(struct file___38 *, struct poll_table_struct___29 *);
	long int (*unlocked_ioctl)(struct file___38 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___38 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___38 *, struct vm_area_struct___41 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___38 *, struct file___38 *);
	int (*flush)(struct file___38 *, fl_owner_t);
	int (*release)(struct inode___38 *, struct file___38 *);
	int (*fsync)(struct file___38 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___38 *, int);
	int (*lock)(struct file___38 *, int, struct file_lock___38 *);
	ssize_t (*sendpage)(struct file___38 *, struct page___40 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___38 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___38 *, long unsigned int);
	int (*flock)(struct file___38 *, int, struct file_lock___38 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___38 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___38 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___38 *, long int, struct file_lock___38 **, void **);
	long int (*fallocate)(struct file___38 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___36 *, struct file___38 *);
	ssize_t (*copy_file_range)(struct file___38 *, loff_t, struct file___38 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___38 *, loff_t, struct file___38 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___38 *, loff_t, loff_t, int);
};

struct static_call_mod___30 {
	struct static_call_mod___30 *next;
	struct module___39 *mod;
	struct static_call_site *sites;
};

struct static_call_key___30 {
	void *func;
	union {
		long unsigned int type;
		struct static_call_mod___30 *mods;
		struct static_call_site *sites;
	};
};

struct vmacache___40 {
	u64 seqnum;
	struct vm_area_struct___41 *vmas[4];
};

struct page_frag___40 {
	struct page___40 *page;
	__u32 offset;
	__u32 size;
};

struct perf_event___26;

struct thread_struct___27 {
	struct desc_struct tls_array[3];
	long unsigned int sp;
	short unsigned int es;
	short unsigned int ds;
	short unsigned int fsindex;
	short unsigned int gsindex;
	long unsigned int fsbase;
	long unsigned int gsbase;
	struct perf_event___26 *ptrace_bps[4];
	long unsigned int virtual_dr6;
	long unsigned int ptrace_dr7;
	long unsigned int cr2;
	long unsigned int trap_nr;
	long unsigned int error_code;
	struct io_bitmap *io_bitmap;
	long unsigned int iopl_emul;
	unsigned int iopl_warn: 1;
	unsigned int sig_on_uaccess_err: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u32 pkru;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct fpu fpu;
};

struct mm_struct___41;

struct pid___33;

struct nsproxy___37;

struct signal_struct___38;

struct rt_mutex_waiter___2;

struct bio_list___26;

struct backing_dev_info___25;

struct io_context___26;

struct css_set___32;

struct perf_event_context___26;

struct mem_cgroup___25;

struct request_queue___26;

struct vm_struct___35;

struct task_struct___41 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___41 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___3 se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___41 *mm;
	struct mm_struct___41 *active_mm;
	struct vmacache___40 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int restore_sigmask: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___41 *real_parent;
	struct task_struct___41 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___41 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___33 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	struct posix_cputimers_work posix_cputimers_work;
	const struct cred___2 *ptracer_cred;
	const struct cred___2 *real_cred;
	const struct cred___2 *cred;
	struct key *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___37 *nsproxy;
	struct signal_struct___38 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___41 *pi_top_task;
	struct rt_mutex_waiter___2 *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___26 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___25 *backing_dev_info;
	struct io_context___26 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___32 *cgroups;
	struct list_head cg_list;
	u32 closid;
	u32 rmid;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___26 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	long: 64;
	long: 64;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___40 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___25 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___25 *active_memcg;
	struct request_queue___26 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___41 *oom_reaper_list;
	struct vm_struct___35 *stack_vm_area;
	refcount_t stack_refcount;
	int patch_state;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	void *mce_vaddr;
	__u64 mce_kflags;
	u64 mce_addr;
	__u64 mce_ripv: 1;
	__u64 mce_whole_page: 1;
	__u64 __mce_reserved: 62;
	long: 2;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct callback_head mce_kill_me;
	int mce_count;
	struct llist_head kretprobe_instances;
	struct callback_head l1d_flush_kill;
	long: 64;
	struct thread_struct___27 thread;
};

typedef struct page___40 *pgtable_t___40;

struct address_space___38;

struct dev_pagemap___38;

struct page___40 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___38 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___13 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___40 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___40 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___41 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___38 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct pv_cpu_ops___33 {
	void (*io_delay)();
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	void (*write_cr4)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___27 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(long unsigned int);
	void (*invalidate_io_bitmap)();
	void (*update_io_bitmap)();
	void (*wbinvd)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int);
	void (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_msr_safe)(unsigned int, int *);
	int (*write_msr_safe)(unsigned int, unsigned int, unsigned int);
	u64 (*read_pmc)(int);
	void (*start_context_switch)(struct task_struct___41 *);
	void (*end_context_switch)(struct task_struct___41 *);
};

struct pv_mmu_ops___35 {
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_one_user)(long unsigned int);
	void (*flush_tlb_multi)(const struct cpumask *, const struct flush_tlb_info___3 *);
	void (*tlb_remove_table)(struct mmu_gather *, void *);
	void (*exit_mmap)(struct mm_struct___41 *);
	struct paravirt_callee_save read_cr2;
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___41 *, struct mm_struct___41 *);
	void (*dup_mmap)(struct mm_struct___41 *, struct mm_struct___41 *);
	int (*pgd_alloc)(struct mm_struct___41 *);
	void (*pgd_free)(struct mm_struct___41 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___41 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___41 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___41 *, long unsigned int);
	void (*alloc_p4d)(struct mm_struct___41 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*release_p4d)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	pte_t (*ptep_modify_prot_start)(struct vm_area_struct___41 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct vm_area_struct___41 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_p4d)(p4d_t *, p4d_t);
	struct paravirt_callee_save p4d_val;
	struct paravirt_callee_save make_p4d;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

struct core_state___40;

struct mm_struct___41 {
	struct {
		struct vm_area_struct___41 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___38 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int mmap_compat_base;
		long unsigned int mmap_compat_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[48];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___40 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___41 *owner;
		struct user_namespace___2 *user_ns;
		struct file___38 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		bool tlb_flush_batched;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct vm_operations_struct___38;

struct vm_area_struct___41 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___41 *vm_next;
	struct vm_area_struct___41 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___41 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___38 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___38 *vm_file;
	struct file___38 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct paravirt_patch_template___35 {
	struct pv_cpu_ops___33 cpu;
	struct pv_irq_ops irq;
	struct pv_mmu_ops___35 mmu;
	struct pv_lock_ops lock;
};

struct tracepoint___30 {
	const char *name;
	struct static_key key;
	struct static_call_key___30 *static_call_key;
	void *static_call_tramp;
	void *iterator;
	int (*regfunc)();
	void (*unregfunc)();
	struct tracepoint_func *funcs;
};

struct bpf_raw_event_map___30 {
	struct tracepoint___30 *tp;
	void *bpf_func;
	u32 num_args;
	u32 writable_size;
	long: 64;
};

struct seq_operations___36 {
	void * (*start)(struct seq_file___36 *, loff_t *);
	void (*stop)(struct seq_file___36 *, void *);
	void * (*next)(struct seq_file___36 *, void *, loff_t *);
	int (*show)(struct seq_file___36 *, void *);
};

struct hw_perf_event___26 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___41 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	union {
		struct {
			u64 last_period;
			local64_t period_left;
		};
		struct {
			u64 saved_metric;
			u64 saved_slots;
		};
	};
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___26)(struct perf_event___26 *, struct perf_sample_data *, struct pt_regs *);

struct pmu___26;

struct fasync_struct___38;

struct pid_namespace___33;

struct trace_event_call___26;

struct perf_cgroup___26;

struct perf_event___26 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___26 *group_leader;
	struct pmu___26 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___26 hw;
	struct perf_event_context___26 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___26 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___41 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct perf_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___38 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	long unsigned int pending_addr;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	struct perf_addr_filter_range *addr_filter_ranges;
	long unsigned int addr_filters_gen;
	struct perf_event___26 *aux_event;
	void (*destroy)(struct perf_event___26 *);
	struct callback_head callback_head;
	struct pid_namespace___33 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___26 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___26 orig_overflow_handler;
	struct bpf_prog *prog;
	u64 bpf_cookie;
	struct trace_event_call___26 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___26 *cgrp;
	void *security;
	struct list_head sb_list;
};

struct swait_queue___4 {
	struct task_struct___41 *task;
	struct list_head task_list;
};

struct upid___33 {
	int nr;
	struct pid_namespace___33 *ns;
};

struct pid_namespace___33 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___41 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___33 *parent;
	struct fs_pin *bacct;
	struct user_namespace___2 *user_ns;
	struct ucounts___2 *ucounts;
	int reboot;
	struct ns_common___5 ns;
};

struct pid___33 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___33 numbers[1];
};

struct rt_mutex_base___2 {
	raw_spinlock_t wait_lock;
	struct rb_root_cached waiters;
	struct task_struct___41 *owner;
};

struct rt_mutex___2 {
	struct rt_mutex_base___2 rtmutex;
};

struct ww_acquire_ctx___2 {
	struct task_struct___41 *task;
	long unsigned int stamp;
	unsigned int acquired;
	short unsigned int wounded;
	short unsigned int is_wait_die;
};

struct signal_struct___38 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___41 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___41 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper;
	unsigned int has_child_subreaper;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___33 *pids[4];
	struct pid___33 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___41 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct cgroup_namespace___32;

struct nsproxy___37 {
	atomic_t count;
	struct uts_namespace *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___33 *pid_ns_for_children;
	struct net *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___32 *cgroup_ns;
};

struct rt_mutex_waiter___2 {
	struct rb_node tree_entry;
	struct rb_node pi_tree_entry;
	struct task_struct___41 *task;
	struct rt_mutex_base___2 *lock;
	unsigned int wake_state;
	int prio;
	u64 deadline;
	struct ww_acquire_ctx___2 *ww_ctx;
};

struct bio___26;

struct bio_list___26 {
	struct bio___26 *head;
	struct bio___26 *tail;
};

struct cgroup_subsys_state___32;

struct bdi_writeback___25 {
	struct backing_dev_info___25 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	atomic_t writeback_inodes;
	struct percpu_counter stat[4];
	long unsigned int congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	struct delayed_work bw_dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___32 *memcg_css;
	struct cgroup_subsys_state___32 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	struct list_head b_attached;
	struct list_head offline_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
};

struct device___42;

struct backing_dev_info___25 {
	u64 id;
	struct rb_node rb_node;
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___25 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct mutex cgwb_release_mutex;
	struct rw_semaphore wb_switch_rwsem;
	wait_queue_head_t wb_waitq;
	struct device___42 *dev;
	char dev_name[64];
	struct device___42 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___38 *debug_dir;
};

struct io_cq___26;

struct io_context___26 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	struct xarray icq_tree;
	struct io_cq___26 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct cgroup___32;

struct css_set___32 {
	struct cgroup_subsys_state___32 *subsys[14];
	refcount_t refcount;
	struct css_set___32 *dom_cset;
	struct cgroup___32 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___32 *mg_src_cgrp;
	struct cgroup___32 *mg_dst_cgrp;
	struct css_set___32 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___26 {
	struct pmu___26 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	int rotate_necessary;
	refcount_t refcount;
	struct task_struct___41 *task;
	u64 time;
	u64 timestamp;
	u64 timeoffset;
	struct perf_event_context___26 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

struct cgroup_subsys___32;

struct cgroup_subsys_state___32 {
	struct cgroup___32 *cgroup;
	struct cgroup_subsys___32 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___32 *parent;
};

struct kernfs_node___39;

struct cgroup_file___32 {
	struct kernfs_node___39 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct obj_cgroup___25;

struct mem_cgroup_per_node___25;

struct mem_cgroup___25 {
	struct cgroup_subsys_state___32 css;
	struct mem_cgroup_id id;
	struct page_counter memory;
	union {
		struct page_counter swap;
		struct page_counter memsw;
	};
	struct page_counter kmem;
	struct page_counter tcpmem;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool oom_group;
	bool oom_lock;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___32 events_file;
	struct cgroup_file___32 events_local_file;
	struct cgroup_file___32 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	struct memcg_vmstats vmstats;
	atomic_long_t memory_events[8];
	atomic_long_t memory_events_local[8];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct obj_cgroup___25 *objcg;
	struct list_head objcg_list;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad2_;
	atomic_t moving_account;
	struct task_struct___41 *move_lock_task;
	struct memcg_vmstats_percpu *vmstats_percpu;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct memcg_cgwb_frn cgwb_frn[4];
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct deferred_split deferred_split_queue;
	struct mem_cgroup_per_node___25 *nodeinfo[0];
	long: 64;
};

struct kset___38;

struct kobj_type___38;

struct kobject___39 {
	const char *name;
	struct list_head entry;
	struct kobject___39 *parent;
	struct kset___38 *kset;
	struct kobj_type___38 *ktype;
	struct kernfs_node___39 *sd;
	struct kref kref;
	unsigned int state_initialized;
	unsigned int state_in_sysfs;
	unsigned int state_add_uevent_sent;
	unsigned int state_remove_uevent_sent;
	unsigned int uevent_suppress;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct blk_integrity_profile___26;

struct blk_integrity___26 {
	const struct blk_integrity_profile___26 *profile;
	unsigned char flags;
	unsigned char tuple_size;
	unsigned char interval_exp;
	unsigned char tag_size;
};

struct bio_set___26 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	struct bio_alloc_cache *cache;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	unsigned int back_pad;
	spinlock_t rescue_lock;
	struct bio_list___26 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	struct hlist_node cpuhp_dead;
};

struct request___26;

struct elevator_queue___26;

struct gendisk___26;

struct blkcg_gq___25;

struct request_queue___26 {
	struct request___26 *last_merge;
	struct elevator_queue___26 *elevator;
	struct percpu_ref q_usage_counter;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	const struct blk_mq_ops *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx **queue_hw_ctx;
	unsigned int nr_hw_queues;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	spinlock_t queue_lock;
	struct gendisk___26 *disk;
	struct kobject___39 kobj;
	struct kobject___39 *mq_kobj;
	struct blk_integrity___26 integrity;
	struct device___42 *dev;
	enum rpm_status rpm_status;
	long unsigned int nr_requests;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_keyslot_manager *ksm;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	atomic_t nr_active_requests_shared_sbitmap;
	struct sbitmap_queue sched_bitmap_tags;
	struct sbitmap_queue sched_breserved_tags;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___25 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int required_elevator_features;
	unsigned int nr_zones;
	long unsigned int *conv_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int max_open_zones;
	unsigned int max_active_zones;
	int node;
	struct mutex debugfs_mutex;
	struct blk_trace *blk_trace;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	struct mutex sysfs_dir_lock;
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	int mq_freeze_depth;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct mutex mq_freeze_lock;
	struct blk_mq_tag_set *tag_set;
	struct list_head tag_set_list;
	struct bio_set___26 bio_split;
	struct dentry___38 *debugfs_dir;
	struct dentry___38 *sched_debugfs_dir;
	struct dentry___38 *rqos_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	u64 write_hints[5];
};

struct vm_struct___35 {
	struct vm_struct___35 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___40 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct dev_pm_ops___42 {
	int (*prepare)(struct device___42 *);
	void (*complete)(struct device___42 *);
	int (*suspend)(struct device___42 *);
	int (*resume)(struct device___42 *);
	int (*freeze)(struct device___42 *);
	int (*thaw)(struct device___42 *);
	int (*poweroff)(struct device___42 *);
	int (*restore)(struct device___42 *);
	int (*suspend_late)(struct device___42 *);
	int (*resume_early)(struct device___42 *);
	int (*freeze_late)(struct device___42 *);
	int (*thaw_early)(struct device___42 *);
	int (*poweroff_late)(struct device___42 *);
	int (*restore_early)(struct device___42 *);
	int (*suspend_noirq)(struct device___42 *);
	int (*resume_noirq)(struct device___42 *);
	int (*freeze_noirq)(struct device___42 *);
	int (*thaw_noirq)(struct device___42 *);
	int (*poweroff_noirq)(struct device___42 *);
	int (*restore_noirq)(struct device___42 *);
	int (*runtime_suspend)(struct device___42 *);
	int (*runtime_resume)(struct device___42 *);
	int (*runtime_idle)(struct device___42 *);
};

struct wakeup_source___42;

struct dev_pm_info___42 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___42 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___42 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___42;

struct bus_type___42;

struct device_driver___42;

struct dev_pm_domain___42;

struct device_node___24;

struct fwnode_handle___39;

struct class___42;

struct attribute_group___39;

struct device___42 {
	struct kobject___39 kobj;
	struct device___42 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___42 *type;
	struct bus_type___42 *bus;
	struct device_driver___42 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___42 power;
	struct dev_pm_domain___42 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___24 *of_node;
	struct fwnode_handle___39 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___42 *class;
	const struct attribute_group___39 **groups;
	void (*release)(struct device___42 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct wakeup_source___42 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___42 *dev;
	bool active;
	bool autosleep_enabled;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___42 {
	struct dev_pm_ops___42 ops;
	int (*start)(struct device___42 *);
	void (*detach)(struct device___42 *, bool);
	int (*activate)(struct device___42 *);
	void (*sync)(struct device___42 *);
	void (*dismiss)(struct device___42 *);
};

struct fwnode_operations___39;

struct fwnode_handle___39 {
	struct fwnode_handle___39 *secondary;
	const struct fwnode_operations___39 *ops;
	struct device___42 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct fwnode_reference_args___39;

struct fwnode_endpoint___39;

struct fwnode_operations___39 {
	struct fwnode_handle___39 * (*get)(struct fwnode_handle___39 *);
	void (*put)(struct fwnode_handle___39 *);
	bool (*device_is_available)(const struct fwnode_handle___39 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___39 *, const struct device___42 *);
	bool (*property_present)(const struct fwnode_handle___39 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___39 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___39 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___39 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___39 *);
	struct fwnode_handle___39 * (*get_parent)(const struct fwnode_handle___39 *);
	struct fwnode_handle___39 * (*get_next_child_node)(const struct fwnode_handle___39 *, struct fwnode_handle___39 *);
	struct fwnode_handle___39 * (*get_named_child_node)(const struct fwnode_handle___39 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___39 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___39 *);
	struct fwnode_handle___39 * (*graph_get_next_endpoint)(const struct fwnode_handle___39 *, struct fwnode_handle___39 *);
	struct fwnode_handle___39 * (*graph_get_remote_endpoint)(const struct fwnode_handle___39 *);
	struct fwnode_handle___39 * (*graph_get_port_parent)(struct fwnode_handle___39 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___39 *, struct fwnode_endpoint___39 *);
	int (*add_links)(struct fwnode_handle___39 *);
};

struct fwnode_endpoint___39 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___39 *local_fwnode;
};

struct fwnode_reference_args___39 {
	struct fwnode_handle___39 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct kernel_param___39;

struct kernel_param_ops___39 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___39 *);
	int (*get)(char *, const struct kernel_param___39 *);
	void (*free)(void *);
};

struct kparam_array___39;

struct kernel_param___39 {
	const char *name;
	struct module___39 *mod;
	const struct kernel_param_ops___39 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___39 *arr;
	};
};

struct kparam_array___39 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___39 *ops;
	void *elem;
};

struct module_kobject___39 {
	struct kobject___39 kobj;
	struct module___39 *mod;
	struct kobject___39 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___39 {
	struct module___39 *mod;
	struct latch_tree_node node;
};

struct module_layout___39 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___39 mtn;
};

struct module_attribute___39;

struct module___39 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___39 mkobj;
	struct module_attribute___39 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___39 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___39 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___39 core_layout;
	struct module_layout___39 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map___30 *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___26 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	int num_static_call_sites;
	struct static_call_site *static_call_sites;
	bool klp;
	bool klp_alive;
	struct klp_modinfo *klp_info;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct address_space_operations___38;

struct address_space___38 {
	struct inode___38 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___38 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct dev_pagemap_ops___38;

struct dev_pagemap___38 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___38 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vfsmount___38;

struct path___38 {
	struct vfsmount___38 *mnt;
	struct dentry___38 *dentry;
};

struct fown_struct___33 {
	rwlock_t lock;
	struct pid___33 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___38 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	long: 64;
	long: 64;
	struct path___38 f_path;
	struct inode___38 *f_inode;
	const struct file_operations___38 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___33 f_owner;
	const struct cred___2 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___38 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___38;

struct vm_operations_struct___38 {
	void (*open)(struct vm_area_struct___41 *);
	void (*close)(struct vm_area_struct___41 *);
	int (*may_split)(struct vm_area_struct___41 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___41 *);
	int (*mprotect)(struct vm_area_struct___41 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___38 *);
	vm_fault_t (*huge_fault)(struct vm_fault___38 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___38 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___41 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___38 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___38 *);
	int (*access)(struct vm_area_struct___41 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___41 *);
	int (*set_policy)(struct vm_area_struct___41 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___41 *, long unsigned int);
	struct page___40 * (*find_special_page)(struct vm_area_struct___41 *, long unsigned int);
};

struct core_thread___40 {
	struct task_struct___41 *task;
	struct core_thread___40 *next;
};

struct core_state___40 {
	atomic_t nr_threads;
	struct core_thread___40 dumper;
	struct completion startup;
};

struct vm_fault___38 {
	const struct {
		struct vm_area_struct___41 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___40 *cow_page;
	struct page___40 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___40 prealloc_pte;
};

struct pglist_data___26;

struct lruvec___26 {
	struct list_head lists[5];
	spinlock_t lru_lock;
	long unsigned int anon_cost;
	long unsigned int file_cost;
	atomic_long_t nonresident_age;
	long unsigned int refaults[2];
	long unsigned int flags;
	struct pglist_data___26 *pgdat;
};

struct zone___26 {
	long unsigned int _watermark[3];
	long unsigned int watermark_boost;
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[5];
	int node;
	struct pglist_data___26 *zone_pgdat;
	struct per_cpu_pages *per_cpu_pageset;
	struct per_cpu_zonestat *per_cpu_zonestats;
	int pageset_high;
	int pageset_batch;
	long unsigned int zone_start_pfn;
	atomic_long_t managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int present_early_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	seqlock_t span_seqlock;
	int initialized;
	int: 32;
	struct zone_padding _pad1_;
	struct free_area free_area[11];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	long unsigned int compact_init_migrate_pfn;
	long unsigned int compact_init_free_pfn;
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	short: 16;
	struct zone_padding _pad3_;
	atomic_long_t vm_stat[11];
	atomic_long_t vm_numa_event[6];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___26 {
	struct zone___26 *zone;
	int zone_idx;
};

struct zonelist___26 {
	struct zoneref___26 _zonerefs[5121];
};

struct pglist_data___26 {
	struct zone___26 node_zones[5];
	struct zonelist___26 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___41 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_highest_zoneidx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_highest_zoneidx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___41 *kcompactd;
	bool proactive_compact_trigger;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct deferred_split deferred_split_queue;
	struct lruvec___26 __lruvec;
	long unsigned int flags;
	long: 64;
	struct zone_padding _pad2_;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[39];
};

struct kernfs_root___39;

struct kernfs_elem_dir___39 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___39 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___39;

struct kernfs_root___39 {
	struct kernfs_node___39 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___39 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___39 {
	struct kernfs_node___39 *target_kn;
};

struct kernfs_ops___39;

struct kernfs_elem_attr___39 {
	const struct kernfs_ops___39 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___39 *notify_next;
};

struct kernfs_node___39 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___39 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___39 dir;
		struct kernfs_elem_symlink___39 symlink;
		struct kernfs_elem_attr___39 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___39;

struct kernfs_ops___39 {
	int (*open)(struct kernfs_open_file___39 *);
	void (*release)(struct kernfs_open_file___39 *);
	int (*seq_show)(struct seq_file___36 *, void *);
	void * (*seq_start)(struct seq_file___36 *, loff_t *);
	void * (*seq_next)(struct seq_file___36 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___36 *, void *);
	ssize_t (*read)(struct kernfs_open_file___39 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___39 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___39 *, struct poll_table_struct___29 *);
	int (*mmap)(struct kernfs_open_file___39 *, struct vm_area_struct___41 *);
};

struct kernfs_syscall_ops___39 {
	int (*show_options)(struct seq_file___36 *, struct kernfs_root___39 *);
	int (*mkdir)(struct kernfs_node___39 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___39 *);
	int (*rename)(struct kernfs_node___39 *, struct kernfs_node___39 *, const char *);
	int (*show_path)(struct seq_file___36 *, struct kernfs_node___39 *, struct kernfs_root___39 *);
};

struct seq_file___36 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___36 *op;
	int poll_event;
	const struct file___38 *file;
	void *private;
};

struct kernfs_open_file___39 {
	struct kernfs_node___39 *kn;
	struct file___38 *file;
	struct seq_file___36 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped;
	bool released;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___38 *vm_ops;
};

typedef void (*poll_queue_proc___29)(struct file___38 *, wait_queue_head_t *, struct poll_table_struct___29 *);

struct poll_table_struct___29 {
	poll_queue_proc___29 _qproc;
	__poll_t _key;
};

struct bin_attribute___39;

struct attribute_group___39 {
	const char *name;
	umode_t (*is_visible)(struct kobject___39 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___39 *, struct bin_attribute___39 *, int);
	struct attribute **attrs;
	struct bin_attribute___39 **bin_attrs;
};

struct bin_attribute___39 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___38 * (*f_mapping)();
	ssize_t (*read)(struct file___38 *, struct kobject___39 *, struct bin_attribute___39 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___38 *, struct kobject___39 *, struct bin_attribute___39 *, char *, loff_t, size_t);
	int (*mmap)(struct file___38 *, struct kobject___39 *, struct bin_attribute___39 *, struct vm_area_struct___41 *);
};

struct sysfs_ops___38 {
	ssize_t (*show)(struct kobject___39 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___39 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___38;

struct kset___38 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___39 kobj;
	const struct kset_uevent_ops___38 *uevent_ops;
};

struct kobj_type___38 {
	void (*release)(struct kobject___39 *);
	const struct sysfs_ops___38 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___39 **default_groups;
	const struct kobj_ns_type_operations___3 * (*child_ns_type)(struct kobject___39 *);
	const void * (*namespace)(struct kobject___39 *);
	void (*get_ownership)(struct kobject___39 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___38 {
	int (* const filter)(struct kset___38 *, struct kobject___39 *);
	const char * (* const name)(struct kset___38 *, struct kobject___39 *);
	int (* const uevent)(struct kset___38 *, struct kobject___39 *, struct kobj_uevent_env *);
};

struct bus_type___42 {
	const char *name;
	const char *dev_name;
	struct device___42 *dev_root;
	const struct attribute_group___39 **bus_groups;
	const struct attribute_group___39 **dev_groups;
	const struct attribute_group___39 **drv_groups;
	int (*match)(struct device___42 *, struct device_driver___42 *);
	int (*uevent)(struct device___42 *, struct kobj_uevent_env *);
	int (*probe)(struct device___42 *);
	void (*sync_state)(struct device___42 *);
	void (*remove)(struct device___42 *);
	void (*shutdown)(struct device___42 *);
	int (*online)(struct device___42 *);
	int (*offline)(struct device___42 *);
	int (*suspend)(struct device___42 *, pm_message_t);
	int (*resume)(struct device___42 *);
	int (*num_vf)(struct device___42 *);
	int (*dma_configure)(struct device___42 *);
	const struct dev_pm_ops___42 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___42 {
	const char *name;
	struct bus_type___42 *bus;
	struct module___39 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___42 *);
	void (*sync_state)(struct device___42 *);
	int (*remove)(struct device___42 *);
	void (*shutdown)(struct device___42 *);
	int (*suspend)(struct device___42 *, pm_message_t);
	int (*resume)(struct device___42 *);
	const struct attribute_group___39 **groups;
	const struct attribute_group___39 **dev_groups;
	const struct dev_pm_ops___42 *pm;
	void (*coredump)(struct device___42 *);
	struct driver_private *p;
};

struct device_type___42 {
	const char *name;
	const struct attribute_group___39 **groups;
	int (*uevent)(struct device___42 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___42 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___42 *);
	const struct dev_pm_ops___42 *pm;
};

struct class___42 {
	const char *name;
	struct module___39 *owner;
	const struct attribute_group___39 **class_groups;
	const struct attribute_group___39 **dev_groups;
	struct kobject___39 *dev_kobj;
	int (*dev_uevent)(struct device___42 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___42 *, umode_t *);
	void (*class_release)(struct class___42 *);
	void (*dev_release)(struct device___42 *);
	int (*shutdown_pre)(struct device___42 *);
	const struct kobj_ns_type_operations___3 *ns_type;
	const void * (*namespace)(struct device___42 *);
	void (*get_ownership)(struct device___42 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___42 *pm;
	struct subsys_private *p;
};

struct device_node___24 {
	const char *name;
	phandle phandle;
	const char *full_name;
	struct fwnode_handle___39 fwnode;
	struct property *properties;
	struct property *deadprops;
	struct device_node___24 *parent;
	struct device_node___24 *child;
	struct device_node___24 *sibling;
	long unsigned int _flags;
	void *data;
};

struct shrink_control___25 {
	gfp_t gfp_mask;
	int nid;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	struct mem_cgroup___25 *memcg;
};

struct shrinker___25 {
	long unsigned int (*count_objects)(struct shrinker___25 *, struct shrink_control___25 *);
	long unsigned int (*scan_objects)(struct shrinker___25 *, struct shrink_control___25 *);
	long int batch;
	int seeks;
	unsigned int flags;
	struct list_head list;
	int id;
	atomic_long_t *nr_deferred;
};

struct dev_pagemap_ops___38 {
	void (*page_free)(struct page___40 *);
	void (*kill)(struct dev_pagemap___38 *);
	void (*cleanup)(struct dev_pagemap___38 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___38 *);
};

struct dentry_operations___38;

struct dentry___38 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___38 *d_parent;
	struct qstr d_name;
	struct inode___38 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___38 *d_op;
	struct super_block___38 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___38;

struct inode___38 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___38 *i_op;
	struct super_block___38 *i_sb;
	struct address_space___38 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___25 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	long: 64;
	long: 64;
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___38 *i_fop;
		void (*free_inode)(struct inode___38 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___38 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct cdev___15 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___38 {
	int (*d_revalidate)(struct dentry___38 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___38 *, unsigned int);
	int (*d_hash)(const struct dentry___38 *, struct qstr *);
	int (*d_compare)(const struct dentry___38 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___38 *);
	int (*d_init)(struct dentry___38 *);
	void (*d_release)(struct dentry___38 *);
	void (*d_prune)(struct dentry___38 *);
	void (*d_iput)(struct dentry___38 *, struct inode___38 *);
	char * (*d_dname)(struct dentry___38 *, char *, int);
	struct vfsmount___38 * (*d_automount)(struct path___38 *);
	int (*d_manage)(const struct path___38 *, bool);
	struct dentry___38 * (*d_real)(struct dentry___38 *, const struct inode___38 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___38;

struct mem_dqinfo___38 {
	struct quota_format_type___38 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___38;

struct quota_info___38 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___38 *files[3];
	struct mem_dqinfo___38 info[3];
	const struct quota_format_ops___38 *ops[3];
};

struct rcuwait___38 {
	struct task_struct___41 *task;
};

struct percpu_rw_semaphore___38 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___38 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___38 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___38 rw_sem[3];
};

struct super_operations___38;

struct dquot_operations___38;

struct quotactl_ops___38;

struct block_device___26;

struct super_block___38 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___38 *s_type;
	const struct super_operations___38 *s_op;
	const struct dquot_operations___38 *dq_op;
	const struct quotactl_ops___38 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___38 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___26 *s_bdev;
	struct backing_dev_info___25 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___38 s_dquot;
	struct sb_writers___38 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___38 *s_d_op;
	int cleancache_poolid;
	struct shrinker___25 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___2 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___38 {
	struct dentry___38 *mnt_root;
	struct super_block___38 *mnt_sb;
	int mnt_flags;
	struct user_namespace___2 *mnt_userns;
};

struct psi_group___32 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___41 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___32;

struct cgroup_rstat_cpu___32;

struct cgroup___32 {
	struct cgroup_subsys_state___32 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___39 *kn;
	struct cgroup_file___32 procs_file;
	struct cgroup_file___32 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___32 *subsys[14];
	struct cgroup_root___32 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___32 *dom_cgrp;
	struct cgroup___32 *old_dom_cgrp;
	struct cgroup_rstat_cpu___32 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___32 psi;
	struct cgroup_bpf___4 bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct io_cq___26 {
	struct request_queue___26 *q;
	struct io_context___26 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct wait_page_queue___22;

struct kiocb___38 {
	struct file___38 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___38 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___22 *ki_waitq;
	};
};

struct iattr___38 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___38 *ia_file;
};

struct dquot___38 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___38 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___38 {
	int qf_fmt_id;
	const struct quota_format_ops___38 *qf_ops;
	struct module___39 *qf_owner;
	struct quota_format_type___38 *qf_next;
};

struct quota_format_ops___38 {
	int (*check_quota_file)(struct super_block___38 *, int);
	int (*read_file_info)(struct super_block___38 *, int);
	int (*write_file_info)(struct super_block___38 *, int);
	int (*free_file_info)(struct super_block___38 *, int);
	int (*read_dqblk)(struct dquot___38 *);
	int (*commit_dqblk)(struct dquot___38 *);
	int (*release_dqblk)(struct dquot___38 *);
	int (*get_next_id)(struct super_block___38 *, struct kqid *);
};

struct dquot_operations___38 {
	int (*write_dquot)(struct dquot___38 *);
	struct dquot___38 * (*alloc_dquot)(struct super_block___38 *, int);
	void (*destroy_dquot)(struct dquot___38 *);
	int (*acquire_dquot)(struct dquot___38 *);
	int (*release_dquot)(struct dquot___38 *);
	int (*mark_dirty)(struct dquot___38 *);
	int (*write_info)(struct super_block___38 *, int);
	qsize_t * (*get_reserved_space)(struct inode___38 *);
	int (*get_projid)(struct inode___38 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___38 *, qsize_t *);
	int (*get_next_id)(struct super_block___38 *, struct kqid *);
};

struct quotactl_ops___38 {
	int (*quota_on)(struct super_block___38 *, int, int, const struct path___38 *);
	int (*quota_off)(struct super_block___38 *, int);
	int (*quota_enable)(struct super_block___38 *, unsigned int);
	int (*quota_disable)(struct super_block___38 *, unsigned int);
	int (*quota_sync)(struct super_block___38 *, int);
	int (*set_info)(struct super_block___38 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___38 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___38 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___38 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___38 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___38 *, unsigned int);
};

struct wait_page_queue___22 {
	struct page___40 *page;
	int bit_nr;
	wait_queue_entry_t wait;
};

struct writeback_control___25;

struct readahead_control___22;

struct swap_info_struct___18;

struct address_space_operations___38 {
	int (*writepage)(struct page___40 *, struct writeback_control___25 *);
	int (*readpage)(struct file___38 *, struct page___40 *);
	int (*writepages)(struct address_space___38 *, struct writeback_control___25 *);
	int (*set_page_dirty)(struct page___40 *);
	int (*readpages)(struct file___38 *, struct address_space___38 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___22 *);
	int (*write_begin)(struct file___38 *, struct address_space___38 *, loff_t, unsigned int, unsigned int, struct page___40 **, void **);
	int (*write_end)(struct file___38 *, struct address_space___38 *, loff_t, unsigned int, unsigned int, struct page___40 *, void *);
	sector_t (*bmap)(struct address_space___38 *, sector_t);
	void (*invalidatepage)(struct page___40 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___40 *, gfp_t);
	void (*freepage)(struct page___40 *);
	ssize_t (*direct_IO)(struct kiocb___38 *, struct iov_iter___31 *);
	int (*migratepage)(struct address_space___38 *, struct page___40 *, struct page___40 *, enum migrate_mode);
	bool (*isolate_page)(struct page___40 *, isolate_mode_t);
	void (*putback_page)(struct page___40 *);
	int (*launder_page)(struct page___40 *);
	int (*is_partially_uptodate)(struct page___40 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___40 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___38 *, struct page___40 *);
	int (*swap_activate)(struct swap_info_struct___18 *, struct file___38 *, sector_t *);
	void (*swap_deactivate)(struct file___38 *);
};

struct writeback_control___25 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate;
	unsigned int for_background;
	unsigned int tagged_writepages;
	unsigned int for_reclaim;
	unsigned int range_cyclic;
	unsigned int for_sync;
	unsigned int no_cgroup_owner;
	unsigned int punt_to_cgroup;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bdi_writeback___25 *wb;
	struct inode___38 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
};

struct readahead_control___22 {
	struct file___38 *file;
	struct address_space___38 *mapping;
	struct file_ra_state *ra;
	long unsigned int _index;
	unsigned int _nr_pages;
	unsigned int _batch_count;
};

struct bio_vec___31;

struct iov_iter___31 {
	u8 iter_type;
	bool data_source;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___31 *bvec;
		struct xarray *xarray;
		struct pipe_inode_info *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			unsigned int head;
			unsigned int start_head;
		};
		loff_t xarray_start;
	};
};

struct swap_info_struct___18 {
	struct percpu_ref users;
	long unsigned int flags;
	short int prio;
	struct plist_node list;
	signed char type;
	unsigned int max;
	unsigned char *swap_map;
	struct swap_cluster_info *cluster_info;
	struct swap_cluster_list free_clusters;
	unsigned int lowest_bit;
	unsigned int highest_bit;
	unsigned int pages;
	unsigned int inuse_pages;
	unsigned int cluster_next;
	unsigned int cluster_nr;
	unsigned int *cluster_next_cpu;
	struct percpu_cluster *percpu_cluster;
	struct rb_root swap_extent_root;
	struct block_device___26 *bdev;
	struct file___38 *swap_file;
	unsigned int old_block_size;
	struct completion comp;
	long unsigned int *frontswap_map;
	atomic_t frontswap_pages;
	spinlock_t lock;
	spinlock_t cont_lock;
	struct work_struct discard_work;
	struct swap_cluster_list discard_clusters;
	struct plist_node avail_lists[0];
};

struct inode_operations___38 {
	struct dentry___38 * (*lookup)(struct inode___38 *, struct dentry___38 *, unsigned int);
	const char * (*get_link)(struct dentry___38 *, struct inode___38 *, struct delayed_call *);
	int (*permission)(struct user_namespace___2 *, struct inode___38 *, int);
	struct posix_acl * (*get_acl)(struct inode___38 *, int, bool);
	int (*readlink)(struct dentry___38 *, char *, int);
	int (*create)(struct user_namespace___2 *, struct inode___38 *, struct dentry___38 *, umode_t, bool);
	int (*link)(struct dentry___38 *, struct inode___38 *, struct dentry___38 *);
	int (*unlink)(struct inode___38 *, struct dentry___38 *);
	int (*symlink)(struct user_namespace___2 *, struct inode___38 *, struct dentry___38 *, const char *);
	int (*mkdir)(struct user_namespace___2 *, struct inode___38 *, struct dentry___38 *, umode_t);
	int (*rmdir)(struct inode___38 *, struct dentry___38 *);
	int (*mknod)(struct user_namespace___2 *, struct inode___38 *, struct dentry___38 *, umode_t, dev_t);
	int (*rename)(struct user_namespace___2 *, struct inode___38 *, struct dentry___38 *, struct inode___38 *, struct dentry___38 *, unsigned int);
	int (*setattr)(struct user_namespace___2 *, struct dentry___38 *, struct iattr___38 *);
	int (*getattr)(struct user_namespace___2 *, const struct path___38 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___38 *, char *, size_t);
	int (*fiemap)(struct inode___38 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___38 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___38 *, struct dentry___38 *, struct file___38 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace___2 *, struct inode___38 *, struct dentry___38 *, umode_t);
	int (*set_acl)(struct user_namespace___2 *, struct inode___38 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace___2 *, struct dentry___38 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___38 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___38 {
	void (*fl_copy_lock)(struct file_lock___38 *, struct file_lock___38 *);
	void (*fl_release_private)(struct file_lock___38 *);
};

struct lock_manager_operations___38;

struct file_lock___38 {
	struct file_lock___38 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___38 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___38 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___38 *fl_ops;
	const struct lock_manager_operations___38 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___38 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___38 *);
	int (*lm_grant)(struct file_lock___38 *, int);
	bool (*lm_break)(struct file_lock___38 *);
	int (*lm_change)(struct file_lock___38 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___38 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___38 *);
};

struct fasync_struct___38 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___38 *fa_next;
	struct file___38 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___38 {
	struct inode___38 * (*alloc_inode)(struct super_block___38 *);
	void (*destroy_inode)(struct inode___38 *);
	void (*free_inode)(struct inode___38 *);
	void (*dirty_inode)(struct inode___38 *, int);
	int (*write_inode)(struct inode___38 *, struct writeback_control___25 *);
	int (*drop_inode)(struct inode___38 *);
	void (*evict_inode)(struct inode___38 *);
	void (*put_super)(struct super_block___38 *);
	int (*sync_fs)(struct super_block___38 *, int);
	int (*freeze_super)(struct super_block___38 *);
	int (*freeze_fs)(struct super_block___38 *);
	int (*thaw_super)(struct super_block___38 *);
	int (*unfreeze_fs)(struct super_block___38 *);
	int (*statfs)(struct dentry___38 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___38 *, int *, char *);
	void (*umount_begin)(struct super_block___38 *);
	int (*show_options)(struct seq_file___36 *, struct dentry___38 *);
	int (*show_devname)(struct seq_file___36 *, struct dentry___38 *);
	int (*show_path)(struct seq_file___36 *, struct dentry___38 *);
	int (*show_stats)(struct seq_file___36 *, struct dentry___38 *);
	ssize_t (*quota_read)(struct super_block___38 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___38 *, int, const char *, size_t, loff_t);
	struct dquot___38 ** (*get_dquots)(struct inode___38 *);
	long int (*nr_cached_objects)(struct super_block___38 *, struct shrink_control___25 *);
	long int (*free_cached_objects)(struct super_block___38 *, struct shrink_control___25 *);
	struct file___38 * (*real_loop)(struct file___38 *);
};

struct block_device___26 {
	sector_t bd_start_sect;
	struct disk_stats *bd_stats;
	long unsigned int bd_stamp;
	bool bd_read_only;
	dev_t bd_dev;
	int bd_openers;
	struct inode___38 *bd_inode;
	struct super_block___38 *bd_super;
	void *bd_claiming;
	struct device___42 bd_device;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct kobject___39 *bd_holder_dir;
	u8 bd_partno;
	spinlock_t bd_size_lock;
	struct gendisk___26 *bd_disk;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	struct super_block___38 *bd_fsfreeze_sb;
	struct partition_meta_info *bd_meta_info;
};

typedef void bio_end_io_t___26(struct bio___26 *);

struct bio_vec___31 {
	struct page___40 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___26;

struct bio___26 {
	struct bio___26 *bi_next;
	struct block_device___26 *bi_bdev;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	atomic_t __bi_remaining;
	struct bvec_iter bi_iter;
	bio_end_io_t___26 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___25 *bi_blkg;
	struct bio_issue bi_issue;
	u64 bi_iocost_cost;
	struct bio_crypt_ctx *bi_crypt_context;
	union {
		struct bio_integrity_payload___26 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___31 *bi_io_vec;
	struct bio_set___26 *bi_pool;
	struct bio_vec___31 bi_inline_vecs[0];
};

struct cgroup_namespace___32 {
	struct ns_common___5 ns;
	struct user_namespace___2 *user_ns;
	struct ucounts___2 *ucounts;
	struct css_set___32 *root_cset;
};

struct perf_cpu_context___26;

struct perf_output_handle___26;

struct pmu___26 {
	struct list_head entry;
	struct module___39 *module;
	struct device___42 *dev;
	const struct attribute_group___39 **attr_groups;
	const struct attribute_group___39 **attr_update;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___26 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___26 *);
	void (*pmu_disable)(struct pmu___26 *);
	int (*event_init)(struct perf_event___26 *);
	void (*event_mapped)(struct perf_event___26 *, struct mm_struct___41 *);
	void (*event_unmapped)(struct perf_event___26 *, struct mm_struct___41 *);
	int (*add)(struct perf_event___26 *, int);
	void (*del)(struct perf_event___26 *, int);
	void (*start)(struct perf_event___26 *, int);
	void (*stop)(struct perf_event___26 *, int);
	void (*read)(struct perf_event___26 *);
	void (*start_txn)(struct pmu___26 *, unsigned int);
	int (*commit_txn)(struct pmu___26 *);
	void (*cancel_txn)(struct pmu___26 *);
	int (*event_idx)(struct perf_event___26 *);
	void (*sched_task)(struct perf_event_context___26 *, bool);
	struct kmem_cache *task_ctx_cache;
	void (*swap_task_ctx)(struct perf_event_context___26 *, struct perf_event_context___26 *);
	void * (*setup_aux)(struct perf_event___26 *, void **, int, bool);
	void (*free_aux)(void *);
	long int (*snapshot_aux)(struct perf_event___26 *, struct perf_output_handle___26 *, long unsigned int);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___26 *);
	int (*aux_output_match)(struct perf_event___26 *);
	int (*filter_match)(struct perf_event___26 *);
	int (*check_period)(struct perf_event___26 *, u64);
};

struct module_attribute___39 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___39 *, struct module_kobject___39 *, char *);
	ssize_t (*store)(struct module_attribute___39 *, struct module_kobject___39 *, const char *, size_t);
	void (*setup)(struct module___39 *, const char *);
	int (*test)(struct module___39 *);
	void (*free)(struct module___39 *);
};

struct trace_event_class___26;

struct trace_event_call___26 {
	struct list_head list;
	struct trace_event_class___26 *class;
	union {
		char *name;
		struct tracepoint___30 *tp;
	};
	struct trace_event event;
	char *print_fmt;
	struct event_filter *filter;
	union {
		void *module;
		atomic_t refcnt;
	};
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
	struct bpf_prog_array___4 *prog_array;
	int (*perf_perm)(struct trace_event_call___26 *, struct perf_event___26 *);
};

struct cftype___32;

struct cgroup_subsys___32 {
	struct cgroup_subsys_state___32 * (*css_alloc)(struct cgroup_subsys_state___32 *);
	int (*css_online)(struct cgroup_subsys_state___32 *);
	void (*css_offline)(struct cgroup_subsys_state___32 *);
	void (*css_released)(struct cgroup_subsys_state___32 *);
	void (*css_free)(struct cgroup_subsys_state___32 *);
	void (*css_reset)(struct cgroup_subsys_state___32 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___32 *, int);
	int (*css_extra_stat_show)(struct seq_file___36 *, struct cgroup_subsys_state___32 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___41 *, struct css_set___32 *);
	void (*cancel_fork)(struct task_struct___41 *, struct css_set___32 *);
	void (*fork)(struct task_struct___41 *);
	void (*exit)(struct task_struct___41 *);
	void (*release)(struct task_struct___41 *);
	void (*bind)(struct cgroup_subsys_state___32 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___32 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___32 *dfl_cftypes;
	struct cftype___32 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___32 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___32 *updated_children;
	struct cgroup___32 *updated_next;
};

struct cgroup_root___32 {
	struct kernfs_root___39 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___32 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___32 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___32 *ss;
	struct list_head node;
	struct kernfs_ops___39 *kf_ops;
	int (*open)(struct kernfs_open_file___39 *);
	void (*release)(struct kernfs_open_file___39 *);
	u64 (*read_u64)(struct cgroup_subsys_state___32 *, struct cftype___32 *);
	s64 (*read_s64)(struct cgroup_subsys_state___32 *, struct cftype___32 *);
	int (*seq_show)(struct seq_file___36 *, void *);
	void * (*seq_start)(struct seq_file___36 *, loff_t *);
	void * (*seq_next)(struct seq_file___36 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___36 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___32 *, struct cftype___32 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___32 *, struct cftype___32 *, s64);
	ssize_t (*write)(struct kernfs_open_file___39 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___39 *, struct poll_table_struct___29 *);
};

struct perf_cpu_context___26 {
	struct perf_event_context___26 ctx;
	struct perf_event_context___26 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___26 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
	int heap_size;
	struct perf_event___26 **heap;
	struct perf_event___26 *heap_default[2];
};

struct perf_output_handle___26 {
	struct perf_event___26 *event;
	struct perf_buffer *rb;
	long unsigned int wakeup;
	long unsigned int size;
	u64 aux_flags;
	union {
		void *addr;
		long unsigned int head;
	};
	int page;
};

struct perf_cgroup___26 {
	struct cgroup_subsys_state___32 css;
	struct perf_cgroup_info *info;
};

struct trace_event_fields___26 {
	const char *type;
	union {
		struct {
			const char *name;
			const int size;
			const int align;
			const int is_signed;
			const int filter_type;
		};
		int (*define_fields)(struct trace_event_call___26 *);
	};
};

struct trace_event_class___26 {
	const char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct trace_event_call___26 *, enum trace_reg, void *);
	struct trace_event_fields___26 *fields_array;
	struct list_head * (*get_fields)(struct trace_event_call___26 *);
	struct list_head fields;
	int (*raw_init)(struct trace_event_call___26 *);
};

struct block_device_operations___26;

struct gendisk___26 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	short unsigned int events;
	short unsigned int event_flags;
	struct xarray part_tbl;
	struct block_device___26 *part0;
	const struct block_device_operations___26 *fops;
	struct request_queue___26 *queue;
	void *private_data;
	int flags;
	long unsigned int state;
	struct mutex open_mutex;
	unsigned int open_partitions;
	struct backing_dev_info___25 *bdi;
	struct kobject___39 *slave_dir;
	struct list_head slave_bdevs;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___39 integrity_kobj;
	struct cdrom_device_info *cdi;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	u64 diskseq;
};

struct bio_integrity_payload___26 {
	struct bio___26 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___31 *bip_vec;
	struct bio_vec___31 bip_inline_vecs[0];
};

struct blkcg___25;

struct blkg_policy_data___25;

struct blkcg_gq___25 {
	struct request_queue___26 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___25 *blkcg;
	struct blkcg_gq___25 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_iostat_set *iostat_cpu;
	struct blkg_iostat_set iostat;
	struct blkg_policy_data___25 *pd[6];
	spinlock_t async_bio_lock;
	struct bio_list___26 async_bios;
	struct work_struct async_bio_work;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
	struct callback_head callback_head;
};

typedef void integrity_prepare_fn___26(struct request___26 *);

typedef void integrity_complete_fn___26(struct request___26 *, unsigned int);

struct blk_integrity_profile___26 {
	integrity_processing_fn *generate_fn;
	integrity_processing_fn *verify_fn;
	integrity_prepare_fn___26 *prepare_fn;
	integrity_complete_fn___26 *complete_fn;
	const char *name;
};

struct block_device_operations___26 {
	blk_qc_t (*submit_bio)(struct bio___26 *);
	int (*open)(struct block_device___26 *, fmode_t);
	void (*release)(struct gendisk___26 *, fmode_t);
	int (*rw_page)(struct block_device___26 *, sector_t, struct page___40 *, unsigned int);
	int (*ioctl)(struct block_device___26 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___26 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___26 *, unsigned int);
	void (*unlock_native_capacity)(struct gendisk___26 *);
	int (*getgeo)(struct block_device___26 *, struct hd_geometry *);
	int (*set_read_only)(struct block_device___26 *, bool);
	void (*swap_slot_free_notify)(struct block_device___26 *, long unsigned int);
	int (*report_zones)(struct gendisk___26 *, sector_t, unsigned int, report_zones_cb, void *);
	char * (*devnode)(struct gendisk___26 *, umode_t *);
	struct module___39 *owner;
	const struct pr_ops *pr_ops;
	int (*alternative_gpt_sector)(struct gendisk___26 *, sector_t *);
};

typedef void rq_end_io_fn___26(struct request___26 *, blk_status_t);

struct request___26 {
	struct request_queue___26 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int tag;
	int internal_tag;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___26 *bio;
	struct bio___26 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct llist_node ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___31 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___26 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___26 *saved_end_io;
		} flush;
	};
	struct gendisk___26 *rq_disk;
	struct block_device___26 *part;
	u64 alloc_time_ns;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int stats_sectors;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	struct bio_crypt_ctx *crypt_ctx;
	struct blk_ksm_keyslot *crypt_keyslot;
	short unsigned int write_hint;
	short unsigned int ioprio;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___26 *end_io;
	void *end_io_data;
};

struct elevator_type___26;

struct elevator_mq_ops___26 {
	int (*init_sched)(struct request_queue___26 *, struct elevator_type___26 *);
	void (*exit_sched)(struct elevator_queue___26 *);
	int (*init_hctx)(struct blk_mq_hw_ctx *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx *, unsigned int);
	void (*depth_updated)(struct blk_mq_hw_ctx *);
	bool (*allow_merge)(struct request_queue___26 *, struct request___26 *, struct bio___26 *);
	bool (*bio_merge)(struct request_queue___26 *, struct bio___26 *, unsigned int);
	int (*request_merge)(struct request_queue___26 *, struct request___26 **, struct bio___26 *);
	void (*request_merged)(struct request_queue___26 *, struct request___26 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___26 *, struct request___26 *, struct request___26 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___26 *);
	void (*finish_request)(struct request___26 *);
	void (*insert_requests)(struct blk_mq_hw_ctx *, struct list_head *, bool);
	struct request___26 * (*dispatch_request)(struct blk_mq_hw_ctx *);
	bool (*has_work)(struct blk_mq_hw_ctx *);
	void (*completed_request)(struct request___26 *, u64);
	void (*requeue_request)(struct request___26 *);
	struct request___26 * (*former_request)(struct request_queue___26 *, struct request___26 *);
	struct request___26 * (*next_request)(struct request_queue___26 *, struct request___26 *);
	void (*init_icq)(struct io_cq___26 *);
	void (*exit_icq)(struct io_cq___26 *);
};

struct elv_fs_entry___26;

struct elevator_type___26 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___26 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___26 *elevator_attrs;
	const char *elevator_name;
	const char *elevator_alias;
	const unsigned int elevator_features;
	struct module___39 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
};

struct elevator_queue___26 {
	struct elevator_type___26 *type;
	void *elevator_data;
	struct kobject___39 kobj;
	struct mutex sysfs_lock;
	unsigned int registered;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hlist_head hash[64];
};

struct elv_fs_entry___26 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___26 *, char *);
	ssize_t (*store)(struct elevator_queue___26 *, const char *, size_t);
};

struct blkcg_policy_data___25;

struct blkcg___25 {
	struct cgroup_subsys_state___32 css;
	spinlock_t lock;
	refcount_t online_pin;
	struct xarray blkg_tree;
	struct blkcg_gq___25 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___25 *cpd[6];
	struct list_head all_blkcgs_node;
	char fc_app_id[129];
	struct list_head cgwb_list;
};

struct blkcg_policy_data___25 {
	struct blkcg___25 *blkcg;
	int plid;
};

struct blkg_policy_data___25 {
	struct blkcg_gq___25 *blkg;
	int plid;
};

struct mem_cgroup_reclaim_iter___25 {
	struct mem_cgroup___25 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___25 {
	struct lruvec___26 lruvec;
	struct lruvec_stats_percpu *lruvec_stats_percpu;
	struct lruvec_stats lruvec_stats;
	long unsigned int lru_zone_size[25];
	struct mem_cgroup_reclaim_iter___25 iter;
	struct shrinker_info *shrinker_info;
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	struct mem_cgroup___25 *memcg;
};

struct obj_cgroup___25 {
	struct percpu_ref refcnt;
	struct mem_cgroup___25 *memcg;
	atomic_t nr_charged_bytes;
	union {
		struct list_head list;
		struct callback_head rcu;
	};
};

struct smp_hotplug_thread___4 {
	struct task_struct___41 **store;
	struct list_head list;
	int (*thread_should_run)(unsigned int);
	void (*thread_fn)(unsigned int);
	void (*create)(unsigned int);
	void (*setup)(unsigned int);
	void (*cleanup)(unsigned int, bool);
	void (*park)(unsigned int);
	void (*unpark)(unsigned int);
	bool selfparking;
	const char *thread_comm;
};

struct rcu_exp_work {
	long unsigned int rew_s;
	struct work_struct rew_work;
};

struct rcu_node {
	raw_spinlock_t lock;
	long unsigned int gp_seq;
	long unsigned int gp_seq_needed;
	long unsigned int completedqs;
	long unsigned int qsmask;
	long unsigned int rcu_gp_init_mask;
	long unsigned int qsmaskinit;
	long unsigned int qsmaskinitnext;
	long unsigned int ofl_seq;
	long unsigned int expmask;
	long unsigned int expmaskinit;
	long unsigned int expmaskinitnext;
	long unsigned int cbovldmask;
	long unsigned int ffmask;
	long unsigned int grpmask;
	int grplo;
	int grphi;
	u8 grpnum;
	u8 level;
	bool wait_blkd_tasks;
	struct rcu_node *parent;
	struct list_head blkd_tasks;
	struct list_head *gp_tasks;
	struct list_head *exp_tasks;
	struct list_head *boost_tasks;
	struct rt_mutex___2 boost_mtx;
	long unsigned int boost_time;
	struct task_struct___41 *boost_kthread_task;
	unsigned int boost_kthread_status;
	long unsigned int n_boosts;
	long: 64;
	raw_spinlock_t fqslock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t exp_lock;
	long unsigned int exp_seq_rq;
	wait_queue_head_t exp_wq[4];
	struct rcu_exp_work rew;
	bool exp_need_flush;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

union rcu_noqs {
	struct {
		u8 norm;
		u8 exp;
	} b;
	u16 s;
};

struct rcu_data {
	long unsigned int gp_seq;
	long unsigned int gp_seq_needed;
	union rcu_noqs cpu_no_qs;
	bool core_needs_qs;
	bool beenonline;
	bool gpwrap;
	bool exp_deferred_qs;
	bool cpu_started;
	struct rcu_node *mynode;
	long unsigned int grpmask;
	long unsigned int ticks_this_gp;
	struct irq_work defer_qs_iw;
	bool defer_qs_iw_pending;
	struct work_struct strict_work;
	struct rcu_segcblist cblist;
	long int qlen_last_fqs_check;
	long unsigned int n_cbs_invoked;
	long unsigned int n_force_qs_snap;
	long int blimit;
	int dynticks_snap;
	long int dynticks_nesting;
	long int dynticks_nmi_nesting;
	atomic_t dynticks;
	bool rcu_need_heavy_qs;
	bool rcu_urgent_qs;
	bool rcu_forced_tick;
	bool rcu_forced_tick_exp;
	struct callback_head barrier_head;
	int exp_dynticks_snap;
	struct task_struct___41 *rcu_cpu_kthread_task;
	unsigned int rcu_cpu_kthread_status;
	char rcu_cpu_has_work;
	unsigned int softirq_snap;
	struct irq_work rcu_iw;
	bool rcu_iw_pending;
	long unsigned int rcu_iw_gp_seq;
	long unsigned int rcu_ofl_gp_seq;
	short int rcu_ofl_gp_flags;
	long unsigned int rcu_onl_gp_seq;
	short int rcu_onl_gp_flags;
	long unsigned int last_fqs_resched;
	int cpu;
};

struct rcu_state {
	struct rcu_node node[521];
	struct rcu_node *level[4];
	int ncpus;
	int n_online_cpus;
	long: 64;
	long: 64;
	long: 64;
	u8 boost;
	long unsigned int gp_seq;
	long unsigned int gp_max;
	struct task_struct___41 *gp_kthread;
	struct swait_queue_head gp_wq;
	short int gp_flags;
	short int gp_state;
	long unsigned int gp_wake_time;
	long unsigned int gp_wake_seq;
	struct mutex barrier_mutex;
	atomic_t barrier_cpu_count;
	struct completion barrier_completion;
	long unsigned int barrier_sequence;
	struct mutex exp_mutex;
	struct mutex exp_wake_mutex;
	long unsigned int expedited_sequence;
	atomic_t expedited_need_qs;
	struct swait_queue_head expedited_wq;
	int ncpus_snap;
	u8 cbovld;
	u8 cbovldnext;
	long unsigned int jiffies_force_qs;
	long unsigned int jiffies_kick_kthreads;
	long unsigned int n_force_qs;
	long unsigned int gp_start;
	long unsigned int gp_end;
	long unsigned int gp_activity;
	long unsigned int gp_req_activity;
	long unsigned int jiffies_stall;
	long unsigned int jiffies_resched;
	long unsigned int n_force_qs_gpstart;
	const char *name;
	char abbr;
	long: 56;
	long: 64;
	long: 64;
	raw_spinlock_t ofl_lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kvfree_rcu_bulk_data {
	long unsigned int nr_records;
	struct kvfree_rcu_bulk_data *next;
	void *records[0];
};

struct kfree_rcu_cpu;

struct kfree_rcu_cpu_work {
	struct rcu_work rcu_work;
	struct callback_head *head_free;
	struct kvfree_rcu_bulk_data *bkvhead_free[2];
	struct kfree_rcu_cpu *krcp;
};

struct kfree_rcu_cpu {
	struct callback_head *head;
	struct kvfree_rcu_bulk_data *bkvhead[2];
	struct kfree_rcu_cpu_work krw_arr[2];
	raw_spinlock_t lock;
	struct delayed_work monitor_work;
	bool monitor_todo;
	bool initialized;
	int count;
	struct delayed_work page_cache_work;
	atomic_t backoff_page_cache_fill;
	atomic_t work_in_progress;
	struct hrtimer hrtimer;
	struct llist_head bkvcache;
	int nr_bkv_objs;
};

struct klp_func {
	const char *old_name;
	void *new_func;
	long unsigned int old_sympos;
	void *old_func;
	struct kobject___39 kobj;
	struct list_head node;
	struct list_head stack_node;
	long unsigned int old_size;
	long unsigned int new_size;
	bool nop;
	bool patched;
	bool transition;
};

struct klp_object;

struct klp_callbacks {
	int (*pre_patch)(struct klp_object *);
	void (*post_patch)(struct klp_object *);
	void (*pre_unpatch)(struct klp_object *);
	void (*post_unpatch)(struct klp_object *);
	bool post_unpatch_enabled;
};

struct klp_object {
	const char *name;
	struct klp_func *funcs;
	struct klp_callbacks callbacks;
	struct kobject___39 kobj;
	struct list_head func_list;
	struct list_head node;
	struct module___39 *mod;
	bool dynamic;
	bool patched;
};

struct klp_state {
	long unsigned int id;
	unsigned int version;
	void *data;
};

struct klp_patch {
	struct module___39 *mod;
	struct klp_object *objs;
	struct klp_state *states;
	bool replace;
	struct list_head list;
	struct kobject___39 kobj;
	struct list_head obj_list;
	bool enabled;
	bool forced;
	struct work_struct free_work;
	struct completion finish;
};

struct klp_find_arg {
	const char *objname;
	const char *name;
	long unsigned int addr;
	long unsigned int count;
	long unsigned int pos;
};

struct klp_ops {
	struct list_head node;
	struct list_head func_stack;
	struct ftrace_ops fops;
};

typedef int (*klp_shadow_ctor_t)(void *, void *, void *);

typedef void (*klp_shadow_dtor_t)(void *, void *);

struct klp_shadow {
	struct hlist_node node;
	struct callback_head callback_head;
	void *obj;
	long unsigned int id;
	char data[0];
};

struct dentry___39;

struct super_block___39;

struct module___40;

struct file_system_type___39 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___39 * (*mount)(struct file_system_type___39 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___39 *);
	struct module___40 *owner;
	struct file_system_type___39 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___39;

struct kiocb___39;

struct iov_iter___32;

struct poll_table_struct___30;

struct vm_area_struct___42;

struct inode___39;

struct file_lock___39;

struct page___41;

struct pipe_inode_info___15;

struct seq_file___37;

struct file_operations___39 {
	struct module___40 *owner;
	loff_t (*llseek)(struct file___39 *, loff_t, int);
	ssize_t (*read)(struct file___39 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___39 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___39 *, struct iov_iter___32 *);
	ssize_t (*write_iter)(struct kiocb___39 *, struct iov_iter___32 *);
	int (*iopoll)(struct kiocb___39 *, bool);
	int (*iterate)(struct file___39 *, struct dir_context *);
	int (*iterate_shared)(struct file___39 *, struct dir_context *);
	__poll_t (*poll)(struct file___39 *, struct poll_table_struct___30 *);
	long int (*unlocked_ioctl)(struct file___39 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___39 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___39 *, struct vm_area_struct___42 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___39 *, struct file___39 *);
	int (*flush)(struct file___39 *, fl_owner_t);
	int (*release)(struct inode___39 *, struct file___39 *);
	int (*fsync)(struct file___39 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___39 *, int);
	int (*lock)(struct file___39 *, int, struct file_lock___39 *);
	ssize_t (*sendpage)(struct file___39 *, struct page___41 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___39 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___39 *, long unsigned int);
	int (*flock)(struct file___39 *, int, struct file_lock___39 *);
	ssize_t (*splice_write)(struct pipe_inode_info___15 *, struct file___39 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___39 *, loff_t *, struct pipe_inode_info___15 *, size_t, unsigned int);
	int (*setlease)(struct file___39 *, long int, struct file_lock___39 **, void **);
	long int (*fallocate)(struct file___39 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___37 *, struct file___39 *);
	ssize_t (*copy_file_range)(struct file___39 *, loff_t, struct file___39 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___39 *, loff_t, struct file___39 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___39 *, loff_t, loff_t, int);
};

struct static_call_mod___31 {
	struct static_call_mod___31 *next;
	struct module___40 *mod;
	struct static_call_site *sites;
};

struct static_call_key___31 {
	void *func;
	union {
		long unsigned int type;
		struct static_call_mod___31 *mods;
		struct static_call_site *sites;
	};
};

struct cfs_rq___4;

struct sched_entity___4 {
	struct load_weight load;
	struct rb_node run_node;
	struct list_head group_node;
	unsigned int on_rq;
	u64 exec_start;
	u64 sum_exec_runtime;
	u64 vruntime;
	u64 prev_sum_exec_runtime;
	u64 nr_migrations;
	struct sched_statistics statistics;
	int depth;
	struct sched_entity___4 *parent;
	struct cfs_rq___4 *cfs_rq;
	struct cfs_rq___4 *my_q;
	long unsigned int runnable_weight;
	long: 64;
	long: 64;
	long: 64;
	struct sched_avg avg;
};

struct vmacache___41 {
	u64 seqnum;
	struct vm_area_struct___42 *vmas[4];
};

struct page_frag___41 {
	struct page___41 *page;
	__u32 offset;
	__u32 size;
};

struct perf_event___27;

struct thread_struct___28 {
	struct desc_struct tls_array[3];
	long unsigned int sp;
	short unsigned int es;
	short unsigned int ds;
	short unsigned int fsindex;
	short unsigned int gsindex;
	long unsigned int fsbase;
	long unsigned int gsbase;
	struct perf_event___27 *ptrace_bps[4];
	long unsigned int virtual_dr6;
	long unsigned int ptrace_dr7;
	long unsigned int cr2;
	long unsigned int trap_nr;
	long unsigned int error_code;
	struct io_bitmap *io_bitmap;
	long unsigned int iopl_emul;
	unsigned int iopl_warn: 1;
	unsigned int sig_on_uaccess_err: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u32 pkru;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct fpu fpu;
};

struct sched_class___4;

struct task_group___4;

struct mm_struct___42;

struct pid___34;

struct nsproxy___38;

struct signal_struct___39;

struct bio_list___27;

struct backing_dev_info___26;

struct io_context___27;

struct css_set___33;

struct perf_event_context___27;

struct mem_cgroup___26;

struct request_queue___27;

struct vm_struct___36;

struct task_struct___42 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___42 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class___4 *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___4 se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group___4 *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___42 *mm;
	struct mm_struct___42 *active_mm;
	struct vmacache___41 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int restore_sigmask: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___42 *real_parent;
	struct task_struct___42 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___42 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___34 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	struct posix_cputimers_work posix_cputimers_work;
	const struct cred___2 *ptracer_cred;
	const struct cred___2 *real_cred;
	const struct cred___2 *cred;
	struct key *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___38 *nsproxy;
	struct signal_struct___39 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___42 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___27 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___26 *backing_dev_info;
	struct io_context___27 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___33 *cgroups;
	struct list_head cg_list;
	u32 closid;
	u32 rmid;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___27 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	struct pipe_inode_info___15 *splice_pipe;
	struct page_frag___41 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___26 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___26 *active_memcg;
	struct request_queue___27 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___42 *oom_reaper_list;
	struct vm_struct___36 *stack_vm_area;
	refcount_t stack_refcount;
	int patch_state;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	void *mce_vaddr;
	__u64 mce_kflags;
	u64 mce_addr;
	__u64 mce_ripv: 1;
	__u64 mce_whole_page: 1;
	__u64 __mce_reserved: 62;
	long: 2;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct callback_head mce_kill_me;
	int mce_count;
	struct llist_head kretprobe_instances;
	struct callback_head l1d_flush_kill;
	long: 64;
	struct thread_struct___28 thread;
};

typedef struct page___41 *pgtable_t___41;

struct address_space___39;

struct page_pool___14;

struct dev_pagemap___39;

struct page___41 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___39 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___14 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___41 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___41 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___42 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___39 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct linux_binfmt___11;

struct core_state___41;

struct mm_struct___42 {
	struct {
		struct vm_area_struct___42 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___39 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int mmap_compat_base;
		long unsigned int mmap_compat_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[48];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___11 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___41 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___42 *owner;
		struct user_namespace___2 *user_ns;
		struct file___39 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		bool tlb_flush_batched;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct vm_operations_struct___39;

struct vm_area_struct___42 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___42 *vm_next;
	struct vm_area_struct___42 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___42 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___39 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___39 *vm_file;
	struct file___39 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct tracepoint___31 {
	const char *name;
	struct static_key key;
	struct static_call_key___31 *static_call_key;
	void *static_call_tramp;
	void *iterator;
	int (*regfunc)();
	void (*unregfunc)();
	struct tracepoint_func *funcs;
};

struct bpf_raw_event_map___31 {
	struct tracepoint___31 *tp;
	void *bpf_func;
	u32 num_args;
	u32 writable_size;
	long: 64;
};

struct seq_operations___37 {
	void * (*start)(struct seq_file___37 *, loff_t *);
	void (*stop)(struct seq_file___37 *, void *);
	void * (*next)(struct seq_file___37 *, void *, loff_t *);
	int (*show)(struct seq_file___37 *, void *);
};

struct hw_perf_event___27 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___42 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	union {
		struct {
			u64 last_period;
			local64_t period_left;
		};
		struct {
			u64 saved_metric;
			u64 saved_slots;
		};
	};
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___27)(struct perf_event___27 *, struct perf_sample_data___3 *, struct pt_regs *);

struct pmu___27;

struct fasync_struct___39;

struct pid_namespace___34;

struct trace_event_call___27;

struct perf_cgroup___27;

struct perf_event___27 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___27 *group_leader;
	struct pmu___27 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___27 hw;
	struct perf_event_context___27 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___27 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___42 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct perf_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___39 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	long unsigned int pending_addr;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	struct perf_addr_filter_range *addr_filter_ranges;
	long unsigned int addr_filters_gen;
	struct perf_event___27 *aux_event;
	void (*destroy)(struct perf_event___27 *);
	struct callback_head callback_head;
	struct pid_namespace___34 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___27 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___27 orig_overflow_handler;
	struct bpf_prog *prog;
	u64 bpf_cookie;
	struct trace_event_call___27 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___27 *cgrp;
	void *security;
	struct list_head sb_list;
};

struct upid___34 {
	int nr;
	struct pid_namespace___34 *ns;
};

struct pid_namespace___34 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___42 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___34 *parent;
	struct fs_pin *bacct;
	struct user_namespace___2 *user_ns;
	struct ucounts___2 *ucounts;
	int reboot;
	struct ns_common___5 ns;
};

struct pid___34 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___34 numbers[1];
};

struct autogroup___4;

struct signal_struct___39 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___42 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___42 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___34 *pids[4];
	struct pid___34 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup___4 *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___42 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct rq___4;

struct cfs_rq___4 {
	struct load_weight load;
	unsigned int nr_running;
	unsigned int h_nr_running;
	unsigned int idle_h_nr_running;
	u64 exec_clock;
	u64 min_vruntime;
	unsigned int forceidle_seq;
	u64 min_vruntime_fi;
	struct rb_root_cached tasks_timeline;
	struct sched_entity___4 *curr;
	struct sched_entity___4 *next;
	struct sched_entity___4 *last;
	struct sched_entity___4 *skip;
	unsigned int nr_spread_over;
	long: 32;
	long: 64;
	struct sched_avg avg;
	struct {
		raw_spinlock_t lock;
		int nr;
		long unsigned int load_avg;
		long unsigned int util_avg;
		long unsigned int runnable_avg;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	} removed;
	long unsigned int tg_load_avg_contrib;
	long int propagate;
	long int prop_runnable_sum;
	long unsigned int h_load;
	u64 last_h_load_update;
	struct sched_entity___4 *h_load_next;
	struct rq___4 *rq;
	int on_list;
	struct list_head leaf_cfs_rq_list;
	struct task_group___4 *tg;
	int idle;
	int runtime_enabled;
	s64 runtime_remaining;
	u64 throttled_clock;
	u64 throttled_clock_task;
	u64 throttled_clock_task_time;
	int throttled;
	int throttle_count;
	struct list_head throttled_list;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct sched_class___4 {
	int uclamp_enabled;
	void (*enqueue_task)(struct rq___4 *, struct task_struct___42 *, int);
	void (*dequeue_task)(struct rq___4 *, struct task_struct___42 *, int);
	void (*yield_task)(struct rq___4 *);
	bool (*yield_to_task)(struct rq___4 *, struct task_struct___42 *);
	void (*check_preempt_curr)(struct rq___4 *, struct task_struct___42 *, int);
	struct task_struct___42 * (*pick_next_task)(struct rq___4 *);
	void (*put_prev_task)(struct rq___4 *, struct task_struct___42 *);
	void (*set_next_task)(struct rq___4 *, struct task_struct___42 *, bool);
	int (*balance)(struct rq___4 *, struct task_struct___42 *, struct rq_flags *);
	int (*select_task_rq)(struct task_struct___42 *, int, int);
	struct task_struct___42 * (*pick_task)(struct rq___4 *);
	void (*migrate_task_rq)(struct task_struct___42 *, int);
	void (*task_woken)(struct rq___4 *, struct task_struct___42 *);
	void (*set_cpus_allowed)(struct task_struct___42 *, const struct cpumask *, u32);
	void (*rq_online)(struct rq___4 *);
	void (*rq_offline)(struct rq___4 *);
	struct rq___4 * (*find_lock_rq)(struct task_struct___42 *, struct rq___4 *);
	void (*task_tick)(struct rq___4 *, struct task_struct___42 *, int);
	void (*task_fork)(struct task_struct___42 *);
	void (*task_dead)(struct task_struct___42 *);
	void (*switched_from)(struct rq___4 *, struct task_struct___42 *);
	void (*switched_to)(struct rq___4 *, struct task_struct___42 *);
	void (*prio_changed)(struct rq___4 *, struct task_struct___42 *, int);
	unsigned int (*get_rr_interval)(struct rq___4 *, struct task_struct___42 *);
	void (*update_curr)(struct rq___4 *);
	void (*task_change_group)(struct task_struct___42 *, int);
};

struct cgroup___33;

struct cgroup_subsys___33;

struct cgroup_subsys_state___33 {
	struct cgroup___33 *cgroup;
	struct cgroup_subsys___33 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___33 *parent;
};

struct task_group___4 {
	struct cgroup_subsys_state___33 css;
	struct sched_entity___4 **se;
	struct cfs_rq___4 **cfs_rq;
	long unsigned int shares;
	int idle;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	atomic_long_t load_avg;
	struct callback_head rcu;
	struct list_head list;
	struct task_group___4 *parent;
	struct list_head siblings;
	struct list_head children;
	struct autogroup___4 *autogroup;
	struct cfs_bandwidth cfs_bandwidth;
	unsigned int uclamp_pct[2];
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct cgroup_namespace___33;

struct nsproxy___38 {
	atomic_t count;
	struct uts_namespace___4 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___34 *pid_ns_for_children;
	struct net___6 *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___33 *cgroup_ns;
};

struct bio___27;

struct bio_list___27 {
	struct bio___27 *head;
	struct bio___27 *tail;
};

struct bdi_writeback___26 {
	struct backing_dev_info___26 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	atomic_t writeback_inodes;
	struct percpu_counter stat[4];
	long unsigned int congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	struct delayed_work bw_dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___33 *memcg_css;
	struct cgroup_subsys_state___33 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	struct list_head b_attached;
	struct list_head offline_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
};

struct device___43;

struct backing_dev_info___26 {
	u64 id;
	struct rb_node rb_node;
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___26 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct mutex cgwb_release_mutex;
	struct rw_semaphore wb_switch_rwsem;
	wait_queue_head_t wb_waitq;
	struct device___43 *dev;
	char dev_name[64];
	struct device___43 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___39 *debug_dir;
};

struct io_cq___27;

struct io_context___27 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	struct xarray icq_tree;
	struct io_cq___27 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct css_set___33 {
	struct cgroup_subsys_state___33 *subsys[14];
	refcount_t refcount;
	struct css_set___33 *dom_cset;
	struct cgroup___33 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___33 *mg_src_cgrp;
	struct cgroup___33 *mg_dst_cgrp;
	struct css_set___33 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___27 {
	struct pmu___27 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	int rotate_necessary;
	refcount_t refcount;
	struct task_struct___42 *task;
	u64 time;
	u64 timestamp;
	u64 timeoffset;
	struct perf_event_context___27 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

struct pipe_buffer___15;

struct pipe_inode_info___15 {
	struct mutex mutex;
	wait_queue_head_t rd_wait;
	wait_queue_head_t wr_wait;
	unsigned int head;
	unsigned int tail;
	unsigned int max_usage;
	unsigned int ring_size;
	bool note_loss;
	unsigned int nr_accounted;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int r_counter;
	unsigned int w_counter;
	unsigned int poll_usage;
	struct page___41 *tmp_page;
	struct fasync_struct___39 *fasync_readers;
	struct fasync_struct___39 *fasync_writers;
	struct pipe_buffer___15 *bufs;
	struct user_struct *user;
	struct watch_queue *watch_queue;
};

struct kernfs_node___40;

struct cgroup_file___33 {
	struct kernfs_node___40 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct obj_cgroup___26;

struct mem_cgroup_per_node___26;

struct mem_cgroup___26 {
	struct cgroup_subsys_state___33 css;
	struct mem_cgroup_id id;
	struct page_counter memory;
	union {
		struct page_counter swap;
		struct page_counter memsw;
	};
	struct page_counter kmem;
	struct page_counter tcpmem;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool oom_group;
	bool oom_lock;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___33 events_file;
	struct cgroup_file___33 events_local_file;
	struct cgroup_file___33 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	struct memcg_vmstats vmstats;
	atomic_long_t memory_events[8];
	atomic_long_t memory_events_local[8];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct obj_cgroup___26 *objcg;
	struct list_head objcg_list;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad2_;
	atomic_t moving_account;
	struct task_struct___42 *move_lock_task;
	struct memcg_vmstats_percpu *vmstats_percpu;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct memcg_cgwb_frn cgwb_frn[4];
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct deferred_split deferred_split_queue;
	struct mem_cgroup_per_node___26 *nodeinfo[0];
	long: 64;
};

struct kset___39;

struct kobj_type___39;

struct kobject___40 {
	const char *name;
	struct list_head entry;
	struct kobject___40 *parent;
	struct kset___39 *kset;
	struct kobj_type___39 *ktype;
	struct kernfs_node___40 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct blk_integrity_profile___27;

struct blk_integrity___27 {
	const struct blk_integrity_profile___27 *profile;
	unsigned char flags;
	unsigned char tuple_size;
	unsigned char interval_exp;
	unsigned char tag_size;
};

struct bio_set___27 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	struct bio_alloc_cache *cache;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	unsigned int back_pad;
	spinlock_t rescue_lock;
	struct bio_list___27 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	struct hlist_node cpuhp_dead;
};

struct request___27;

struct elevator_queue___27;

struct gendisk___27;

struct blkcg_gq___26;

struct request_queue___27 {
	struct request___27 *last_merge;
	struct elevator_queue___27 *elevator;
	struct percpu_ref q_usage_counter;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	const struct blk_mq_ops *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx **queue_hw_ctx;
	unsigned int nr_hw_queues;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	spinlock_t queue_lock;
	struct gendisk___27 *disk;
	struct kobject___40 kobj;
	struct kobject___40 *mq_kobj;
	struct blk_integrity___27 integrity;
	struct device___43 *dev;
	enum rpm_status rpm_status;
	long unsigned int nr_requests;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_keyslot_manager *ksm;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	atomic_t nr_active_requests_shared_sbitmap;
	struct sbitmap_queue sched_bitmap_tags;
	struct sbitmap_queue sched_breserved_tags;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___26 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int required_elevator_features;
	unsigned int nr_zones;
	long unsigned int *conv_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int max_open_zones;
	unsigned int max_active_zones;
	int node;
	struct mutex debugfs_mutex;
	struct blk_trace *blk_trace;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	struct mutex sysfs_dir_lock;
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	int mq_freeze_depth;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct mutex mq_freeze_lock;
	struct blk_mq_tag_set *tag_set;
	struct list_head tag_set_list;
	struct bio_set___27 bio_split;
	struct dentry___39 *debugfs_dir;
	struct dentry___39 *sched_debugfs_dir;
	struct dentry___39 *rqos_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	u64 write_hints[5];
};

struct vm_struct___36 {
	struct vm_struct___36 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___41 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct address_space_operations___39;

struct address_space___39 {
	struct inode___39 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___39 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct page_pool_params___14 {
	unsigned int flags;
	unsigned int order;
	unsigned int pool_size;
	int nid;
	struct device___43 *dev;
	enum dma_data_direction dma_dir;
	unsigned int max_len;
	unsigned int offset;
};

struct pp_alloc_cache___14 {
	u32 count;
	struct page___41 *cache[128];
};

struct page_pool___14 {
	struct page_pool_params___14 p;
	struct delayed_work release_dw;
	void (*disconnect)(void *);
	long unsigned int defer_start;
	long unsigned int defer_warn;
	u32 pages_state_hold_cnt;
	unsigned int frag_offset;
	struct page___41 *frag_page;
	long int frag_users;
	long: 64;
	long: 64;
	struct pp_alloc_cache___14 alloc;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct ptr_ring ring;
	atomic_t pages_state_release_cnt;
	refcount_t user_cnt;
	u64 destroy_cnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pagemap_ops___39;

struct dev_pagemap___39 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___39 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vfsmount___39;

struct path___39 {
	struct vfsmount___39 *mnt;
	struct dentry___39 *dentry;
};

struct fown_struct___34 {
	rwlock_t lock;
	struct pid___34 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___39 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___39 f_path;
	struct inode___39 *f_inode;
	const struct file_operations___39 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___34 f_owner;
	const struct cred___2 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___39 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___39;

struct vm_operations_struct___39 {
	void (*open)(struct vm_area_struct___42 *);
	void (*close)(struct vm_area_struct___42 *);
	int (*may_split)(struct vm_area_struct___42 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___42 *);
	int (*mprotect)(struct vm_area_struct___42 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___39 *);
	vm_fault_t (*huge_fault)(struct vm_fault___39 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___39 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___42 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___39 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___39 *);
	int (*access)(struct vm_area_struct___42 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___42 *);
	int (*set_policy)(struct vm_area_struct___42 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___42 *, long unsigned int);
	struct page___41 * (*find_special_page)(struct vm_area_struct___42 *, long unsigned int);
};

struct core_thread___41 {
	struct task_struct___42 *task;
	struct core_thread___41 *next;
};

struct core_state___41 {
	atomic_t nr_threads;
	struct core_thread___41 dumper;
	struct completion startup;
};

struct linux_binprm___12;

struct coredump_params___11;

struct linux_binfmt___11 {
	struct list_head lh;
	struct module___40 *module;
	int (*load_binary)(struct linux_binprm___12 *);
	int (*load_shlib)(struct file___39 *);
	int (*core_dump)(struct coredump_params___11 *);
	long unsigned int min_coredump;
};

struct vm_fault___39 {
	const struct {
		struct vm_area_struct___42 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___41 *cow_page;
	struct page___41 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___41 prealloc_pte;
};

struct pglist_data___27;

struct lruvec___27 {
	struct list_head lists[5];
	spinlock_t lru_lock;
	long unsigned int anon_cost;
	long unsigned int file_cost;
	atomic_long_t nonresident_age;
	long unsigned int refaults[2];
	long unsigned int flags;
	struct pglist_data___27 *pgdat;
};

struct zone___27 {
	long unsigned int _watermark[3];
	long unsigned int watermark_boost;
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[5];
	int node;
	struct pglist_data___27 *zone_pgdat;
	struct per_cpu_pages *per_cpu_pageset;
	struct per_cpu_zonestat *per_cpu_zonestats;
	int pageset_high;
	int pageset_batch;
	long unsigned int zone_start_pfn;
	atomic_long_t managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int present_early_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	seqlock_t span_seqlock;
	int initialized;
	int: 32;
	struct zone_padding _pad1_;
	struct free_area free_area[11];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	long unsigned int compact_init_migrate_pfn;
	long unsigned int compact_init_free_pfn;
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	short: 16;
	struct zone_padding _pad3_;
	atomic_long_t vm_stat[11];
	atomic_long_t vm_numa_event[6];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___27 {
	struct zone___27 *zone;
	int zone_idx;
};

struct zonelist___27 {
	struct zoneref___27 _zonerefs[5121];
};

struct pglist_data___27 {
	struct zone___27 node_zones[5];
	struct zonelist___27 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___42 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_highest_zoneidx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_highest_zoneidx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___42 *kcompactd;
	bool proactive_compact_trigger;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct deferred_split deferred_split_queue;
	struct lruvec___27 __lruvec;
	long unsigned int flags;
	long: 64;
	struct zone_padding _pad2_;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[39];
};

struct kernfs_root___40;

struct kernfs_elem_dir___40 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___40 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___40;

struct kernfs_root___40 {
	struct kernfs_node___40 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___40 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___40 {
	struct kernfs_node___40 *target_kn;
};

struct kernfs_ops___40;

struct kernfs_elem_attr___40 {
	const struct kernfs_ops___40 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___40 *notify_next;
};

struct kernfs_node___40 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___40 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___40 dir;
		struct kernfs_elem_symlink___40 symlink;
		struct kernfs_elem_attr___40 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___40;

struct kernfs_ops___40 {
	int (*open)(struct kernfs_open_file___40 *);
	void (*release)(struct kernfs_open_file___40 *);
	int (*seq_show)(struct seq_file___37 *, void *);
	void * (*seq_start)(struct seq_file___37 *, loff_t *);
	void * (*seq_next)(struct seq_file___37 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___37 *, void *);
	ssize_t (*read)(struct kernfs_open_file___40 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___40 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___40 *, struct poll_table_struct___30 *);
	int (*mmap)(struct kernfs_open_file___40 *, struct vm_area_struct___42 *);
};

struct kernfs_syscall_ops___40 {
	int (*show_options)(struct seq_file___37 *, struct kernfs_root___40 *);
	int (*mkdir)(struct kernfs_node___40 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___40 *);
	int (*rename)(struct kernfs_node___40 *, struct kernfs_node___40 *, const char *);
	int (*show_path)(struct seq_file___37 *, struct kernfs_node___40 *, struct kernfs_root___40 *);
};

struct seq_file___37 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___37 *op;
	int poll_event;
	const struct file___39 *file;
	void *private;
};

struct kernfs_open_file___40 {
	struct kernfs_node___40 *kn;
	struct file___39 *file;
	struct seq_file___37 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___39 *vm_ops;
};

typedef void (*poll_queue_proc___30)(struct file___39 *, wait_queue_head_t *, struct poll_table_struct___30 *);

struct poll_table_struct___30 {
	poll_queue_proc___30 _qproc;
	__poll_t _key;
};

struct bin_attribute___40;

struct attribute_group___40 {
	const char *name;
	umode_t (*is_visible)(struct kobject___40 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___40 *, struct bin_attribute___40 *, int);
	struct attribute **attrs;
	struct bin_attribute___40 **bin_attrs;
};

struct bin_attribute___40 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___39 * (*f_mapping)();
	ssize_t (*read)(struct file___39 *, struct kobject___40 *, struct bin_attribute___40 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___39 *, struct kobject___40 *, struct bin_attribute___40 *, char *, loff_t, size_t);
	int (*mmap)(struct file___39 *, struct kobject___40 *, struct bin_attribute___40 *, struct vm_area_struct___42 *);
};

struct sysfs_ops___39 {
	ssize_t (*show)(struct kobject___40 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___40 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___39;

struct kset___39 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___40 kobj;
	const struct kset_uevent_ops___39 *uevent_ops;
};

struct kobj_type___39 {
	void (*release)(struct kobject___40 *);
	const struct sysfs_ops___39 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___40 **default_groups;
	const struct kobj_ns_type_operations___3 * (*child_ns_type)(struct kobject___40 *);
	const void * (*namespace)(struct kobject___40 *);
	void (*get_ownership)(struct kobject___40 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___39 {
	int (* const filter)(struct kset___39 *, struct kobject___40 *);
	const char * (* const name)(struct kset___39 *, struct kobject___40 *);
	int (* const uevent)(struct kset___39 *, struct kobject___40 *, struct kobj_uevent_env *);
};

struct wakeup_source___43;

struct dev_pm_qos___9;

struct dev_pm_info___43 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___43 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___43 *, s32);
	struct dev_pm_qos___9 *qos;
};

struct device_type___43;

struct bus_type___43;

struct device_driver___43;

struct dev_pm_domain___43;

struct device_node___25;

struct fwnode_handle___40;

struct class___43;

struct device___43 {
	struct kobject___40 kobj;
	struct device___43 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___43 *type;
	struct bus_type___43 *bus;
	struct device_driver___43 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___43 power;
	struct dev_pm_domain___43 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___25 *of_node;
	struct fwnode_handle___40 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___43 *class;
	const struct attribute_group___40 **groups;
	void (*release)(struct device___43 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_ops___43 {
	int (*prepare)(struct device___43 *);
	void (*complete)(struct device___43 *);
	int (*suspend)(struct device___43 *);
	int (*resume)(struct device___43 *);
	int (*freeze)(struct device___43 *);
	int (*thaw)(struct device___43 *);
	int (*poweroff)(struct device___43 *);
	int (*restore)(struct device___43 *);
	int (*suspend_late)(struct device___43 *);
	int (*resume_early)(struct device___43 *);
	int (*freeze_late)(struct device___43 *);
	int (*thaw_early)(struct device___43 *);
	int (*poweroff_late)(struct device___43 *);
	int (*restore_early)(struct device___43 *);
	int (*suspend_noirq)(struct device___43 *);
	int (*resume_noirq)(struct device___43 *);
	int (*freeze_noirq)(struct device___43 *);
	int (*thaw_noirq)(struct device___43 *);
	int (*poweroff_noirq)(struct device___43 *);
	int (*restore_noirq)(struct device___43 *);
	int (*runtime_suspend)(struct device___43 *);
	int (*runtime_resume)(struct device___43 *);
	int (*runtime_idle)(struct device___43 *);
};

struct wakeup_source___43 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___43 *dev;
	bool active: 1;
	bool autosleep_enabled: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_qos_request___9;

struct dev_pm_qos___9 {
	struct pm_qos_constraints resume_latency;
	struct pm_qos_constraints latency_tolerance;
	struct freq_constraints freq;
	struct pm_qos_flags flags;
	struct dev_pm_qos_request___9 *resume_latency_req;
	struct dev_pm_qos_request___9 *latency_tolerance_req;
	struct dev_pm_qos_request___9 *flags_req;
};

struct dev_pm_domain___43 {
	struct dev_pm_ops___43 ops;
	int (*start)(struct device___43 *);
	void (*detach)(struct device___43 *, bool);
	int (*activate)(struct device___43 *);
	void (*sync)(struct device___43 *);
	void (*dismiss)(struct device___43 *);
};

struct bus_type___43 {
	const char *name;
	const char *dev_name;
	struct device___43 *dev_root;
	const struct attribute_group___40 **bus_groups;
	const struct attribute_group___40 **dev_groups;
	const struct attribute_group___40 **drv_groups;
	int (*match)(struct device___43 *, struct device_driver___43 *);
	int (*uevent)(struct device___43 *, struct kobj_uevent_env *);
	int (*probe)(struct device___43 *);
	void (*sync_state)(struct device___43 *);
	void (*remove)(struct device___43 *);
	void (*shutdown)(struct device___43 *);
	int (*online)(struct device___43 *);
	int (*offline)(struct device___43 *);
	int (*suspend)(struct device___43 *, pm_message_t);
	int (*resume)(struct device___43 *);
	int (*num_vf)(struct device___43 *);
	int (*dma_configure)(struct device___43 *);
	const struct dev_pm_ops___43 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___43 {
	const char *name;
	struct bus_type___43 *bus;
	struct module___40 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___43 *);
	void (*sync_state)(struct device___43 *);
	int (*remove)(struct device___43 *);
	void (*shutdown)(struct device___43 *);
	int (*suspend)(struct device___43 *, pm_message_t);
	int (*resume)(struct device___43 *);
	const struct attribute_group___40 **groups;
	const struct attribute_group___40 **dev_groups;
	const struct dev_pm_ops___43 *pm;
	void (*coredump)(struct device___43 *);
	struct driver_private *p;
};

struct device_type___43 {
	const char *name;
	const struct attribute_group___40 **groups;
	int (*uevent)(struct device___43 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___43 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___43 *);
	const struct dev_pm_ops___43 *pm;
};

struct class___43 {
	const char *name;
	struct module___40 *owner;
	const struct attribute_group___40 **class_groups;
	const struct attribute_group___40 **dev_groups;
	struct kobject___40 *dev_kobj;
	int (*dev_uevent)(struct device___43 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___43 *, umode_t *);
	void (*class_release)(struct class___43 *);
	void (*dev_release)(struct device___43 *);
	int (*shutdown_pre)(struct device___43 *);
	const struct kobj_ns_type_operations___3 *ns_type;
	const void * (*namespace)(struct device___43 *);
	void (*get_ownership)(struct device___43 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___43 *pm;
	struct subsys_private *p;
};

struct module_kobject___40 {
	struct kobject___40 kobj;
	struct module___40 *mod;
	struct kobject___40 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___40 {
	struct module___40 *mod;
	struct latch_tree_node node;
};

struct module_layout___40 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___40 mtn;
};

struct module_attribute___40;

struct kernel_param___40;

struct module___40 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___40 mkobj;
	struct module_attribute___40 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___40 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___40 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___40 core_layout;
	struct module_layout___40 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map___31 *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___27 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	int num_static_call_sites;
	struct static_call_site *static_call_sites;
	bool klp;
	bool klp_alive;
	struct klp_modinfo *klp_info;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fwnode_operations___40;

struct fwnode_handle___40 {
	struct fwnode_handle___40 *secondary;
	const struct fwnode_operations___40 *ops;
	struct device___43 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct device_node___25 {
	const char *name;
	phandle phandle;
	const char *full_name;
	struct fwnode_handle___40 fwnode;
	struct property *properties;
	struct property *deadprops;
	struct device_node___25 *parent;
	struct device_node___25 *child;
	struct device_node___25 *sibling;
	long unsigned int _flags;
	void *data;
};

struct psi_group___33 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___42 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___33;

struct cgroup_rstat_cpu___33;

struct cgroup___33 {
	struct cgroup_subsys_state___33 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___40 *kn;
	struct cgroup_file___33 procs_file;
	struct cgroup_file___33 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___33 *subsys[14];
	struct cgroup_root___33 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___33 *dom_cgrp;
	struct cgroup___33 *old_dom_cgrp;
	struct cgroup_rstat_cpu___33 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___33 psi;
	struct cgroup_bpf___4 bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct autogroup___4 {
	struct kref kref;
	struct task_group___4 *tg;
	struct rw_semaphore lock;
	long unsigned int id;
	int nice;
};

struct shrink_control___26 {
	gfp_t gfp_mask;
	int nid;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	struct mem_cgroup___26 *memcg;
};

struct shrinker___26 {
	long unsigned int (*count_objects)(struct shrinker___26 *, struct shrink_control___26 *);
	long unsigned int (*scan_objects)(struct shrinker___26 *, struct shrink_control___26 *);
	long int batch;
	int seeks;
	unsigned int flags;
	struct list_head list;
	int id;
	atomic_long_t *nr_deferred;
};

struct dev_pagemap_ops___39 {
	void (*page_free)(struct page___41 *);
	void (*kill)(struct dev_pagemap___39 *);
	void (*cleanup)(struct dev_pagemap___39 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___39 *);
};

struct dentry_operations___39;

struct dentry___39 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___39 *d_parent;
	struct qstr d_name;
	struct inode___39 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___39 *d_op;
	struct super_block___39 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___39;

struct inode___39 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___39 *i_op;
	struct super_block___39 *i_sb;
	struct address_space___39 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___26 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___39 *i_fop;
		void (*free_inode)(struct inode___39 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___39 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___15 *i_pipe;
		struct cdev *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___39 {
	int (*d_revalidate)(struct dentry___39 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___39 *, unsigned int);
	int (*d_hash)(const struct dentry___39 *, struct qstr *);
	int (*d_compare)(const struct dentry___39 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___39 *);
	int (*d_init)(struct dentry___39 *);
	void (*d_release)(struct dentry___39 *);
	void (*d_prune)(struct dentry___39 *);
	void (*d_iput)(struct dentry___39 *, struct inode___39 *);
	char * (*d_dname)(struct dentry___39 *, char *, int);
	struct vfsmount___39 * (*d_automount)(struct path___39 *);
	int (*d_manage)(const struct path___39 *, bool);
	struct dentry___39 * (*d_real)(struct dentry___39 *, const struct inode___39 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___39;

struct mem_dqinfo___39 {
	struct quota_format_type___39 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___39;

struct quota_info___39 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___39 *files[3];
	struct mem_dqinfo___39 info[3];
	const struct quota_format_ops___39 *ops[3];
};

struct rcuwait___39 {
	struct task_struct___42 *task;
};

struct percpu_rw_semaphore___39 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___39 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___39 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___39 rw_sem[3];
};

struct super_operations___39;

struct dquot_operations___39;

struct quotactl_ops___39;

struct block_device___27;

struct super_block___39 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___39 *s_type;
	const struct super_operations___39 *s_op;
	const struct dquot_operations___39 *dq_op;
	const struct quotactl_ops___39 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___39 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___27 *s_bdev;
	struct backing_dev_info___26 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___39 s_dquot;
	struct sb_writers___39 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___39 *s_d_op;
	int cleancache_poolid;
	struct shrinker___26 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___2 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___39 {
	struct dentry___39 *mnt_root;
	struct super_block___39 *mnt_sb;
	int mnt_flags;
	struct user_namespace___2 *mnt_userns;
};

struct io_cq___27 {
	struct request_queue___27 *q;
	struct io_context___27 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct wait_page_queue___23;

struct kiocb___39 {
	struct file___39 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___39 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___23 *ki_waitq;
	};
};

struct iattr___39 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___39 *ia_file;
};

struct dquot___39 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___39 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___39 {
	int qf_fmt_id;
	const struct quota_format_ops___39 *qf_ops;
	struct module___40 *qf_owner;
	struct quota_format_type___39 *qf_next;
};

struct quota_format_ops___39 {
	int (*check_quota_file)(struct super_block___39 *, int);
	int (*read_file_info)(struct super_block___39 *, int);
	int (*write_file_info)(struct super_block___39 *, int);
	int (*free_file_info)(struct super_block___39 *, int);
	int (*read_dqblk)(struct dquot___39 *);
	int (*commit_dqblk)(struct dquot___39 *);
	int (*release_dqblk)(struct dquot___39 *);
	int (*get_next_id)(struct super_block___39 *, struct kqid *);
};

struct dquot_operations___39 {
	int (*write_dquot)(struct dquot___39 *);
	struct dquot___39 * (*alloc_dquot)(struct super_block___39 *, int);
	void (*destroy_dquot)(struct dquot___39 *);
	int (*acquire_dquot)(struct dquot___39 *);
	int (*release_dquot)(struct dquot___39 *);
	int (*mark_dirty)(struct dquot___39 *);
	int (*write_info)(struct super_block___39 *, int);
	qsize_t * (*get_reserved_space)(struct inode___39 *);
	int (*get_projid)(struct inode___39 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___39 *, qsize_t *);
	int (*get_next_id)(struct super_block___39 *, struct kqid *);
};

struct quotactl_ops___39 {
	int (*quota_on)(struct super_block___39 *, int, int, const struct path___39 *);
	int (*quota_off)(struct super_block___39 *, int);
	int (*quota_enable)(struct super_block___39 *, unsigned int);
	int (*quota_disable)(struct super_block___39 *, unsigned int);
	int (*quota_sync)(struct super_block___39 *, int);
	int (*set_info)(struct super_block___39 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___39 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___39 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___39 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___39 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___39 *, unsigned int);
};

struct wait_page_queue___23 {
	struct page___41 *page;
	int bit_nr;
	wait_queue_entry_t wait;
};

struct writeback_control___26;

struct readahead_control___23;

struct swap_info_struct___19;

struct address_space_operations___39 {
	int (*writepage)(struct page___41 *, struct writeback_control___26 *);
	int (*readpage)(struct file___39 *, struct page___41 *);
	int (*writepages)(struct address_space___39 *, struct writeback_control___26 *);
	int (*set_page_dirty)(struct page___41 *);
	int (*readpages)(struct file___39 *, struct address_space___39 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___23 *);
	int (*write_begin)(struct file___39 *, struct address_space___39 *, loff_t, unsigned int, unsigned int, struct page___41 **, void **);
	int (*write_end)(struct file___39 *, struct address_space___39 *, loff_t, unsigned int, unsigned int, struct page___41 *, void *);
	sector_t (*bmap)(struct address_space___39 *, sector_t);
	void (*invalidatepage)(struct page___41 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___41 *, gfp_t);
	void (*freepage)(struct page___41 *);
	ssize_t (*direct_IO)(struct kiocb___39 *, struct iov_iter___32 *);
	int (*migratepage)(struct address_space___39 *, struct page___41 *, struct page___41 *, enum migrate_mode);
	bool (*isolate_page)(struct page___41 *, isolate_mode_t);
	void (*putback_page)(struct page___41 *);
	int (*launder_page)(struct page___41 *);
	int (*is_partially_uptodate)(struct page___41 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___41 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___39 *, struct page___41 *);
	int (*swap_activate)(struct swap_info_struct___19 *, struct file___39 *, sector_t *);
	void (*swap_deactivate)(struct file___39 *);
};

struct writeback_control___26 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	unsigned int no_cgroup_owner: 1;
	unsigned int punt_to_cgroup: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bdi_writeback___26 *wb;
	struct inode___39 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
};

struct readahead_control___23 {
	struct file___39 *file;
	struct address_space___39 *mapping;
	struct file_ra_state *ra;
	long unsigned int _index;
	unsigned int _nr_pages;
	unsigned int _batch_count;
};

struct bio_vec___32;

struct iov_iter___32 {
	u8 iter_type;
	bool data_source;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___32 *bvec;
		struct xarray *xarray;
		struct pipe_inode_info___15 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			unsigned int head;
			unsigned int start_head;
		};
		loff_t xarray_start;
	};
};

struct swap_info_struct___19 {
	struct percpu_ref users;
	long unsigned int flags;
	short int prio;
	struct plist_node list;
	signed char type;
	unsigned int max;
	unsigned char *swap_map;
	struct swap_cluster_info *cluster_info;
	struct swap_cluster_list free_clusters;
	unsigned int lowest_bit;
	unsigned int highest_bit;
	unsigned int pages;
	unsigned int inuse_pages;
	unsigned int cluster_next;
	unsigned int cluster_nr;
	unsigned int *cluster_next_cpu;
	struct percpu_cluster *percpu_cluster;
	struct rb_root swap_extent_root;
	struct block_device___27 *bdev;
	struct file___39 *swap_file;
	unsigned int old_block_size;
	struct completion comp;
	long unsigned int *frontswap_map;
	atomic_t frontswap_pages;
	spinlock_t lock;
	spinlock_t cont_lock;
	struct work_struct discard_work;
	struct swap_cluster_list discard_clusters;
	struct plist_node avail_lists[0];
};

struct inode_operations___39 {
	struct dentry___39 * (*lookup)(struct inode___39 *, struct dentry___39 *, unsigned int);
	const char * (*get_link)(struct dentry___39 *, struct inode___39 *, struct delayed_call *);
	int (*permission)(struct user_namespace___2 *, struct inode___39 *, int);
	struct posix_acl * (*get_acl)(struct inode___39 *, int, bool);
	int (*readlink)(struct dentry___39 *, char *, int);
	int (*create)(struct user_namespace___2 *, struct inode___39 *, struct dentry___39 *, umode_t, bool);
	int (*link)(struct dentry___39 *, struct inode___39 *, struct dentry___39 *);
	int (*unlink)(struct inode___39 *, struct dentry___39 *);
	int (*symlink)(struct user_namespace___2 *, struct inode___39 *, struct dentry___39 *, const char *);
	int (*mkdir)(struct user_namespace___2 *, struct inode___39 *, struct dentry___39 *, umode_t);
	int (*rmdir)(struct inode___39 *, struct dentry___39 *);
	int (*mknod)(struct user_namespace___2 *, struct inode___39 *, struct dentry___39 *, umode_t, dev_t);
	int (*rename)(struct user_namespace___2 *, struct inode___39 *, struct dentry___39 *, struct inode___39 *, struct dentry___39 *, unsigned int);
	int (*setattr)(struct user_namespace___2 *, struct dentry___39 *, struct iattr___39 *);
	int (*getattr)(struct user_namespace___2 *, const struct path___39 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___39 *, char *, size_t);
	int (*fiemap)(struct inode___39 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___39 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___39 *, struct dentry___39 *, struct file___39 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace___2 *, struct inode___39 *, struct dentry___39 *, umode_t);
	int (*set_acl)(struct user_namespace___2 *, struct inode___39 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace___2 *, struct dentry___39 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___39 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___39 {
	void (*fl_copy_lock)(struct file_lock___39 *, struct file_lock___39 *);
	void (*fl_release_private)(struct file_lock___39 *);
};

struct lock_manager_operations___39;

struct file_lock___39 {
	struct file_lock___39 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___39 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___39 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___39 *fl_ops;
	const struct lock_manager_operations___39 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___39 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___39 *);
	int (*lm_grant)(struct file_lock___39 *, int);
	bool (*lm_break)(struct file_lock___39 *);
	int (*lm_change)(struct file_lock___39 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___39 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___39 *);
};

struct fasync_struct___39 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___39 *fa_next;
	struct file___39 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___39 {
	struct inode___39 * (*alloc_inode)(struct super_block___39 *);
	void (*destroy_inode)(struct inode___39 *);
	void (*free_inode)(struct inode___39 *);
	void (*dirty_inode)(struct inode___39 *, int);
	int (*write_inode)(struct inode___39 *, struct writeback_control___26 *);
	int (*drop_inode)(struct inode___39 *);
	void (*evict_inode)(struct inode___39 *);
	void (*put_super)(struct super_block___39 *);
	int (*sync_fs)(struct super_block___39 *, int);
	int (*freeze_super)(struct super_block___39 *);
	int (*freeze_fs)(struct super_block___39 *);
	int (*thaw_super)(struct super_block___39 *);
	int (*unfreeze_fs)(struct super_block___39 *);
	int (*statfs)(struct dentry___39 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___39 *, int *, char *);
	void (*umount_begin)(struct super_block___39 *);
	int (*show_options)(struct seq_file___37 *, struct dentry___39 *);
	int (*show_devname)(struct seq_file___37 *, struct dentry___39 *);
	int (*show_path)(struct seq_file___37 *, struct dentry___39 *);
	int (*show_stats)(struct seq_file___37 *, struct dentry___39 *);
	ssize_t (*quota_read)(struct super_block___39 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___39 *, int, const char *, size_t, loff_t);
	struct dquot___39 ** (*get_dquots)(struct inode___39 *);
	long int (*nr_cached_objects)(struct super_block___39 *, struct shrink_control___26 *);
	long int (*free_cached_objects)(struct super_block___39 *, struct shrink_control___26 *);
	struct file___39 * (*real_loop)(struct file___39 *);
};

struct block_device___27 {
	sector_t bd_start_sect;
	struct disk_stats *bd_stats;
	long unsigned int bd_stamp;
	bool bd_read_only;
	dev_t bd_dev;
	int bd_openers;
	struct inode___39 *bd_inode;
	struct super_block___39 *bd_super;
	void *bd_claiming;
	struct device___43 bd_device;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct kobject___40 *bd_holder_dir;
	u8 bd_partno;
	spinlock_t bd_size_lock;
	struct gendisk___27 *bd_disk;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	struct super_block___39 *bd_fsfreeze_sb;
	struct partition_meta_info *bd_meta_info;
};

typedef void bio_end_io_t___27(struct bio___27 *);

struct bio_vec___32 {
	struct page___41 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___27;

struct bio___27 {
	struct bio___27 *bi_next;
	struct block_device___27 *bi_bdev;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	atomic_t __bi_remaining;
	struct bvec_iter bi_iter;
	bio_end_io_t___27 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___26 *bi_blkg;
	struct bio_issue bi_issue;
	u64 bi_iocost_cost;
	struct bio_crypt_ctx *bi_crypt_context;
	union {
		struct bio_integrity_payload___27 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___32 *bi_io_vec;
	struct bio_set___27 *bi_pool;
	struct bio_vec___32 bi_inline_vecs[0];
};

struct cgroup_namespace___33 {
	struct ns_common___5 ns;
	struct user_namespace___2 *user_ns;
	struct ucounts___2 *ucounts;
	struct css_set___33 *root_cset;
};

struct kernel_param_ops___40 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___40 *);
	int (*get)(char *, const struct kernel_param___40 *);
	void (*free)(void *);
};

struct kparam_array___40;

struct kernel_param___40 {
	const char *name;
	struct module___40 *mod;
	const struct kernel_param_ops___40 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___40 *arr;
	};
};

struct kparam_array___40 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___40 *ops;
	void *elem;
};

struct module_attribute___40 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___40 *, struct module_kobject___40 *, char *);
	ssize_t (*store)(struct module_attribute___40 *, struct module_kobject___40 *, const char *, size_t);
	void (*setup)(struct module___40 *, const char *);
	int (*test)(struct module___40 *);
	void (*free)(struct module___40 *);
};

struct trace_event_class___27;

struct trace_event_call___27 {
	struct list_head list;
	struct trace_event_class___27 *class;
	union {
		char *name;
		struct tracepoint___31 *tp;
	};
	struct trace_event event;
	char *print_fmt;
	struct event_filter *filter;
	union {
		void *module;
		atomic_t refcnt;
	};
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
	struct bpf_prog_array___4 *prog_array;
	int (*perf_perm)(struct trace_event_call___27 *, struct perf_event___27 *);
};

struct cftype___33;

struct cgroup_subsys___33 {
	struct cgroup_subsys_state___33 * (*css_alloc)(struct cgroup_subsys_state___33 *);
	int (*css_online)(struct cgroup_subsys_state___33 *);
	void (*css_offline)(struct cgroup_subsys_state___33 *);
	void (*css_released)(struct cgroup_subsys_state___33 *);
	void (*css_free)(struct cgroup_subsys_state___33 *);
	void (*css_reset)(struct cgroup_subsys_state___33 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___33 *, int);
	int (*css_extra_stat_show)(struct seq_file___37 *, struct cgroup_subsys_state___33 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___42 *, struct css_set___33 *);
	void (*cancel_fork)(struct task_struct___42 *, struct css_set___33 *);
	void (*fork)(struct task_struct___42 *);
	void (*exit)(struct task_struct___42 *);
	void (*release)(struct task_struct___42 *);
	void (*bind)(struct cgroup_subsys_state___33 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___33 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___33 *dfl_cftypes;
	struct cftype___33 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___33 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___33 *updated_children;
	struct cgroup___33 *updated_next;
};

struct cgroup_root___33 {
	struct kernfs_root___40 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___33 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___33 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___33 *ss;
	struct list_head node;
	struct kernfs_ops___40 *kf_ops;
	int (*open)(struct kernfs_open_file___40 *);
	void (*release)(struct kernfs_open_file___40 *);
	u64 (*read_u64)(struct cgroup_subsys_state___33 *, struct cftype___33 *);
	s64 (*read_s64)(struct cgroup_subsys_state___33 *, struct cftype___33 *);
	int (*seq_show)(struct seq_file___37 *, void *);
	void * (*seq_start)(struct seq_file___37 *, loff_t *);
	void * (*seq_next)(struct seq_file___37 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___37 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___33 *, struct cftype___33 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___33 *, struct cftype___33 *, s64);
	ssize_t (*write)(struct kernfs_open_file___40 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___40 *, struct poll_table_struct___30 *);
};

struct block_device_operations___27;

struct gendisk___27 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	short unsigned int events;
	short unsigned int event_flags;
	struct xarray part_tbl;
	struct block_device___27 *part0;
	const struct block_device_operations___27 *fops;
	struct request_queue___27 *queue;
	void *private_data;
	int flags;
	long unsigned int state;
	struct mutex open_mutex;
	unsigned int open_partitions;
	struct backing_dev_info___26 *bdi;
	struct kobject___40 *slave_dir;
	struct list_head slave_bdevs;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___40 integrity_kobj;
	struct cdrom_device_info *cdi;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	u64 diskseq;
};

struct bio_integrity_payload___27 {
	struct bio___27 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___32 *bip_vec;
	struct bio_vec___32 bip_inline_vecs[0];
};

struct blkcg___26;

struct blkg_policy_data___26;

struct blkcg_gq___26 {
	struct request_queue___27 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___26 *blkcg;
	struct blkcg_gq___26 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_iostat_set *iostat_cpu;
	struct blkg_iostat_set iostat;
	struct blkg_policy_data___26 *pd[6];
	spinlock_t async_bio_lock;
	struct bio_list___27 async_bios;
	struct work_struct async_bio_work;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
	struct callback_head callback_head;
};

typedef void integrity_prepare_fn___27(struct request___27 *);

typedef void integrity_complete_fn___27(struct request___27 *, unsigned int);

struct blk_integrity_profile___27 {
	integrity_processing_fn *generate_fn;
	integrity_processing_fn *verify_fn;
	integrity_prepare_fn___27 *prepare_fn;
	integrity_complete_fn___27 *complete_fn;
	const char *name;
};

struct block_device_operations___27 {
	blk_qc_t (*submit_bio)(struct bio___27 *);
	int (*open)(struct block_device___27 *, fmode_t);
	void (*release)(struct gendisk___27 *, fmode_t);
	int (*rw_page)(struct block_device___27 *, sector_t, struct page___41 *, unsigned int);
	int (*ioctl)(struct block_device___27 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___27 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___27 *, unsigned int);
	void (*unlock_native_capacity)(struct gendisk___27 *);
	int (*getgeo)(struct block_device___27 *, struct hd_geometry *);
	int (*set_read_only)(struct block_device___27 *, bool);
	void (*swap_slot_free_notify)(struct block_device___27 *, long unsigned int);
	int (*report_zones)(struct gendisk___27 *, sector_t, unsigned int, report_zones_cb, void *);
	char * (*devnode)(struct gendisk___27 *, umode_t *);
	struct module___40 *owner;
	const struct pr_ops *pr_ops;
	int (*alternative_gpt_sector)(struct gendisk___27 *, sector_t *);
};

struct fwnode_reference_args___40;

struct fwnode_endpoint___40;

struct fwnode_operations___40 {
	struct fwnode_handle___40 * (*get)(struct fwnode_handle___40 *);
	void (*put)(struct fwnode_handle___40 *);
	bool (*device_is_available)(const struct fwnode_handle___40 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___40 *, const struct device___43 *);
	bool (*property_present)(const struct fwnode_handle___40 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___40 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___40 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___40 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___40 *);
	struct fwnode_handle___40 * (*get_parent)(const struct fwnode_handle___40 *);
	struct fwnode_handle___40 * (*get_next_child_node)(const struct fwnode_handle___40 *, struct fwnode_handle___40 *);
	struct fwnode_handle___40 * (*get_named_child_node)(const struct fwnode_handle___40 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___40 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___40 *);
	struct fwnode_handle___40 * (*graph_get_next_endpoint)(const struct fwnode_handle___40 *, struct fwnode_handle___40 *);
	struct fwnode_handle___40 * (*graph_get_remote_endpoint)(const struct fwnode_handle___40 *);
	struct fwnode_handle___40 * (*graph_get_port_parent)(struct fwnode_handle___40 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___40 *, struct fwnode_endpoint___40 *);
	int (*add_links)(struct fwnode_handle___40 *);
};

struct fwnode_endpoint___40 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___40 *local_fwnode;
};

struct fwnode_reference_args___40 {
	struct fwnode_handle___40 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

typedef void rq_end_io_fn___27(struct request___27 *, blk_status_t);

struct request___27 {
	struct request_queue___27 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int tag;
	int internal_tag;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___27 *bio;
	struct bio___27 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct llist_node ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___32 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___27 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___27 *saved_end_io;
		} flush;
	};
	struct gendisk___27 *rq_disk;
	struct block_device___27 *part;
	u64 alloc_time_ns;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int stats_sectors;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	struct bio_crypt_ctx *crypt_ctx;
	struct blk_ksm_keyslot *crypt_keyslot;
	short unsigned int write_hint;
	short unsigned int ioprio;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___27 *end_io;
	void *end_io_data;
};

struct elevator_type___27;

struct elevator_mq_ops___27 {
	int (*init_sched)(struct request_queue___27 *, struct elevator_type___27 *);
	void (*exit_sched)(struct elevator_queue___27 *);
	int (*init_hctx)(struct blk_mq_hw_ctx *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx *, unsigned int);
	void (*depth_updated)(struct blk_mq_hw_ctx *);
	bool (*allow_merge)(struct request_queue___27 *, struct request___27 *, struct bio___27 *);
	bool (*bio_merge)(struct request_queue___27 *, struct bio___27 *, unsigned int);
	int (*request_merge)(struct request_queue___27 *, struct request___27 **, struct bio___27 *);
	void (*request_merged)(struct request_queue___27 *, struct request___27 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___27 *, struct request___27 *, struct request___27 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___27 *);
	void (*finish_request)(struct request___27 *);
	void (*insert_requests)(struct blk_mq_hw_ctx *, struct list_head *, bool);
	struct request___27 * (*dispatch_request)(struct blk_mq_hw_ctx *);
	bool (*has_work)(struct blk_mq_hw_ctx *);
	void (*completed_request)(struct request___27 *, u64);
	void (*requeue_request)(struct request___27 *);
	struct request___27 * (*former_request)(struct request_queue___27 *, struct request___27 *);
	struct request___27 * (*next_request)(struct request_queue___27 *, struct request___27 *);
	void (*init_icq)(struct io_cq___27 *);
	void (*exit_icq)(struct io_cq___27 *);
};

struct elv_fs_entry___27;

struct elevator_type___27 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___27 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___27 *elevator_attrs;
	const char *elevator_name;
	const char *elevator_alias;
	const unsigned int elevator_features;
	struct module___40 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
};

struct elevator_queue___27 {
	struct elevator_type___27 *type;
	void *elevator_data;
	struct kobject___40 kobj;
	struct mutex sysfs_lock;
	unsigned int registered: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hlist_head hash[64];
};

struct elv_fs_entry___27 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___27 *, char *);
	ssize_t (*store)(struct elevator_queue___27 *, const char *, size_t);
};

struct blkcg_policy_data___26;

struct blkcg___26 {
	struct cgroup_subsys_state___33 css;
	spinlock_t lock;
	refcount_t online_pin;
	struct xarray blkg_tree;
	struct blkcg_gq___26 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___26 *cpd[6];
	struct list_head all_blkcgs_node;
	char fc_app_id[129];
	struct list_head cgwb_list;
};

struct blkcg_policy_data___26 {
	struct blkcg___26 *blkcg;
	int plid;
};

struct blkg_policy_data___26 {
	struct blkcg_gq___26 *blkg;
	int plid;
};

struct mem_cgroup_reclaim_iter___26 {
	struct mem_cgroup___26 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___26 {
	struct lruvec___27 lruvec;
	struct lruvec_stats_percpu *lruvec_stats_percpu;
	struct lruvec_stats lruvec_stats;
	long unsigned int lru_zone_size[25];
	struct mem_cgroup_reclaim_iter___26 iter;
	struct shrinker_info *shrinker_info;
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	struct mem_cgroup___26 *memcg;
};

struct obj_cgroup___26 {
	struct percpu_ref refcnt;
	struct mem_cgroup___26 *memcg;
	atomic_t nr_charged_bytes;
	union {
		struct list_head list;
		struct callback_head rcu;
	};
};

struct klp_func___2 {
	const char *old_name;
	void *new_func;
	long unsigned int old_sympos;
	void *old_func;
	struct kobject___40 kobj;
	struct list_head node;
	struct list_head stack_node;
	long unsigned int old_size;
	long unsigned int new_size;
	bool nop;
	bool patched;
	bool transition;
};

struct klp_object___2;

struct klp_callbacks___2 {
	int (*pre_patch)(struct klp_object___2 *);
	void (*post_patch)(struct klp_object___2 *);
	void (*pre_unpatch)(struct klp_object___2 *);
	void (*post_unpatch)(struct klp_object___2 *);
	bool post_unpatch_enabled;
};

struct klp_object___2 {
	const char *name;
	struct klp_func___2 *funcs;
	struct klp_callbacks___2 callbacks;
	struct kobject___40 kobj;
	struct list_head func_list;
	struct list_head node;
	struct module___40 *mod;
	bool dynamic;
	bool patched;
};

struct klp_patch___2 {
	struct module___40 *mod;
	struct klp_object___2 *objs;
	struct klp_state *states;
	bool replace;
	struct list_head list;
	struct kobject___40 kobj;
	struct list_head obj_list;
	bool enabled;
	bool forced;
	struct work_struct free_work;
	struct completion finish;
};

struct linux_binprm___12 {
	struct vm_area_struct___42 *vma;
	long unsigned int vma_pages;
	struct mm_struct___42 *mm;
	long unsigned int p;
	long unsigned int argmin;
	unsigned int have_execfd: 1;
	unsigned int execfd_creds: 1;
	unsigned int secureexec: 1;
	unsigned int point_of_no_return: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct file___39 *executable;
	struct file___39 *interpreter;
	struct file___39 *file;
	struct cred___2 *cred;
	int unsafe;
	unsigned int per_clear;
	int argc;
	int envc;
	const char *filename;
	const char *interp;
	const char *fdpath;
	unsigned int interp_flags;
	int execfd;
	long unsigned int loader;
	long unsigned int exec;
	struct rlimit rlim_stack;
	char buf[256];
};

struct coredump_params___11 {
	const kernel_siginfo_t *siginfo;
	struct pt_regs *regs;
	struct file___39 *file;
	long unsigned int limit;
	long unsigned int mm_flags;
	loff_t written;
	loff_t pos;
	loff_t to_skip;
};

struct dev_pm_qos_request___9 {
	enum dev_pm_qos_req_type type;
	union {
		struct plist_node pnode;
		struct pm_qos_flags_request flr;
		struct freq_qos_request freq;
	} data;
	struct device___43 *dev;
};

struct cpuidle_driver___4;

struct cpuidle_state___4 {
	char name[16];
	char desc[32];
	s64 exit_latency_ns;
	s64 target_residency_ns;
	unsigned int flags;
	unsigned int exit_latency;
	int power_usage;
	unsigned int target_residency;
	int (*enter)(struct cpuidle_device___2 *, struct cpuidle_driver___4 *, int);
	int (*enter_dead)(struct cpuidle_device___2 *, int);
	int (*enter_s2idle)(struct cpuidle_device___2 *, struct cpuidle_driver___4 *, int);
};

struct cpuidle_driver___4 {
	const char *name;
	struct module___40 *owner;
	unsigned int bctimer: 1;
	long: 63;
	long: 64;
	long: 64;
	struct cpuidle_state___4 states[10];
	int state_count;
	int safe_state_index;
	struct cpumask *cpumask;
	const char *governor;
};

struct pipe_buf_operations___15;

struct pipe_buffer___15 {
	struct page___41 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___15 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___15 {
	int (*confirm)(struct pipe_inode_info___15 *, struct pipe_buffer___15 *);
	void (*release)(struct pipe_inode_info___15 *, struct pipe_buffer___15 *);
	bool (*try_steal)(struct pipe_inode_info___15 *, struct pipe_buffer___15 *);
	bool (*get)(struct pipe_inode_info___15 *, struct pipe_buffer___15 *);
};

enum migrate_reason {
	MR_COMPACTION = 0,
	MR_MEMORY_FAILURE = 1,
	MR_MEMORY_HOTPLUG = 2,
	MR_SYSCALL = 3,
	MR_MEMPOLICY_MBIND = 4,
	MR_NUMA_MISPLACED = 5,
	MR_CONTIG_RANGE = 6,
	MR_LONGTERM_PIN = 7,
	MR_DEMOTION = 8,
	MR_TYPES = 9,
};

struct perf_cpu_context___27;

struct perf_output_handle___27;

struct pmu___27 {
	struct list_head entry;
	struct module___40 *module;
	struct device___43 *dev;
	const struct attribute_group___40 **attr_groups;
	const struct attribute_group___40 **attr_update;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___27 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___27 *);
	void (*pmu_disable)(struct pmu___27 *);
	int (*event_init)(struct perf_event___27 *);
	void (*event_mapped)(struct perf_event___27 *, struct mm_struct___42 *);
	void (*event_unmapped)(struct perf_event___27 *, struct mm_struct___42 *);
	int (*add)(struct perf_event___27 *, int);
	void (*del)(struct perf_event___27 *, int);
	void (*start)(struct perf_event___27 *, int);
	void (*stop)(struct perf_event___27 *, int);
	void (*read)(struct perf_event___27 *);
	void (*start_txn)(struct pmu___27 *, unsigned int);
	int (*commit_txn)(struct pmu___27 *);
	void (*cancel_txn)(struct pmu___27 *);
	int (*event_idx)(struct perf_event___27 *);
	void (*sched_task)(struct perf_event_context___27 *, bool);
	struct kmem_cache *task_ctx_cache;
	void (*swap_task_ctx)(struct perf_event_context___27 *, struct perf_event_context___27 *);
	void * (*setup_aux)(struct perf_event___27 *, void **, int, bool);
	void (*free_aux)(void *);
	long int (*snapshot_aux)(struct perf_event___27 *, struct perf_output_handle___27 *, long unsigned int);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___27 *);
	int (*aux_output_match)(struct perf_event___27 *);
	int (*filter_match)(struct perf_event___27 *);
	int (*check_period)(struct perf_event___27 *, u64);
};

struct perf_cpu_context___27 {
	struct perf_event_context___27 ctx;
	struct perf_event_context___27 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___27 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
	int heap_size;
	struct perf_event___27 **heap;
	struct perf_event___27 *heap_default[2];
};

struct perf_output_handle___27 {
	struct perf_event___27 *event;
	struct perf_buffer *rb;
	long unsigned int wakeup;
	long unsigned int size;
	u64 aux_flags;
	union {
		void *addr;
		long unsigned int head;
	};
	int page;
};

struct perf_cgroup___27 {
	struct cgroup_subsys_state___33 css;
	struct perf_cgroup_info *info;
};

struct trace_event_fields___27 {
	const char *type;
	union {
		struct {
			const char *name;
			const int size;
			const int align;
			const int is_signed;
			const int filter_type;
		};
		int (*define_fields)(struct trace_event_call___27 *);
	};
};

struct trace_event_class___27 {
	const char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct trace_event_call___27 *, enum trace_reg, void *);
	struct trace_event_fields___27 *fields_array;
	struct list_head * (*get_fields)(struct trace_event_call___27 *);
	struct list_head fields;
	int (*raw_init)(struct trace_event_call___27 *);
};

struct rq___4 {
	raw_spinlock_t __lock;
	unsigned int nr_running;
	unsigned int nr_numa_running;
	unsigned int nr_preferred_running;
	unsigned int numa_migrate_on;
	long unsigned int last_blocked_load_update_tick;
	unsigned int has_blocked_load;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	call_single_data_t nohz_csd;
	unsigned int nohz_tick_stopped;
	atomic_t nohz_flags;
	unsigned int ttwu_pending;
	u64 nr_switches;
	long: 64;
	struct uclamp_rq uclamp[2];
	unsigned int uclamp_flags;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	struct cfs_rq___4 cfs;
	struct rt_rq rt;
	struct dl_rq dl;
	struct list_head leaf_cfs_rq_list;
	struct list_head *tmp_alone_branch;
	unsigned int nr_uninterruptible;
	struct task_struct___42 *curr;
	struct task_struct___42 *idle;
	struct task_struct___42 *stop;
	long unsigned int next_balance;
	struct mm_struct___42 *prev_mm;
	unsigned int clock_update_flags;
	u64 clock;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u64 clock_task;
	u64 clock_pelt;
	long unsigned int lost_idle_time;
	atomic_t nr_iowait;
	u64 last_seen_need_resched_ns;
	int ticks_without_resched;
	int membarrier_state;
	struct root_domain *rd;
	struct sched_domain *sd;
	long unsigned int cpu_capacity;
	long unsigned int cpu_capacity_orig;
	struct callback_head *balance_callback;
	unsigned char nohz_idle_balance;
	unsigned char idle_balance;
	long unsigned int misfit_task_load;
	int active_balance;
	int push_cpu;
	struct cpu_stop_work active_balance_work;
	int cpu;
	int online;
	struct list_head cfs_tasks;
	long: 64;
	struct sched_avg avg_rt;
	struct sched_avg avg_dl;
	u64 idle_stamp;
	u64 avg_idle;
	long unsigned int wake_stamp;
	u64 wake_avg_idle;
	u64 max_idle_balance_cost;
	struct rcuwait___39 hotplug_wait;
	u64 prev_steal_time;
	long unsigned int calc_load_update;
	long int calc_load_active;
	long: 64;
	long: 64;
	long: 64;
	call_single_data_t hrtick_csd;
	struct hrtimer hrtick_timer;
	ktime_t hrtick_time;
	struct sched_info rq_sched_info;
	long long unsigned int rq_cpu_time;
	unsigned int yld_count;
	unsigned int sched_count;
	unsigned int sched_goidle;
	unsigned int ttwu_count;
	unsigned int ttwu_local;
	struct cpuidle_state___4 *idle_state;
	unsigned int nr_pinned;
	unsigned int push_busy;
	struct cpu_stop_work push_work;
	struct rq___4 *core;
	struct task_struct___42 *core_pick;
	unsigned int core_enabled;
	unsigned int core_sched_seq;
	struct rb_root core_tree;
	unsigned int core_task_seq;
	unsigned int core_pick_seq;
	long unsigned int core_cookie;
	unsigned char core_forceidle;
	unsigned int core_forceidle_seq;
};

typedef void (*dr_release_t___4)(struct device___8 *, void *);

typedef int (*dr_match_t___3)(struct device___8 *, void *, void *);

struct dma_sgt_handle {
	struct sg_table sgt;
	struct page___40 **pages;
};

struct dma_devres {
	size_t size;
	void *vaddr;
	dma_addr_t dma_handle;
	long unsigned int attrs;
};

struct dentry___40;

struct super_block___40;

struct module___41;

struct file_system_type___40 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___40 * (*mount)(struct file_system_type___40 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___40 *);
	struct module___41 *owner;
	struct file_system_type___40 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___40;

struct kiocb___40;

struct poll_table_struct___31;

struct vm_area_struct___43;

struct inode___40;

struct file_lock___40;

struct page___42;

struct seq_file___38;

struct file_operations___40 {
	struct module___41 *owner;
	loff_t (*llseek)(struct file___40 *, loff_t, int);
	ssize_t (*read)(struct file___40 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___40 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___40 *, struct iov_iter___32 *);
	ssize_t (*write_iter)(struct kiocb___40 *, struct iov_iter___32 *);
	int (*iopoll)(struct kiocb___40 *, bool);
	int (*iterate)(struct file___40 *, struct dir_context *);
	int (*iterate_shared)(struct file___40 *, struct dir_context *);
	__poll_t (*poll)(struct file___40 *, struct poll_table_struct___31 *);
	long int (*unlocked_ioctl)(struct file___40 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___40 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___40 *, struct vm_area_struct___43 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___40 *, struct file___40 *);
	int (*flush)(struct file___40 *, fl_owner_t);
	int (*release)(struct inode___40 *, struct file___40 *);
	int (*fsync)(struct file___40 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___40 *, int);
	int (*lock)(struct file___40 *, int, struct file_lock___40 *);
	ssize_t (*sendpage)(struct file___40 *, struct page___42 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___40 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___40 *, long unsigned int);
	int (*flock)(struct file___40 *, int, struct file_lock___40 *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file___40 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___40 *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file___40 *, long int, struct file_lock___40 **, void **);
	long int (*fallocate)(struct file___40 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___38 *, struct file___40 *);
	ssize_t (*copy_file_range)(struct file___40 *, loff_t, struct file___40 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___40 *, loff_t, struct file___40 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___40 *, loff_t, loff_t, int);
};

struct static_call_mod___32 {
	struct static_call_mod___32 *next;
	struct module___41 *mod;
	struct static_call_site *sites;
};

struct static_call_key___32 {
	void *func;
	union {
		long unsigned int type;
		struct static_call_mod___32 *mods;
		struct static_call_site *sites;
	};
};

struct vmacache___42 {
	u64 seqnum;
	struct vm_area_struct___43 *vmas[4];
};

struct page_frag___42 {
	struct page___42 *page;
	__u32 offset;
	__u32 size;
};

struct perf_event___28;

struct thread_struct___29 {
	struct desc_struct tls_array[3];
	long unsigned int sp;
	short unsigned int es;
	short unsigned int ds;
	short unsigned int fsindex;
	short unsigned int gsindex;
	long unsigned int fsbase;
	long unsigned int gsbase;
	struct perf_event___28 *ptrace_bps[4];
	long unsigned int virtual_dr6;
	long unsigned int ptrace_dr7;
	long unsigned int cr2;
	long unsigned int trap_nr;
	long unsigned int error_code;
	struct io_bitmap *io_bitmap;
	long unsigned int iopl_emul;
	unsigned int iopl_warn: 1;
	unsigned int sig_on_uaccess_err: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u32 pkru;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct fpu fpu;
};

struct mm_struct___43;

struct pid___35;

struct nsproxy___39;

struct signal_struct___40;

struct css_set___34;

struct perf_event_context___28;

struct vm_struct___37;

struct task_struct___43 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___43 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___4 se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___43 *mm;
	struct mm_struct___43 *active_mm;
	struct vmacache___42 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int restore_sigmask: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___43 *real_parent;
	struct task_struct___43 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___43 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___35 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	struct posix_cputimers_work posix_cputimers_work;
	const struct cred___2 *ptracer_cred;
	const struct cred___2 *real_cred;
	const struct cred___2 *cred;
	struct key *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___39 *nsproxy;
	struct signal_struct___40 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___43 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context___27 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___34 *cgroups;
	struct list_head cg_list;
	u32 closid;
	u32 rmid;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___28 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	long: 64;
	long: 64;
	struct pipe_inode_info *splice_pipe;
	struct page_frag___42 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup *active_memcg;
	struct request_queue *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___43 *oom_reaper_list;
	struct vm_struct___37 *stack_vm_area;
	refcount_t stack_refcount;
	int patch_state;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	void *mce_vaddr;
	__u64 mce_kflags;
	u64 mce_addr;
	__u64 mce_ripv: 1;
	__u64 mce_whole_page: 1;
	__u64 __mce_reserved: 62;
	long: 2;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct callback_head mce_kill_me;
	int mce_count;
	struct llist_head kretprobe_instances;
	struct callback_head l1d_flush_kill;
	long: 64;
	struct thread_struct___29 thread;
};

typedef struct page___42 *pgtable_t___42;

struct address_space___40;

struct dev_pagemap___40;

struct page___42 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___40 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___14 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___42 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___42 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___43 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___40 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct pv_cpu_ops___34 {
	void (*io_delay)();
	long unsigned int (*get_debugreg)(int);
	void (*set_debugreg)(int, long unsigned int);
	long unsigned int (*read_cr0)();
	void (*write_cr0)(long unsigned int);
	void (*write_cr4)(long unsigned int);
	void (*load_tr_desc)();
	void (*load_gdt)(const struct desc_ptr *);
	void (*load_idt)(const struct desc_ptr *);
	void (*set_ldt)(const void *, unsigned int);
	long unsigned int (*store_tr)();
	void (*load_tls)(struct thread_struct___29 *, unsigned int);
	void (*load_gs_index)(unsigned int);
	void (*write_ldt_entry)(struct desc_struct *, int, const void *);
	void (*write_gdt_entry)(struct desc_struct *, int, const void *, int);
	void (*write_idt_entry)(gate_desc *, int, const gate_desc *);
	void (*alloc_ldt)(struct desc_struct *, unsigned int);
	void (*free_ldt)(struct desc_struct *, unsigned int);
	void (*load_sp0)(long unsigned int);
	void (*invalidate_io_bitmap)();
	void (*update_io_bitmap)();
	void (*wbinvd)();
	void (*cpuid)(unsigned int *, unsigned int *, unsigned int *, unsigned int *);
	u64 (*read_msr)(unsigned int);
	void (*write_msr)(unsigned int, unsigned int, unsigned int);
	u64 (*read_msr_safe)(unsigned int, int *);
	int (*write_msr_safe)(unsigned int, unsigned int, unsigned int);
	u64 (*read_pmc)(int);
	void (*start_context_switch)(struct task_struct___43 *);
	void (*end_context_switch)(struct task_struct___43 *);
};

struct pv_mmu_ops___36 {
	void (*flush_tlb_user)();
	void (*flush_tlb_kernel)();
	void (*flush_tlb_one_user)(long unsigned int);
	void (*flush_tlb_multi)(const struct cpumask *, const struct flush_tlb_info___3 *);
	void (*tlb_remove_table)(struct mmu_gather *, void *);
	void (*exit_mmap)(struct mm_struct___43 *);
	struct paravirt_callee_save read_cr2;
	void (*write_cr2)(long unsigned int);
	long unsigned int (*read_cr3)();
	void (*write_cr3)(long unsigned int);
	void (*activate_mm)(struct mm_struct___43 *, struct mm_struct___43 *);
	void (*dup_mmap)(struct mm_struct___43 *, struct mm_struct___43 *);
	int (*pgd_alloc)(struct mm_struct___43 *);
	void (*pgd_free)(struct mm_struct___43 *, pgd_t *);
	void (*alloc_pte)(struct mm_struct___43 *, long unsigned int);
	void (*alloc_pmd)(struct mm_struct___43 *, long unsigned int);
	void (*alloc_pud)(struct mm_struct___43 *, long unsigned int);
	void (*alloc_p4d)(struct mm_struct___43 *, long unsigned int);
	void (*release_pte)(long unsigned int);
	void (*release_pmd)(long unsigned int);
	void (*release_pud)(long unsigned int);
	void (*release_p4d)(long unsigned int);
	void (*set_pte)(pte_t *, pte_t);
	void (*set_pmd)(pmd_t *, pmd_t);
	pte_t (*ptep_modify_prot_start)(struct vm_area_struct___43 *, long unsigned int, pte_t *);
	void (*ptep_modify_prot_commit)(struct vm_area_struct___43 *, long unsigned int, pte_t *, pte_t);
	struct paravirt_callee_save pte_val;
	struct paravirt_callee_save make_pte;
	struct paravirt_callee_save pgd_val;
	struct paravirt_callee_save make_pgd;
	void (*set_pud)(pud_t *, pud_t);
	struct paravirt_callee_save pmd_val;
	struct paravirt_callee_save make_pmd;
	struct paravirt_callee_save pud_val;
	struct paravirt_callee_save make_pud;
	void (*set_p4d)(p4d_t *, p4d_t);
	struct paravirt_callee_save p4d_val;
	struct paravirt_callee_save make_p4d;
	void (*set_pgd)(pgd_t *, pgd_t);
	struct pv_lazy_ops lazy_mode;
	void (*set_fixmap)(unsigned int, phys_addr_t, pgprot_t);
};

struct core_state___42;

struct mm_struct___43 {
	struct {
		struct vm_area_struct___43 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___40 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int mmap_compat_base;
		long unsigned int mmap_compat_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[48];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___42 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___43 *owner;
		struct user_namespace___2 *user_ns;
		struct file___40 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		bool tlb_flush_batched;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct vm_operations_struct___40;

struct vm_area_struct___43 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___43 *vm_next;
	struct vm_area_struct___43 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___43 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___40 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___40 *vm_file;
	struct file___40 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct paravirt_patch_template___36 {
	struct pv_cpu_ops___34 cpu;
	struct pv_irq_ops irq;
	struct pv_mmu_ops___36 mmu;
	struct pv_lock_ops lock;
};

struct tracepoint___32 {
	const char *name;
	struct static_key key;
	struct static_call_key___32 *static_call_key;
	void *static_call_tramp;
	void *iterator;
	int (*regfunc)();
	void (*unregfunc)();
	struct tracepoint_func *funcs;
};

struct bpf_raw_event_map___32 {
	struct tracepoint___32 *tp;
	void *bpf_func;
	u32 num_args;
	u32 writable_size;
	long: 64;
};

struct seq_operations___38 {
	void * (*start)(struct seq_file___38 *, loff_t *);
	void (*stop)(struct seq_file___38 *, void *);
	void * (*next)(struct seq_file___38 *, void *, loff_t *);
	int (*show)(struct seq_file___38 *, void *);
};

struct hw_perf_event___28 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___43 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	union {
		struct {
			u64 last_period;
			local64_t period_left;
		};
		struct {
			u64 saved_metric;
			u64 saved_slots;
		};
	};
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___28)(struct perf_event___28 *, struct perf_sample_data *, struct pt_regs *);

struct pmu___28;

struct fasync_struct___40;

struct pid_namespace___35;

struct trace_event_call___28;

struct perf_cgroup___28;

struct perf_event___28 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___28 *group_leader;
	struct pmu___28 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___28 hw;
	struct perf_event_context___28 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___28 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___43 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct perf_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___40 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	long unsigned int pending_addr;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	struct perf_addr_filter_range *addr_filter_ranges;
	long unsigned int addr_filters_gen;
	struct perf_event___28 *aux_event;
	void (*destroy)(struct perf_event___28 *);
	struct callback_head callback_head;
	struct pid_namespace___35 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___28 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___28 orig_overflow_handler;
	struct bpf_prog *prog;
	u64 bpf_cookie;
	struct trace_event_call___28 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___28 *cgrp;
	void *security;
	struct list_head sb_list;
};

struct upid___35 {
	int nr;
	struct pid_namespace___35 *ns;
};

struct pid_namespace___35 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___43 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___35 *parent;
	struct fs_pin *bacct;
	struct user_namespace___2 *user_ns;
	struct ucounts___2 *ucounts;
	int reboot;
	struct ns_common___5 ns;
};

struct pid___35 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___35 numbers[1];
};

struct signal_struct___40 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___43 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___43 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper;
	unsigned int has_child_subreaper;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___35 *pids[4];
	struct pid___35 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___43 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct cgroup_namespace___34;

struct nsproxy___39 {
	atomic_t count;
	struct uts_namespace *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___35 *pid_ns_for_children;
	struct net *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___34 *cgroup_ns;
};

struct cgroup_subsys_state___34;

struct cgroup___34;

struct css_set___34 {
	struct cgroup_subsys_state___34 *subsys[14];
	refcount_t refcount;
	struct css_set___34 *dom_cset;
	struct cgroup___34 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___34 *mg_src_cgrp;
	struct cgroup___34 *mg_dst_cgrp;
	struct css_set___34 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___28 {
	struct pmu___28 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	int rotate_necessary;
	refcount_t refcount;
	struct task_struct___43 *task;
	u64 time;
	u64 timestamp;
	u64 timeoffset;
	struct perf_event_context___28 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

struct vm_struct___37 {
	struct vm_struct___37 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___42 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct address_space_operations___40;

struct address_space___40 {
	struct inode___40 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___40 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct dev_pagemap_ops___40;

struct dev_pagemap___40 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___40 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vfsmount___40;

struct path___40 {
	struct vfsmount___40 *mnt;
	struct dentry___40 *dentry;
};

struct fown_struct___35 {
	rwlock_t lock;
	struct pid___35 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___40 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	long: 64;
	long: 64;
	struct path___40 f_path;
	struct inode___40 *f_inode;
	const struct file_operations___40 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___35 f_owner;
	const struct cred___2 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___40 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___40;

struct vm_operations_struct___40 {
	void (*open)(struct vm_area_struct___43 *);
	void (*close)(struct vm_area_struct___43 *);
	int (*may_split)(struct vm_area_struct___43 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___43 *);
	int (*mprotect)(struct vm_area_struct___43 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___40 *);
	vm_fault_t (*huge_fault)(struct vm_fault___40 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___40 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___43 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___40 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___40 *);
	int (*access)(struct vm_area_struct___43 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___43 *);
	int (*set_policy)(struct vm_area_struct___43 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___43 *, long unsigned int);
	struct page___42 * (*find_special_page)(struct vm_area_struct___43 *, long unsigned int);
};

struct core_thread___42 {
	struct task_struct___43 *task;
	struct core_thread___42 *next;
};

struct core_state___42 {
	atomic_t nr_threads;
	struct core_thread___42 dumper;
	struct completion startup;
};

struct vm_fault___40 {
	const struct {
		struct vm_area_struct___43 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___42 *cow_page;
	struct page___42 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___42 prealloc_pte;
};

struct kernfs_root___41;

struct kernfs_elem_dir___41 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___41 *root;
	long unsigned int rev;
};

struct kernfs_node___41;

struct kernfs_syscall_ops___41;

struct kernfs_root___41 {
	struct kernfs_node___41 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___41 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___41 {
	struct kernfs_node___41 *target_kn;
};

struct kernfs_ops___41;

struct kernfs_elem_attr___41 {
	const struct kernfs_ops___41 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___41 *notify_next;
};

struct kernfs_node___41 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___41 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___41 dir;
		struct kernfs_elem_symlink___41 symlink;
		struct kernfs_elem_attr___41 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___41;

struct kernfs_ops___41 {
	int (*open)(struct kernfs_open_file___41 *);
	void (*release)(struct kernfs_open_file___41 *);
	int (*seq_show)(struct seq_file___38 *, void *);
	void * (*seq_start)(struct seq_file___38 *, loff_t *);
	void * (*seq_next)(struct seq_file___38 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___38 *, void *);
	ssize_t (*read)(struct kernfs_open_file___41 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___41 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___41 *, struct poll_table_struct___31 *);
	int (*mmap)(struct kernfs_open_file___41 *, struct vm_area_struct___43 *);
};

struct kernfs_syscall_ops___41 {
	int (*show_options)(struct seq_file___38 *, struct kernfs_root___41 *);
	int (*mkdir)(struct kernfs_node___41 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___41 *);
	int (*rename)(struct kernfs_node___41 *, struct kernfs_node___41 *, const char *);
	int (*show_path)(struct seq_file___38 *, struct kernfs_node___41 *, struct kernfs_root___41 *);
};

struct seq_file___38 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___38 *op;
	int poll_event;
	const struct file___40 *file;
	void *private;
};

struct kernfs_open_file___41 {
	struct kernfs_node___41 *kn;
	struct file___40 *file;
	struct seq_file___38 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped;
	bool released;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___40 *vm_ops;
};

typedef void (*poll_queue_proc___31)(struct file___40 *, wait_queue_head_t *, struct poll_table_struct___31 *);

struct poll_table_struct___31 {
	poll_queue_proc___31 _qproc;
	__poll_t _key;
};

struct kobject___41;

struct bin_attribute___41;

struct attribute_group___41 {
	const char *name;
	umode_t (*is_visible)(struct kobject___41 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___41 *, struct bin_attribute___41 *, int);
	struct attribute **attrs;
	struct bin_attribute___41 **bin_attrs;
};

struct kset___40;

struct kobj_type___40;

struct kobject___41 {
	const char *name;
	struct list_head entry;
	struct kobject___41 *parent;
	struct kset___40 *kset;
	struct kobj_type___40 *ktype;
	struct kernfs_node___41 *sd;
	struct kref kref;
	unsigned int state_initialized;
	unsigned int state_in_sysfs;
	unsigned int state_add_uevent_sent;
	unsigned int state_remove_uevent_sent;
	unsigned int uevent_suppress;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bin_attribute___41 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___40 * (*f_mapping)();
	ssize_t (*read)(struct file___40 *, struct kobject___41 *, struct bin_attribute___41 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___40 *, struct kobject___41 *, struct bin_attribute___41 *, char *, loff_t, size_t);
	int (*mmap)(struct file___40 *, struct kobject___41 *, struct bin_attribute___41 *, struct vm_area_struct___43 *);
};

struct sysfs_ops___40 {
	ssize_t (*show)(struct kobject___41 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___41 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___40;

struct kset___40 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___41 kobj;
	const struct kset_uevent_ops___40 *uevent_ops;
};

struct kobj_type___40 {
	void (*release)(struct kobject___41 *);
	const struct sysfs_ops___40 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___41 **default_groups;
	const struct kobj_ns_type_operations___3 * (*child_ns_type)(struct kobject___41 *);
	const void * (*namespace)(struct kobject___41 *);
	void (*get_ownership)(struct kobject___41 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___40 {
	int (* const filter)(struct kset___40 *, struct kobject___41 *);
	const char * (* const name)(struct kset___40 *, struct kobject___41 *);
	int (* const uevent)(struct kset___40 *, struct kobject___41 *, struct kobj_uevent_env *);
};

struct wakeup_source___44;

struct device___44;

struct dev_pm_info___44 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___44 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___44 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___44;

struct bus_type___44;

struct device_driver___44;

struct dev_pm_domain___44;

struct dma_map_ops___3;

struct io_tlb_mem___4;

struct fwnode_handle___41;

struct class___44;

struct device___44 {
	struct kobject___41 kobj;
	struct device___44 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___44 *type;
	struct bus_type___44 *bus;
	struct device_driver___44 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___44 power;
	struct dev_pm_domain___44 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops___3 *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct io_tlb_mem___4 *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node *of_node;
	struct fwnode_handle___41 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___44 *class;
	const struct attribute_group___41 **groups;
	void (*release)(struct device___44 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_ops___44 {
	int (*prepare)(struct device___44 *);
	void (*complete)(struct device___44 *);
	int (*suspend)(struct device___44 *);
	int (*resume)(struct device___44 *);
	int (*freeze)(struct device___44 *);
	int (*thaw)(struct device___44 *);
	int (*poweroff)(struct device___44 *);
	int (*restore)(struct device___44 *);
	int (*suspend_late)(struct device___44 *);
	int (*resume_early)(struct device___44 *);
	int (*freeze_late)(struct device___44 *);
	int (*thaw_early)(struct device___44 *);
	int (*poweroff_late)(struct device___44 *);
	int (*restore_early)(struct device___44 *);
	int (*suspend_noirq)(struct device___44 *);
	int (*resume_noirq)(struct device___44 *);
	int (*freeze_noirq)(struct device___44 *);
	int (*thaw_noirq)(struct device___44 *);
	int (*poweroff_noirq)(struct device___44 *);
	int (*restore_noirq)(struct device___44 *);
	int (*runtime_suspend)(struct device___44 *);
	int (*runtime_resume)(struct device___44 *);
	int (*runtime_idle)(struct device___44 *);
};

struct wakeup_source___44 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___44 *dev;
	bool active;
	bool autosleep_enabled;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___44 {
	struct dev_pm_ops___44 ops;
	int (*start)(struct device___44 *);
	void (*detach)(struct device___44 *, bool);
	int (*activate)(struct device___44 *);
	void (*sync)(struct device___44 *);
	void (*dismiss)(struct device___44 *);
};

struct bus_type___44 {
	const char *name;
	const char *dev_name;
	struct device___44 *dev_root;
	const struct attribute_group___41 **bus_groups;
	const struct attribute_group___41 **dev_groups;
	const struct attribute_group___41 **drv_groups;
	int (*match)(struct device___44 *, struct device_driver___44 *);
	int (*uevent)(struct device___44 *, struct kobj_uevent_env *);
	int (*probe)(struct device___44 *);
	void (*sync_state)(struct device___44 *);
	void (*remove)(struct device___44 *);
	void (*shutdown)(struct device___44 *);
	int (*online)(struct device___44 *);
	int (*offline)(struct device___44 *);
	int (*suspend)(struct device___44 *, pm_message_t);
	int (*resume)(struct device___44 *);
	int (*num_vf)(struct device___44 *);
	int (*dma_configure)(struct device___44 *);
	const struct dev_pm_ops___44 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___44 {
	const char *name;
	struct bus_type___44 *bus;
	struct module___41 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___44 *);
	void (*sync_state)(struct device___44 *);
	int (*remove)(struct device___44 *);
	void (*shutdown)(struct device___44 *);
	int (*suspend)(struct device___44 *, pm_message_t);
	int (*resume)(struct device___44 *);
	const struct attribute_group___41 **groups;
	const struct attribute_group___41 **dev_groups;
	const struct dev_pm_ops___44 *pm;
	void (*coredump)(struct device___44 *);
	struct driver_private *p;
};

struct device_type___44 {
	const char *name;
	const struct attribute_group___41 **groups;
	int (*uevent)(struct device___44 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___44 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___44 *);
	const struct dev_pm_ops___44 *pm;
};

struct class___44 {
	const char *name;
	struct module___41 *owner;
	const struct attribute_group___41 **class_groups;
	const struct attribute_group___41 **dev_groups;
	struct kobject___41 *dev_kobj;
	int (*dev_uevent)(struct device___44 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___44 *, umode_t *);
	void (*class_release)(struct class___44 *);
	void (*dev_release)(struct device___44 *);
	int (*shutdown_pre)(struct device___44 *);
	const struct kobj_ns_type_operations___3 *ns_type;
	const void * (*namespace)(struct device___44 *);
	void (*get_ownership)(struct device___44 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___44 *pm;
	struct subsys_private *p;
};

struct module_kobject___41 {
	struct kobject___41 kobj;
	struct module___41 *mod;
	struct kobject___41 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___41 {
	struct module___41 *mod;
	struct latch_tree_node node;
};

struct module_layout___41 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___41 mtn;
};

struct module_attribute___41;

struct kernel_param___41;

struct module___41 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___41 mkobj;
	struct module_attribute___41 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___41 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___41 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___41 core_layout;
	struct module_layout___41 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map___32 *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___28 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	int num_static_call_sites;
	struct static_call_site *static_call_sites;
	bool klp;
	bool klp_alive;
	struct klp_modinfo *klp_info;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dma_map_ops___3 {
	void * (*alloc)(struct device___44 *, size_t, dma_addr_t *, gfp_t, long unsigned int);
	void (*free)(struct device___44 *, size_t, void *, dma_addr_t, long unsigned int);
	struct page___42 * (*alloc_pages)(struct device___44 *, size_t, dma_addr_t *, enum dma_data_direction, gfp_t);
	void (*free_pages)(struct device___44 *, size_t, struct page___42 *, dma_addr_t, enum dma_data_direction);
	struct sg_table * (*alloc_noncontiguous)(struct device___44 *, size_t, enum dma_data_direction, gfp_t, long unsigned int);
	void (*free_noncontiguous)(struct device___44 *, size_t, struct sg_table *, enum dma_data_direction);
	int (*mmap)(struct device___44 *, struct vm_area_struct___43 *, void *, dma_addr_t, size_t, long unsigned int);
	int (*get_sgtable)(struct device___44 *, struct sg_table *, void *, dma_addr_t, size_t, long unsigned int);
	dma_addr_t (*map_page)(struct device___44 *, struct page___42 *, long unsigned int, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_page)(struct device___44 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	int (*map_sg)(struct device___44 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	void (*unmap_sg)(struct device___44 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	dma_addr_t (*map_resource)(struct device___44 *, phys_addr_t, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_resource)(struct device___44 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	void (*sync_single_for_cpu)(struct device___44 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___44 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___44 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___44 *, struct scatterlist *, int, enum dma_data_direction);
	void (*cache_sync)(struct device___44 *, void *, size_t, enum dma_data_direction);
	int (*dma_supported)(struct device___44 *, u64);
	u64 (*get_required_mask)(struct device___44 *);
	size_t (*max_mapping_size)(struct device___44 *);
	long unsigned int (*get_merge_boundary)(struct device___44 *);
};

struct io_tlb_mem___4 {
	phys_addr_t start;
	phys_addr_t end;
	long unsigned int nslabs;
	long unsigned int used;
	unsigned int index;
	spinlock_t lock;
	struct dentry___40 *debugfs;
	bool late_alloc;
	bool force_bounce;
	bool for_alloc;
	struct io_tlb_slot *slots;
};

struct fwnode_operations___41;

struct fwnode_handle___41 {
	struct fwnode_handle___41 *secondary;
	const struct fwnode_operations___41 *ops;
	struct device___44 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct dev_pagemap_ops___40 {
	void (*page_free)(struct page___42 *);
	void (*kill)(struct dev_pagemap___40 *);
	void (*cleanup)(struct dev_pagemap___40 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___40 *);
};

struct dentry_operations___40;

struct dentry___40 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___40 *d_parent;
	struct qstr d_name;
	struct inode___40 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___40 *d_op;
	struct super_block___40 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___40;

struct inode___40 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___40 *i_op;
	struct super_block___40 *i_sb;
	struct address_space___40 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	long: 64;
	long: 64;
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___40 *i_fop;
		void (*free_inode)(struct inode___40 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___40 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___15 *i_pipe;
		struct cdev *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___40 {
	int (*d_revalidate)(struct dentry___40 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___40 *, unsigned int);
	int (*d_hash)(const struct dentry___40 *, struct qstr *);
	int (*d_compare)(const struct dentry___40 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___40 *);
	int (*d_init)(struct dentry___40 *);
	void (*d_release)(struct dentry___40 *);
	void (*d_prune)(struct dentry___40 *);
	void (*d_iput)(struct dentry___40 *, struct inode___40 *);
	char * (*d_dname)(struct dentry___40 *, char *, int);
	struct vfsmount___40 * (*d_automount)(struct path___40 *);
	int (*d_manage)(const struct path___40 *, bool);
	struct dentry___40 * (*d_real)(struct dentry___40 *, const struct inode___40 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___40;

struct mem_dqinfo___40 {
	struct quota_format_type___40 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___40;

struct quota_info___40 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___40 *files[3];
	struct mem_dqinfo___40 info[3];
	const struct quota_format_ops___40 *ops[3];
};

struct rcuwait___40 {
	struct task_struct___43 *task;
};

struct percpu_rw_semaphore___40 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___40 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___40 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___40 rw_sem[3];
};

struct super_operations___40;

struct dquot_operations___40;

struct quotactl_ops___40;

struct super_block___40 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___40 *s_type;
	const struct super_operations___40 *s_op;
	const struct dquot_operations___40 *dq_op;
	const struct quotactl_ops___40 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___40 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device *s_bdev;
	struct backing_dev_info *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___40 s_dquot;
	struct sb_writers___40 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___40 *s_d_op;
	int cleancache_poolid;
	struct shrinker___26 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___2 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___40 {
	struct dentry___40 *mnt_root;
	struct super_block___40 *mnt_sb;
	int mnt_flags;
	struct user_namespace___2 *mnt_userns;
};

struct cgroup_subsys___34;

struct cgroup_subsys_state___34 {
	struct cgroup___34 *cgroup;
	struct cgroup_subsys___34 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___34 *parent;
};

struct cgroup_file___34 {
	struct kernfs_node___41 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct psi_group___34 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___43 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___34;

struct cgroup_rstat_cpu___34;

struct cgroup___34 {
	struct cgroup_subsys_state___34 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___41 *kn;
	struct cgroup_file___34 procs_file;
	struct cgroup_file___34 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___34 *subsys[14];
	struct cgroup_root___34 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___34 *dom_cgrp;
	struct cgroup___34 *old_dom_cgrp;
	struct cgroup_rstat_cpu___34 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___34 psi;
	struct cgroup_bpf___4 bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct kiocb___40 {
	struct file___40 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___40 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___23 *ki_waitq;
	};
};

struct iattr___40 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___40 *ia_file;
};

struct dquot___40 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___40 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___40 {
	int qf_fmt_id;
	const struct quota_format_ops___40 *qf_ops;
	struct module___41 *qf_owner;
	struct quota_format_type___40 *qf_next;
};

struct quota_format_ops___40 {
	int (*check_quota_file)(struct super_block___40 *, int);
	int (*read_file_info)(struct super_block___40 *, int);
	int (*write_file_info)(struct super_block___40 *, int);
	int (*free_file_info)(struct super_block___40 *, int);
	int (*read_dqblk)(struct dquot___40 *);
	int (*commit_dqblk)(struct dquot___40 *);
	int (*release_dqblk)(struct dquot___40 *);
	int (*get_next_id)(struct super_block___40 *, struct kqid *);
};

struct dquot_operations___40 {
	int (*write_dquot)(struct dquot___40 *);
	struct dquot___40 * (*alloc_dquot)(struct super_block___40 *, int);
	void (*destroy_dquot)(struct dquot___40 *);
	int (*acquire_dquot)(struct dquot___40 *);
	int (*release_dquot)(struct dquot___40 *);
	int (*mark_dirty)(struct dquot___40 *);
	int (*write_info)(struct super_block___40 *, int);
	qsize_t * (*get_reserved_space)(struct inode___40 *);
	int (*get_projid)(struct inode___40 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___40 *, qsize_t *);
	int (*get_next_id)(struct super_block___40 *, struct kqid *);
};

struct quotactl_ops___40 {
	int (*quota_on)(struct super_block___40 *, int, int, const struct path___40 *);
	int (*quota_off)(struct super_block___40 *, int);
	int (*quota_enable)(struct super_block___40 *, unsigned int);
	int (*quota_disable)(struct super_block___40 *, unsigned int);
	int (*quota_sync)(struct super_block___40 *, int);
	int (*set_info)(struct super_block___40 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___40 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___40 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___40 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___40 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___40 *, unsigned int);
};

struct address_space_operations___40 {
	int (*writepage)(struct page___42 *, struct writeback_control *);
	int (*readpage)(struct file___40 *, struct page___42 *);
	int (*writepages)(struct address_space___40 *, struct writeback_control *);
	int (*set_page_dirty)(struct page___42 *);
	int (*readpages)(struct file___40 *, struct address_space___40 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control *);
	int (*write_begin)(struct file___40 *, struct address_space___40 *, loff_t, unsigned int, unsigned int, struct page___42 **, void **);
	int (*write_end)(struct file___40 *, struct address_space___40 *, loff_t, unsigned int, unsigned int, struct page___42 *, void *);
	sector_t (*bmap)(struct address_space___40 *, sector_t);
	void (*invalidatepage)(struct page___42 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___42 *, gfp_t);
	void (*freepage)(struct page___42 *);
	ssize_t (*direct_IO)(struct kiocb___40 *, struct iov_iter___32 *);
	int (*migratepage)(struct address_space___40 *, struct page___42 *, struct page___42 *, enum migrate_mode);
	bool (*isolate_page)(struct page___42 *, isolate_mode_t);
	void (*putback_page)(struct page___42 *);
	int (*launder_page)(struct page___42 *);
	int (*is_partially_uptodate)(struct page___42 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___42 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___40 *, struct page___42 *);
	int (*swap_activate)(struct swap_info_struct *, struct file___40 *, sector_t *);
	void (*swap_deactivate)(struct file___40 *);
};

struct inode_operations___40 {
	struct dentry___40 * (*lookup)(struct inode___40 *, struct dentry___40 *, unsigned int);
	const char * (*get_link)(struct dentry___40 *, struct inode___40 *, struct delayed_call *);
	int (*permission)(struct user_namespace___2 *, struct inode___40 *, int);
	struct posix_acl * (*get_acl)(struct inode___40 *, int, bool);
	int (*readlink)(struct dentry___40 *, char *, int);
	int (*create)(struct user_namespace___2 *, struct inode___40 *, struct dentry___40 *, umode_t, bool);
	int (*link)(struct dentry___40 *, struct inode___40 *, struct dentry___40 *);
	int (*unlink)(struct inode___40 *, struct dentry___40 *);
	int (*symlink)(struct user_namespace___2 *, struct inode___40 *, struct dentry___40 *, const char *);
	int (*mkdir)(struct user_namespace___2 *, struct inode___40 *, struct dentry___40 *, umode_t);
	int (*rmdir)(struct inode___40 *, struct dentry___40 *);
	int (*mknod)(struct user_namespace___2 *, struct inode___40 *, struct dentry___40 *, umode_t, dev_t);
	int (*rename)(struct user_namespace___2 *, struct inode___40 *, struct dentry___40 *, struct inode___40 *, struct dentry___40 *, unsigned int);
	int (*setattr)(struct user_namespace___2 *, struct dentry___40 *, struct iattr___40 *);
	int (*getattr)(struct user_namespace___2 *, const struct path___40 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___40 *, char *, size_t);
	int (*fiemap)(struct inode___40 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___40 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___40 *, struct dentry___40 *, struct file___40 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace___2 *, struct inode___40 *, struct dentry___40 *, umode_t);
	int (*set_acl)(struct user_namespace___2 *, struct inode___40 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace___2 *, struct dentry___40 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___40 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___40 {
	void (*fl_copy_lock)(struct file_lock___40 *, struct file_lock___40 *);
	void (*fl_release_private)(struct file_lock___40 *);
};

struct lock_manager_operations___40;

struct file_lock___40 {
	struct file_lock___40 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___40 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___40 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___40 *fl_ops;
	const struct lock_manager_operations___40 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___40 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___40 *);
	int (*lm_grant)(struct file_lock___40 *, int);
	bool (*lm_break)(struct file_lock___40 *);
	int (*lm_change)(struct file_lock___40 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___40 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___40 *);
};

struct fasync_struct___40 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___40 *fa_next;
	struct file___40 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___40 {
	struct inode___40 * (*alloc_inode)(struct super_block___40 *);
	void (*destroy_inode)(struct inode___40 *);
	void (*free_inode)(struct inode___40 *);
	void (*dirty_inode)(struct inode___40 *, int);
	int (*write_inode)(struct inode___40 *, struct writeback_control *);
	int (*drop_inode)(struct inode___40 *);
	void (*evict_inode)(struct inode___40 *);
	void (*put_super)(struct super_block___40 *);
	int (*sync_fs)(struct super_block___40 *, int);
	int (*freeze_super)(struct super_block___40 *);
	int (*freeze_fs)(struct super_block___40 *);
	int (*thaw_super)(struct super_block___40 *);
	int (*unfreeze_fs)(struct super_block___40 *);
	int (*statfs)(struct dentry___40 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___40 *, int *, char *);
	void (*umount_begin)(struct super_block___40 *);
	int (*show_options)(struct seq_file___38 *, struct dentry___40 *);
	int (*show_devname)(struct seq_file___38 *, struct dentry___40 *);
	int (*show_path)(struct seq_file___38 *, struct dentry___40 *);
	int (*show_stats)(struct seq_file___38 *, struct dentry___40 *);
	ssize_t (*quota_read)(struct super_block___40 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___40 *, int, const char *, size_t, loff_t);
	struct dquot___40 ** (*get_dquots)(struct inode___40 *);
	long int (*nr_cached_objects)(struct super_block___40 *, struct shrink_control___26 *);
	long int (*free_cached_objects)(struct super_block___40 *, struct shrink_control___26 *);
	struct file___40 * (*real_loop)(struct file___40 *);
};

struct fwnode_reference_args___41;

struct fwnode_endpoint___41;

struct fwnode_operations___41 {
	struct fwnode_handle___41 * (*get)(struct fwnode_handle___41 *);
	void (*put)(struct fwnode_handle___41 *);
	bool (*device_is_available)(const struct fwnode_handle___41 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___41 *, const struct device___44 *);
	bool (*property_present)(const struct fwnode_handle___41 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___41 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___41 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___41 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___41 *);
	struct fwnode_handle___41 * (*get_parent)(const struct fwnode_handle___41 *);
	struct fwnode_handle___41 * (*get_next_child_node)(const struct fwnode_handle___41 *, struct fwnode_handle___41 *);
	struct fwnode_handle___41 * (*get_named_child_node)(const struct fwnode_handle___41 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___41 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___41 *);
	struct fwnode_handle___41 * (*graph_get_next_endpoint)(const struct fwnode_handle___41 *, struct fwnode_handle___41 *);
	struct fwnode_handle___41 * (*graph_get_remote_endpoint)(const struct fwnode_handle___41 *);
	struct fwnode_handle___41 * (*graph_get_port_parent)(struct fwnode_handle___41 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___41 *, struct fwnode_endpoint___41 *);
	int (*add_links)(struct fwnode_handle___41 *);
};

struct fwnode_endpoint___41 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___41 *local_fwnode;
};

struct fwnode_reference_args___41 {
	struct fwnode_handle___41 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct cgroup_namespace___34 {
	struct ns_common___5 ns;
	struct user_namespace___2 *user_ns;
	struct ucounts___2 *ucounts;
	struct css_set___34 *root_cset;
};

struct perf_cpu_context___28;

struct perf_output_handle___28;

struct pmu___28 {
	struct list_head entry;
	struct module___41 *module;
	struct device___44 *dev;
	const struct attribute_group___41 **attr_groups;
	const struct attribute_group___41 **attr_update;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___28 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___28 *);
	void (*pmu_disable)(struct pmu___28 *);
	int (*event_init)(struct perf_event___28 *);
	void (*event_mapped)(struct perf_event___28 *, struct mm_struct___43 *);
	void (*event_unmapped)(struct perf_event___28 *, struct mm_struct___43 *);
	int (*add)(struct perf_event___28 *, int);
	void (*del)(struct perf_event___28 *, int);
	void (*start)(struct perf_event___28 *, int);
	void (*stop)(struct perf_event___28 *, int);
	void (*read)(struct perf_event___28 *);
	void (*start_txn)(struct pmu___28 *, unsigned int);
	int (*commit_txn)(struct pmu___28 *);
	void (*cancel_txn)(struct pmu___28 *);
	int (*event_idx)(struct perf_event___28 *);
	void (*sched_task)(struct perf_event_context___28 *, bool);
	struct kmem_cache *task_ctx_cache;
	void (*swap_task_ctx)(struct perf_event_context___28 *, struct perf_event_context___28 *);
	void * (*setup_aux)(struct perf_event___28 *, void **, int, bool);
	void (*free_aux)(void *);
	long int (*snapshot_aux)(struct perf_event___28 *, struct perf_output_handle___28 *, long unsigned int);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___28 *);
	int (*aux_output_match)(struct perf_event___28 *);
	int (*filter_match)(struct perf_event___28 *);
	int (*check_period)(struct perf_event___28 *, u64);
};

struct kernel_param_ops___41 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___41 *);
	int (*get)(char *, const struct kernel_param___41 *);
	void (*free)(void *);
};

struct kparam_array___41;

struct kernel_param___41 {
	const char *name;
	struct module___41 *mod;
	const struct kernel_param_ops___41 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___41 *arr;
	};
};

struct kparam_array___41 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___41 *ops;
	void *elem;
};

struct module_attribute___41 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___41 *, struct module_kobject___41 *, char *);
	ssize_t (*store)(struct module_attribute___41 *, struct module_kobject___41 *, const char *, size_t);
	void (*setup)(struct module___41 *, const char *);
	int (*test)(struct module___41 *);
	void (*free)(struct module___41 *);
};

struct trace_event_class___28;

struct trace_event_call___28 {
	struct list_head list;
	struct trace_event_class___28 *class;
	union {
		char *name;
		struct tracepoint___32 *tp;
	};
	struct trace_event event;
	char *print_fmt;
	struct event_filter *filter;
	union {
		void *module;
		atomic_t refcnt;
	};
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
	struct bpf_prog_array___4 *prog_array;
	int (*perf_perm)(struct trace_event_call___28 *, struct perf_event___28 *);
};

struct cftype___34;

struct cgroup_subsys___34 {
	struct cgroup_subsys_state___34 * (*css_alloc)(struct cgroup_subsys_state___34 *);
	int (*css_online)(struct cgroup_subsys_state___34 *);
	void (*css_offline)(struct cgroup_subsys_state___34 *);
	void (*css_released)(struct cgroup_subsys_state___34 *);
	void (*css_free)(struct cgroup_subsys_state___34 *);
	void (*css_reset)(struct cgroup_subsys_state___34 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___34 *, int);
	int (*css_extra_stat_show)(struct seq_file___38 *, struct cgroup_subsys_state___34 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___43 *, struct css_set___34 *);
	void (*cancel_fork)(struct task_struct___43 *, struct css_set___34 *);
	void (*fork)(struct task_struct___43 *);
	void (*exit)(struct task_struct___43 *);
	void (*release)(struct task_struct___43 *);
	void (*bind)(struct cgroup_subsys_state___34 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___34 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___34 *dfl_cftypes;
	struct cftype___34 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___34 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___34 *updated_children;
	struct cgroup___34 *updated_next;
};

struct cgroup_root___34 {
	struct kernfs_root___41 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___34 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___34 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___34 *ss;
	struct list_head node;
	struct kernfs_ops___41 *kf_ops;
	int (*open)(struct kernfs_open_file___41 *);
	void (*release)(struct kernfs_open_file___41 *);
	u64 (*read_u64)(struct cgroup_subsys_state___34 *, struct cftype___34 *);
	s64 (*read_s64)(struct cgroup_subsys_state___34 *, struct cftype___34 *);
	int (*seq_show)(struct seq_file___38 *, void *);
	void * (*seq_start)(struct seq_file___38 *, loff_t *);
	void * (*seq_next)(struct seq_file___38 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___38 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___34 *, struct cftype___34 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___34 *, struct cftype___34 *, s64);
	ssize_t (*write)(struct kernfs_open_file___41 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___41 *, struct poll_table_struct___31 *);
};

struct perf_cpu_context___28 {
	struct perf_event_context___28 ctx;
	struct perf_event_context___28 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___28 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
	int heap_size;
	struct perf_event___28 **heap;
	struct perf_event___28 *heap_default[2];
};

struct perf_output_handle___28 {
	struct perf_event___28 *event;
	struct perf_buffer *rb;
	long unsigned int wakeup;
	long unsigned int size;
	u64 aux_flags;
	union {
		void *addr;
		long unsigned int head;
	};
	int page;
};

struct perf_cgroup___28 {
	struct cgroup_subsys_state___34 css;
	struct perf_cgroup_info *info;
};

struct trace_event_fields___28 {
	const char *type;
	union {
		struct {
			const char *name;
			const int size;
			const int align;
			const int is_signed;
			const int filter_type;
		};
		int (*define_fields)(struct trace_event_call___28 *);
	};
};

struct trace_event_class___28 {
	const char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct trace_event_call___28 *, enum trace_reg, void *);
	struct trace_event_fields___28 *fields_array;
	struct list_head * (*get_fields)(struct trace_event_call___28 *);
	struct list_head fields;
	int (*raw_init)(struct trace_event_call___28 *);
};

struct trace_event_file___13;

struct trace_event_buffer___13 {
	struct trace_buffer *buffer;
	struct ring_buffer_event *event;
	struct trace_event_file___13 *trace_file;
	void *entry;
	unsigned int trace_ctx;
	struct pt_regs *regs;
};

struct trace_event_file___13 {
	struct list_head list;
	struct trace_event_call___28 *event_call;
	struct event_filter *filter;
	struct dentry___40 *dir;
	struct trace_array *tr;
	struct trace_subsystem_dir *system;
	struct list_head triggers;
	long unsigned int flags;
	atomic_t sm_ref;
	atomic_t tm_ref;
};

struct trace_event_raw_swiotlb_bounced {
	struct trace_entry ent;
	u32 __data_loc_dev_name;
	u64 dma_mask;
	dma_addr_t dev_addr;
	size_t size;
	enum swiotlb_force swiotlb_force;
	char __data[0];
};

struct trace_event_data_offsets_swiotlb_bounced {
	u32 dev_name;
};

typedef void (*btf_trace_swiotlb_bounced)(void *, struct device___44 *, dma_addr_t, size_t, enum swiotlb_force);

struct gen_pool___2;

typedef long unsigned int (*genpool_algo_t___2)(long unsigned int *, long unsigned int, long unsigned int, unsigned int, void *, struct gen_pool___2 *, long unsigned int);

struct gen_pool___2 {
	spinlock_t lock;
	struct list_head chunks;
	int min_alloc_order;
	genpool_algo_t___2 algo;
	void *data;
	const char *name;
};

struct cma;

struct trace_event_raw_sys_enter {
	struct trace_entry ent;
	long int id;
	long unsigned int args[6];
	char __data[0];
};

struct trace_event_raw_sys_exit {
	struct trace_entry ent;
	long int id;
	long int ret;
	char __data[0];
};

struct trace_event_data_offsets_sys_enter {};

struct trace_event_data_offsets_sys_exit {};

typedef void (*btf_trace_sys_enter)(void *, struct pt_regs *, long int);

typedef void (*btf_trace_sys_exit)(void *, struct pt_regs *, long int);

struct preempt_notifier___2;

struct preempt_ops___2 {
	void (*sched_in)(struct preempt_notifier___2 *, int);
	void (*sched_out)(struct preempt_notifier___2 *, struct task_struct___8 *);
};

struct preempt_notifier___2 {
	struct hlist_node link;
	struct preempt_ops___2 *ops;
};

struct kvm_regs {
	__u64 rax;
	__u64 rbx;
	__u64 rcx;
	__u64 rdx;
	__u64 rsi;
	__u64 rdi;
	__u64 rsp;
	__u64 rbp;
	__u64 r8;
	__u64 r9;
	__u64 r10;
	__u64 r11;
	__u64 r12;
	__u64 r13;
	__u64 r14;
	__u64 r15;
	__u64 rip;
	__u64 rflags;
};

struct kvm_segment {
	__u64 base;
	__u32 limit;
	__u16 selector;
	__u8 type;
	__u8 present;
	__u8 dpl;
	__u8 db;
	__u8 s;
	__u8 l;
	__u8 g;
	__u8 avl;
	__u8 unusable;
	__u8 padding;
};

struct kvm_dtable {
	__u64 base;
	__u16 limit;
	__u16 padding[3];
};

struct kvm_sregs {
	struct kvm_segment cs;
	struct kvm_segment ds;
	struct kvm_segment es;
	struct kvm_segment fs;
	struct kvm_segment gs;
	struct kvm_segment ss;
	struct kvm_segment tr;
	struct kvm_segment ldt;
	struct kvm_dtable gdt;
	struct kvm_dtable idt;
	__u64 cr0;
	__u64 cr2;
	__u64 cr3;
	__u64 cr4;
	__u64 cr8;
	__u64 efer;
	__u64 apic_base;
	__u64 interrupt_bitmap[4];
};

struct kvm_msr_entry {
	__u32 index;
	__u32 reserved;
	__u64 data;
};

struct kvm_cpuid_entry2 {
	__u32 function;
	__u32 index;
	__u32 flags;
	__u32 eax;
	__u32 ebx;
	__u32 ecx;
	__u32 edx;
	__u32 padding[3];
};

struct kvm_debug_exit_arch {
	__u32 exception;
	__u32 pad;
	__u64 pc;
	__u64 dr6;
	__u64 dr7;
};

struct kvm_vcpu_events {
	struct {
		__u8 injected;
		__u8 nr;
		__u8 has_error_code;
		__u8 pending;
		__u32 error_code;
	} exception;
	struct {
		__u8 injected;
		__u8 nr;
		__u8 soft;
		__u8 shadow;
	} interrupt;
	struct {
		__u8 injected;
		__u8 pending;
		__u8 masked;
		__u8 pad;
	} nmi;
	__u32 sipi_vector;
	__u32 flags;
	struct {
		__u8 smm;
		__u8 pending;
		__u8 smm_inside_nmi;
		__u8 latched_init;
	} smi;
	__u8 reserved[27];
	__u8 exception_has_payload;
	__u64 exception_payload;
};

struct kvm_sync_regs {
	struct kvm_regs regs;
	struct kvm_sregs sregs;
	struct kvm_vcpu_events events;
};

struct kvm_vmx_nested_state_data {
	__u8 vmcs12[4096];
	__u8 shadow_vmcs12[4096];
};

struct kvm_vmx_nested_state_hdr {
	__u64 vmxon_pa;
	__u64 vmcs12_pa;
	struct {
		__u16 flags;
	} smm;
	__u16 pad;
	__u32 flags;
	__u64 preemption_timer_deadline;
};

struct kvm_svm_nested_state_data {
	__u8 vmcb12[4096];
};

struct kvm_svm_nested_state_hdr {
	__u64 vmcb_pa;
};

struct kvm_nested_state {
	__u16 flags;
	__u16 format;
	__u32 size;
	union {
		struct kvm_vmx_nested_state_hdr vmx;
		struct kvm_svm_nested_state_hdr svm;
		__u8 pad[120];
	} hdr;
	union {
		struct kvm_vmx_nested_state_data vmx[0];
		struct kvm_svm_nested_state_data svm[0];
	} data;
};

struct kvm_pmu_event_filter {
	__u32 action;
	__u32 nevents;
	__u32 fixed_counter_bitmap;
	__u32 flags;
	__u32 pad[4];
	__u64 events[0];
};

struct kvm_hyperv_exit {
	__u32 type;
	__u32 pad1;
	union {
		struct {
			__u32 msr;
			__u32 pad2;
			__u64 control;
			__u64 evt_page;
			__u64 msg_page;
		} synic;
		struct {
			__u64 input;
			__u64 result;
			__u64 params[2];
		} hcall;
		struct {
			__u32 msr;
			__u32 pad2;
			__u64 control;
			__u64 status;
			__u64 send_page;
			__u64 recv_page;
			__u64 pending_page;
		} syndbg;
	} u;
};

struct kvm_xen_exit {
	__u32 type;
	union {
		struct {
			__u32 longmode;
			__u32 cpl;
			__u64 input;
			__u64 result;
			__u64 params[6];
		} hcall;
	} u;
};

struct kvm_run {
	__u8 request_interrupt_window;
	__u8 immediate_exit;
	__u8 padding1[6];
	__u32 exit_reason;
	__u8 ready_for_interrupt_injection;
	__u8 if_flag;
	__u16 flags;
	__u64 cr8;
	__u64 apic_base;
	union {
		struct {
			__u64 hardware_exit_reason;
		} hw;
		struct {
			__u64 hardware_entry_failure_reason;
			__u32 cpu;
		} fail_entry;
		struct {
			__u32 exception;
			__u32 error_code;
		} ex;
		struct {
			__u8 direction;
			__u8 size;
			__u16 port;
			__u32 count;
			__u64 data_offset;
		} io;
		struct {
			struct kvm_debug_exit_arch arch;
		} debug;
		struct {
			__u64 phys_addr;
			__u8 data[8];
			__u32 len;
			__u8 is_write;
		} mmio;
		struct {
			__u64 nr;
			__u64 args[6];
			__u64 ret;
			__u32 longmode;
			__u32 pad;
		} hypercall;
		struct {
			__u64 rip;
			__u32 is_write;
			__u32 pad;
		} tpr_access;
		struct {
			__u8 icptcode;
			__u16 ipa;
			__u32 ipb;
		} s390_sieic;
		__u64 s390_reset_flags;
		struct {
			__u64 trans_exc_code;
			__u32 pgm_code;
		} s390_ucontrol;
		struct {
			__u32 dcrn;
			__u32 data;
			__u8 is_write;
		} dcr;
		struct {
			__u32 suberror;
			__u32 ndata;
			__u64 data[16];
		} internal;
		struct {
			__u32 suberror;
			__u32 ndata;
			__u64 flags;
			__u8 insn_size;
			__u8 insn_bytes[15];
		} emulation_failure;
		struct {
			__u64 gprs[32];
		} osi;
		struct {
			__u64 nr;
			__u64 ret;
			__u64 args[9];
		} papr_hcall;
		struct {
			__u16 subchannel_id;
			__u16 subchannel_nr;
			__u32 io_int_parm;
			__u32 io_int_word;
			__u32 ipb;
			__u8 dequeued;
		} s390_tsch;
		struct {
			__u32 epr;
		} epr;
		struct {
			__u32 type;
			__u64 flags;
		} system_event;
		struct {
			__u64 addr;
			__u8 ar;
			__u8 reserved;
			__u8 fc;
			__u8 sel1;
			__u16 sel2;
		} s390_stsi;
		struct {
			__u8 vector;
		} eoi;
		struct kvm_hyperv_exit hyperv;
		struct {
			__u64 esr_iss;
			__u64 fault_ipa;
		} arm_nisv;
		struct {
			__u8 error;
			__u8 pad[7];
			__u32 reason;
			__u32 index;
			__u64 data;
		} msr;
		struct kvm_xen_exit xen;
		char padding[256];
	};
	__u64 kvm_valid_regs;
	__u64 kvm_dirty_regs;
	union {
		struct kvm_sync_regs regs;
		char padding[2048];
	} s;
};

struct kvm_coalesced_mmio {
	__u64 phys_addr;
	__u32 len;
	union {
		__u32 pad;
		__u32 pio;
	};
	__u8 data[8];
};

struct kvm_coalesced_mmio_ring {
	__u32 first;
	__u32 last;
	struct kvm_coalesced_mmio coalesced_mmio[0];
};

struct kvm_xen_hvm_config {
	__u32 flags;
	__u32 msr;
	__u64 blob_addr_32;
	__u64 blob_addr_64;
	__u8 blob_size_32;
	__u8 blob_size_64;
	__u8 pad2[30];
};

struct kvm_enc_region {
	__u64 addr;
	__u64 size;
};

struct kvm_dirty_gfn {
	__u32 flags;
	__u32 slot;
	__u64 offset;
};

struct kvm_stats_desc {
	__u32 flags;
	__s16 exponent;
	__u16 size;
	__u32 offset;
	__u32 bucket_size;
	char name[0];
};

typedef long unsigned int gva_t;

typedef u64 gpa_t;

typedef u64 gfn_t;

typedef u64 hpa_t;

struct kvm_memory_slot;

struct gfn_to_hva_cache {
	u64 generation;
	gpa_t gpa;
	long unsigned int hva;
	long unsigned int len;
	struct kvm_memory_slot *memslot;
};

struct kvm_rmap_head;

struct kvm_lpage_info;

struct kvm_arch_memory_slot {
	struct kvm_rmap_head *rmap[3];
	struct kvm_lpage_info *lpage_info[2];
	short unsigned int *gfn_track[1];
};

struct kvm_memory_slot {
	gfn_t base_gfn;
	long unsigned int npages;
	long unsigned int *dirty_bitmap;
	struct kvm_arch_memory_slot arch;
	long unsigned int userspace_addr;
	u32 flags;
	short int id;
	u16 as_id;
};

struct kvm_mmu_memory_cache {
	int nobjs;
	gfp_t gfp_zero;
	struct kmem_cache *kmem_cache;
	void *objects[40];
};

struct kvm_vm_stat_generic {
	u64 remote_tlb_flush;
	u64 remote_tlb_flush_requests;
};

struct kvm_vcpu_stat_generic {
	u64 halt_successful_poll;
	u64 halt_attempted_poll;
	u64 halt_poll_invalid;
	u64 halt_wakeup;
	u64 halt_poll_success_ns;
	u64 halt_poll_fail_ns;
	u64 halt_wait_ns;
	u64 halt_poll_success_hist[32];
	u64 halt_poll_fail_hist[32];
	u64 halt_wait_hist[32];
};

struct hv_partition_assist_pg {
	u32 tlb_lock_count;
};

union hv_message_flags {
	__u8 asu8;
	struct {
		__u8 msg_pending: 1;
		__u8 reserved: 7;
	};
};

union hv_port_id {
	__u32 asu32;
	struct {
		__u32 id: 24;
		__u32 reserved: 8;
	} u;
};

struct hv_message_header {
	__u32 message_type;
	__u8 payload_size;
	union hv_message_flags message_flags;
	__u8 reserved[2];
	union {
		__u64 sender;
		union hv_port_id port;
	};
};

struct hv_message {
	struct hv_message_header header;
	union {
		__u64 payload[30];
	} u;
};

union hv_stimer_config {
	u64 as_uint64;
	struct {
		u64 enable: 1;
		u64 periodic: 1;
		u64 lazy: 1;
		u64 auto_enable: 1;
		u64 apic_vector: 8;
		u64 direct_mode: 1;
		u64 reserved_z0: 3;
		u64 sintx: 4;
		u64 reserved_z1: 44;
	};
};

enum kvm_page_track_mode {
	KVM_PAGE_TRACK_WRITE = 0,
	KVM_PAGE_TRACK_MAX = 1,
};

struct kvm_page_track_notifier_head {
	struct srcu_struct track_srcu;
	struct hlist_head track_notifier_list;
};

struct kvm_vcpu;

struct kvm;

struct kvm_page_track_notifier_node {
	struct hlist_node node;
	void (*track_write)(struct kvm_vcpu *, gpa_t, const u8 *, int, struct kvm_page_track_notifier_node *);
	void (*track_flush_slot)(struct kvm *, struct kvm_memory_slot *, struct kvm_page_track_notifier_node *);
};

struct kvm_mmio_fragment {
	gpa_t gpa;
	void *data;
	unsigned int len;
};

struct kvm_lapic;

struct x86_exception;

struct kvm_mmu_page;

union kvm_mmu_page_role {
	u32 word;
	struct {
		unsigned int level: 4;
		unsigned int gpte_is_8_bytes: 1;
		unsigned int quadrant: 2;
		unsigned int direct: 1;
		unsigned int access: 3;
		unsigned int invalid: 1;
		unsigned int efer_nx: 1;
		unsigned int cr0_wp: 1;
		unsigned int smep_andnot_wp: 1;
		unsigned int smap_andnot_wp: 1;
		unsigned int ad_disabled: 1;
		unsigned int guest_mode: 1;
		unsigned int smm: 8;
	};
};

union kvm_mmu_extended_role {
	u32 word;
	struct {
		unsigned int valid: 1;
		unsigned int execonly: 1;
		unsigned int cr0_pg: 1;
		unsigned int cr4_pae: 1;
		unsigned int cr4_pse: 1;
		unsigned int cr4_pke: 1;
		unsigned int cr4_smap: 1;
		unsigned int cr4_smep: 1;
		unsigned int cr4_la57: 1;
		unsigned int efer_lma: 1;
	};
};

union kvm_mmu_role {
	u64 as_u64;
	struct {
		union kvm_mmu_page_role base;
		union kvm_mmu_extended_role ext;
	};
};

struct kvm_mmu_root_info {
	gpa_t pgd;
	hpa_t hpa;
};

struct rsvd_bits_validate {
	u64 rsvd_bits_mask[10];
	u64 bad_mt_xwr;
};

struct kvm_mmu {
	long unsigned int (*get_guest_pgd)(struct kvm_vcpu *);
	u64 (*get_pdptr)(struct kvm_vcpu *, int);
	int (*page_fault)(struct kvm_vcpu *, gpa_t, u32, bool);
	void (*inject_page_fault)(struct kvm_vcpu *, struct x86_exception *);
	gpa_t (*gva_to_gpa)(struct kvm_vcpu *, gpa_t, u32, struct x86_exception *);
	gpa_t (*translate_gpa)(struct kvm_vcpu *, gpa_t, u32, struct x86_exception *);
	int (*sync_page)(struct kvm_vcpu *, struct kvm_mmu_page *);
	void (*invlpg)(struct kvm_vcpu *, gva_t, hpa_t);
	hpa_t root_hpa;
	gpa_t root_pgd;
	union kvm_mmu_role mmu_role;
	u8 root_level;
	u8 shadow_root_level;
	u8 ept_ad;
	bool direct_map;
	struct kvm_mmu_root_info prev_roots[3];
	u8 permissions[16];
	u32 pkru_mask;
	u64 *pae_root;
	u64 *pml4_root;
	u64 *pml5_root;
	struct rsvd_bits_validate shadow_zero_check;
	struct rsvd_bits_validate guest_rsvd_check;
	u64 pdptrs[4];
};

struct kvm_pio_request {
	long unsigned int linear_rip;
	long unsigned int count;
	int in;
	int port;
	int size;
};

struct kvm_queued_exception {
	bool pending;
	bool injected;
	bool has_error_code;
	u8 nr;
	u32 error_code;
	long unsigned int payload;
	bool has_payload;
	u8 nested_apf;
};

struct kvm_queued_interrupt {
	bool injected;
	bool soft;
	u8 nr;
};

struct x86_emulate_ctxt;

struct kvm_mtrr_range {
	u64 base;
	u64 mask;
	struct list_head node;
};

struct kvm_mtrr {
	struct kvm_mtrr_range var_ranges[8];
	mtrr_type fixed_ranges[88];
	u64 deftype;
	struct list_head head;
};

enum pmc_type {
	KVM_PMC_GP = 0,
	KVM_PMC_FIXED = 1,
};

struct kvm_pmc {
	enum pmc_type type;
	u8 idx;
	u64 counter;
	u64 eventsel;
	struct perf_event___4 *perf_event;
	struct kvm_vcpu *vcpu;
	u64 current_config;
	bool is_paused;
};

struct kvm_pmu {
	unsigned int nr_arch_gp_counters;
	unsigned int nr_arch_fixed_counters;
	unsigned int available_event_types;
	u64 fixed_ctr_ctrl;
	u64 global_ctrl;
	u64 global_status;
	u64 global_ovf_ctrl;
	u64 counter_bitmask[2];
	u64 global_ctrl_mask;
	u64 global_ovf_ctrl_mask;
	u64 reserved_bits;
	u8 version;
	struct kvm_pmc gp_counters[32];
	struct kvm_pmc fixed_counters[4];
	struct irq_work irq_work;
	long unsigned int reprogram_pmi[1];
	long unsigned int all_valid_pmc_idx[1];
	long unsigned int pmc_in_use[1];
	bool need_cleanup;
	u8 event_count;
};

struct kvm_vcpu_xen {
	u64 hypercall_rip;
	u32 current_runstate;
	bool vcpu_info_set;
	bool vcpu_time_info_set;
	bool runstate_set;
	struct gfn_to_hva_cache vcpu_info_cache;
	struct gfn_to_hva_cache vcpu_time_info_cache;
	struct gfn_to_hva_cache runstate_cache;
	u64 last_steal;
	u64 runstate_entry_time;
	u64 runstate_times[4];
};

struct kvm_vcpu_hv;

struct kvm_vcpu_arch {
	long unsigned int regs[17];
	u32 regs_avail;
	u32 regs_dirty;
	long unsigned int cr0;
	long unsigned int cr0_guest_owned_bits;
	long unsigned int cr2;
	long unsigned int cr3;
	long unsigned int cr4;
	long unsigned int cr4_guest_owned_bits;
	long unsigned int cr4_guest_rsvd_bits;
	long unsigned int cr8;
	u32 host_pkru;
	u32 pkru;
	u32 hflags;
	u64 efer;
	u64 apic_base;
	struct kvm_lapic *apic;
	bool apicv_active;
	bool load_eoi_exitmap_pending;
	long unsigned int ioapic_handled_vectors[4];
	long unsigned int apic_attention;
	int32_t apic_arb_prio;
	int mp_state;
	u64 ia32_misc_enable_msr;
	u64 smbase;
	u64 smi_count;
	bool tpr_access_reporting;
	bool xsaves_enabled;
	u64 ia32_xss;
	u64 microcode_version;
	u64 arch_capabilities;
	u64 perf_capabilities;
	struct kvm_mmu *mmu;
	struct kvm_mmu root_mmu;
	struct kvm_mmu guest_mmu;
	struct kvm_mmu nested_mmu;
	struct kvm_mmu *walk_mmu;
	struct kvm_mmu_memory_cache mmu_pte_list_desc_cache;
	struct kvm_mmu_memory_cache mmu_shadow_page_cache;
	struct kvm_mmu_memory_cache mmu_gfn_array_cache;
	struct kvm_mmu_memory_cache mmu_page_header_cache;
	struct fpu_guest guest_fpu;
	u64 xcr0;
	u64 guest_supported_xcr0;
	struct kvm_pio_request pio;
	void *pio_data;
	void *sev_pio_data;
	unsigned int sev_pio_count;
	u8 event_exit_inst_len;
	struct kvm_queued_exception exception;
	struct kvm_queued_interrupt interrupt;
	int halt_request;
	int cpuid_nent;
	struct kvm_cpuid_entry2 *cpuid_entries;
	u64 reserved_gpa_bits;
	int maxphyaddr;
	struct x86_emulate_ctxt *emulate_ctxt;
	bool emulate_regs_need_sync_to_vcpu;
	bool emulate_regs_need_sync_from_vcpu;
	int (*complete_userspace_io)(struct kvm_vcpu *);
	gpa_t time;
	struct pvclock_vcpu_time_info hv_clock;
	unsigned int hw_tsc_khz;
	struct gfn_to_hva_cache pv_time;
	bool pv_time_enabled;
	bool pvclock_set_guest_stopped_request;
	struct {
		u8 preempted;
		u64 msr_val;
		u64 last_steal;
		struct gfn_to_hva_cache cache;
	} st;
	u64 l1_tsc_offset;
	u64 tsc_offset;
	u64 last_guest_tsc;
	u64 last_host_tsc;
	u64 tsc_offset_adjustment;
	u64 this_tsc_nsec;
	u64 this_tsc_write;
	u64 this_tsc_generation;
	bool tsc_catchup;
	bool tsc_always_catchup;
	s8 virtual_tsc_shift;
	u32 virtual_tsc_mult;
	u32 virtual_tsc_khz;
	s64 ia32_tsc_adjust_msr;
	u64 msr_ia32_power_ctl;
	u64 l1_tsc_scaling_ratio;
	u64 tsc_scaling_ratio;
	atomic_t nmi_queued;
	unsigned int nmi_pending;
	bool nmi_injected;
	bool smi_pending;
	struct kvm_mtrr mtrr_state;
	u64 pat;
	unsigned int switch_db_regs;
	long unsigned int db[4];
	long unsigned int dr6;
	long unsigned int dr7;
	long unsigned int eff_db[4];
	long unsigned int guest_debug_dr7;
	u64 msr_platform_info;
	u64 msr_misc_features_enables;
	u64 mcg_cap;
	u64 mcg_status;
	u64 mcg_ctl;
	u64 mcg_ext_ctl;
	u64 *mce_banks;
	u64 mmio_gva;
	unsigned int mmio_access;
	gfn_t mmio_gfn;
	u64 mmio_gen;
	struct kvm_pmu pmu;
	long unsigned int singlestep_rip;
	bool hyperv_enabled;
	struct kvm_vcpu_hv *hyperv;
	struct kvm_vcpu_xen xen;
	cpumask_var_t wbinvd_dirty_mask;
	long unsigned int last_retry_eip;
	long unsigned int last_retry_addr;
	struct {
		bool halted;
		gfn_t gfns[64];
		struct gfn_to_hva_cache data;
		u64 msr_en_val;
		u64 msr_int_val;
		u16 vec;
		u32 id;
		bool send_user_only;
		u32 host_apf_flags;
		long unsigned int nested_apf_token;
		bool delivery_as_pf_vmexit;
		bool pageready_pending;
	} apf;
	struct {
		u64 length;
		u64 status;
	} osvw;
	struct {
		u64 msr_val;
		struct gfn_to_hva_cache data;
	} pv_eoi;
	u64 msr_kvm_poll_control;
	bool write_fault_to_shadow_pgtable;
	long unsigned int exit_qualification;
	struct {
		bool pv_unhalted;
	} pv;
	int pending_ioapic_eoi;
	int pending_external_vector;
	bool preempted_in_kernel;
	bool l1tf_flush_l1d;
	int last_vmentry_cpu;
	u64 msr_hwcr;
	struct {
		u32 features;
		bool enforce;
	} pv_cpuid;
	bool guest_state_protected;
	bool pdptrs_from_userspace;
	hpa_t hv_root_tdp;
};

struct kvm_vcpu_stat {
	struct kvm_vcpu_stat_generic generic;
	u64 pf_fixed;
	u64 pf_guest;
	u64 tlb_flush;
	u64 invlpg;
	u64 exits;
	u64 io_exits;
	u64 mmio_exits;
	u64 signal_exits;
	u64 irq_window_exits;
	u64 nmi_window_exits;
	u64 l1d_flush;
	u64 halt_exits;
	u64 request_irq_exits;
	u64 irq_exits;
	u64 host_state_reload;
	u64 fpu_reload;
	u64 insn_emulation;
	u64 insn_emulation_fail;
	u64 hypercalls;
	u64 irq_injections;
	u64 nmi_injections;
	u64 req_event;
	u64 nested_run;
	u64 directed_yield_attempted;
	u64 directed_yield_successful;
	u64 guest_mode;
};

struct kvm_dirty_ring {
	u32 dirty_index;
	u32 reset_index;
	u32 size;
	u32 soft_limit;
	struct kvm_dirty_gfn *dirty_gfns;
	int index;
};

struct kvm_vcpu {
	struct kvm *kvm;
	struct preempt_notifier___2 preempt_notifier;
	int cpu;
	int vcpu_id;
	int vcpu_idx;
	int srcu_idx;
	int mode;
	u64 requests;
	long unsigned int guest_debug;
	int pre_pcpu;
	struct list_head blocked_vcpu_list;
	struct mutex mutex;
	struct kvm_run *run;
	struct rcuwait___6 wait;
	struct pid___5 *pid;
	int sigset_active;
	sigset_t sigset;
	unsigned int halt_poll_ns;
	bool valid_wakeup;
	int mmio_needed;
	int mmio_read_completed;
	int mmio_is_write;
	int mmio_cur_fragment;
	int mmio_nr_fragments;
	struct kvm_mmio_fragment mmio_fragments[2];
	struct {
		u32 queued;
		struct list_head queue;
		struct list_head done;
		spinlock_t lock;
	} async_pf;
	struct {
		bool in_spin_loop;
		bool dy_eligible;
	} spin_loop;
	bool preempted;
	bool ready;
	struct kvm_vcpu_arch arch;
	struct kvm_vcpu_stat stat;
	char stats_id[48];
	struct kvm_dirty_ring dirty_ring;
	int last_used_slot;
};

struct kvm_vm_stat {
	struct kvm_vm_stat_generic generic;
	u64 mmu_shadow_zapped;
	u64 mmu_pte_write;
	u64 mmu_pde_zapped;
	u64 mmu_flooded;
	u64 mmu_recycled;
	u64 mmu_cache_miss;
	u64 mmu_unsync;
	union {
		struct {
			atomic64_t pages_4k;
			atomic64_t pages_2m;
			atomic64_t pages_1g;
		};
		atomic64_t pages[3];
	};
	u64 nx_lpage_splits;
	u64 max_mmu_page_hash_collisions;
	u64 max_mmu_rmap_size;
};

struct iommu_domain___3;

struct kvm_pic;

struct kvm_ioapic;

struct kvm_pit;

enum hv_tsc_page_status {
	HV_TSC_PAGE_UNSET = 0,
	HV_TSC_PAGE_GUEST_CHANGED = 1,
	HV_TSC_PAGE_HOST_CHANGED = 2,
	HV_TSC_PAGE_SET = 3,
	HV_TSC_PAGE_UPDATING = 4,
	HV_TSC_PAGE_BROKEN = 5,
};

struct kvm_hv_syndbg {
	struct {
		u64 control;
		u64 status;
		u64 send_page;
		u64 recv_page;
		u64 pending_page;
	} control;
	u64 options;
};

struct kvm_hv {
	struct mutex hv_lock;
	u64 hv_guest_os_id;
	u64 hv_hypercall;
	u64 hv_tsc_page;
	enum hv_tsc_page_status hv_tsc_page_status;
	u64 hv_crash_param[5];
	u64 hv_crash_ctl;
	struct ms_hyperv_tsc_page tsc_ref;
	struct idr conn_to_evt;
	u64 hv_reenlightenment_control;
	u64 hv_tsc_emulation_control;
	u64 hv_tsc_emulation_status;
	atomic_t num_mismatched_vp_indexes;
	unsigned int synic_auto_eoi_used;
	struct hv_partition_assist_pg *hv_pa_pg;
	struct kvm_hv_syndbg hv_syndbg;
};

struct kvm_xen {
	bool long_mode;
	u8 upcall_vector;
	gfn_t shinfo_gfn;
};

enum kvm_irqchip_mode {
	KVM_IRQCHIP_NONE = 0,
	KVM_IRQCHIP_KERNEL = 1,
	KVM_IRQCHIP_SPLIT = 2,
};

struct kvm_apic_map;

struct kvm_x86_msr_filter;

struct kvm_arch {
	long unsigned int n_used_mmu_pages;
	long unsigned int n_requested_mmu_pages;
	long unsigned int n_max_mmu_pages;
	unsigned int indirect_shadow_pages;
	u8 mmu_valid_gen;
	struct hlist_head mmu_page_hash[4096];
	struct list_head active_mmu_pages;
	struct list_head zapped_obsolete_pages;
	struct list_head lpage_disallowed_mmu_pages;
	struct kvm_page_track_notifier_node mmu_sp_tracker;
	struct kvm_page_track_notifier_head track_notifier_head;
	spinlock_t mmu_unsync_pages_lock;
	struct list_head assigned_dev_head;
	struct iommu_domain___3 *iommu_domain;
	bool iommu_noncoherent;
	atomic_t noncoherent_dma_count;
	atomic_t assigned_device_count;
	struct kvm_pic *vpic;
	struct kvm_ioapic *vioapic;
	struct kvm_pit *vpit;
	atomic_t vapics_in_nmi_mode;
	struct mutex apic_map_lock;
	struct kvm_apic_map *apic_map;
	atomic_t apic_map_dirty;
	struct mutex apicv_update_lock;
	bool apic_access_memslot_enabled;
	long unsigned int apicv_inhibit_reasons;
	gpa_t wall_clock;
	bool mwait_in_guest;
	bool hlt_in_guest;
	bool pause_in_guest;
	bool cstate_in_guest;
	long unsigned int irq_sources_bitmap;
	s64 kvmclock_offset;
	raw_spinlock_t tsc_write_lock;
	u64 last_tsc_nsec;
	u64 last_tsc_write;
	u32 last_tsc_khz;
	u64 cur_tsc_nsec;
	u64 cur_tsc_write;
	u64 cur_tsc_offset;
	u64 cur_tsc_generation;
	int nr_vcpus_matched_tsc;
	raw_spinlock_t pvclock_gtod_sync_lock;
	bool use_master_clock;
	u64 master_kernel_ns;
	u64 master_cycle_now;
	struct delayed_work kvmclock_update_work;
	struct delayed_work kvmclock_sync_work;
	struct kvm_xen_hvm_config xen_hvm_config;
	struct hlist_head mask_notifier_list;
	struct kvm_hv hyperv;
	struct kvm_xen xen;
	bool backwards_tsc_observed;
	bool boot_vcpu_runs_old_kvmclock;
	u32 bsp_vcpu_id;
	u64 disabled_quirks;
	int cpu_dirty_logging_count;
	enum kvm_irqchip_mode irqchip_mode;
	u8 nr_reserved_ioapic_pins;
	bool disabled_lapic_found;
	bool x2apic_format;
	bool x2apic_broadcast_quirk_disabled;
	bool guest_can_read_msr_platform_info;
	bool exception_payload_enabled;
	bool bus_lock_detection_enabled;
	bool exit_on_emulation_error;
	u32 user_space_msr_mask;
	struct kvm_x86_msr_filter *msr_filter;
	u32 hypercall_exit_enabled;
	bool sgx_provisioning_allowed;
	struct kvm_pmu_event_filter *pmu_event_filter;
	struct task_struct___8 *nx_lpage_recovery_thread;
	bool tdp_mmu_enabled;
	struct list_head tdp_mmu_roots;
	struct list_head tdp_mmu_pages;
	spinlock_t tdp_mmu_pages_lock;
	bool memslots_have_rmaps;
	hpa_t hv_root_tdp;
	spinlock_t hv_root_tdp_lock;
};

struct kvm_memslots;

struct kvm_io_bus;

struct kvm_irq_routing_table;

struct kvm_stat_data;

struct kvm {
	rwlock_t mmu_lock;
	struct mutex slots_lock;
	struct mutex slots_arch_lock;
	struct mm_struct___8 *mm;
	struct kvm_memslots *memslots[2];
	struct kvm_vcpu *vcpus[1024];
	spinlock_t mn_invalidate_lock;
	long unsigned int mn_active_invalidate_count;
	struct rcuwait___6 mn_memslots_update_rcuwait;
	atomic_t online_vcpus;
	int created_vcpus;
	int last_boosted_vcpu;
	struct list_head vm_list;
	struct mutex lock;
	struct kvm_io_bus *buses[4];
	struct {
		spinlock_t lock;
		struct list_head items;
		struct list_head resampler_list;
		struct mutex resampler_lock;
	} irqfds;
	struct list_head ioeventfds;
	struct kvm_vm_stat stat;
	struct kvm_arch arch;
	refcount_t users_count;
	struct kvm_coalesced_mmio_ring *coalesced_mmio_ring;
	spinlock_t ring_lock;
	struct list_head coalesced_zones;
	struct mutex irq_lock;
	struct kvm_irq_routing_table *irq_routing;
	struct hlist_head irq_ack_notifier_list;
	struct mmu_notifier mmu_notifier;
	long unsigned int mmu_notifier_seq;
	long int mmu_notifier_count;
	long unsigned int mmu_notifier_range_start;
	long unsigned int mmu_notifier_range_end;
	struct list_head devices;
	u64 manual_dirty_log_protect;
	struct dentry___6 *debugfs_dentry;
	struct kvm_stat_data **debugfs_stat_data;
	struct srcu_struct srcu;
	struct srcu_struct irq_srcu;
	pid_t userspace_pid;
	unsigned int max_halt_poll_ns;
	u32 dirty_ring_size;
	bool vm_bugged;
	struct notifier_block pm_notifier;
	char stats_id[48];
};

enum kvm_reg {
	VCPU_REGS_RAX = 0,
	VCPU_REGS_RCX = 1,
	VCPU_REGS_RDX = 2,
	VCPU_REGS_RBX = 3,
	VCPU_REGS_RSP = 4,
	VCPU_REGS_RBP = 5,
	VCPU_REGS_RSI = 6,
	VCPU_REGS_RDI = 7,
	VCPU_REGS_R8 = 8,
	VCPU_REGS_R9 = 9,
	VCPU_REGS_R10 = 10,
	VCPU_REGS_R11 = 11,
	VCPU_REGS_R12 = 12,
	VCPU_REGS_R13 = 13,
	VCPU_REGS_R14 = 14,
	VCPU_REGS_R15 = 15,
	VCPU_REGS_RIP = 16,
	NR_VCPU_REGS = 17,
	VCPU_EXREG_PDPTR = 17,
	VCPU_EXREG_CR0 = 18,
	VCPU_EXREG_CR3 = 19,
	VCPU_EXREG_CR4 = 20,
	VCPU_EXREG_RFLAGS = 21,
	VCPU_EXREG_SEGMENTS = 22,
	VCPU_EXREG_EXIT_INFO_1 = 23,
	VCPU_EXREG_EXIT_INFO_2 = 24,
};

enum exit_fastpath_completion {
	EXIT_FASTPATH_NONE = 0,
	EXIT_FASTPATH_REENTER_GUEST = 1,
	EXIT_FASTPATH_EXIT_HANDLED = 2,
};

struct kvm_rmap_head {
	long unsigned int val;
};

struct kvm_tlb_range {
	u64 start_gfn;
	u64 pages;
};

struct kvm_vcpu_hv_stimer {
	struct hrtimer timer;
	int index;
	union hv_stimer_config config;
	u64 count;
	u64 exp_time;
	struct hv_message msg;
	bool msg_pending;
};

struct kvm_vcpu_hv_synic {
	u64 version;
	u64 control;
	u64 msg_page;
	u64 evt_page;
	atomic64_t sint[16];
	atomic_t sint_to_gsi[16];
	long unsigned int auto_eoi_bitmap[4];
	long unsigned int vec_bitmap[4];
	bool active;
	bool dont_zero_synic_pages;
};

struct kvm_vcpu_hv {
	struct kvm_vcpu *vcpu;
	u32 vp_index;
	u64 hv_vapic;
	s64 runtime_offset;
	struct kvm_vcpu_hv_synic synic;
	struct kvm_hyperv_exit exit;
	struct kvm_vcpu_hv_stimer stimer[4];
	long unsigned int stimer_pending_bitmap[1];
	cpumask_t tlb_flush;
	bool enforce_cpuid;
	struct {
		u32 features_eax;
		u32 features_ebx;
		u32 features_edx;
		u32 enlightenments_eax;
		u32 enlightenments_ebx;
		u32 syndbg_cap_eax;
	} cpuid_cache;
};

struct kvm_lpage_info {
	int disallow_lpage;
};

struct kvm_apic_map {
	struct callback_head rcu;
	u8 mode;
	u32 max_apic_id;
	union {
		struct kvm_lapic *xapic_flat_map[8];
		struct kvm_lapic *xapic_cluster_map[64];
	};
	struct kvm_lapic *phys_map[0];
};

struct msr_bitmap_range {
	u32 flags;
	u32 nmsrs;
	u32 base;
	long unsigned int *bitmap;
};

struct kvm_x86_msr_filter {
	u8 count;
	bool default_allow: 1;
	struct msr_bitmap_range ranges[16];
};

struct msr_data {
	bool host_initiated;
	u32 index;
	u64 data;
};

struct x86_instruction_info;

enum x86_intercept_stage;

struct kvm_pmu_ops;

struct kvm_x86_nested_ops;

struct kvm_x86_ops {
	int (*hardware_enable)();
	void (*hardware_disable)();
	void (*hardware_unsetup)();
	bool (*cpu_has_accelerated_tpr)();
	bool (*has_emulated_msr)(struct kvm *, u32);
	void (*vcpu_after_set_cpuid)(struct kvm_vcpu *);
	unsigned int vm_size;
	int (*vm_init)(struct kvm *);
	void (*vm_destroy)(struct kvm *);
	int (*vcpu_create)(struct kvm_vcpu *);
	void (*vcpu_free)(struct kvm_vcpu *);
	void (*vcpu_reset)(struct kvm_vcpu *, bool);
	void (*prepare_guest_switch)(struct kvm_vcpu *);
	void (*vcpu_load)(struct kvm_vcpu *, int);
	void (*vcpu_put)(struct kvm_vcpu *);
	void (*update_exception_bitmap)(struct kvm_vcpu *);
	int (*get_msr)(struct kvm_vcpu *, struct msr_data *);
	int (*set_msr)(struct kvm_vcpu *, struct msr_data *);
	u64 (*get_segment_base)(struct kvm_vcpu *, int);
	void (*get_segment)(struct kvm_vcpu *, struct kvm_segment *, int);
	int (*get_cpl)(struct kvm_vcpu *);
	void (*set_segment)(struct kvm_vcpu *, struct kvm_segment *, int);
	void (*get_cs_db_l_bits)(struct kvm_vcpu *, int *, int *);
	void (*set_cr0)(struct kvm_vcpu *, long unsigned int);
	bool (*is_valid_cr4)(struct kvm_vcpu *, long unsigned int);
	void (*set_cr4)(struct kvm_vcpu *, long unsigned int);
	int (*set_efer)(struct kvm_vcpu *, u64);
	void (*get_idt)(struct kvm_vcpu *, struct desc_ptr *);
	void (*set_idt)(struct kvm_vcpu *, struct desc_ptr *);
	void (*get_gdt)(struct kvm_vcpu *, struct desc_ptr *);
	void (*set_gdt)(struct kvm_vcpu *, struct desc_ptr *);
	void (*sync_dirty_debug_regs)(struct kvm_vcpu *);
	void (*set_dr7)(struct kvm_vcpu *, long unsigned int);
	void (*cache_reg)(struct kvm_vcpu *, enum kvm_reg);
	long unsigned int (*get_rflags)(struct kvm_vcpu *);
	void (*set_rflags)(struct kvm_vcpu *, long unsigned int);
	bool (*get_if_flag)(struct kvm_vcpu *);
	void (*tlb_flush_all)(struct kvm_vcpu *);
	void (*tlb_flush_current)(struct kvm_vcpu *);
	int (*tlb_remote_flush)(struct kvm *);
	int (*tlb_remote_flush_with_range)(struct kvm *, struct kvm_tlb_range *);
	void (*tlb_flush_gva)(struct kvm_vcpu *, gva_t);
	void (*tlb_flush_guest)(struct kvm_vcpu *);
	enum exit_fastpath_completion (*run)(struct kvm_vcpu *);
	int (*handle_exit)(struct kvm_vcpu *, enum exit_fastpath_completion);
	int (*skip_emulated_instruction)(struct kvm_vcpu *);
	void (*update_emulated_instruction)(struct kvm_vcpu *);
	void (*set_interrupt_shadow)(struct kvm_vcpu *, int);
	u32 (*get_interrupt_shadow)(struct kvm_vcpu *);
	void (*patch_hypercall)(struct kvm_vcpu *, unsigned char *);
	void (*set_irq)(struct kvm_vcpu *);
	void (*set_nmi)(struct kvm_vcpu *);
	void (*queue_exception)(struct kvm_vcpu *);
	void (*cancel_injection)(struct kvm_vcpu *);
	int (*interrupt_allowed)(struct kvm_vcpu *, bool);
	int (*nmi_allowed)(struct kvm_vcpu *, bool);
	bool (*get_nmi_mask)(struct kvm_vcpu *);
	void (*set_nmi_mask)(struct kvm_vcpu *, bool);
	void (*enable_nmi_window)(struct kvm_vcpu *);
	void (*enable_irq_window)(struct kvm_vcpu *);
	void (*update_cr8_intercept)(struct kvm_vcpu *, int, int);
	bool (*check_apicv_inhibit_reasons)(ulong);
	void (*refresh_apicv_exec_ctrl)(struct kvm_vcpu *);
	void (*hwapic_irr_update)(struct kvm_vcpu *, int);
	void (*hwapic_isr_update)(struct kvm_vcpu *, int);
	bool (*guest_apic_has_interrupt)(struct kvm_vcpu *);
	void (*load_eoi_exitmap)(struct kvm_vcpu *, u64 *);
	void (*set_virtual_apic_mode)(struct kvm_vcpu *);
	void (*set_apic_access_page_addr)(struct kvm_vcpu *);
	int (*deliver_posted_interrupt)(struct kvm_vcpu *, int);
	int (*sync_pir_to_irr)(struct kvm_vcpu *);
	int (*set_tss_addr)(struct kvm *, unsigned int);
	int (*set_identity_map_addr)(struct kvm *, u64);
	u64 (*get_mt_mask)(struct kvm_vcpu *, gfn_t, bool);
	void (*load_mmu_pgd)(struct kvm_vcpu *, hpa_t, int);
	bool (*has_wbinvd_exit)();
	u64 (*get_l2_tsc_offset)(struct kvm_vcpu *);
	u64 (*get_l2_tsc_multiplier)(struct kvm_vcpu *);
	void (*write_tsc_offset)(struct kvm_vcpu *, u64);
	void (*write_tsc_multiplier)(struct kvm_vcpu *, u64);
	void (*get_exit_info)(struct kvm_vcpu *, u64 *, u64 *, u32 *, u32 *);
	int (*check_intercept)(struct kvm_vcpu *, struct x86_instruction_info *, enum x86_intercept_stage, struct x86_exception *);
	void (*handle_exit_irqoff)(struct kvm_vcpu *);
	void (*request_immediate_exit)(struct kvm_vcpu *);
	void (*sched_in)(struct kvm_vcpu *, int);
	int cpu_dirty_log_size;
	void (*update_cpu_dirty_logging)(struct kvm_vcpu *);
	const struct kvm_pmu_ops *pmu_ops;
	const struct kvm_x86_nested_ops *nested_ops;
	int (*pre_block)(struct kvm_vcpu *);
	void (*post_block)(struct kvm_vcpu *);
	void (*vcpu_blocking)(struct kvm_vcpu *);
	void (*vcpu_unblocking)(struct kvm_vcpu *);
	int (*update_pi_irte)(struct kvm *, unsigned int, uint32_t, bool);
	void (*start_assignment)(struct kvm *);
	void (*apicv_post_state_restore)(struct kvm_vcpu *);
	bool (*dy_apicv_has_pending_interrupt)(struct kvm_vcpu *);
	int (*set_hv_timer)(struct kvm_vcpu *, u64, bool *);
	void (*cancel_hv_timer)(struct kvm_vcpu *);
	void (*setup_mce)(struct kvm_vcpu *);
	int (*smi_allowed)(struct kvm_vcpu *, bool);
	int (*enter_smm)(struct kvm_vcpu *, char *);
	int (*leave_smm)(struct kvm_vcpu *, const char *);
	void (*enable_smi_window)(struct kvm_vcpu *);
	int (*mem_enc_op)(struct kvm *, void *);
	int (*mem_enc_reg_region)(struct kvm *, struct kvm_enc_region *);
	int (*mem_enc_unreg_region)(struct kvm *, struct kvm_enc_region *);
	int (*vm_copy_enc_context_from)(struct kvm *, unsigned int);
	int (*get_msr_feature)(struct kvm_msr_entry *);
	bool (*can_emulate_instruction)(struct kvm_vcpu *, void *, int);
	bool (*apic_init_signal_blocked)(struct kvm_vcpu *);
	int (*enable_direct_tlbflush)(struct kvm_vcpu *);
	void (*migrate_timers)(struct kvm_vcpu *);
	void (*msr_filter_changed)(struct kvm_vcpu *);
	int (*complete_emulated_msr)(struct kvm_vcpu *, int);
	void (*vcpu_deliver_sipi_vector)(struct kvm_vcpu *, u8);
};

struct kvm_x86_nested_ops {
	void (*leave_nested)(struct kvm_vcpu *);
	int (*check_events)(struct kvm_vcpu *);
	bool (*hv_timer_pending)(struct kvm_vcpu *);
	void (*triple_fault)(struct kvm_vcpu *);
	int (*get_state)(struct kvm_vcpu *, struct kvm_nested_state *, unsigned int);
	int (*set_state)(struct kvm_vcpu *, struct kvm_nested_state *, struct kvm_nested_state *);
	bool (*get_nested_state_pages)(struct kvm_vcpu *);
	int (*write_log_dirty)(struct kvm_vcpu *, gpa_t);
	int (*enable_evmcs)(struct kvm_vcpu *, uint16_t *);
	uint16_t (*get_evmcs_version)(struct kvm_vcpu *);
};

struct kvm_io_device;

struct kvm_io_range {
	gpa_t addr;
	int len;
	struct kvm_io_device *dev;
};

struct kvm_io_bus {
	int dev_count;
	int ioeventfd_count;
	struct kvm_io_range range[0];
};

enum kvm_bus {
	KVM_MMIO_BUS = 0,
	KVM_PIO_BUS = 1,
	KVM_VIRTIO_CCW_NOTIFY_BUS = 2,
	KVM_FAST_MMIO_BUS = 3,
	KVM_NR_BUSES = 4,
};

struct kvm_irq_routing_table {
	int chip[72];
	u32 nr_rt_entries;
	struct hlist_head map[0];
};

struct kvm_memslots {
	u64 generation;
	short int id_to_index[32767];
	atomic_t last_used_slot;
	int used_slots;
	struct kvm_memory_slot memslots[0];
};

enum kvm_stat_kind {
	KVM_STAT_VM = 0,
	KVM_STAT_VCPU = 1,
};

struct _kvm_stats_desc;

struct kvm_stat_data {
	struct kvm *kvm;
	const struct _kvm_stats_desc *desc;
	enum kvm_stat_kind kind;
};

struct _kvm_stats_desc {
	struct kvm_stats_desc desc;
	char name[48];
};

typedef void (*poll_queue_proc___32)(struct file___40 *, wait_queue_head_t *, struct poll_table_struct___21 *);

enum kcmp_type {
	KCMP_FILE = 0,
	KCMP_VM = 1,
	KCMP_FILES = 2,
	KCMP_FS = 3,
	KCMP_SIGHAND = 4,
	KCMP_IO = 5,
	KCMP_SYSVSEM = 6,
	KCMP_EPOLL_TFD = 7,
	KCMP_TYPES = 8,
};

struct kcmp_epoll_slot {
	__u32 efd;
	__u32 tfd;
	__u32 toff;
};

typedef void (*poll_queue_proc___33)(struct file___37 *, wait_queue_head_t *, struct poll_table_struct___2 *);

enum profile_type {
	PROFILE_TASK_EXIT = 0,
	PROFILE_MUNMAP = 1,
};

struct profile_hit {
	u32 pc;
	u32 hits;
};

struct stacktrace_cookie {
	long unsigned int *store;
	unsigned int size;
	unsigned int skip;
	unsigned int len;
};

typedef __kernel_long_t __kernel_suseconds_t;

typedef __kernel_long_t __kernel_old_time_t;

typedef __kernel_suseconds_t suseconds_t;

typedef __u64 timeu64_t;

struct __kernel_itimerspec {
	struct __kernel_timespec it_interval;
	struct __kernel_timespec it_value;
};

struct timezone {
	int tz_minuteswest;
	int tz_dsttime;
};

struct itimerspec64 {
	struct timespec64 it_interval;
	struct timespec64 it_value;
};

struct old_itimerspec32 {
	struct old_timespec32 it_interval;
	struct old_timespec32 it_value;
};

struct old_timex32 {
	u32 modes;
	s32 offset;
	s32 freq;
	s32 maxerror;
	s32 esterror;
	s32 status;
	s32 constant;
	s32 precision;
	s32 tolerance;
	struct old_timeval32 time;
	s32 tick;
	s32 ppsfreq;
	s32 jitter;
	s32 shift;
	s32 stabil;
	s32 jitcnt;
	s32 calcnt;
	s32 errcnt;
	s32 stbcnt;
	s32 tai;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct __kernel_timex_timeval {
	__kernel_time64_t tv_sec;
	long long int tv_usec;
};

struct __kernel_timex {
	unsigned int modes;
	long long int offset;
	long long int freq;
	long long int maxerror;
	long long int esterror;
	int status;
	long long int constant;
	long long int precision;
	long long int tolerance;
	struct __kernel_timex_timeval time;
	long long int tick;
	long long int ppsfreq;
	long long int jitter;
	int shift;
	long long int stabil;
	long long int jitcnt;
	long long int calcnt;
	long long int errcnt;
	long long int stbcnt;
	int tai;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct trace_event_file___14;

struct trace_event_buffer___14 {
	struct trace_buffer *buffer;
	struct ring_buffer_event *event;
	struct trace_event_file___14 *trace_file;
	void *entry;
	unsigned int trace_ctx;
	struct pt_regs *regs;
};

struct trace_event_file___14 {
	struct list_head list;
	struct trace_event_call___22 *event_call;
	struct event_filter *filter;
	struct dentry___34 *dir;
	struct trace_array *tr;
	struct trace_subsystem_dir *system;
	struct list_head triggers;
	long unsigned int flags;
	atomic_t sm_ref;
	atomic_t tm_ref;
};

struct trace_event_raw_timer_class {
	struct trace_entry ent;
	void *timer;
	char __data[0];
};

struct trace_event_raw_timer_start {
	struct trace_entry ent;
	void *timer;
	void *function;
	long unsigned int expires;
	long unsigned int now;
	unsigned int flags;
	char __data[0];
};

struct trace_event_raw_timer_expire_entry {
	struct trace_entry ent;
	void *timer;
	long unsigned int now;
	void *function;
	long unsigned int baseclk;
	char __data[0];
};

struct trace_event_raw_hrtimer_init {
	struct trace_entry ent;
	void *hrtimer;
	clockid_t clockid;
	enum hrtimer_mode mode;
	char __data[0];
};

struct trace_event_raw_hrtimer_start {
	struct trace_entry ent;
	void *hrtimer;
	void *function;
	s64 expires;
	s64 softexpires;
	enum hrtimer_mode mode;
	char __data[0];
};

struct trace_event_raw_hrtimer_expire_entry {
	struct trace_entry ent;
	void *hrtimer;
	s64 now;
	void *function;
	char __data[0];
};

struct trace_event_raw_hrtimer_class {
	struct trace_entry ent;
	void *hrtimer;
	char __data[0];
};

struct trace_event_raw_itimer_state {
	struct trace_entry ent;
	int which;
	long long unsigned int expires;
	long int value_sec;
	long int value_nsec;
	long int interval_sec;
	long int interval_nsec;
	char __data[0];
};

struct trace_event_raw_itimer_expire {
	struct trace_entry ent;
	int which;
	pid_t pid;
	long long unsigned int now;
	char __data[0];
};

struct trace_event_raw_tick_stop {
	struct trace_entry ent;
	int success;
	int dependency;
	char __data[0];
};

struct trace_event_data_offsets_timer_class {};

struct trace_event_data_offsets_timer_start {};

struct trace_event_data_offsets_timer_expire_entry {};

struct trace_event_data_offsets_hrtimer_init {};

struct trace_event_data_offsets_hrtimer_start {};

struct trace_event_data_offsets_hrtimer_expire_entry {};

struct trace_event_data_offsets_hrtimer_class {};

struct trace_event_data_offsets_itimer_state {};

struct trace_event_data_offsets_itimer_expire {};

struct trace_event_data_offsets_tick_stop {};

typedef void (*btf_trace_timer_init)(void *, struct timer_list *);

typedef void (*btf_trace_timer_start)(void *, struct timer_list *, long unsigned int, unsigned int);

typedef void (*btf_trace_timer_expire_entry)(void *, struct timer_list *, long unsigned int);

typedef void (*btf_trace_timer_expire_exit)(void *, struct timer_list *);

typedef void (*btf_trace_timer_cancel)(void *, struct timer_list *);

typedef void (*btf_trace_hrtimer_init)(void *, struct hrtimer *, clockid_t, enum hrtimer_mode);

typedef void (*btf_trace_hrtimer_start)(void *, struct hrtimer *, enum hrtimer_mode);

typedef void (*btf_trace_hrtimer_expire_entry)(void *, struct hrtimer *, ktime_t *);

typedef void (*btf_trace_hrtimer_expire_exit)(void *, struct hrtimer *);

typedef void (*btf_trace_hrtimer_cancel)(void *, struct hrtimer *);

typedef void (*btf_trace_itimer_state)(void *, int, const struct itimerspec64 * const, long long unsigned int);

typedef void (*btf_trace_itimer_expire)(void *, int, struct pid___29 *, long long unsigned int);

typedef void (*btf_trace_tick_stop)(void *, int, int);

struct timer_base {
	raw_spinlock_t lock;
	struct timer_list *running_timer;
	long unsigned int clk;
	long unsigned int next_expiry;
	unsigned int cpu;
	bool next_expiry_recalc;
	bool is_idle;
	bool timers_pending;
	long unsigned int pending_map[9];
	struct hlist_head vectors[576];
	long: 64;
	long: 64;
};

struct process_timer {
	struct timer_list timer;
	struct task_struct___38 *task;
};

struct hrtimer_sleeper___2 {
	struct hrtimer timer;
	struct task_struct___41 *task;
};

enum tick_device_mode {
	TICKDEV_MODE_PERIODIC = 0,
	TICKDEV_MODE_ONESHOT = 1,
};

struct tick_device {
	struct clock_event_device *evtdev;
	enum tick_device_mode mode;
};

struct ktime_timestamps {
	u64 mono;
	u64 boot;
	u64 real;
};

struct system_time_snapshot {
	u64 cycles;
	ktime_t real;
	ktime_t raw;
	enum clocksource_ids cs_id;
	unsigned int clock_was_set_seq;
	u8 cs_was_changed_seq;
};

struct system_device_crosststamp {
	ktime_t device;
	ktime_t sys_realtime;
	ktime_t sys_monoraw;
};

struct audit_ntp_val {
	long long int oldval;
	long long int newval;
};

struct audit_ntp_data {
	struct audit_ntp_val vals[6];
};

enum timekeeping_adv_mode {
	TK_ADV_TICK = 0,
	TK_ADV_FREQ = 1,
};

struct tk_fast {
	seqcount_latch_t seq;
	struct tk_read_base base[2];
};

struct rtc_wkalrm {
	unsigned char enabled;
	unsigned char pending;
	struct rtc_time time;
};

struct rtc_class_ops {
	int (*ioctl)(struct device___7 *, unsigned int, long unsigned int);
	int (*read_time)(struct device___7 *, struct rtc_time *);
	int (*set_time)(struct device___7 *, struct rtc_time *);
	int (*read_alarm)(struct device___7 *, struct rtc_wkalrm *);
	int (*set_alarm)(struct device___7 *, struct rtc_wkalrm *);
	int (*proc)(struct device___7 *, struct seq_file___27 *);
	int (*alarm_irq_enable)(struct device___7 *, unsigned int);
	int (*read_offset)(struct device___7 *, long int *);
	int (*set_offset)(struct device___7 *, long int);
};

struct rtc_device;

struct rtc_timer {
	struct timerqueue_node node;
	ktime_t period;
	void (*func)(struct rtc_device *);
	struct rtc_device *rtc;
	int enabled;
};

struct rtc_device {
	struct device___7 dev;
	struct module___28 *owner;
	int id;
	const struct rtc_class_ops *ops;
	struct mutex ops_lock;
	struct cdev___14 char_dev;
	long unsigned int flags;
	long unsigned int irq_data;
	spinlock_t irq_lock;
	wait_queue_head_t irq_queue;
	struct fasync_struct___29 *async_queue;
	int irq_freq;
	int max_user_freq;
	struct timerqueue_head timerqueue;
	struct rtc_timer aie_timer;
	struct rtc_timer uie_rtctimer;
	struct hrtimer pie_timer;
	int pie_enabled;
	struct work_struct irqwork;
	int uie_unsupported;
	long unsigned int set_offset_nsec;
	long unsigned int features[1];
	time64_t range_min;
	timeu64_t range_max;
	time64_t start_secs;
	time64_t offset_secs;
	bool set_start_time;
};

#ifndef BPF_NO_PRESERVE_ACCESS_INDEX
#pragma clang attribute pop
#endif

#endif /* __VMLINUX_H__ */
